(************** Content-type: application/mathematica **************
                       CreatedBy='Publicon 1.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    137001,       3137]*)
(*NotebookOutlinePosition[    465314,      15100]*)
(*  CellTagsIndexPosition[    465236,      15094]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Style Sheet and Palette Adjustments for Elsevier Format", "Section"],

Cell["\<\
The following changes are made to the APS_PhysRev style sheet and palette in \
order to convert them for use as the Elsevier article submission format. The \
primary differences are in the structure of frontmatter and formatting of \
references. Cosmetic changes to the section headings are borrowed from \
LaTeX_Article, and some extra styles are pulled in from the PubliconDefault \
style sheet.\
\>", "Text"],

Cell[TextData[{
  "We\[CloseCurlyQuote]ll begin with editing the style sheet. The changes are \
determined by studying sample documents in target ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"L", 
            StyleBox[
              AdjustmentBox["A",
                BoxMargins->{{-0.5, -0.3}, {0, 0}},
                BoxBaselineShift->-0.4],
              FontSize->Smaller], "T", 
            AdjustmentBox["E",
              BoxMargins->{{-0.3, 0}, {0, 0}},
              BoxBaselineShift->0.5], "X"}],
          SingleLetterItalics->False], TraditionalForm]]],
  " format and comparing to available ",
  StyleBox["Publicon",
    FontSlant->"Italic"],
  " supported formats. There are some ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"L", 
            StyleBox[
              AdjustmentBox["A",
                BoxMargins->{{-0.5, -0.3}, {0, 0}},
                BoxBaselineShift->-0.4],
              FontSize->Smaller], "T", 
            AdjustmentBox["E",
              BoxMargins->{{-0.3, 0}, {0, 0}},
              BoxBaselineShift->0.5], "X"}],
          SingleLetterItalics->False], TraditionalForm]]],
  " styles like IEEE and AGU that are very similar to ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"L", 
            StyleBox[
              AdjustmentBox["A",
                BoxMargins->{{-0.5, -0.3}, {0, 0}},
                BoxBaselineShift->-0.4],
              FontSize->Smaller], "T", 
            AdjustmentBox["E",
              BoxMargins->{{-0.3, 0}, {0, 0}},
              BoxBaselineShift->0.5], "X"}],
          SingleLetterItalics->False], TraditionalForm]]],
  " Article but which \[OpenCurlyDoubleQuote]overload\[CloseCurlyDoubleQuote] \
the author macro with a lot of customization which ",
  StyleBox["Publicon",
    FontSlant->"Italic"],
  " is not yet able to support directly, but which will be supported with \
future updates."
}], "Text"],

Cell["\<\
We\[CloseCurlyQuote]ll do the document palette last, since it\
\[CloseCurlyQuote]s handy to have the style sheet available for it. The new \
document template will be configured as the last step, exploiting a new \
utility that will become available shortly.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Custom Format Production Steps: ", "Subsubsection"],

Cell[CellGroupData[{

Cell["Style sheet adjustments", "Item1Numbered",
  ShowGroupOpenCloseIcon->False],

Cell["Document palette adjustments", "Item1Numbered"],

Cell["Palette draft", "Item1Numbered"],

Cell["New document template changes", "Item1Numbered"],

Cell["Final palette, module assembly, and installation", "Item1Numbered"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Collect Source Copies", "Subsection"],

Cell[TextData[{
  "The various formats supported by ",
  StyleBox["Publicon",
    FontSlant->"Italic"],
  " are installed into the Autoload directory as packages, which we call \
custom modules. They mostly consist of the style sheets and palettes in a \
standard package layout, but they also include source files for the document \
palette as well as a sample document."
}], "Text"],

Cell[TextData[{
  "To begin this particular exercise, we want copies of the ",
  StyleBox["APS_PhysRev",
    FontWeight->"Bold"],
  " style sheet and palette source file, as well as the ",
  StyleBox["LaTeX_Article",
    FontWeight->"Bold"],
  " style sheet. Work with them on the desktop. Then let\[CloseCurlyQuote]s \
begin by editing the style sheet."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Style Sheet Internal Name", "Subsection"],

Cell[TextData[{
  "Change title of the APS style sheet to use the name of the new style \
sheet, and resave it on the desktop as ",
  StyleBox["Elsevier.nb",
    FontWeight->"Bold"],
  ": "
}], "Text"]
}, Open  ]],

Cell["Elsevier.nb Style Definitions", "Title"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["TeX Configuration cell", "Subsection"],

Cell[TextData[{
  "Change first two lines as follows. Note that this is like a few other \
non-StyleData cells in ",
  StyleBox["Publicon",
    FontSlant->"Italic"],
  " style sheets. They simply inform various behaviors for which we have no \
other convenient method for storing and modifying, short of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programming."
}], "Text"],

Cell["\<\
\\documentclass{elsart}

\\usepackage{graphicx,amsmath,amscd,amssymb,verbatim,natbib}\
\>", "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["FrontmatterGroup", "Subsection"],

Cell["\<\
Elsevier sets up a frontmatter environment, which we begin using the \
frontmatter grouping label. The environment gets closed with the mainmatter \
grouping label.\
\>", "Text"],

Cell["\<\
ConversionRules:>{\"TeX\" -> {\"\\n\\\\begin{frontmatter}\",  NoOutput[ ], \"\
\"}, \"HTML\" -> {\"\", NoOutput[ ], \"\"}}\
\>", "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Author Form Customization", "Subsection"],

Cell[TextData[{
  "Field correlations allow you to customize the author form dialog box, \
adding fields which accomodate special ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"L", 
            StyleBox[
              AdjustmentBox["A",
                BoxMargins->{{-0.5, -0.3}, {0, 0}},
                BoxBaselineShift->-0.4],
              FontSize->Smaller], "T", 
            AdjustmentBox["E",
              BoxMargins->{{-0.3, 0}, {0, 0}},
              BoxBaselineShift->0.5], "X"}],
          SingleLetterItalics->False], TraditionalForm]]],
  "-specific data formats. These are maintained in the author group cell\
\[CloseCurlyQuote]s tagging rules."
}], "Text"],

Cell["\<\
Field Correlations:

AUTHORNAME -> \\author{}
Email -> \\ead{}
Homepage -> \\ead[url]{}
Institution -> \\address{}\
\>", "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Abstract", "Subsection"],

Cell[TextData[{
  "Tagging rules in the style definitions allow us to provide additional \
instructions to the ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"L", 
            StyleBox[
              AdjustmentBox["A",
                BoxMargins->{{-0.5, -0.3}, {0, 0}},
                BoxBaselineShift->-0.4],
              FontSize->Smaller], "T", 
            AdjustmentBox["E",
              BoxMargins->{{-0.3, 0}, {0, 0}},
              BoxBaselineShift->0.5], "X"}],
          SingleLetterItalics->False], TraditionalForm]]],
  " conversion process. Here the nesting level indicates cell grouping at the \
lowest level (similar to CellGroupingRules), and the cell group corresponds \
to the ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"L", 
            StyleBox[
              AdjustmentBox["A",
                BoxMargins->{{-0.5, -0.3}, {0, 0}},
                BoxBaselineShift->-0.4],
              FontSize->Smaller], "T", 
            AdjustmentBox["E",
              BoxMargins->{{-0.3, 0}, {0, 0}},
              BoxBaselineShift->0.5], "X"}],
          SingleLetterItalics->False], TraditionalForm]]],
  " \[OpenCurlyDoubleQuote]abstract\[CloseCurlyDoubleQuote] environment. \
Multiple abstract paragraphs are self-grouping cells controlled by the \
\[OpenCurlyDoubleQuote]GraphicsGrouping\[CloseCurlyDoubleQuote] setting, \
which is currently the only self-grouping rule available."
}], "Text"],

Cell["\<\
CellGroupingRules->\"GraphicsGrouping\",
ConversionRules:>{\"TeX\" -> {{\"\", Automatic, \"\"}, {\"\\n\\n\", \
Automatic, \"\"}}},
TaggingRules:>{\"ExtraConversionRules\" -> {\"General\" -> {\"NestingLevel\" \
-> 90}, \"TeX\" -> {\"CellGroupEnvironment\" -> \"abstract\"}}},\
\>", "Program"],

Cell["\<\
For cosmetic improvement, apply cell margins of 50 left and right.\
\>", "Text"],

Cell["CellMargins->{{50,50},{4,4}}", "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["AbstractSection", "Subsection"],

Cell[TextData[{
  "An example of this style is available in Article2, but let\
\[CloseCurlyQuote]s just insert this entire cell expression into a copy of \
the ",
  "\[OpenCurlyDoubleQuote]Abstract\[CloseCurlyDoubleQuote]",
  " style prototype for expediency. This section head could just as well be \
based on any other section style, but pretty much every formatting detail \
would have to be changed anyway. The main thing to notice here is the \
\[OpenCurlyDoubleQuote]NoOutput[]\[CloseCurlyDoubleQuote] conversion rule. \
This heading is merely cosmetic, to emulate the ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"L", 
            StyleBox[
              AdjustmentBox["A",
                BoxMargins->{{-0.5, -0.3}, {0, 0}},
                BoxBaselineShift->-0.4],
              FontSize->Smaller], "T", 
            AdjustmentBox["E",
              BoxMargins->{{-0.3, 0}, {0, 0}},
              BoxBaselineShift->0.5], "X"}],
          SingleLetterItalics->False], TraditionalForm]]],
  " format, but the heading itself is rendered via the \
\[OpenCurlyDoubleQuote]abstract\[CloseCurlyDoubleQuote] macro itself."
}], "Text"],

Cell["\<\
Cell[StyleData[\"AbstractSection\"],
  CellMargins->{{50, 50}, {4, 18}},
  CellGroupingRules->\"GraphicsGrouping\",
  CellFrame->{{0, 0},{0,1}},
  ConversionRules:>{\"TeX\" -> {{\"\", NoOutput[], \"\"}, {
    \"\", NoOutput[], \"\"}}},
  StyleMenuListing->None,
  FontFamily->\"Times\",
  FontSize->14,
  FontWeight->\"Bold\"]\
\>", "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Keywords", "Subsection"],

Cell[TextData[{
  "You can copy these settings from the Default style sheet. A more natural \
location for the \[OpenCurlyDoubleQuote]Keywords\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]PACS\[CloseCurlyDoubleQuote] styles is right after \
\[OpenCurlyDoubleQuote]Abstract\[CloseCurlyDoubleQuote] rather than in the \
Author style group, so lets move them. Note the conversion rule which changes \
commas to the expected macro. Rules like these will also become simpler in \
the next update, so as not to require the argument structure which is pretty \
obscure to someone unfamiliar with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell["\<\
CellGroupingRules->\"GraphicsGrouping\",
ConversionRules:>{\"TeX\" -> {\"\\n\", 
ReplaceCharacter[ \",\" -> \" \\sep \"][ ExtractElement[1,1,1 ][ #]]&, \
\"\"}},
TaggingRules:>{\"ExtraConversionRules\" -> {\"General\" -> {\"NestingLevel\" \
-> 90}, \"TeX\" -> {\"CellGroupEnvironment\" -> \"keyword\"}}},
CellFrameLabels->{{Cell[\"Key words:\"], Inherited}, {Inherited, Inherited}},
CellMargins->{{50, 50}, {0, 12}},\
\>", "Program"],

Cell["\<\
Also apply the same margin adjustments as for \[OpenCurlyDoubleQuote]Abstract\
\[CloseCurlyDoubleQuote], along with bottom/top of 0,12.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["PACS", "Subsection"],

Cell[TextData[{
  "This style is misnamed \[OpenCurlyDoubleQuote]AuthorPACS\
\[CloseCurlyDoubleQuote] in current style sheets and will be updated to \
simply \[OpenCurlyDoubleQuote]PACS\[CloseCurlyDoubleQuote]. Will be updated \
for v1.0.1. Let\[CloseCurlyQuote]s take care of that now. Note the conversion \
rule which changes commas to the expected macro. Rules like these will also \
become simpler in the next update, so as not to require the argument \
structure which is pretty obscure to someone unfamiliar with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell["\<\
CellGroupingRules->\"GraphicsGrouping\",
ConversionRules:>{\"TeX\" -> {\"\\n\\n\\\\PACS \", ReplaceCharacter[ \",\" -> \
\" \\sep \"][ ExtractElement[1,1,1 ][ #]]&, \"\"}},
TaggingRules:>{\"ExtraConversionRules\" -> {\"General\" -> {\"NestingLevel\" \
-> 90}, \"TeX\" -> {\"CellGroupEnvironment\" -> \"keyword\"}}},\
\[LineSeparator]CellMargins->{{50, 50}, {12, 0}},\
\>", "Program"],

Cell["\<\
Also apply the same margin adjustments as for \[OpenCurlyDoubleQuote]Abstract\
\[CloseCurlyDoubleQuote], along with bottom/top of 12,0.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["SingleLine", "Subsection"],

Cell[TextData[{
  "This style resides down in the Miscellaneous section. This is another \
cosmetic adjustment, and something of a hack to get around the fact that \
lines are drawn on cells via the ",
  StyleBox["CellFrame", "MR"],
  " option, but do not extend past cell frame labels. This is expected to be \
remedied in M6. In the meantime we\[CloseCurlyQuote]ll add a blank cell which \
renders the line which should appear at the end of the abstract. An \
alternative method would be to use inline cell labels, which we\
\[CloseCurlyQuote]ll look at in the cell templates stored in the APS palette \
buttons. It offers a somewhat purer approach, but also requires more work to \
configure, and is something to consider at another time."
}], "Text"],

Cell["\<\
CellFrame->{{0, 0}, {0, 1}},
CellMargins->{{50, 50}, {0, 0}},
CellBracketOptions->{\"Color\"->RGBColor[0.9, 0.9, 1]},
CellElementSpacings->{\"CellMinHeight\"->2},\
\>", "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["MainmatterGroup", "Subsection"],

Cell[TextData[{
  "Close off the ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"L", 
            StyleBox[
              AdjustmentBox["A",
                BoxMargins->{{-0.5, -0.3}, {0, 0}},
                BoxBaselineShift->-0.4],
              FontSize->Smaller], "T", 
            AdjustmentBox["E",
              BoxMargins->{{-0.3, 0}, {0, 0}},
              BoxBaselineShift->0.5], "X"}],
          SingleLetterItalics->False], TraditionalForm]]],
  " frontmatter environment, but otherwise ignore the cell contents on \
export."
}], "Text"],

Cell["\<\
ConversionRules:>{\"TeX\" -> {\"\\n\\n\\\\end{frontmatter}\", NoOutput[ ], \"\
\"}, \"HTML\" -> {\"\", NoOutput[ ], \"\"}},\
\>", "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Section and Appendix Heads", "Subsection"],

Cell["Copy from LaTeX_Article.", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Reference", "Subsection"],

Cell["\<\
Note the conversion rule, which is a new function being made available with \
the forthcoming XtraUtilities package.\
\>", "Text"],

Cell["\<\
ConversionRules:>{\"TeX\" -> {\"\\n\\n\", ConvertAsNatbib[ ], \"\"}, 
\"HTML\" -> {\"<table class=\\\"Reference\\\"><tr valign=\\\"top\\\">\", \
Automatic, \"</td></tr></table>\"}},\
\>", "Program"],

Cell["\<\
\[LineSeparator]Aesthetic tweak, which will be controlled via environments in \
the future:\
\>", "Text"],

Cell["ParagraphIndent->-8, ", "Program"],

Cell["\<\
(*  -12 for presentation, -5 for printout  *)\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["RefReturnPointer", "Subsection"],

Cell["Copy this style from Default and add this option:", "Text"],

Cell["\<\
ConversionRules:>{{\"TeX\" -> {\"\", NoOutput[ ], \"\"}}, {\"HTML\" -> \
{\"<table class=\\\"Reference\\\"><tr valign=\\\"top\\\">\", \
\"</td></tr></table>\"}}},\
\>", "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Reference Templates", "Subsection"],

Cell["\<\
Copy entire reference template group from Default, then change sorting \
template to:\
\>", "Text"],

Cell["Sorting:Author", "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Save Style Sheet in StyleSheetPath", "Subsection"],

Cell[TextData[{
  "With your style sheet edits completed, save the style sheet into one of \
the style sheet path directories (such as Configuration), just temporarily in \
order to complete the document template. This step is required for making the \
AuthorName template easy to configure, but it\[CloseCurlyQuote]s still a \
minor nuisance to have to restart ",
  StyleBox["Publicon",
    FontSlant->"Italic"],
  " in order to refresh the style sheet listings. This process will be \
streamlined in future updates."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Document Palette Adjustments for Elsevier Format", "Section"],

Cell[TextData[{
  "The document palette is derived from a source notebook, with a button that \
automatically generates the palette as well as a properly populated module \
(package) layout based on the name provided. We\[CloseCurlyQuote]ll edit a \
copy of the ",
  StyleBox["APS palette source file",
    FontWeight->"Bold"],
  " and reference the ",
  StyleBox["LaTeX_Article",
    FontWeight->"Bold"],
  " source file, then generate a draft to simplify creation of the template."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["\<\
Rename Palette\[CloseCurlyQuote]s Embedded Style Sheet\
\>", "Subsection"],

Cell[TextData[{
  "The target document style sheet and palette style sheet must share the \
same name, so that ",
  StyleBox["CheckDocStyleMatch", "MR"],
  " will not reject document edits via the palette. Change the style sheet \
title for the palette the same as was done for the document style sheet."
}], "Text"]
}, Open  ]],

Cell["\<\
Elsevier.nb Document Palette Styles\
\>", "Title"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Adjust Frontmatter", "Subsection"],

Cell["\<\
Remove \[OpenCurlyDoubleQuote]Date\[CloseCurlyDoubleQuote] button and add \
\[OpenCurlyDoubleQuote]Keywords\[CloseCurlyDoubleQuote] button before \
\[OpenCurlyDoubleQuote]PACS\[CloseCurlyDoubleQuote]. Buttons are stacked as \
single column grid boxes, so simply add new rows to accomodate changes and \
reordering. Multiple clicks on buttons will expand the selection to the \
appropriate limits for copying and deleting buttons. Buttons can also be \
edited through the Edit Button dialog, which is probably what novices should \
use, but editing cell expressions is more convenient for those experienced \
with notebook syntax.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Adjust Section and Appendix Buttons", "Subsection"],

Cell[TextData[{
  "Copy section head and appendix head buttons from LaTeX_Article, but \
eliminate \[OpenCurlyDoubleQuote]Subsubsubsection\[CloseCurlyDoubleQuote], as \
Elsevier does not support it. It\[CloseCurlyQuote]s a good idea to turn on \
cell tags to make sure you maintain the same tags when editing. Compare the \
differences between the APS and the LaTeX_Article buttons: the former uses \
inline cells (called \[OpenCurlyDoubleQuote]labels\[CloseCurlyDoubleQuote]) \
to provide inline numbering elements that allow centered formatting, instead \
of displaying the numbers via the cell frame labels in the style definitions. \
Most buttons on a document palette rely on the ",
  StyleBox["CellWriteStyle", "MR"],
  " function, which manages the button behavior based on various arguments to \
",
  StyleBox["ButtonData", "MR"],
  "."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Remove Wide Equations", "Subsection"],

Cell["\<\
These are not required for Elsevier\[CloseCurlyQuote]s article submission \
format.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Generate Draft Palette", "Subsection"],

Cell["\<\
We call it \[OpenCurlyDoubleQuote]Draft\[CloseCurlyDoubleQuote] not only \
becuase it isn\[CloseCurlyQuote]t final but also because we want to reserve \
the real name for the final version, since the process of generating a \
palette also creates the module layout itself. It gets confusing to have \
duplicates. In future updates we hope to simplify this stage a little more.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Modify Document Template", "Subsection"],

Cell[TextData[{
  "Here we create a new document with the new palette (",
  StyleBox["save it",
    FontWeight->"Bold"],
  " immediately to the desktop), but we note that it is still in the APS \
format, because we did not change the \[OpenCurlyDoubleQuote]New Document\
\[CloseCurlyDoubleQuote] button. Now change the style sheet to Elsevier (",
  StyleBox["save it",
    FontWeight->"Bold"],
  " again), and make the following adjustments:"
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Delete Author cell and insert new one using palette, create last name of \
\[OpenCurlyDoubleQuote]AuthorName\[CloseCurlyDoubleQuote] as new place \
holder.\
\>", "Item1Numbered",
  ShowGroupOpenCloseIcon->False,
  CounterAssignments->{{"Item1Numbered", 0}}],

Cell[TextData[{
  "By inspecting the cell expression you can see all the tricky ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"T", 
            AdjustmentBox["E",
              BoxMargins->{{-0.3, 0}, {0, 0}},
              BoxBaselineShift->0.5], "X"}],
          SingleLetterItalics->False], TraditionalForm]]],
  "-specific tagging rules that were picked up from the style sheet and which \
create the extra fields in the author form. To inspect the cell expression, \
copy cell expression and paste in text editor or apply \
\[OpenCurlyDoubleQuote]AllowShowExpression\[CloseCurlyDoubleQuote]->True \
tagging rule via preferences."
}], "Item1Paragraph"],

Cell[TextData[{
  "Add \[OpenCurlyDoubleQuote]AbstractSection\[CloseCurlyDoubleQuote] cell, \
use ",
  StyleBox["Format > Style > Other", "SR"],
  " to apply style."
}], "Item1Numbered"],

Cell["Delete \[OpenCurlyDoubleQuote]Date\[CloseCurlyDoubleQuote] cell.", \
"Item1Numbered"],

Cell["\<\
Add \[OpenCurlyDoubleQuote]Keywords\[CloseCurlyDoubleQuote] before \
\[OpenCurlyDoubleQuote]PACS\[CloseCurlyDoubleQuote] cell.\
\>", "Item1Numbered"],

Cell[TextData[{
  "Add \[OpenCurlyDoubleQuote]SingleLine\[CloseCurlyDoubleQuote] cell, simply \
insert space in new cell and use ",
  StyleBox["Format \[RightTriangle] Style ", "SR"],
  StyleBox["\[RightTriangle]", "SR"],
  StyleBox[" Other", "SR"],
  " to apply style."
}], "Item1Numbered"],

Cell["\<\
Replace \[OpenCurlyDoubleQuote]Section\[CloseCurlyDoubleQuote] cell with new \
template.\
\>", "Item1Numbered"],

Cell["\<\
Replace \[OpenCurlyDoubleQuote]Appendix\[CloseCurlyDoubleQuote] cell with new \
template.\
\>", "Item1Numbered"],

Cell["\<\
Collect the new template cells using the \[OpenCurlyDoubleQuote]New Document\
\[CloseCurlyDoubleQuote] utility button.\
\>", "Item1Numbered"],

Cell["\<\
Replace \[OpenCurlyDoubleQuote]New Document\[CloseCurlyDoubleQuote] button in \
document palette source file with new one.\
\>", "Item1Numbered"],

Cell["Generate final palette.", "Item1Numbered"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Adjust Sample Document Button", "Subsection"],

Cell["\<\
Update the sample document button with the new module name and sample \
document name. The actual file can be provided later. It resides in the top \
level of the module.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"LastSlide"],

Cell[CellGroupData[{

Cell["Assemble New Module and Install", "Subsection"],

Cell["\<\
Move the style sheet to its proper location in the new module. Here\
\[CloseCurlyQuote]s a diagram of a module (add-on application) layout:\
\>", "Text"],

Cell[BoxData[Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005o00018b000`400?l0
0000o`00003oo`3ooon00?ooo`00o`3ooon00?ooo`002@3oool00`3moOd0
l_;b0>k^kP3o0>k^kW80k^k^0@3`l?010?_kn`00203oool00`3Vi^H0hN7Q
0=GEe@3o0=;BdW80d];B0@3GemL10>k^kP40no_k00070?ooo`040?Gem@34
a<@0^k^k0;>c/ol0/K6aL@2a/K400`2h^;P0d];B0>k^kP010?_kn`001P3o
ool0103]kNd0];Bd096AT@2=SHgo08N7Qg40QhN700@0Shn?0;6a/@3Bd]80
k^k^0@3kno/000D0ooooo`00001f0000000408J6QP2a/K40d];B0>k^kP40
no_k00050?ooo`030000003oool0oooo0?l0ooooL@3oool01P3no_h00000
08J6QP2a/K40d];B0>k^kP40no_k00050?ooo`030000003oool0oooo0?l0
ooooLP3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`03
0000003oool0oooo0?l0ooooLP3oool01@000000QXJ60;6a/@3Bd]80k^k^
0040no_k00050?ooo`030000003oool0oooo0?l0ooooLP3oool01@000000
QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo0?l0
ooooLP3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`03
0000003oool0oooo0?l0ooooLP3oool01@000000QXJ60;6a/@3Bd]80k^k^
0040no_k00050?ooo`030000003oool0oooo0?l0ooooLP3oool01@000000
QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo0?l0
ooooLP3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`03
0000003oool0oooo0?l0ooooLP3oool01@000000QXJ60;6a/@3Bd]80k^k^
0040no_k00050?ooo`030000003oool0oooo0?l0ooooLP3oool01@000000
QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo0?l0
ooooLP3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`03
0000003oool0oooo0?l0ooooLP3oool01@000000QXJ60;6a/@3Bd]80k^k^
0040no_k00050?ooo`030000003oool0oooo0?l0ooooLP3oool01@000000
QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo0?l0
ooooLP3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`03
0000003oool0oooo0?l0ooooLP3oool01@000000QXJ60;6a/@3Bd]80k^k^
0040no_k00050?ooo`030000003oool0oooo00d0ooooZ`00002i0?ooo`05
00000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0;L0
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2W0?ooo`03
0000003oool0oooo0;L0oooo00D0000008J6QP2a/K40d];B0>k^kP010?_k
n`001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0
oooo00<000000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^
0040no_k00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2W0?ooo`030000003oool0oooo0;L0oooo00D0000008J6QP2a
/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0:L0oooo00<000000?ooo`3oool0]`3oool01@000000
QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2g0?ooo`05
00000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0;L0
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2W0?ooo`03
0000003oool0oooo0;L0oooo00D0000008J6QP2a/K40d];B0>k^kP010?_k
n`001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0
oooo00<000000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^
0040no_k00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?oooh`000003`3oool00`000000oooo0?ooo`2g0?ooo`05
00000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2g0?ooo`05
00000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2g0?ooo`05
00000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2g0?ooo`05
00000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2g0?ooo`05
00000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2g0?ooo`05
00000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2g0?ooo`05
00000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2g0?ooo`05
00000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2g0?ooo`05
00000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01L0
oooo00<0RXZ:0;^k^`3oool0KP3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0;L0oooo00D0000008J6QP2a/K40d];B0>k^kP010?_k
n`001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool05P3oool0103Ogml0RXZ:014A4@3Ogmm^0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0]`3oool01@00
0000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0H0?oo
o`0308Z:RP1VIVH0oooo06d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/0
00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00d0oooo00P000000?ooo`3oool08B4Q06IVIP3o
ool0^k^k04E5A@<0oooo00H0VYZJ014A4@3oool0oooo09ZJVP1EEED50?oo
o`04014A4@3Ogml0RXZ:08Z:RP<0oooo00`0EEEE0000003Ogml0ADE50;^k
^`3oool0kno_06IVIP0000004A4A08Z:RP3oool208Z:RP030?ooo`3_knl0
IVIV0080000000<0MWIf0>o_k`3oool00P2:RXX00`3oool0^k^k04E5A@03
0?ooo`030000003oool0^k^k0080ADE500<0000004E5A@3?cll0>03oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo00D00000
08J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool0
20000000oooo0<o?c`0Q8B404A4A0?ooo`2k^k/0ADE50`3oool00`0a<C40
4A4A0;^k^`020?ooo`03014A4@3_knl0oooo0080oooo00<0ZZZZ05EEE@3o
ool00P2:RXX30?ooo`060000003_knl0oooo04E5A@2k^k/0oooo0P1VIVH0
103_knl0gmoO024Q8@2k^k/208Z:RP030?ooo`1VIVH0IVIV0080kno_00<0
EEEE08Z:RP3oool00`3oool00`2k^k/0ADE50?ooo`020?ooo`080000003o
ool0^k^k0000002JVYX0oooo08Z:RP0a<C4h0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80
k^k^0040no_k00050?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0=0?ooo`050000003oool0RXZ:
07IfMP0a<C400P2k^k/01`15ADD0oooo0?ooo`3Ogml04A4A08Z:RP1fMWH0
0P3oool207IfMP<0^k^k00<0ADE50:ZZZP3oool00P2:RXX30?ooo`080000
003oool0oooo04E5A@2k^k/0oooo014A4@3_knl20?ooo`070;^k^`3Ogml0
RXZ:08Z:RP3oool04A4A0>o_k`020?ooo`80kno_103oool00`2k^k/0ADE5
0?ooo`020?ooo`040000003oool0^k^k034a<@<0oooo00<0<C4a0<o?c`3o
ool0=P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool010000000oooo034a<@2ZZZX207IfMP080;^k^`15ADD0oooo
0?ooo`2:RXX0IVIV0<o?c`0Q8B420?ooo`060=oOg`000000ADE504E5A@0a
<C408B4Q0P3oool208Z:RP<0oooo00L000000?ooo`3oool0ADE50;^k^`3o
ool0000000D0oooo0P2:RXX00`3oool00000000000030000000304E5A@3o
ool0oooo0080oooo00<0^k^k04E5A@3oool00P3oool010000000oooo0;^k
^`15ADD30?ooo`0304E5A@2k^k/0oooo03H0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^
k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00P000000>o_k`0A4A40
oooo0<o?c`0a<C40^k^k04E5A@80oooo00D0<C4a0:ZZZP3oool08B4Q0<o?
c`020?ooo`0504E5A@3Ogml0oooo09ZJVP2:RXX00P3oool00`2:RXX0IVIV
0?ooo`020?ooo`080000003oool0oooo04E5A@2k^k/0oooo024Q8@3Ogml2
0?ooo`0709ZJVP3_knl0RXZ:08Z:RP3oool08B4Q0=oOg`020?ooo`0309ZJ
VP1VIVH0oooo00<0oooo00<0^k^k024Q8@3oool00P3oool010000000oooo
0;^k^`0Q8B430?ooo`03024Q8@3Ogml0oooo03H0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0000009ZJVP1E
EED00P3oool01P0A4A40VYZJ04E5A@3oool0gmoO024Q8@80oooo00T0MWIf
08Z:RP3oool0oooo09ZJVP1fMWH0oooo034a<@3Ogml00P3oool04@2:RXX0
4A4A0:ZZZP2ZZZX0VYZJ0000002:RXX0oooo04E5A@2k^k/0oooo08Z:RP0a
<C40ZZZZ08Z:RP0A4A40kno_0080RXZ:00L0oooo08Z:RP0a<C40ZZZZ09ZJ
VP0A4A40^k^k00@0oooo00d0^k^k014A4@1VIVH0^k^k06IVIP0a<C40oooo
0;^k^`000000EEEE0;^k^`1VIVH0ADE503P0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^
k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0000006IVIP2JVYX0
0P3oool206IVIP0404E5A@3oool0clo?0:ZZZP80oooo00<0gmoO09ZJVP3o
ool00P3oool00`0a<C40gmoO05EEE@030?ooo`0:0;^k^`2ZZZX0EEEE06IV
IP2JVYX0000008Z:RP3oool0VYZJ0=oOg`80oooo00D0RXZ:04E5A@1EEED0
clo?0?ooo`0208Z:RP80oooo00@0VYZJ04E5A@1EEED0^k^k1@3oool03@3O
gml0VYZJ0:ZZZP15ADD0EEEE0<o?c`3oool0^k^k04E5A@2:RXX0ADE507If
MP3_knl0>03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0;L0oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`0000004A4A0>o_k`020?ooo`030:ZZZP0A4A40ADE5
00X0oooo00<0MWIf034a<@2ZZZX0203oool01@000000oooo0?ooo`3?cll0
kno_00L0oooo0P2:RXXB0?ooo`030;^k^`15ADD0oooo03/0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0
/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0ADE5
06IVIP3oool00P3oool00`3_knl0ADE507IfMP0:0?ooo`030=oOg`1EEED0
oooo00P0oooo00D0ZZZZ0?ooo`3oool0MWIf0<o?c`070?ooo`80VYZJ4P3o
ool00`3?cll0MWIf0?ooo`0k0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
oon<000000l0oooo00<000000?ooo`3oool0]`3oool01@000000QXJ60;6a
/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2g0?ooo`0500000026
QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0;L0oooo00D0
000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0]`3o
ool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?oo
o`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo0;L0oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01P0oooo00<0
^k^k08Z:RP3_knl0S03oool00`000000oooo0?ooo`2g0?ooo`0500000026
QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0H0?ooo`0309ZJVP1EEED0IVIV08`0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03`3o
ool20;^k^`T0oooo00<04A4A0=oOg`3oool03P3oool20;^k^gX0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3o
ool01P2JVYX04A4A034a<@15ADD04A4A09ZJVP80oooo00<0RXZ:0000002J
VYX00P3oool01P0Q8B40RXZ:0?ooo`3oool0^k^k04E5A@80oooo00D0ZZZZ
024Q8@0000008B4Q0;^k^`020?ooo`0909ZJVP0A4A40<C4a04E5A@0A4A40
VYZJ0?ooo`2k^k/0ADE500<0oooo00P000000?ooo`3oool0ZZZZ024Q8@00
00008B4Q0;^k^`80oooo00L0ZZZZ024Q8@0000008B4Q0;^k^`3oool0kno_
00808B4Q00H0oooo0<o?c`0Q8B400000024Q8@3?clmI0?ooo`030000003o
ool0oooo0;L0oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0
clo?014A4@3?cll00P3oool01P3Ogml04A4A0>o_k`3oool0ADE50:ZZZP80
oooo00<0ZZZZ014A4@15ADD00P3oool03@2k^k/0ADE50?ooo`3Ogml04A4A
0;^k^`3oool0^k^k014A4@3_knl0clo?014A4@3?cll00P3oool01@3Ogml0
4A4A0>o_k`2k^k/0ADE500<0oooo018000000?ooo`3Ogml04A4A0;^k^`3o
ool0^k^k014A4@3_knl0gmoO014A4@2k^k/0oooo0;^k^`0A4A40kno_0;^k
^`0a<C420?ooo`05024Q8@2JVYX0oooo0;^k^`0Q8B40F@3oool00`000000
oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
09ZJVP2:RXX0oooo00<0oooo00D0<C4a0;^k^`3oool0ADE50;^k^`020?oo
o`0:06IVIP2:RXX04A4A0>o_k`3oool0^k^k04E5A@3oool0RXZ:07IfMP<0
oooo00@0gmoO0?ooo`2JVYX0RXZ:103oool0100a<C40^k^k0;^k^`15ADD3
0?ooo`040000003oool0RXZ:07IfMP<0oooo00@0gmoO0?ooo`2:RXX0MWIf
0`3oool0103Ogml0oooo0;^k^`15ADD20?ooo`050=oOg`3oool0gmoO08Z:
RP0A4A40F@3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a
0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0@0?ooo`070<o?c`1VIVH04A4A0>o_k`3oool0ADE50;^k
^`020?ooo`09014A4@3Ogml0EEEE09ZJVP3oool0^k^k04E5A@3oool0RXZ:
00D0000000<0^k^k0?ooo`3oool00P3oool01P3?cll0IVIV014A4@3_knl0
^k^k04E5A@<0oooo00<000000?ooo`2:RXX01@0000000`2k^k/0RXZ:0000
000400000080^k^k00P0ADE50?ooo`3oool0clo?034a<@000000<C4a0:ZZ
ZUT0oooo00<000000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80
k^k^0040no_k00050?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool01P3?cll0IVIV014A4@000000EEEE0<o?c`80oooo00h0
ADE50;^k^`3oool0ZZZZ034a<@3oool0VYZJ05EEE@3oool0^k^k04E5A@3o
ool0VYZJ06IVIP<0oooo00`08B4Q0=oOg`3oool0clo?06IVIP0A4A400000
05EEE@3?cll0oooo0;^k^`0Q8B430?ooo`040000003oool0VYZJ06IVIP<0
oooo00@08B4Q0=oOg`2JVYX0IVIV0`3oool0100Q8B40gmoO0;^k^`15ADD2
0?ooo`0305EEE@1VIVH0gmoO0080kno_F@3oool00`000000oooo0?ooo`2g
0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`050>o_k`0A4A40
IVIV0:ZZZP3_knl00`3oool06@2k^k/08B4Q06IVIP3Ogml0IVIV09ZJVP3o
ool0kno_014A4@3oool0^k^k04E5A@3oool0kno_024Q8@2:RXX0^k^k05EE
E@15ADD0oooo0>o_k`0A4A40IVIV0:ZZZP3_knl00`3oool06@2k^k/00000
05EEE@2k^k/0IVIV034a<@3oool0kno_024Q8@2:RXX0^k^k05EEE@15ADD0
oooo0>o_k`0Q8B40RXZ:0;^k^`1EEED0ADE50?ooo`1VIVH08B4Q09ZJVP3o
ool00P1VIVH00`2k^k/0IVIV06IVIP1I0?ooo`030000003oool0oooo0;L0
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0^k^k04E5A@3o
ool00`3oool0202:RXX0oooo0;^k^`0Q8B40IVIV0=oOg`2:RXX0kno_0P3o
ool0102JVYX0gmoO0;^k^`15ADD20?ooo`080=oOg`1VIVH0ADE508Z:RP3_
knl0oooo0;^k^`15ADD40?ooo`0808Z:RP3oool0^k^k04E5A@2JVYX0ADE5
06IVIP3?cll20?ooo`050=oOg`1VIVH0ADE508Z:RP3_knl00P3oool03`3O
gml0IVIV04E5A@2:RXX0kno_0?ooo`1VIVH08B4Q09ZJVP3oool0kno_06IV
IP15ADD0IVIV0>o_k`1I0?ooo`030000003oool0oooo0;L0oooo00D00000
08J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00L0kno_024Q8@2k^k/0oooo0>o_
k`1fMWH0ADE50080oooo00<0ADE50;^k^`3oool01P3oool00`2k^k/0ADE5
0?ooo`070?ooo`0:0>o_k`0Q8B40^k^k0?ooo`3_knl0MWIf04E5A@3oool0
^k^k04E5AA<0oooo00<0^k^k04E5A@3oool0G`3oool00`000000oooo0?oo
o`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`060<o?c`0a
<C4000000000001VIVH0kno_0P3oool00`3?cll0gmoO0?ooo`060?ooo`03
0<o?c`1fMWH0oooo00P0oooo00T0clo?034a<@000000000006IVIP3_knl0
oooo0<o?c`1fMWH0503oool00`2ZZZX0oooo0?ooo`1N0?ooo`030000003o
ool0oooo0;L0oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0Y`3o
ool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h0
0@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`2W0?ooo`030000003oool0oooo0;L0oooo00D0000008J6QP2a/K40d];B
0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0:L0oooo00<000000?ooo`3oool0]`3oool01@000000QXJ60;6a
/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2g0?ooo`0500000026
QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0;L0oooo00D0
000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0]`3o
ool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?oo
o`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo0;L0oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0Y`3o
ool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h0
0@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`2W0?ooo`030000003oool0oooo0;L0oooo00D0000008J6QP2a/K40d];B
0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0:L0oooo00<000000?ooo`3oool0]`3oool01@000000QXJ60;6a
/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2g0?ooo`0500000026
QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0;L0oooo00D0
000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0]`3o
ool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0303ooon<000000l0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0G0?ooo`0308Z:RP2k^k/0oooo06h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`2g0?ooo`0500000026
QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00@0
gmoO08Z:RP0A4A40gmoOKP3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0;L0oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`00
1@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0603oool00`2:RXX0IVIV0?ooo`1]0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0]`3oool01@000000QXJ6
0;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`080000
003oool0oooo024Q8@1VIVH0oooo0;^k^`15ADD30?ooo`0609ZJVP0A4A40
oooo0?ooo`2JVYX0EEEE1@3oool0100A4A40gmoO08Z:RP2:RXX30?ooo`0<
05EEE@000000gmoO04E5A@2k^k/0oooo0>o_k`1VIVH00000014A4@2:RXX0
oooo0P2:RXX00`3oool0kno_06IVIP020000000307IfMP3_knl0oooo0080
RXZ:00<0oooo0;^k^`15ADD00`3oool00`000000oooo0;^k^`0204E5A@03
00000015ADD0clo?03P0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00P000000?ooo`3?cll08B4Q014A4@3oool0
^k^k04E5A@<0oooo00<0<C4a014A4@2k^k/00P3oool00`0A4A40kno_0?oo
o`020?ooo`030:ZZZP1EEED0oooo0080RXZ:0`3oool01P000000kno_0?oo
o`15ADD0^k^k0?ooo`80IVIV00@0kno_0=oOg`0Q8B40^k^k0P2:RXX00`3o
ool0IVIV06IVIP020>o_k`0305EEE@2:RXX0oooo00<0oooo00<0^k^k04E5
A@3oool00P3oool020000000oooo0;^k^`000000VYZJ0?ooo`2:RXX0<C4a
>03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo
00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool01@000000oooo08Z:RP1fMWH0<C4a0080^k^k00L0ADE50?ooo`3o
ool0gmoO014A4@2:RXX0MWIf0080oooo0P1fMWH30;^k^`0304E5A@2ZZZX0
oooo0080RXZ:0`3oool020000000oooo0?ooo`15ADD0^k^k0?ooo`0A4A40
kno_0P3oool01`2k^k/0gmoO08Z:RP2:RXX0oooo014A4@3_knl00P3oool2
0>o_k`@0oooo00<0^k^k04E5A@3oool00P3oool010000000oooo0;^k^`0a
<C430?ooo`03034a<@3?cll0oooo03H0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h0
0@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`0a<C40ZZZZ
0P1fMWH0202k^k/0ADE50?ooo`3oool0RXZ:06IVIP3?cll08B4Q0P3oool0
1P3Ogml0000004E5A@15ADD0<C4a024Q8@80oooo0P2:RXX30?ooo`070000
003oool0oooo04E5A@2k^k/0oooo000000050?ooo`80RXZ:00<0oooo0000
000000000`0000000`15ADD0oooo0?ooo`020?ooo`030;^k^`15ADD0oooo
0080oooo00@000000?ooo`2k^k/0ADE50`3oool00`15ADD0^k^k0?ooo`0f
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0]`3oool0
1@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`080000003_knl04A4A0?ooo`3?cll0<C4a0;^k^`15ADD20?ooo`05
034a<@2ZZZX0oooo024Q8@3?cll00P3oool01@15ADD0gmoO0?ooo`2JVYX0
RXZ:0080oooo00<0RXZ:06IVIP3oool00P3oool020000000oooo0?ooo`15
ADD0^k^k0?ooo`0Q8B40gmoO0P3oool01`2JVYX0kno_08Z:RP2:RXX0oooo
024Q8@3Ogml00P3oool00`2JVYX0IVIV0?ooo`030?ooo`030;^k^`0Q8B40
oooo0080oooo00@000000?ooo`2k^k/08B4Q0`3oool00`0Q8B40gmoO0?oo
o`0f0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0]`3o
ool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0=0?ooo`030000002JVYX0EEEE0080oooo00H04A4A09ZJVP15ADD0oooo
0=oOg`0Q8B420?ooo`0907IfMP2:RXX0oooo0?ooo`2JVYX0MWIf0?ooo`0a
<C40gmoO0080oooo0140RXZ:014A4@2ZZZX0ZZZZ09ZJVP000000RXZ:0?oo
o`15ADD0^k^k0?ooo`2:RXX0<C4a0:ZZZP2:RXX04A4A0>o_k`0208Z:RP07
0?ooo`2:RXX0<C4a0:ZZZP2JVYX04A4A0;^k^`040?ooo`0=0;^k^`0A4A40
IVIV0;^k^`1VIVH0<C4a0?ooo`2k^k/0000005EEE@2k^k/0IVIV04E5A@0h
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0]`3oool0
1@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000001VIVH0VYZJ0080oooo0P1VIVH01015ADD0oooo0<o?c`2Z
ZZX20?ooo`030=oOg`2JVYX0oooo0080oooo00<0<C4a0=oOg`1EEED00`3o
ool02P2k^k/0ZZZZ05EEE@1VIVH0VYZJ0000002:RXX0oooo09ZJVP3Ogml2
0?ooo`0508Z:RP15ADD0EEEE0<o?c`3oool00P2:RXX20?ooo`0409ZJVP15
ADD0EEEE0;^k^`D0oooo00d0gmoO09ZJVP2ZZZX0ADE505EEE@3?cll0oooo
0;^k^`15ADD0RXZ:04E5A@1fMWH0kno_03P0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^
k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<00000014A4@3_knl0
0P3oool00`2ZZZX04A4A04E5A@0:0?ooo`0307IfMP0a<C40ZZZZ00P0oooo
00D000000?ooo`3oool0clo?0>o_k`070?ooo`80RXZ:4P3oool00`2k^k/0
ADE50?ooo`0k0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0=0?ooo`0304E5A@1VIVH0oooo0080oooo00<0kno_04E5A@1f
MWH02P3oool00`3Ogml0EEEE0?ooo`080?ooo`050:ZZZP3oool0oooo07If
MP3?cll01`3oool209ZJVQ80oooo00<0clo?07IfMP3oool0>`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0ooooS000000?0?ooo`030000003oool0oooo
0;L0oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?oo
o`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0Y`3oool00`00
0000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/0
00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2W0?oo
o`030000003oool0oooo0;L0oooo00D0000008J6QP2a/K40d];B0>k^kP01
0?_kn`001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0:L0oooo00<000000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80
k^k^0040no_k00050?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0Y`3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a
0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`2W0?ooo`030000003oool0oooo0;L0oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0]`3oool01@00
0000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2g0?oo
o`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00D0oooo00P0MWIf000000000000EEEE04E5A@2JVYX0oooo00000080oooo
00D0ZZZZ024Q8@0000008B4Q0;^k^`020?ooo`0<05EEE@000000gmoO0;^k
^`0A4A40IVIV0?ooo`2ZZZX08B4Q0000000Q8B40^k^k0P3oool0101fMWH0
00000000001fMWI_0?ooo`030000003oool0oooo0;L0oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool08@3?
cll08B4Q0>o_k`3oool0RXZ:0000002k^k/0oooo0000003oool0gmoO014A
4@2k^k/0oooo0;^k^`0A4A40kno_0?ooo`000000kno_0?ooo`2:RXX0MWIf
0?ooo`3Ogml04A4A0;^k^`3oool0^k^k014A4@3_knl0VYZJ034a<@020>o_
k`0305EEE@2JVYX0oooo06d0oooo00<000000?ooo`3oool0]`3oool01@00
0000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?oo
o`0<0=oOg`0A4A40ZZZZ0>o_k`3oool0ADE50;^k^`3oool000000?ooo`2:
RXX0MWIf0`3oool0103Ogml0oooo0?ooo`0000020?ooo`80RXZ:00<0oooo
08Z:RP1fMWH00`3oool0203Ogml0oooo0?ooo`3Ogml0oooo0:ZZZP0a<C40
RXZ:KP3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`060000002:RXX0RXZ:08Z:RP2JVYX0kno_0P3oool0
0`2ZZZX0ADE5014A4@02014A4@050;^k^`3oool000000?ooo`2:RXX01@00
00000`2k^k/0oooo000000020?ooo`80RXZ:00<0oooo08Z:RP0000001000
00000`2k^k/0oooo07IfMP02014A4@0306IVIP3_knl0oooo06d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3o
ool04`000000RXZ:08Z:RP2:RXX0IVIV024Q8@3_knl0oooo09ZJVP3_knl0
oooo0>o_k`0a<C40^k^k0?ooo`000000oooo09ZJVP1VIVH00`3oool0100Q
8B40gmoO0?ooo`0000020?ooo`80RXZ:00<0oooo09ZJVP1VIVH00`3oool0
1`0Q8B40gmoO0<o?c`0A4A40ZZZZ0?ooo`3Ogml0K`3oool00`000000oooo
0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0080oooo01L0IVIV08Z:RP3oool0ADE506IVIP2k^k/0VYZJ
014A4@3Ogml0oooo0000003oool0kno_024Q8@2:RXX0^k^k05EEE@15ADD0
oooo09ZJVP000000RXZ:0=oOg`0204E5A@0:0;^k^`3_knl08B4Q08Z:RP2k
^k/0EEEE04E5A@3oool0gmoO014A4@80ZZZZ00<04A4A0=oOg`3oool0K@3o
ool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h0
0@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0080oooo00D0MWIf08Z:RP3oool0kno_
07IfMP0204E5A@040:ZZZP3oool0oooo00000080oooo00X0gmoO06IVIP15
ADD0RXZ:0>o_k`3oool0VYZJ0000002:RXX0gmoO0P15ADD01`2k^k/0oooo
0=oOg`1VIVH0ADE508Z:RP3_knl00P3oool0102ZZZX0ADE504E5A@2ZZZY_
0?ooo`030000003oool0oooo0;L0oooo00D0000008J6QP2a/K40d];B0>k^
kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00d0oooo00L000000;^k^`2k^k/0^k^k09ZJVP0A4A40gmoO00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0208Z:RW`0oooo
00<000000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040
no_k00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool404E5A@0305EEE@2k^k/0oooo00P0oooo00<0ADE50?ooo`3oool0
1`3oool01@2ZZZX0oooo0?ooo`3_knl0^k^k07`0oooo00<000000?ooo`3o
ool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2W0?ooo`03
0000003oool0oooo0;L0oooo00D0000008J6QP2a/K40d];B0>k^kP010?_k
n`001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0
oooo00<000000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^
0040no_k00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2W0?ooo`030000003oool0oooo0;L0oooo00D0000008J6QP2a
/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0:L0oooo00<000000?ooo`3oool0]`3oool01@000000
QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2g0?ooo`05
00000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0;L0
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2W0?ooo`03
0000003oool0oooo0;L0oooo00D0000008J6QP2a/K40d];B0>k^kP010?_k
n`001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0
oooo00<000000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^
0040no_k00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2W0?ooo`030000003oool0oooo0;L0oooo00D0000008J6QP2a
/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0:L0oooo00<000000?ooo`3oool0]`3oool01@000000
QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2g0?ooo`05
00000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?oooh`000003`3oool00`000000
oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01L0oooo00<0RXZ:0;^k^`3oool0KP3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo00D0000008J6QP2a
/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool0103Ogml0
RXZ:014A4@3Ogmm^0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0H0?ooo`0308Z:RP1VIVH0oooo06d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a
0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00P000000?oo
o`3oool08B4Q06IVIP3oool0^k^k04E5A@<0oooo00H0VYZJ014A4@3oool0
oooo09ZJVP1EEED50?ooo`04014A4@3Ogml0RXZ:08Z:RP<0oooo00`0EEEE
0000003Ogml0ADE50;^k^`3oool0kno_06IVIP0000004A4A08Z:RP3oool2
08Z:RP030?ooo`3_knl0IVIV0080000000@0MWIf0>o_k`3oool0RXZ:1000
00002@1EEED0clo?0?ooo`3oool0kno_06IVIP0000004A4A08Z:RP020?oo
o`060<o?c`15ADD00000024Q8@2ZZZX0oooo0P2:RXX60?ooo`070<o?c`0Q
8B400000024Q8@1fMWH08B4Q0?ooo`0208Z:RP030?ooo`2:RXX0RXZ:0080
oooo00D000000?ooo`3oool0oooo04E5A@020;^k^`80ADE500<0000004E5
A@3?cll0403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0;L0oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool020000000oooo0<o?c`0Q8B404A4A0?ooo`2k^k/0ADE5
0`3oool00`0a<C404A4A0;^k^`020?ooo`03014A4@3_knl0oooo0080oooo
00<0ZZZZ05EEE@3oool00P2:RXX30?ooo`060000003_knl0oooo04E5A@2k
^k/0oooo0P1VIVH0103_knl0gmoO024Q8@2k^k/208Z:RP030?ooo`1VIVH0
IVIV0080kno_00<0EEEE08Z:RP3oool00P2:RXX20?ooo`050>o_k`2:RXX0
4A4A0>o_k`3oool00P1VIVH02`3_knl0gmoO034a<@2JVYX0oooo024Q8@2:
RXX0oooo0;^k^`0A4A40kno_0080RXZ:1P3oool01`1EEED0RXZ:0?ooo`3O
gml0<C4a04E5A@3oool00P2:RXX50?ooo`050000003oool0oooo0?ooo`15
ADD00P2k^k/01@000000VYZJ0?ooo`2:RXX0<C4a0100oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a
0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00D000000?oo
o`2:RXX0MWIf034a<@020;^k^`0704E5A@3oool0oooo0=oOg`0A4A40RXZ:
07IfMP020?ooo`80MWIf0`2k^k/00`15ADD0ZZZZ0?ooo`0208Z:RP<0oooo
00P000000?ooo`3oool0ADE50;^k^`3oool04A4A0>o_k`80oooo00L0^k^k
0=oOg`2:RXX0RXZ:0?ooo`0A4A40kno_0080oooo0P3_knl00`3oool0RXZ:
08Z:RP040?ooo`0506IVIP2:RXX0oooo014A4@3_knl00P3oool0102JVYX0
EEEE0<o?c`0a<C430?ooo`040:ZZZP3_knl0RXZ:08Z:RPH0oooo0P1VIVH0
1@3?cll0oooo0;^k^`15ADD0oooo0080RXZ:1@3oool01@000000oooo0?oo
o`3oool0ADE50080^k^k00H0<C4a0?ooo`3oool0oooo034a<@3?cll?0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0]`3oool01@00
0000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?oo
o`040000003oool0<C4a0:ZZZP80MWIf00P0^k^k04E5A@3oool0oooo08Z:
RP1VIVH0clo?024Q8@80oooo00H0gmoO00000015ADD0ADE5034a<@0Q8B42
0?ooo`80RXZ:0`3oool01`000000oooo0?ooo`15ADD0^k^k0?ooo`000000
1@3oool208Z:RP030?ooo`000000000000<0000000@0ADE50?ooo`2:RXX0
RXZ:103oool0102ZZZX0ADE50?ooo`0000030?ooo`040;^k^`15ADD0^k^k
04E5A@D0oooo00<0RXZ:04E5A@2:RXX00P2:RXX02P3?cll0oooo0?ooo`3_
knl0IVIV034a<@0000008B4Q04E5A@3oool208Z:RPD0oooo00D000000?oo
o`3oool0oooo04E5A@020;^k^`0604E5A@3oool0oooo0?ooo`15ADD0^k^k
3`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo
00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool020000000kno_014A4@3oool0clo?034a<@2k^k/0ADE50P3oool0
1@0a<C40ZZZZ0?ooo`0Q8B40clo?0080oooo00D0ADE50=oOg`3oool0VYZJ
08Z:RP020?ooo`0308Z:RP1VIVH0oooo0080oooo00P000000?ooo`3oool0
ADE50;^k^`3oool08B4Q0=oOg`80oooo00L0VYZJ0>o_k`2:RXX0RXZ:0?oo
o`0Q8B40gmoO0080oooo00<0VYZJ06IVIP3oool00P2:RXX40?ooo`050;^k
^`15ADD0oooo024Q8@3Ogml00P3oool0102JVYX0IVIV0=oOg`0Q8B420?oo
o`050>o_k`2JVYX0oooo08Z:RP15ADD00`2:RXX01@0Q8B40RXZ:0?ooo`3O
gml0ZZZZ0080oooo00<0VYZJ04E5A@3oool00P2:RXX50?ooo`050000003O
gml0oooo0?ooo`15ADD00P2k^k/01P0Q8B40oooo0?ooo`3oool08B4Q0=oO
g`l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2g0?oo
o`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00d0oooo00<0000009ZJVP1EEED00P3oool01P0A4A40VYZJ04E5A@3oool0
gmoO024Q8@80oooo00T0MWIf08Z:RP3oool0oooo09ZJVP1fMWH0oooo034a
<@3Ogml00P3oool04@2:RXX04A4A0:ZZZP2ZZZX0VYZJ0000002:RXX0oooo
04E5A@2k^k/0oooo08Z:RP0a<C40ZZZZ08Z:RP0A4A40kno_0080RXZ:00P0
oooo08Z:RP0a<C40ZZZZ09ZJVP0A4A40^k^k0?ooo`80RXZ:103oool0402Z
ZZX0EEEE0?ooo`2:RXX0<C4a0:ZZZP2JVYX04A4A0;^k^`3oool0ADE505EE
E@2k^k/0IVIV04E5A@3oool208Z:RP<0oooo00X0gmoO014A4@3oool0^k^k
014A4@2ZZZX0^k^k05EEE@1VIVH0oooo0P2:RXX50?ooo`0<00000015ADD0
^k^k08Z:RP000000kno_0;^k^`000000EEEE0;^k^`1VIVH0ADE5403oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo00D00000
08J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool0
0`000000IVIV09ZJVP020?ooo`80IVIV00@0ADE50?ooo`3?cll0ZZZZ0P3o
ool00`3Ogml0VYZJ0?ooo`020?ooo`03034a<@3Ogml0EEEE00<0oooo00X0
^k^k0:ZZZP1EEED0IVIV09ZJVP000000RXZ:0?ooo`2JVYX0gmoO0P3oool0
1@2:RXX0ADE505EEE@3?cll0oooo0080RXZ:0P3oool0102JVYX0ADE505EE
E@2k^k/20?ooo`80RXZ:103oool02015ADD0VYZJ0?ooo`3oool0VYZJ04E5
A@1EEED0^k^k0P3oool01P3_knl0MWIf04E5A@1VIVH0kno_0?ooo`80RXZ:
0`3oool02P3_knl000000?ooo`3oool0ZZZZ05EEE@15ADD0IVIV0>o_k`3o
ool208Z:RPD0oooo00`0RXZ:0<o?c`1EEED0ADE50:ZZZP3oool0^k^k04E5
A@2:RXX0ADE507IfMP3_knl@0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0]`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0=0?ooo`030000000A4A40kno_0080oooo00<0
ZZZZ014A4@15ADD02P3oool00`1fMWH0<C4a0:ZZZP080?ooo`050000003o
ool0oooo0<o?c`3_knl01`3oool208Z:RPP0oooo00<0RXZ:06IVIP2k^k/0
0P2k^k/00`1EEED0<C4a0?ooo`0>0?ooo`0308Z:RP1VIVH0^k^k0080^k^k
00<0EEEE06IVIP3oool01`3oool208Z:RP/0oooo00<0^k^k04E5A@3oool0
4`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0;L0oooo
00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00`15ADD0IVIV0?ooo`020?ooo`030>o_k`15ADD0MWIf00X0oooo
00<0gmoO05EEE@3oool0203oool01@2ZZZX0oooo0?ooo`1fMWH0clo?00L0
oooo0P2JVYX80?ooo`0309ZJVP15ADD0ADE50080ADE500<0RXZ:0>o_k`3o
ool03P3oool00`2JVYX0ADE504E5A@0204E5A@0308Z:RP3_knl0oooo00L0
oooo0P2JVYX;0?ooo`030<o?c`1fMWH0oooo01<0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`2g0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0>0?oooiL000004P3oool01@000000
QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo0100oooo00D0000008J6QP2a
/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`0@0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool0403oool01@000000QXJ60;6a/@3Bd]80k^k^
0040no_k00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo0100oooo00D0000008J6QP2a/K40d];B0>k^kP010?_k
n`001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
ooooS000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`0@0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2W0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`0@0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2W0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`0@0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2W0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`0@0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2W0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`0@0?ooo`0500000026QXH0/K6a0=;B
dP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2W0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool05`3oool00`2:RXX0^k^k0?ooo`1i0?ooo`030000003oool0oooo0100
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0F0?ooo`040=oOg`2:RXX04A4A0=oO
ggT0oooo00<000000?ooo`3oool0403oool01@000000QXJ60;6a/@3Bd]80
k^k^0040no_k00050?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0Y`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
01P0oooo00<0RXZ:06IVIP3oool09`3oool00`3Ogml0^k^k0=oOg`1>0?oo
o`030000003oool0oooo0100oooo00D0000008J6QP2a/K40d];B0>k^kP01
0?_kn`001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0:L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?oo
o`080000003oool0oooo024Q8@1VIVH0oooo0;^k^`15ADD30?ooo`0609ZJ
VP0A4A40oooo0?ooo`2JVYX0EEEE1@3oool0100A4A40gmoO08Z:RP2:RXX3
0?ooo`0<05EEE@000000gmoO04E5A@2k^k/0oooo0>o_k`1VIVH00000014A
4@2:RXX0oooo0P2:RXX00`3oool0kno_06IVIP020000000;07IfMP3_knl0
oooo0>o_k`15ADD04A4A04E5A@0Q8B40ADE50>o_k`3oool00P2:RXX30?oo
o`090:ZZZP0Q8B40000004E5A@3?cll0oooo04E5A@2k^k/0oooo0080RXZ:
0P3oool02@2k^k/0ADE50?ooo`2:RXX0IVIV024Q8@000000IVIV0>o_k`0`
0?ooo`030000003oool0oooo0100oooo00D0000008J6QP2a/K40d];B0>k^
kP010?_kn`001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00`0oooo100000000`0Q8B40RXZ:0?ooo`020?ooo`050:ZZZP0Q8B40
000004E5A@3?cll00P3oool01`2:RXX04A4A0000001VIVH0kno_0?ooo`1f
MWH00P0A4A401@2JVYX000000?ooo`2k^k/0ADE50080oooo0P2:RXX20?oo
o`0;04E5A@2k^k/0oooo0<o?c`15ADD00000014A4@2:RXX0oooo0;^k^`15
ADD00`3oool01P000000oooo0?ooo`1EEED000000=oOg`80RXZ:1P3oool0
1`3?cll08B4Q0000000Q8B40MWIf024Q8@3oool00P2:RXX20?ooo`0I08Z:
RP0A4A40000004E5A@3Ogml0oooo0;^k^`0A4A40IVIV0?ooo`2:RXX00000
09ZJVP3oool0RXZ:014A4@000000ADE50=oOg`3oool0kno_04E5A@000000
4A4A09ZJVP0g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool020000000oooo0<o?c`0Q8B404A4A0?ooo`2k^k/0ADE50`3o
ool00`0a<C404A4A0;^k^`020?ooo`03014A4@3_knl0oooo0080oooo00<0
ZZZZ05EEE@3oool00P2:RXX30?ooo`060000003_knl0oooo04E5A@2k^k/0
oooo0P1VIVH0103_knl0gmoO024Q8@2k^k/208Z:RP030?ooo`1VIVH0IVIV
0080kno_00D0EEEE08Z:RP3oool0EEEE06IVIP030?ooo`80MWIf00<0oooo
08Z:RP2:RXX00P3oool01P3Ogml04A4A0;^k^`3oool0RXZ:04E5A@@0oooo
0P2:RXX20?ooo`090;^k^`15ADD0oooo08Z:RP0A4A40clo?0>o_k`1VIVH0
MWIf0300oooo00<000000?ooo`3oool0403oool01@000000QXJ60;6a/@3B
d]80k^k^0040no_k00050?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0303oool07P000000oooo0?ooo`3oool0clo?034a<@2:RXX0
oooo0=oOg`0A4A40^k^k0?ooo`2:RXX08B4Q0?ooo`2JVYX0<C4a0=oOg`3_
knl0EEEE08Z:RP3?cll04A4A0=oOg`3oool0IVIV0000003oool0^k^k04E5
A@80oooo0P2:RXX20?ooo`0804E5A@2k^k/0oooo024Q8@2:RXX0oooo0=oO
g`0Q8B420;^k^`0504E5A@3oool0oooo0?ooo`0000000P3oool00`000000
kno_0?ooo`0208Z:RPH0oooo00L0EEEE08Z:RP3oool0gmoO034a<@15ADD0
oooo0080RXZ:00X0oooo09ZJVP0a<C40gmoO0?ooo`2:RXX0ADE50?ooo`2:
RXX0MWIf0P3oool02P15ADD0ZZZZ0?ooo`2JVYX0<C4a0=oOg`3oool0RXZ:
04E5A@3oool206IVIP040?ooo`3Ogml08B4Q0=oOgcH0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0RXZ:
07IfMP0a<C400P2k^k/01`15ADD0oooo0?ooo`3Ogml04A4A08Z:RP1fMWH0
0P3oool207IfMP<0^k^k00<0ADE50:ZZZP3oool00P2:RXX30?ooo`080000
003oool0oooo04E5A@2k^k/0oooo014A4@3_knl20?ooo`070;^k^`3Ogml0
RXZ:08Z:RP3oool04A4A0>o_k`020?ooo`80kno_00<0oooo04E5A@3_knl0
0`3oool00`2ZZZX0ADE50?ooo`0208Z:RP80oooo00<0RXZ:07IfMP3oool0
0P3oool00`2JVYX0oooo0?ooo`020?ooo`80RXZ:0P3oool01@2k^k/0ADE5
0?ooo`2:RXX0MWIf0080oooo00<0kno_014A4@3oool0;`3oool00`000000
oooo0?ooo`0@0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0080oooo00D0gmoO014A4@3oool0RXZ:07IfMP030?oo
o`04024Q8@3?cll0EEEE0:ZZZP80oooo00@0gmoO0;^k^`2k^k/0ADE50`3o
ool010000000oooo0;^k^`15ADD20?ooo`80RXZ:0P3oool01015ADD0^k^k
0<o?c`0a<C430?ooo`040=oOg`3oool0^k^k04E5A@<0oooo00@000000?oo
o`3oool000000P3oool208Z:RPH0oooo0P1VIVH01@3?cll0oooo0;^k^`15
ADD0oooo0080RXZ:00<0oooo05EEE@2ZZZX00`3oool0103Ogml0oooo08Z:
RP2:RXX20?ooo`0504E5A@2k^k/0oooo05EEE@2ZZZX00`3oool00`3Ogml0
oooo0>o_k`020>o_k`0309ZJVP0A4A40clo?03H0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0<C4a0:ZZ
ZP80MWIf00P0^k^k04E5A@3oool0oooo08Z:RP1VIVH0clo?024Q8@80oooo
00H0gmoO00000015ADD0ADE5034a<@0Q8B420?ooo`80RXZ:0`3oool01`00
0000oooo0?ooo`15ADD0^k^k0?ooo`0000001@3oool208Z:RP030?ooo`00
0000000000<0000000<0ADE50?ooo`3oool00P3oool01@3_knl0VYZJ024Q
8@2:RXX0oooo0080RXZ:0P3oool208Z:RPP0oooo0P2:RXX20?ooo`030;^k
^`15ADD0oooo0080RXZ:0`3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0100oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`00
1@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool0100a<C40^k^k08Z:RP2:RXX30?ooo`04
04E5A@2k^k/0ADE50;^k^`@0oooo00<0^k^k04E5A@3oool00P3oool01000
0000oooo0;^k^`15ADD20?ooo`80RXZ:0P3oool00`15ADD0^k^k0;^k^`05
0000000308Z:RP2k^k/0ADE500<0oooo00@000000?ooo`3oool000000P3o
ool00`2:RXX0ADE508Z:RP0208Z:RP0:0<o?c`3oool0oooo0>o_k`1VIVH0
<C4a0000000Q8B40ADE50?ooo`80RXZ:00<0oooo04E5A@00000010000000
0`3oool0RXZ:08Z:RP020?ooo`0404E5A@2k^k/0oooo04E5A@D0000000H0
oooo0>o_k`1EEED00000024Q8@2:RXXg0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool020000000kno_014A4@3oool0clo?
034a<@2k^k/0ADE50P3oool01@0a<C40ZZZZ0?ooo`0Q8B40clo?0080oooo
00D0ADE50=oOg`3oool0VYZJ08Z:RP020?ooo`0308Z:RP1VIVH0oooo0080
oooo00P000000?ooo`3oool0ADE50;^k^`3oool08B4Q0=oOg`80oooo00L0
VYZJ0>o_k`2:RXX0RXZ:0?ooo`0Q8B40gmoO0080oooo00T0VYZJ06IVIP3o
ool0oooo08Z:RP0a<C400000024Q8@2:RXX00P3oool01P2:RXX0IVIV0?oo
o`3oool0VYZJ06IVIP80oooo00<0clo?0;^k^`3oool00`3oool02@2:RXX0
IVIV0?ooo`3oool0^k^k04E5A@3oool0RXZ:06IVIP020?ooo`030=oOg`0Q
8B40oooo02l0oooo00<000000?ooo`3oool0403oool01@000000QXJ60;6a
/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`0404E5A@2k
^k/0VYZJ06IVIP<0oooo00@08B4Q0=oOg`1VIVH0VYZJ0P3oool0102ZZZX0
gmoO0;^k^`15ADD30?ooo`040000003oool0^k^k024Q8@80oooo00P0RXZ:
07IfMP3oool0oooo04E5A@2k^k/0gmoO024Q8@<0oooo00@0IVIV09ZJVP2k
^k/08B4Q0`3oool010000000oooo0?ooo`0000020?ooo`0308Z:RP15ADD0
RXZ:0080RXZ:00D08B4Q08Z:RP3oool0gmoO0:ZZZP020?ooo`0309ZJVP15
ADD0oooo0080RXZ:00<0oooo06IVIP2JVYX00P3oool00`3Ogml08B4Q0?oo
o`0208Z:RP80oooo00D0ADE50;^k^`3oool0IVIV09ZJVP020?ooo`080=oO
g`0Q8B40oooo08Z:RP0a<C40clo?0?ooo`3Ogmlg0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000VYZJ05EEE@02
0?ooo`06014A4@2JVYX0ADE50?ooo`3Ogml08B4Q0P3oool02@1fMWH0RXZ:
0?ooo`3oool0VYZJ07IfMP3oool0<C4a0=oOg`020?ooo`0A08Z:RP0A4A40
ZZZZ0:ZZZP2JVYX0000008Z:RP3oool0ADE50;^k^`3oool0RXZ:034a<@2Z
ZZX0RXZ:014A4@3_knl00P2:RXX0303oool0RXZ:034a<@2ZZZX0VYZJ014A
4@2k^k/0oooo08Z:RP0Q8B40RXZ:0<o?c`@0oooo00X0RXZ:014A4@2ZZZX0
ZZZZ0>o_k`0A4A40RXZ:0;^k^`0a<C40RXZ:103oool03@2:RXX04A4A08Z:
RP2k^k/0<C4a07IfMP3oool0RXZ:0000002:RXX0^k^k034a<@2:RXX0<03o
ool00`000000oooo0?ooo`0@0?ooo`0500000026QXH0/K6a0=;BdP3^k^h0
0@3kno/000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00<0oooo00h0<C4a0<o?c`3_knl04A4A
08Z:RP2k^k/0EEEE04E5A@3oool0^k^k014A4@2JVYX0ZZZZ014A4@80^k^k
0140ADE50?ooo`3oool0oooo0000003oool0^k^k014A4@2:RXX0^k^k024Q
8@0a<C40VYZJ0:ZZZP0A4A40gmoO0?ooo`0205EEE@0?0;^k^`2:RXX04A4A
0>o_k`2k^k/04A4A06IVIP2k^k/0IVIV034a<@3oool0VYZJ0000002:RXX0
oooo0080RXZ:0`3oool02P3Ogml04A4A0?ooo`2k^k/04A4A0:ZZZP2k^k/0
EEEE06IVIP3oool208Z:RP080?ooo`3?cll04A4A09ZJVP2ZZZX0<C4a08Z:
RP3Ogml204E5A@80^k^k00l08B4Q06IVIP3Ogml0clo?014A4@2JVYX0ZZZZ
034a<@2:RXX0oooo09ZJVP0a<C40^k^k08Z:RP0Q8B40=`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0000006IVIP2J
VYX00P3oool206IVIP0404E5A@3oool0clo?0:ZZZP80oooo00<0gmoO09ZJ
VP3oool00P3oool00`0a<C40gmoO05EEE@030?ooo`0:0;^k^`2ZZZX0EEEE
06IVIP2JVYX0000008Z:RP3oool0VYZJ0=oOg`80oooo00D0RXZ:04E5A@1E
EED0clo?0?ooo`0208Z:RP80oooo00@0VYZJ04E5A@1EEED0^k^k0P3oool0
0`15ADD0^k^k0?ooo`020?ooo`80^k^k00X0oooo0;^k^`2ZZZX0EEEE06IV
IP3oool0clo?06IVIP15ADD0RXZ:1@3oool20;^k^`0:08Z:RP15ADD0IVIV
0>o_k`3oool0RXZ:07IfMP1VIVH0ADE508Z:RS40oooo00<000000?ooo`3o
ool0403oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`020?ooo`090;^k^`0Q8B40oooo0?ooo`3Ogml0IVIV04E5A@2:
RXX0kno_0080oooo00L0ZZZZ05EEE@15ADD0ZZZZ0?ooo`3Ogml0VYZJ00<0
oooo00<0RXZ:0?ooo`3Ogml00P2JVYX01P15ADD0RXZ:0>o_k`1VIVH0ADE5
0:ZZZP80oooo0140kno_08Z:RP15ADD0IVIV0=oOg`3oool0gmoO09ZJVP2Z
ZZX0ADE505EEE@3?cll0oooo09ZJVP000000RXZ:0?ooo`0208Z:RP<0oooo
00X0kno_0000003oool0oooo0:ZZZP1EEED0ADE506IVIP3_knl0oooo0P2:
RXX20?ooo`060;^k^`1EEED0ADE509ZJVP3oool0gmoO0P15ADD20;^k^`08
024Q8@1VIVH0gmoO0?ooo`2k^k/0EEEE04E5A@2JVYX30?ooo`0408Z:RP15
ADD0EEEE0<o?ccL0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000000A4A40kno_0080oooo00<0ZZZZ014A4@15ADD0
2P3oool00`1fMWH0<C4a0:ZZZP080?ooo`050000003oool0oooo0<o?c`3_
knl01`3oool208Z:RPP0oooo00L0RXZ:06IVIP3_knl0oooo0;^k^`0Q8B40
^k^k01H0oooo0P2:RXXd0?ooo`030000003oool0oooo0100oooo00D00000
08J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00L000000;^k^`2k^k/0^k^k09ZJ
VP0A4A40ZZZZ02h0oooo00D000000?ooo`3oool0RXZ:06IVIP030;^k^`03
05EEE@1VIVH0oooo00L0oooo0P2:RXX80?ooo`80RXZ:0P3oool00`15ADD0
^k^k0?ooo`130?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`15ADD0IVIV0?ooo`020?ooo`030>o_k`15ADD0MWIf00X0
oooo00<0gmoO05EEE@3oool0203oool01@2ZZZX0oooo0?ooo`1fMWH0clo?
00L0oooo0P2JVYX90?ooo`0507IfMP0A4A400000024Q8@2ZZZX05`3oool2
09ZJVS@0oooo00<000000?ooo`3oool0403oool01@000000QXJ60;6a/@3B
d]80k^k^0040no_k00050?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0303oool404E5A@0306IVIP2k^k/0oooo02h0oooo00@0ZZZZ
0?ooo`3oool0VYZJ1015ADD00`2:RXX0kno_0?ooo`070?ooo`80VYZJ203o
ool01P3_knl0^k^k0?ooo`3oool0clo?0=oOgd@0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0100
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0100
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0100
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0100
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0100
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0100
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0100
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0100
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0100
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0100
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0100
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0100
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0100
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`0=0?oooj/00000403ooonG00000180oooo00D0000008J6QP2a
/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`3o0?ooog80
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`3o0?ooog80oooo00D0000008J6QP2a/K40d];B0>k^kP010?_k
n`001@3oool00`000000oooo0?ooo`3o0?ooog80oooo00D0000008J6QP2a
/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`3o0?ooog80
oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000
oooo0?ooo`3o0?ooog80oooo00D0000008J6QP2a/K40d];B0>k^kP010?_k
n`001@3oool00`000000oooo0?ooo`3o0?ooog80oooo00D0000008J6QP2a
/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`3a0?ooo`80
^k^kOP3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`15ADD0
^k^k0?ooo`020?ooo`0608Z:RP0A4A40000006IVIP3_knl0oooo0P2:RXX2
0?ooo`040;^k^`15ADD0oooo0>o_k`808B4Q103oool00`2k^k/000000000
0004000000030?ooo`2k^k/0ADE500<0oooo00P000000?ooo`3oool0ZZZZ
024Q8@000000MWIf000008D0oooo00<000000?ooo`3oool01@3oool0201f
MWH000000000001EEED0ADE509ZJVP3oool000000P3oool01@2ZZZX08B4Q
0000000Q8B40^k^k0080oooo00`0EEEE0000003Ogml0^k^k014A4@1VIVH0
oooo0:ZZZP0Q8B400000024Q8@2k^k/20?ooo`0609ZJVP0A4A40<C4a04E5
A@0A4A40VYZJ0P3oool01@3?cll0ADE50000000Q8B40ZZZZ0080oooo00D0
VYZJ024Q8@000000MWIf04E5A@020;^k^`0<04E5A@3oool0oooo0?ooo`3?
cll0ADE50000000Q8B40ZZZZ0?ooo`3_knl0IVIV0P0000000`1fMWH0kno_
0?ooo`1K0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`0804E5
A@2k^k/0oooo0?ooo`2JVYX0<C4a0=oOg`3_knl206IVIP030?ooo`2:RXX0
RXZ:0080oooo00D0^k^k04E5A@3oool0^k^k034a<@050?ooo`030;^k^`15
ADD0oooo00D0oooo00<0^k^k04E5A@3oool00P3oool020000000oooo0=oO
g`0Q8B40^k^k0?ooo`1VIVH00000Q@3oool00`000000oooo0?ooo`040?oo
o`0R0<o?c`0Q8B40kno_0?ooo`2:RXX000000;^k^`3oool000000?ooo`3O
gml04A4A0;^k^`3oool0^k^k014A4@3_knl0oooo0000003_knl0oooo08Z:
RP1fMWH0oooo0=oOg`0A4A40^k^k0?ooo`2k^k/04A4A0>o_k`3?cll04A4A
0<o?c`80oooo0100gmoO014A4@3_knl0oooo024Q8@2:RXX0oooo0;^k^`0A
4A40gmoO0?ooo`0A4A40ZZZZ0?ooo`2JVYX000000P2k^k/02P15ADD0oooo
0?ooo`3oool08B4Q08Z:RP3oool0^k^k014A4@3_knl206IVIP80kno_00<0
EEEE08Z:RP3oool0F`3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k
00050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103o
ool01P15ADD0^k^k0?ooo`3oool0EEEE0:ZZZP80oooo00<0gmoO014A4@3o
ool00P2:RXX20?ooo`050;^k^`15ADD0oooo0;^k^`15ADD01@3oool00`2k
^k/0ADE50?ooo`050?ooo`030;^k^`15ADD0oooo0080oooo00@000000?oo
o`2:RXX0MWIf0P3oool00`3_knl000000?ooo`240?ooo`030000003oool0
oooo00@0oooo00`0gmoO014A4@2ZZZX0kno_0?ooo`15ADD0^k^k0?ooo`00
0000oooo08Z:RP1fMWH30?ooo`040=oOg`3oool0oooo00000080oooo0P2:
RXX00`3oool0RXZ:07IfMP030?ooo`040=oOg`3oool0VYZJ08Z:RP@0oooo
00@0<C4a0;^k^`3?cll0<C4a0`3oool0101VIVH0RXZ:0?ooo`0000030?oo
o`0404E5A@2k^k/0^k^k04E5A@80oooo00<0clo?034a<@3oool00P3oool0
102ZZZX0kno_014A4@3_knl20?ooo`80kno_G03oool01@000000QXJ60;6a
/@3Bd]80k^k^0040no_k00050?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0103oool01P15ADD0^k^k0?ooo`3oool0ADE50;^k^`<0
oooo00@000000?ooo`2:RXX0RXZ:0P3oool01@2k^k/0ADE50?ooo`2k^k/0
ADE500D0oooo00<0^k^k04E5A@3oool01@3oool00`2k^k/0ADE50?ooo`02
0?ooo`040000003oool0RXZ:08Z:RP<0oooo00<000000?ooo`3oool0P`3o
ool01P000000RXZ:08Z:RP2:RXX0VYZJ0>o_k`80oooo00<0ZZZZ04E5A@0A
4A400P0A4A401@2k^k/0oooo0000003oool0RXZ:00D0000000<0^k^k0?oo
o`0000000P3oool208Z:RP030?ooo`2:RXX0000000@0000000<0^k^k0?oo
o`3oool00P3oool01P3?cll0IVIV014A4@3_knl0^k^k04E5A@<0oooo0P2:
RXX00`3oool000000?ooo`020?ooo`0404E5A@2k^k/0^k^k04E5A@80oooo
00<0^k^k04E5A@3oool0103oool50000000304E5A@3oool0oooo05X0oooo
00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo
0?ooo`0>0?ooo`D000000P3oool01P15ADD0VYZJ0?ooo`3oool0IVIV09ZJ
VP80oooo00D0gmoO024Q8@3oool0RXZ:06IVIP020?ooo`050;^k^`15ADD0
oooo0;^k^`15ADD01@3oool00`2k^k/00000000000030000000408Z:RP3o
ool0^k^k024Q8@<0oooo00@000000?ooo`2JVYX0IVIV0P3oool00`3?cll0
00000?ooo`240?ooo`0C0000002:RXX0RXZ:08Z:RP1VIVH08B4Q0>o_k`3o
ool0VYZJ0>o_k`3oool0kno_034a<@2k^k/0oooo0000003oool0VYZJ06IV
IP030?ooo`04024Q8@3Ogml0oooo00000080oooo0P2:RXX00`3oool0VYZJ
06IVIP030?ooo`0<024Q8@3Ogml0oooo0<o?c`1VIVH04A4A0000001EEED0
clo?0?ooo`3Ogml08B4Q0`3oool0101VIVH0VYZJ0?ooo`0000030?ooo`04
04E5A@2k^k/0^k^k024Q8@80oooo00T0gmoO024Q8@3oool0oooo0>o_k`2J
VYX0oooo024Q8@3Ogml00P3oool00`2JVYX0IVIV0?ooo`1K0?ooo`050000
0026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`040?ooo`0304E5A@0a<C40^k^k0080^k^k
01004A4A09ZJVP2ZZZX0<C4a08Z:RP3oool0RXZ:014A4@2:RXX0^k^k034a
<@1fMWH0oooo06IVIP0Q8B40VYZJ103oool00`2k^k/0ADE50?ooo`050?oo
o`0=0;^k^`0A4A40IVIV0;^k^`1VIVH0<C4a0?ooo`3_knl04A4A08Z:RP2Z
ZZX0<C4a000000250?ooo`030000003oool0oooo0080oooo01L0IVIV08Z:
RP3oool0ADE506IVIP2k^k/0VYZJ014A4@3Ogml0oooo0000003oool0kno_
024Q8@2:RXX0^k^k05EEE@15ADD0oooo09ZJVP000000RXZ:0=oOg`0204E5
A@0=0;^k^`3_knl08B4Q08Z:RP2k^k/0EEEE04E5A@3oool0kno_014A4@1V
IVH0ZZZZ0>o_k`040?ooo`0804E5A@1EEED0^k^k08Z:RP0A4A40kno_0?oo
o`0000030?ooo`0C04E5A@2k^k/0^k^k0000002:RXX0VYZJ0?ooo`15ADD0
EEEE0;^k^`1VIVH0ADE50?ooo`2:RXX0<C4a0:ZZZP2JVYX04A4A0;^k^`1L
0?ooo`0500000026QXH0/K6a0=;BdP3^k^h00@3kno/000D0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`0909ZJVP2ZZZX0
ADE508Z:RP3oool0^k^k05EEE@15ADD0VYZJ0080oooo0P2k^k/0202:RXX0
ADE506IVIP3_knl0oooo06IVIP0Q8B40VYZJ103oool00`2k^k/0ADE50?oo
o`050?ooo`060=oOg`2JVYX0ZZZZ04E5A@1EEED0clo?0P3oool01@3?cll0
IVIV04E5A@2ZZZX0000008D0oooo00<000000?ooo`3oool00P3oool01@1f
MWH0RXZ:0?ooo`3_knl0MWIf0080ADE500@0ZZZZ0?ooo`3oool000000P3o
ool02P3Ogml0IVIV04E5A@2:RXX0kno_0?ooo`2JVYX0000008Z:RP3Ogml2
04E5A@0:0;^k^`3oool0gmoO06IVIP15ADD0RXZ:0>o_k`3oool0^k^k04E5
A@@0oooo00P0RXZ:0?ooo`3oool0kno_08Z:RP15ADD0IVIV0=oOg`80oooo
00D0RXZ:0?ooo`3oool0oooo09ZJVP020=oOg`090:ZZZP1VIVH0EEEE0=oO
g`3_knl0MWIf04E5A@1VIVH0kno_0080oooo00@0VYZJ04E5A@1EEED0^k^k
G@3oool01@000000QXJ60;6a/@3Bd]80k^k^0040no_k00050?ooo`030000
003oool0oooo00h0oooo00<000000;^k^`2k^k/00P2k^k/00`3?cll0oooo
0?ooo`0A0?ooo`030;^k^`15ADD0oooo00@0oooo00<0^k^k034a<@2k^k/0
0`2k^k/00`3?cll0oooo0?ooo`0;0?ooo`030000003oool0oooo08<0oooo
00L000000;^k^`2k^k/0^k^k09ZJVP0A4A40gmoO00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0208Z:RPP0oooo00L0kno_024Q
8@2k^k/0oooo0>o_k`1fMWH0ADE507`0oooo00D0000008J6QP2a/K40d];B
0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`0>0?ooo`D0ADE500<0
MWIf0?ooo`3oool04P3oool00`2ZZZX0oooo0?ooo`030?ooo`030<o?c`15
ADD0ADE500<0ADE500<0MWIf0?ooo`3oool02`3oool00`15ADD0oooo0?oo
o`230?ooo`@0ADE500<0EEEE0;^k^`3oool0203oool00`15ADD0oooo0?oo
o`070?ooo`050:ZZZP3oool0oooo0>o_k`2k^k/02@3oool01P3?cll0<C4a
000000000000IVIV0>o_kg`0oooo00D0000008J6QP2a/K40d];B0>k^kP01
0?_kn`001@3oool00`000000oooo0?ooo`3o0?ooog80oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`3o0?oo
og80oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`00
0000oooo0?ooo`3o0?ooog80oooo00D0000008J6QP2a/K40d];B0>k^kP01
0?_kn`001@3oool00`000000oooo0?ooo`3o0?ooog80oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`3o0?oo
og80oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`00
0000oooo0?ooo`3o0?ooog80oooo00D0000008J6QP2a/K40d];B0>k^kP01
0?_kn`001@3oool00`000000oooo0?ooo`3o0?ooog80oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`3o0?oo
og80oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`00
0000oooo0?ooo`3o0?ooog80oooo00D0000008J6QP2a/K40d];B0>k^kP01
0?_kn`001@3oool00`000000oooo0?ooo`3o0?ooog80oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`3o0?oo
og80oooo00D0000008J6QP2a/K40d];B0>k^kP010?_kn`001@3oool00`00
0000oooo0?ooo`3o0?ooog80oooo00D0000008J6QP2a/K40d];B0>k^kP01
0?_kn`001@3oool00`000000oooo0?ooo`3o0?ooog80oooo00D0000008J6
QP2a/K40d];B0>k^kP010?_kn`001@3oool00`000000oooo0?ooo`3o0?oo
og80oooo00D0000008N7Q`2c/k<0eMGE0?;blP010?clo0001@3oool00`00
0000oooo0?ooo`3o0?ooog80oooo00D0000008f=S@2k^k/0hN7Q0?gmo@01
0?ooo`001@3oool00`000000oooo0?ooo`3o0?ooog80oooo00@00000096A
T@34a<@0i^KV0P3oool000D0oooo00<000000?ooo`3oool0o`3ooomb0?oo
o`030000002d];@0mOGe00<0oooo00050?ooo`030000003oool0oooo0?l0
ooooLP3oool00`000000kNg]0?ooo`030?ooo`001@3ooooo000007H00000
1@3oool00?l0ooooP03oool00?l0ooooP03oool00?l0ooooP03oool00?l0
ooooP03oool00?l0ooooP03oool00140oooo00<0RXZ:0;^k^`3oool0o`3o
oom/0?ooo`00403oool0103Ogml0RXZ:014A4@3Ogmoo0?ooof`0oooo000B
0?ooo`0308Z:RP1VIVH0oooo0?l0ooooJ`3oool000L0oooo00P000000?oo
o`3oool08B4Q06IVIP3oool0^k^k04E5A@<0oooo00H0VYZJ014A4@3oool0
oooo09ZJVP1EEED50?ooo`04014A4@3Ogml0RXZ:08Z:RP<0oooo00`0EEEE
0000003Ogml0ADE50;^k^`3oool0kno_06IVIP0000004A4A08Z:RP3oool2
08Z:RP030?ooo`3_knl0IVIV0080000000<0MWIf0>o_k`3oool0o`3ooom6
0?ooo`001`3oool020000000oooo0<o?c`0Q8B404A4A0?ooo`2k^k/0ADE5
0`3oool00`0a<C404A4A0;^k^`020?ooo`03014A4@3_knl0oooo0080oooo
00<0ZZZZ05EEE@3oool00P2:RXX30?ooo`060000003_knl0oooo04E5A@2k
^k/0oooo0P1VIVH0103_knl0gmoO024Q8@2k^k/208Z:RP030?ooo`1VIVH0
IVIV0080kno_00<0EEEE08Z:RP3oool0o`3ooom60?ooo`001`3oool01@00
0000oooo08Z:RP1fMWH0<C4a0080^k^k00L0ADE50?ooo`3oool0gmoO014A
4@2:RXX0MWIf0080oooo0P1fMWH30;^k^`0304E5A@2ZZZX0oooo0080RXZ:
0`3oool020000000oooo0?ooo`15ADD0^k^k0?ooo`0A4A40kno_0P3oool0
1`2k^k/0gmoO08Z:RP2:RXX0oooo014A4@3_knl00P3oool20>o_kol0oooo
A`3oool000L0oooo00@000000?ooo`0a<C40ZZZZ0P1fMWH0202k^k/0ADE5
0?ooo`3oool0RXZ:06IVIP3?cll08B4Q0P3oool01P3Ogml0000004E5A@15
ADD0<C4a024Q8@80oooo0P2:RXX30?ooo`070000003oool0oooo04E5A@2k
^k/0oooo000000050?ooo`80RXZ:00<0oooo0000000000000`0000000`15
ADD0oooo0?ooo`3o0?ooodD0oooo00070?ooo`080000003_knl04A4A0?oo
o`3?cll0<C4a0;^k^`15ADD20?ooo`05034a<@2ZZZX0oooo024Q8@3?cll0
0P3oool01@15ADD0gmoO0?ooo`2JVYX0RXZ:0080oooo00<0RXZ:06IVIP3o
ool00P3oool020000000oooo0?ooo`15ADD0^k^k0?ooo`0Q8B40gmoO0P3o
ool01`2JVYX0kno_08Z:RP2:RXX0oooo024Q8@3Ogml00P3oool00`2JVYX0
IVIV0?ooo`3o0?ooodH0oooo00070?ooo`030000002JVYX0EEEE0080oooo
00H04A4A09ZJVP15ADD0oooo0=oOg`0Q8B420?ooo`0907IfMP2:RXX0oooo
0?ooo`2JVYX0MWIf0?ooo`0a<C40gmoO0080oooo0140RXZ:014A4@2ZZZX0
ZZZZ09ZJVP000000RXZ:0?ooo`15ADD0^k^k0?ooo`2:RXX0<C4a0:ZZZP2:
RXX04A4A0>o_k`0208Z:RP070?ooo`2:RXX0<C4a0:ZZZP2JVYX04A4A0;^k
^`3o0?ooodL0oooo00070?ooo`030000001VIVH0VYZJ0080oooo0P1VIVH0
1015ADD0oooo0<o?c`2ZZZX20?ooo`030=oOg`2JVYX0oooo0080oooo00<0
<C4a0=oOg`1EEED00`3oool02P2k^k/0ZZZZ05EEE@1VIVH0VYZJ0000002:
RXX0oooo09ZJVP3Ogml20?ooo`0508Z:RP15ADD0EEEE0<o?c`3oool00P2:
RXX20?ooo`0409ZJVP15ADD0EEEE0;^k^ol0ooooB03oool000L0oooo00<0
0000014A4@3_knl00P3oool00`2ZZZX04A4A04E5A@0:0?ooo`0307IfMP0a
<C40ZZZZ00P0oooo00D000000?ooo`3oool0clo?0>o_k`070?ooo`80RXZ:
o`3ooom>0?ooo`001`3oool00`15ADD0IVIV0?ooo`020?ooo`030>o_k`15
ADD0MWIf00X0oooo00<0gmoO05EEE@3oool0203oool01@2ZZZX0oooo0?oo
o`1fMWH0clo?00L0oooo0P2JVY[o0?ooodh0oooo003o0?oooh00oooo003o
0?oooh00oooo003o0?oooh00oooo003o0?oooh00oooo003o0?oooh00oooo
003o0?oooh00oooo003o0?oooh00oooo003o0?oooh00oooo003o0?oooh00
oooo0000\
\>"], "Graphics",
      GeneratedCell->False,
      CellAutoOverwrite->False,
      ImageSize->{254.313, 193.188},
      ImageMargins->{{0, 0}, {0, 0}},
      ImageRegion->{{0, 1}, {0, 1}},
      CellTags->"Creating Custom Modules"]], "Figure",
  TaggingRules:>{"OriginalImageSize" -> {383.0, 291.0}}],

Cell[TextData[{
  "Install the module in any of the following locations and restart ",
  StyleBox["Publicon",
    FontSlant->"Italic"],
  " to take it for a spin."
}], "Text"],

Cell[TextData[{
  StyleBox["OS X:", "TB"],
  "\n",
  StyleBox["Publicon 1.0.app/AddOns/Autoload/\nLibrary/Publicon/Autoload/\n\
~/Library/Publicon/Autoload/", "MR"]
}], "Text"],

Cell[TextData[{
  StyleBox["Windows:", "TB"],
  "\n",
  StyleBox["C:\\Program Files\\\\Wolfram Research\\Publicon \
1.0\\AddOns\\Autoload\\\nC:\\Documents and Settings\\All Users\\Application \
Data\\Publicon 1.0\\Autoload\\\nC:\\Documents and \
Settings\\USERNAME\\Application Data\\Publicon 1.0\\Autoload\\", "MR"]
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 795}},
Editable->True,
ScreenStyleEnvironment->"Presentation",
Selectable->True,
WindowSize->{722, 631},
WindowMargins->{{11, Automatic}, {Automatic, 2}},
Visible->True,
DefaultFormatType->DefaultTextFormatType,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["PubliconDefault.nb Style Definitions", "Title"],
  
  Cell[CellGroupData[{
  
  Cell["CSS", "Section"],
  
  Cell["\<\

<style type=\"text/css\">
/* global */
body { margin: 10pt; background-color: #FFFFFF; }

math { text-align: left; }

p.NoSpace { margin: 0pt }

img { vertical-align: middle;  } 

/* Frontmatter */

.Title { margin: 36pt 2pt 4pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 24pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.Subtitle { margin: 6pt 2pt 4pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 16pt;
\tfont-weight: normal;
\tfont-style: italic;
\ttext-align: left;
\tcolor: #000080;
\t}

.Subsubtitle { margin: 6pt 2pt 2pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 13pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000080;
\t}

.Source,.DateReceived,.CopyrightYear
 { margin: 12pt 2pt 0pt 24pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 8pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.ISSN,.Volume,.Number,.FirstPage,.LastPage,.URL,
.DateRevisionRequested,.DateRevisionReceived,.DateAccepted,
.DatePublished, 
.CopyrightBy
 { margin: 0pt 2pt 0pt 24pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 8pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.Date { margin: 0pt 2pt 6pt 24pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 7pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000080;
\t}

.Author { margin: 24pt 2pt 0pt 24pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 10pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000080;
\t}

.AuthorTitle, .Institution { margin: 0pt 2pt 0pt 24pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000080;
\t}

.AuthorEmail { margin: 0pt 2pt 0pt 24pt;
\tfont-family: \"Courier New\", Courier;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #0000FF;
\t}

.AbstractSection { margin: 12pt 24pt 3pt 2pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 12pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.AbstractSubsection { margin: 0pt 24pt 3pt 2pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 9pt;
\tfont-weight: normal;
\tfont-style: italic;
\ttext-align: left;
\tcolor: #000000;
\t}

.Abstract { margin: 18pt 120pt 3pt 24pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 9pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000080;
\tborder-bottom: 1pt solid #000000;
\tborder-top: 1pt solid #000000;
\tpadding-bottom: 4pt;
\tpadding-top: 4pt;
\t}

.AbstractShortSection { margin: 7pt 2pt 2pt 2pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 10pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.AbstractShort { margin: 3pt 2pt 3pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.TOCTitle, .TOCIllustrations, .TOCTables, .LOASection,
.BookChapterTitle
\t{ margin: 36pt 2pt 24pt 2pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 21pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.TOCFrontmatterTitle, .TOCBackmatterTitle, .TOCFrontBackTitle
\t{ margin: 1pt 2pt 1pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 12pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.TOCSpacer { margin: 0pt 2pt 0pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.TOCSection { margin: 1pt 2pt 1pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 12pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.TOCSubsection, .TOCItem { margin: 1pt 2pt 1pt 24pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.TOCSubsubsection { margin: 1pt 2pt 1pt 48pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.LOAItem { margin: 4pt 2pt 4pt 2pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.LOAAbbreviation { font-weight: bold; }
\t
/* keyboard shortcuts styles */

h3 { margin: 24pt 2pt 4pt 2pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 14pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\tborder-bottom: 1pt solid #000000;
\tpadding-bottom: 4pt;
\t}

h4 { margin: 16pt 2pt 3pt 2pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 12pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

h5 { margin: 9pt 2pt 3pt 2pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 10pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #333333;
\t}

.Subsubsubsection { margin: 6pt 2pt 3pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #333333;
\t}

.SectionAlt { margin: 24pt 2pt 3pt 2pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 12pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\tborder: none;
\t}

.SubsectionAlt { margin: 12pt 2pt 3pt 2pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 10pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.SubsubsectionAlt { margin: 6pt 2pt 3pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #4C4C4C;
\t}

.SubsubsubsectionAlt { margin: 6pt 2pt 3pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: italic;
\ttext-align: left;
\tcolor: #4C4C4C;
\t}

.Text, .TextContinuation, .TextNoIndent, .Acknowledgments, .Appendix 
\t{ margin: 5pt 2pt 3pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: justify;
\tcolor: #000000;
\t}

/* Itemized Lists */

li { margin: 2pt 12pt 1pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size:10pt;
\t}

ol ol { list-style: lower-alpha; }

ol ol ol { list-style: lower-roman; }

.Item1Paragraph, .Item2Paragraph, .Item3Paragraph 
{ margin-top: 3pt; margin-bottom: 3pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

/* Illustrations */

.Figure, .Picture, .Illustration, .Graphics 
\t{ margin: 7pt 2pt 0pt 2pt; text-align: left; }

.FigureCaption, .PictureCaption, .IllustrationCaption,
.ProgramCaption, .Caption 
\t{ margin: 2pt 2pt 6pt 2pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 7pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.FigureCaptionLabel, .PictureCaptionLabel, 
.IllustrationCaptionLabel,
.ProgramCaptionLabel, .CaptionLabel,
.FigureNumber, .PictureNumber, .IllustrationNumber,
.ProgramNumber, .CaptionNumber,
.TableTitleLabel, .TableNoteLabel
\t{ font-weight: bold; }

.FigureText, .PictureText, .IllustrationText, .ProgramText
\t{ margin: 0pt 2pt 12pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 7pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.Program { margin: 7pt 2pt 2pt 2pt;
\tfont-family: \"Courier New\", Courier;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\tborder-bottom: 1pt solid #000000;
\tborder-top: 1pt solid #000000;
\tpadding-bottom: 4pt;
\tpadding-top: 4pt;
\t}

.SupplementalCaptionLabel { margin: 7pt 2pt 1pt 2pt;
\tborder-bottom: 1px solid black;
\tfont-family: Helvetica, Arial;
\tfont-size: 9pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.SupplementalCaption { margin: 4pt 2pt 8pt 2pt;
\tborder-bottom: 1px solid black;
\tfont-family: Helvetica, Arial;
\tfont-size: 9pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.SupplementalText { margin: 4pt 2pt 7pt 2pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 9pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.FigureFile, .Supplemental { margin: 2pt 2pt 7pt 2pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 9pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\tbackground-color:#C6C6EC;
\tpadding:3pt;
\t}

.TableTitle { margin: 7pt 2pt 1pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

table { margin: 1pt 2pt 1pt 2pt; }

table.TableMasterGrid { width:100%; 
\tmargin: 3pt 2pt 7pt 2pt;
\tborder-bottom: 1pt solid #000000;
\tborder-top: 2pt solid #000000;
\t}

table.TableMasterGrid td.TableLineElement {
\tborder-bottom: solid 1pt #000000;
\tfont-size: 1pt;
\tpadding: 0pt;
\tmargin:0pt;
\tline-height: 0pt;
\t}

.TableNote { margin: -3pt 2pt 7pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 9pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #4C4C4C;
\t}

.TableColumnHead, .TableSpanHead {
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: italic; 
\tcolor: #000000;
\t}

.TableText, .TableSpanText {
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal; 
\tcolor: #000000;
\t}

.Extract { margin: 8pt 12pt 8pt 24pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 9pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

/* mathematics */

.Equation, .EquationWide, 
.EquationNumbered, .EquationWideNumbered, 
.AppendixEquation,
.EquationGroupAlignedNumbered, .EquationGroupAligned,
.EquationGroupNumbered, .EquationGroup,
.SubequationNumbered, .SubequationAlignedNumbered, {
\tmargin: 7pt 2pt 7pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal; 
\ttext-align: left; 
\tfont-style: normal; 
\tcolor: #000000;
\t}

table.EquationNumbered {
\twidth: 100%;
\t}

table.AppendixEquation {
\twidth: 100%;
\t}

table.AppendixEquation td.AppendixEquationLabel {
\twidth: 4%;
\tfont-size: 10pt;
\tpadding: 0pt;
\t}

table.EquationNumbered td.EquationNumberedLabel {
\twidth: 4%;
\tfont-size: 10pt;
\tpadding: 0pt;
\t}

table.EquationGroup,
table.EquationGroupNumbered,
table.SubequationNumbered {
\twidth: 100%;
\tpadding-top: 0pt;
\tpadding-bottom: 0pt;
\tmargin-top: 0pt;
\tmargin-bottom: 0pt;
\t}

p.EquationGroup {
\tpadding-left: 4.5%;
\t}

table.EquationGroupNumbered td.EquationGroupNumberedLabel {
\twidth: 4%;
\tfont-size: 10pt;
\tpadding: 0pt;
\t}

table.SubequationNumbered td.SubequationNumberedLabel {
\twidth: 4%;
\tfont-size: 10pt;
\tpadding: 0pt;
\t}

.EquationGroupAligned table {
\twidth: 100%;
\tpadding-top: 0pt;
\tpadding-bottom: 0pt;
\tpadding-left: 4.5%;
\tmargin-top: 0pt;
\tmargin-bottom: 0pt;
\t}

.EquationGroupAligned table td,
.EquationGroupAligned table th {
\tpadding: 0pt;
\t}

table.EquationGroupAlignedNumbered {
\twidth: 100%;
\tpadding-top: 0pt;
\tpadding-bottom: 0pt;
\tmargin-top: 0pt;
\tmargin-bottom: 0pt;
\t}

table.SubequationAlignedNumbered {
\twidth: 100%;
\tpadding-top: 0pt;
\tpadding-bottom: 0pt;
\tmargin-top: 0pt;
\tmargin-bottom: 0pt;
\t}

table.EquationGroupAlignedNumbered td,
table.EquationGroupAlignedNumbered th,
table.SubequationAlignedNumbered td,
table.SubequationAlignedNumbered th {
\tpadding: 0pt;
\t}

table.EquationGroupAlignedNumbered td.EquationGroupAlignedNumberedLabel {
\twidth: 4%;
\tfont-size: 10pt;
\tpadding: 0pt;
\t}

table.SubequationAlignedNumbered td.SubequationAlignedNumberedLabel {
\twidth: 4%;
\tfont-size: 10pt;
\tpadding: 0pt;
\t}

.Theorem,.Corollary,.Lemma,.Proposition,.Conjecture
\t{ margin: 7pt 2pt 7pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: italic;
\ttext-align: left;
\tcolor: #000000;
\ttext-align: justify;
\t}

.Definition,.Axiom,.Example,.Remark,.Proof
\t{ margin: 7pt 2pt 7pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\ttext-align: justify;
\t}

.TheoremLabel,.CorollaryLabel,.LemmaLabel,.PropositionLabel,
.ConjectureLabel,.DefinitionLabel,.AxiomLabel,.ExampleLabel
\t{
\tfont-weight: bold;
\tfont-style: normal;
\t}

.RemarkLabel,.ProofLabel, .CaseLabel, .ProblemsLabel
\t{
\tfont-weight: normal;
\tfont-style: italic;
\t}

.ProofSection, .CaseSection, .ProblemsSection
\t{ margin: 7pt 2pt 7pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

/* Cross-References */

.XRef { color: #000000; text-decoration:none }
.DkBlue { color: #000080; }

/* Backmatter */

.Reference, .Endnote { margin: 1pt 2pt 1pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

td.EndnoteLabel { width: 32px; }
td.ReferenceLabel { width: 32px; }

.RefReviewVolume, .RefJournalVolume
\t{ font-weight: bold; font-style: normal; }

.RefBookTitle, .RefJournalTitle, .RefSchoolDept
{ font-weight: normal; font-style: italic; }

.IndexEntry { 
\tmargin: 0pt 2pt 2pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 9pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.IndexSubentry { 
\tmargin: 0pt 2pt 2pt 18pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 9pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.IndexSubsubentry { 
\tmargin: 0pt 2pt 2pt 30pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 9pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.IndexNote { 
\tmargin: 0pt 2pt 2pt 2pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 9pt;
\tfont-weight: normal;
\tfont-style: italic;
\ttext-align: left;
\tcolor: #000000;
\t}

/* Book Elements */

.BookPartLabel { 
\tmargin: 7pt 48pt 7pt 48pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 24pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: center;
\tcolor: #000000;
\t}

.BookPartTitle { 
\tmargin: 7pt 48pt 12pt 48pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 30pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: center;
\tcolor: #000000;
\t}

.BookPartSubtitle { 
\tmargin: 7pt 48pt 12pt 48pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 21pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: center;
\tcolor: #000000;
\t}

.BookPartSubsubtitle { 
\tmargin: 7pt 48pt 12pt 48pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 16pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: center;
\tcolor: #000000;
\t}

.BookPartText { 
\tmargin: 7pt 60pt 7pt 60pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\ttext-indent: 10pt;
\tcolor: #000000;
\t}

.BookPartTextNoIndent { 
\tmargin: 7pt 60pt 7pt 60pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

.BookChapterLabel { 
\tmargin: 72pt 2pt 4pt 2pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 11pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: center;
\tcolor: #000000;
\t}

.BookChapterNumber { 
\tfont-family: Helvetica, Arial;
\tfont-size: 17pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: center;
\tcolor: #000000;
\t}

\t/* BookChapterTitle is in frontmatter 
\t   section, with TOCTitle */

.Epigraph { margin: 0pt 48pt 0pt 48pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: italic;
\ttext-align: left;
\tcolor: #000000;
\t}

.EpigraphAuthor { margin: 10pt 48pt 21pt 48pt;
\tfont-family: \"Times New Roman\", Times;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}

/* miscellaneous */

.PageBreak { page-break-before:always; }

/* Common Inline */

.RM  { font-style: normal; font-weight: normal }
.BF  { font-style: normal; font-weight: bold }
.IT  { font-style: italic; font-weight: normal }
.TR  { font-family: \"Times New Roman\", Times; font-style: normal; \
font-weight: normal }
.TI  { font-family: \"Times New Roman\", Times; font-style: italic; \
font-weight: normal }
.TB  { font-family: \"Times New Roman\", Times; font-style: normal; \
font-weight: bold }
.TBI { font-family: \"Times New Roman\", Times; font-style: italic; \
font-weight: bold }
.MR  { font-family: \"Courier New\", Courier; font-style: normal; \
font-weight: normal }
.MO  { font-family: \"Courier New\", Courier; font-style: italic; \
font-weight: normal }
.MB  { font-family: \"Courier New\", Courier; font-style: normal; \
font-weight: normal }
.MBO { font-family: \"Courier New\", Courier; font-style: italic; \
font-weight: bold }
.SR  { font-family: Helvetica, Arial; font-style: normal; font-weight: normal \
}
.SO  { font-family: Helvetica, Arial; font-style: italic; font-weight: normal \
}
.SB  { font-family: Helvetica, Arial; font-style: normal; font-weight: bold }
.SBO { font-family: Helvetica, Arial; font-style: italic; font-weight: bold }

/* conformance */

.Input { margin: 7pt 12pt 7pt 48pt;
\tfont-family: Courier New, Courier;
\tfont-size: 10pt;
\tfont-weight: bold;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}
.Output { margin: 7pt 12pt 7pt 48pt;
\tfont-family: Courier New, Courier;
\tfont-size: 10pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #000000;
\t}
.CellLabel { margin: 7pt 2pt 2pt 24pt;
\tfont-family: Helvetica, Arial;
\tfont-size: 7pt;
\tfont-weight: normal;
\tfont-style: normal;
\ttext-align: left;
\tcolor: #0000ff;
\t}

</style>\
\>", "Text",
    CellTags->"CSSDefinitions"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["TeX Configuration", "Section"],
  
  Cell["\<\

\\documentclass{article}

\\usepackage{amssymb,amscd,amsmath,graphicx,verbatim}
\\usepackage[dvips]{hyperref}
\\usepackage[TS1,OT1,T1]{fontenc}
\
\>", "Text",
    ShowCellTags->True,
    CellTags->"TeXPreamble"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Screen"],
    PageWidth->WindowWidth,
    LineSpacing->{1, 3},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "NumberedHeads"],
    PageWidth->WindowWidth,
    LineSpacing->{1, 3},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True},
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellBracket->False,
    Hyphenation->True,
    LineSpacing->{1, 2},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "NumberedHeadsPrintout"],
    PageWidth->PaperWidth,
    ShowCellBracket->False,
    Hyphenation->True,
    LineSpacing->{1, 2},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellElementSpacings->{"ClosedCellHeight"->9},
    CellFrameLabelMargins->6,
    DefaultNewCellStyle->"Text",
    InputAutoReplacements->{"TeX"->FormBox[ 
            StyleBox[ 
              RowBox[ {"T", 
                AdjustmentBox[ 
                "E", BoxMargins -> {{-0.29999999999999999, 0}, {0, 0}}, 
                  BoxBaselineShift -> 0.5], "X"}], SingleLetterItalics -> 
              False], TraditionalForm], "LaTeX"->FormBox[ 
            StyleBox[ 
              RowBox[ {"L", 
                StyleBox[ 
                  AdjustmentBox[ 
                  "A", BoxMargins -> {{-0.5, -0.29999999999999999}, {0, 0}}, 
                    BoxBaselineShift -> -0.40000000000000002], FontSize -> 
                  Smaller], "T", 
                AdjustmentBox[ 
                "E", BoxMargins -> {{-0.29999999999999999, 0}, {0, 0}}, 
                  BoxBaselineShift -> 0.5], "X"}], SingleLetterItalics -> 
              False], TraditionalForm], "mma"->"Mathematica", 
        "Mma"->"Mathematica", "MMA"->"Mathematica", "--"->"\[Dash]", 
        "---"->"\[LongDash]", " \""->" \[OpenCurlyDoubleQuote]", 
        "\"'"->"\[OpenCurlyDoubleQuote]\[OpenCurlyQuote]", 
        "'\""->"\[CloseCurlyQuote]\[CloseCurlyDoubleQuote]", 
        ".\""->".\[CloseCurlyDoubleQuote]", 
        ",\""->",\[CloseCurlyDoubleQuote]", 
        "?\""->"?\[CloseCurlyDoubleQuote]", 
        ";\""->";\[CloseCurlyDoubleQuote]", 
        ":\""->":\[CloseCurlyDoubleQuote]", 
        "!\""->"!\[CloseCurlyDoubleQuote]", " '"->" \[OpenCurlyQuote]", 
        "',"->"\[CloseCurlyQuote],", "'."->"\[CloseCurlyQuote].", 
        "';"->"\[CloseCurlyQuote];", "':"->"\[CloseCurlyQuote]:", 
        "'!"->"\[CloseCurlyQuote]!", ",\""->",\[CloseCurlyQuote]", 
        ".'"->".\[CloseCurlyQuote]", "?'"->"?\[CloseCurlyQuote]", 
        ";'"->";\[CloseCurlyQuote]", ":'"->":\[CloseCurlyQuote]", 
        "!'"->"!\[CloseCurlyQuote]", ". '"->". \[OpenCurlyQuote]", 
        ", '"->", \[OpenCurlyQuote]", "? '"->"? \[OpenCurlyQuote]", 
        "; '"->"; \[OpenCurlyQuote]", ": '"->": \[OpenCurlyQuote]", 
        "! '"->"! \[OpenCurlyQuote]", ", \""->", \[OpenCurlyDoubleQuote]", 
        ". \""->". \[OpenCurlyDoubleQuote]", 
        "? \""->"? \[OpenCurlyDoubleQuote]", 
        "; \""->"; \[OpenCurlyDoubleQuote]", 
        ": \""->": \[OpenCurlyDoubleQuote]", 
        "! \""->"! \[OpenCurlyDoubleQuote]", 
        "\","->"\[CloseCurlyDoubleQuote],", 
        "\"."->"\[CloseCurlyDoubleQuote].", 
        "\";"->"\[CloseCurlyDoubleQuote];", 
        "\":"->"\[CloseCurlyDoubleQuote]:", 
        "\"!"->"\[CloseCurlyDoubleQuote]!", "'a "->"\[CloseCurlyQuote]a ", 
        "'d "->"\[CloseCurlyQuote]d ", "'l "->"\[CloseCurlyQuote]l ", 
        "'ll "->"\[CloseCurlyQuote]ll ", "'m "->"\[CloseCurlyQuote]m ", 
        "'o "->"\[CloseCurlyQuote]o ", "'ol "->"\[CloseCurlyQuote]ol ", 
        "'Ol "->"\[CloseCurlyQuote]Ol ", "'r "->"\[CloseCurlyQuote]r ", 
        "'s "->"\[CloseCurlyQuote]s ", "'t "->"\[CloseCurlyQuote]t ", 
        "'ve "->"\[CloseCurlyQuote]ve ", "'er "->"\[CloseCurlyQuote]er ", 
        "'re "->"\[CloseCurlyQuote]re ", "'y "->"\[CloseCurlyQuote]y ", 
        "'z "->"\[CloseCurlyQuote]z ", "'x "->"\[CloseCurlyQuote]x ", 
        "\" "->"\[CloseCurlyDoubleQuote] ", "\"\""->"\[OpenCurlyDoubleQuote]",
         "''"->"\[OpenCurlyQuote]", "'tis "->"\[CloseCurlyQuote]tis ", 
        "'ts "->"\[CloseCurlyQuote]ts ", "' "->"\[CloseCurlyQuote] ", 
        "'am "->"\[CloseCurlyQuote]am ", 
        ",'\" "->",\[CloseCurlyQuote]\[CloseCurlyDoubleQuote]", 
        ".'\""->".\[CloseCurlyQuote]\[CloseCurlyDoubleQuote]", 
        "?'\""->"?\[CloseCurlyQuote]\[CloseCurlyDoubleQuote]", 
        ";'\""->";\[CloseCurlyQuote]\[CloseCurlyDoubleQuote]", 
        ":'\""->":\[CloseCurlyQuote]\[CloseCurlyDoubleQuote]", 
        "!'\""->"!\[CloseCurlyQuote]\[CloseCurlyDoubleQuote]", 
        "'\","->"\[CloseCurlyQuote]\[CloseCurlyDoubleQuote],", 
        "'\"."->"\[CloseCurlyQuote]\[CloseCurlyDoubleQuote].", 
        "'\"?"->"\[CloseCurlyQuote]\[CloseCurlyDoubleQuote]?", 
        "'\";"->"\[CloseCurlyQuote]\[CloseCurlyDoubleQuote];", 
        "'\":"->"\[CloseCurlyQuote]\[CloseCurlyDoubleQuote]:", 
        "'\"!"->"\[CloseCurlyQuote]\[CloseCurlyDoubleQuote]!"},
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    SpanMaxSize->Infinity,
    SpanCharacterRounding->Round,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Frontmatter", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FrontmatterGroup"],
    CellMargins->{{12, 12}, {7, 24}},
    CellGroupingRules->{"SectionGrouping", 5},
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}, "HTML" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["FrontmatterGroup", "NumberedHeads"]],
  
  Cell[StyleData["FrontmatterGroup", "Presentation"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["FrontmatterGroup", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["FrontmatterGroup", "NumberedHeadsPrintout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Title", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, 12}, {4, 36}},
    CellGroupingRules->{"TitleGrouping", 10},
    ConversionRules:>{"TeX" -> {"\n\\title{", "}"}},
    PageBreakBelow->False,
    LineSpacing->{1, 2},
    StyleMenuListing->None,
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "NumberedHeads"]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{23, 12}, {6, 54}},
    FontSize->45],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 2}, {3, 30}},
    FontSize->24],
  
  Cell[StyleData["Title", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {3, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, 12}, {4, 6}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->20,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Subtitle", "NumberedHeads"]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{23, 12}, {6, 9}},
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 2}, {3, 5}},
    FontSize->16,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Subtitle", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {3, 5}},
    FontSize->16,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, 12}, {2, 6}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->15,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Subsubtitle", "NumberedHeads"]],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{23, 12}, {3, 9}},
    FontSize->23],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 2}, {1, 5}},
    FontSize->13,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Subsubtitle", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 5}},
    FontSize->13,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Title Inline Cells", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TitleLabel"],
    StyleMenuListing->None],
  
  Cell[StyleData["TitleLabel", "NumberedHeads"]],
  
  Cell[StyleData["TitleLabel", "Presentation"]],
  
  Cell[StyleData["TitleLabel", "Printout"]],
  
  Cell[StyleData["TitleLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubtitleLabel"],
    StyleMenuListing->None],
  
  Cell[StyleData["SubtitleLabel", "NumberedHeads"]],
  
  Cell[StyleData["SubtitleLabel", "Presentation"]],
  
  Cell[StyleData["SubtitleLabel", "Printout"]],
  
  Cell[StyleData["SubtitleLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubtitleLabel"],
    StyleMenuListing->None],
  
  Cell[StyleData["SubsubtitleLabel", "NumberedHeads"]],
  
  Cell[StyleData["SubsubtitleLabel", "Presentation"]],
  
  Cell[StyleData["SubsubtitleLabel", "Printout"]],
  
  Cell[StyleData["SubsubtitleLabel", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Copyrights", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CopyrightLine"],
    StyleMenuListing->None],
  
  Cell[StyleData["CopyrightLine", "NumberedHeads"]],
  
  Cell[StyleData["CopyrightLine", "Presentation"]],
  
  Cell[StyleData["CopyrightLine", "Printout"]],
  
  Cell[StyleData["CopyrightLine", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CopyrightYear"],
    CellMargins->{{36, 10}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 20},
    ConversionRules:>{"HTML" -> {
      "<p class=\"CopyrightYear\"><span class=\"DkBlue\">Copyright:</span> ", 
      "</p>"}},
    CellFrameLabels->{{
      Cell[ "Copyright: ", FontColor -> RGBColor[ 
            0.20000000000000001, 0.29999999999999999, 0.5]], Inherited}, {
        Inherited, Inherited}},
    CellFrameLabelMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["CopyrightYear", "NumberedHeads"]],
  
  Cell[StyleData["CopyrightYear", "Presentation"],
    CellMargins->{{47, 10}, {0, 18}},
    FontSize->14],
  
  Cell[StyleData["CopyrightYear", "Printout"],
    CellMargins->{{24, 2}, {0, 10}},
    FontSize->8],
  
  Cell[StyleData["CopyrightYear", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 10}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CopyrightBy"],
    CellMargins->{{36, 10}, {0, 0}},
    ConversionRules:>{"HTML" -> {
      "<p class=\"CopyrightBy\"><span class=\"DkBlue\">...by:</span> ", 
      "</p>"}},
    CellFrameLabels->{{
      Cell[ "...by: ", FontColor -> RGBColor[ 
            0.20000000000000001, 0.29999999999999999, 0.5]], Inherited}, {
        Inherited, Inherited}},
    CellFrameLabelMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["CopyrightBy", "NumberedHeads"]],
  
  Cell[StyleData["CopyrightBy", "Presentation"],
    CellMargins->{{47, 10}, {0, 0}},
    FontSize->14],
  
  Cell[StyleData["CopyrightBy", "Printout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8],
  
  Cell[StyleData["CopyrightBy", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Date", "Subsection",
    StyleMenuListing->None],
  
  Cell[StyleData["Day"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>(EditDate[ #]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Day",
    Active->True}],
  
  Cell[StyleData["Month"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>(EditDate[ #]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Month",
    Active->True}],
  
  Cell[StyleData["Year"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>(EditDate[ #]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Year",
    Active->True}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Date"],
    CellMargins->{{36, 12}, {6, 0}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], "\n\\date{\\today}"}},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Date", "NumberedHeads"]],
  
  Cell[StyleData["Date", "Presentation"],
    CellMargins->{{47, 12}, {9, 0}},
    FontSize->14],
  
  Cell[StyleData["Date", "Printout"],
    CellMargins->{{24, 2}, {5, 0}},
    LineSpacing->{1, 1},
    FontSize->7,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Date", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {5, 0}},
    LineSpacing->{1, 1},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Author", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{36, 12}, {0, 24}},
    CellGroupingRules->"InputGrouping",
    ConversionRules:>{"TeX" -> {"\n\\author{", "}"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Author", "NumberedHeads"]],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{47, 12}, {0, 36}},
    FontSize->18],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{24, 2}, {0, 20}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Author", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 20}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[StyleData["AuthorData"],
    Selectable->False,
    ScriptMinSize->8,
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AuthorGroup"],
    StyleMenuListing->None],
  
  Cell[StyleData["AuthorGroup", "NumberedHeads"]],
  
  Cell[StyleData["AuthorGroup", "Presentation"]],
  
  Cell[StyleData["AuthorGroup", "Printout"]],
  
  Cell[StyleData["AuthorGroup", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[StyleData["AuthorFirstName"],
    StyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>(FillInAuthorForm[ #]&),
    ButtonEvaluator->Automatic,
    Active->True}],
  
  Cell[StyleData["AuthorMiddleName"],
    StyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>(FillInAuthorForm[ #]&),
    ButtonEvaluator->Automatic,
    Active->True}],
  
  Cell[StyleData["AuthorLastName"],
    StyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>(FillInAuthorForm[ #]&),
    ButtonEvaluator->Automatic,
    Active->True}],
  
  Cell[StyleData["AuthorNameSuffix"],
    StyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>(FillInAuthorForm[ #]&),
    ButtonEvaluator->Automatic,
    Active->True}],
  
  Cell[StyleData["AuthorAffiliation"],
    StyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>(FillInAuthorForm[ #]&),
    ButtonEvaluator->Automatic,
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AuthorTitle"],
    CellMargins->{{36, 12}, {0, 0}},
    CellGroupingRules->"OutputGrouping",
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontColor->RGBColor[0, 0, 0.500008],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["AuthorTitle", "NumberedHeads"]],
  
  Cell[StyleData["AuthorTitle", "Presentation"],
    CellMargins->{{47, 12}, {0, 0}},
    CellGroupingRules->"OutputGrouping",
    FontSize->17],
  
  Cell[StyleData["AuthorTitle", "Printout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["AuthorTitle", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AuthorEmail"],
    CellMargins->{{36, 12}, {0, 0}},
    CellGroupingRules->"OutputGrouping",
    ConversionRules:>{"HTML" -> {"<p class=\"AuthorEmail\"><a href=\"mailto:",
       JoinWords[ 
        ExtractElement[ 1, 1, 1][ #], "\">", 
        ExtractElement[ 1, 1, 1][ #]]&, "</a></p>"}},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontColor->RGBColor[0, 0, 1],
    ButtonBoxOptions->{ButtonFunction:>LinkToEmail[ ],
    ButtonEvaluator->Automatic,
    Active->True,
    ButtonFrame->"None",
    ButtonNote->"Email link"}],
  
  Cell[StyleData["AuthorEmail", "NumberedHeads"]],
  
  Cell[StyleData["AuthorEmail", "Presentation"],
    CellMargins->{{47, 12}, {0, 0}},
    CellGroupingRules->"OutputGrouping",
    FontSize->17],
  
  Cell[StyleData["AuthorEmail", "Printout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["AuthorEmail", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AuthorPhone"],
    StyleMenuListing->None],
  
  Cell[StyleData["AuthorPhone", "NumberedHeads"]],
  
  Cell[StyleData["AuthorPhone", "Presentation"]],
  
  Cell[StyleData["AuthorPhone", "Printout"]],
  
  Cell[StyleData["AuthorPhone", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AuthorAddress"],
    CellMargins->{{12, 12}, {0, 3}},
    CounterIncrements->"AuthorAddress",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["AuthorAddress", "NumberedHeads"],
    CellMargins->{{12, 12}, {0, 3}},
    CounterIncrements->"AuthorAddress",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["AuthorAddress", "Presentation"],
    CellMargins->{{12, 12}, {0, 3}},
    CounterIncrements->"AuthorAddress",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["AuthorAddress", "Printout"],
    CellMargins->{{2, 2}, {0, 2}},
    FontSize->10],
  
  Cell[StyleData["AuthorAddress", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {0, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AuthorCurrentAddress"],
    StyleMenuListing->None],
  
  Cell[StyleData["AuthorCurrentAddress", "NumberedHeads"]],
  
  Cell[StyleData["AuthorCurrentAddress", "Presentation"]],
  
  Cell[StyleData["AuthorCurrentAddress", "Printout"]],
  
  Cell[StyleData["AuthorCurrentAddress", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AuthorThanks"],
    StyleMenuListing->None],
  
  Cell[StyleData["AuthorThanks", "NumberedHeads"]],
  
  Cell[StyleData["AuthorThanks", "Presentation"]],
  
  Cell[StyleData["AuthorThanks", "Printout"]],
  
  Cell[StyleData["AuthorThanks", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AuthorHomepage"],
    StyleMenuListing->None],
  
  Cell[StyleData["AuthorHomepage", "NumberedHeads"]],
  
  Cell[StyleData["AuthorHomepage", "Presentation"]],
  
  Cell[StyleData["AuthorHomepage", "Printout"]],
  
  Cell[StyleData["AuthorHomepage", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AuthorPACS"],
    StyleMenuListing->None],
  
  Cell[StyleData["AuthorPACS", "NumberedHeads"]],
  
  Cell[StyleData["AuthorPACS", "Presentation"]],
  
  Cell[StyleData["AuthorPACS", "Printout"]],
  
  Cell[StyleData["AuthorPACS", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Institution", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Institution"],
    CellMargins->{{36, 12}, {0, 0}},
    CellGroupingRules->"OutputGrouping",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Institution", "NumberedHeads"]],
  
  Cell[StyleData["Institution", "Presentation"],
    CellMargins->{{47, 12}, {0, 0}},
    FontSize->17],
  
  Cell[StyleData["Institution", "Printout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Institution", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[StyleData["InstitutionNumber"],
    StyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>(FillInAuthorForm[ #]&),
    ButtonEvaluator->Automatic,
    Active->True}],
  
  Cell[StyleData["InstitutionName"],
    StyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>(FillInAuthorForm[ #]&),
    ButtonEvaluator->Automatic,
    Active->True}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AltInstitution"],
    Editable->False,
    StyleMenuListing->None],
  
  Cell[StyleData["AltInstitution", "NumberedHeads"]],
  
  Cell[StyleData["AltInstitution", "Presentation"]],
  
  Cell[StyleData["AltInstitution", "Printout"]],
  
  Cell[StyleData["AltInstitution", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Abstract", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AbstractSection"],
    CellMargins->{{12, 30}, {3, 12}},
    CellGroupingRules->{"SectionGrouping", 30},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["AbstractSection", "NumberedHeads"]],
  
  Cell[StyleData["AbstractSection", "Presentation"],
    CellMargins->{{23, 30}, {5, 18}},
    FontSize->21],
  
  Cell[StyleData["AbstractSection", "Printout"],
    CellMargins->{{2, 24}, {2, 10}},
    StyleMenuListing->None,
    FontSize->12],
  
  Cell[StyleData["AbstractSection", "NumberedHeadsPrintout"],
    CellMargins->{{2, 24}, {2, 10}},
    StyleMenuListing->None,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AbstractSubsection"],
    CellMargins->{{12, 30}, {3, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["AbstractSubsection", "NumberedHeads"]],
  
  Cell[StyleData["AbstractSubsection", "Presentation"],
    CellMargins->{{23, 30}, {5, 0}},
    FontSize->17],
  
  Cell[StyleData["AbstractSubsection", "Printout"],
    CellMargins->{{2, 24}, {2, 0}},
    FontSize->9],
  
  Cell[StyleData["AbstractSubsection", "NumberedHeadsPrintout"],
    CellMargins->{{2, 24}, {2, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellFrame->{{0, 0}, {0.25, 0.25}},
    CellMargins->{{36, 144}, {4, 18}},
    CellFrameMargins->5,
    TextAlignment->Left,
    LineSpacing->{1, 2},
    StyleMenuListing->None,
    FontSize->12,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Abstract", "NumberedHeads"],
    StyleMenuListing->None],
  
  Cell[StyleData["Abstract", "Presentation"],
    CellFrame->{{0, 0}, {1, 1}},
    CellMargins->{{47, 144}, {5, 27}},
    CellFrameMargins->8,
    StyleMenuListing->None,
    FontSize->18],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{24, 120}, {2, 16}},
    CellFrameMargins->3,
    StyleMenuListing->None,
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Abstract", "NumberedHeadsPrintout"],
    CellMargins->{{24, 120}, {2, 16}},
    CellFrameMargins->3,
    StyleMenuListing->None,
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Short Abstract", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AbstractShortSection"],
    CellMargins->{{12, 12}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 30},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["AbstractShortSection", "NumberedHeads"]],
  
  Cell[StyleData["AbstractShortSection", "Presentation"],
    CellMargins->{{23, 12}, {3, 11}},
    FontSize->18],
  
  Cell[StyleData["AbstractShortSection", "Printout"],
    CellMargins->{{2, 2}, {1, 5}},
    FontSize->10],
  
  Cell[StyleData["AbstractShortSection", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 5}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AbstractShort"],
    CellMargins->{{12, 12}, {4, 4}},
    StyleMenuListing->None],
  
  Cell[StyleData["AbstractShort", "NumberedHeads"]],
  
  Cell[StyleData["AbstractShort", "Presentation"],
    CellMargins->{{23, 12}, {6, 6}},
    FontSize->17],
  
  Cell[StyleData["AbstractShort", "Printout"],
    CellMargins->{{2, 2}, {3, 3}},
    FontSize->10],
  
  Cell[StyleData["AbstractShort", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {3, 3}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Cataloging Information", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UniqueIdentifier"],
    StyleMenuListing->None],
  
  Cell[StyleData["UniqueIdentifier", "NumberedHeads"]],
  
  Cell[StyleData["UniqueIdentifier", "Presentation"]],
  
  Cell[StyleData["UniqueIdentifier", "Printout"]],
  
  Cell[StyleData["UniqueIdentifier", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DocumentLabel"],
    StyleMenuListing->None],
  
  Cell[StyleData["DocumentLabel", "NumberedHeads"]],
  
  Cell[StyleData["DocumentLabel", "Presentation"]],
  
  Cell[StyleData["DocumentLabel", "Printout"]],
  
  Cell[StyleData["DocumentLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Source"],
    CellMargins->{{36, 10}, {0, 0}},
    ConversionRules:>{"HTML" -> {
      "<p class=\"Source\"><span class=\"DkBlue\">Source:</span> ", "</p>"}},
    CellFrameLabels->{{
      Cell[ "Source: ", FontColor -> RGBColor[ 
            0.20000000000000001, 0.29999999999999999, 0.5]], Inherited}, {
        Inherited, Inherited}},
    CellFrameLabelMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Source", "NumberedHeads"]],
  
  Cell[StyleData["Source", "Presentation"],
    CellMargins->{{47, 10}, {0, 0}},
    FontSize->14],
  
  Cell[StyleData["Source", "Printout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8],
  
  Cell[StyleData["Source", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ISSN"],
    CellMargins->{{36, 10}, {0, 0}},
    ConversionRules:>{"HTML" -> {
      "<p class=\"ISSN\"><span class=\"DkBlue\">ISSN:</span> ", "</p>"}},
    CellFrameLabels->{{
      Cell[ "ISSN: ", FontColor -> RGBColor[ 
            0.20000000000000001, 0.29999999999999999, 0.5]], Inherited}, {
        Inherited, Inherited}},
    CellFrameLabelMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["ISSN", "NumberedHeads"]],
  
  Cell[StyleData["ISSN", "Presentation"],
    CellMargins->{{47, 10}, {0, 0}},
    FontSize->14],
  
  Cell[StyleData["ISSN", "Printout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8],
  
  Cell[StyleData["ISSN", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Volume"],
    CellMargins->{{36, 10}, {0, 0}},
    ConversionRules:>{"HTML" -> {
      "<p class=\"Volume\"><span class=\"DkBlue\">Volume:</span> ", "</p>"}},
    CellFrameLabels->{{
      Cell[ "Volume: ", FontColor -> RGBColor[ 
            0.20000000000000001, 0.29999999999999999, 0.5]], Inherited}, {
        Inherited, Inherited}},
    CellFrameLabelMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Volume", "NumberedHeads"]],
  
  Cell[StyleData["Volume", "Presentation"],
    CellMargins->{{47, 10}, {0, 0}},
    FontSize->14],
  
  Cell[StyleData["Volume", "Printout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8],
  
  Cell[StyleData["Volume", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Number"],
    CellMargins->{{36, 10}, {0, 0}},
    ConversionRules:>{"HTML" -> {
      "<p class=\"Number\"><span class=\"DkBlue\">Number:</span> ", "</p>"}},
    CellFrameLabels->{{
      Cell[ "Issue: ", FontColor -> RGBColor[ 
            0.20000000000000001, 0.29999999999999999, 0.5]], Inherited}, {
        Inherited, Inherited}},
    CellFrameLabelMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Number", "NumberedHeads"]],
  
  Cell[StyleData["Number", "Presentation"],
    CellMargins->{{47, 10}, {0, 0}},
    FontSize->14],
  
  Cell[StyleData["Number", "Printout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8],
  
  Cell[StyleData["Number", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FirstPage"],
    CellMargins->{{36, 10}, {0, 0}},
    ConversionRules:>{"HTML" -> {
      "<p class=\"FirstPage\"><span class=\"DkBlue\">First page:</span> ", 
      "</p>"}},
    CellFrameLabels->{{
      Cell[ "First page: ", FontColor -> RGBColor[ 
            0.20000000000000001, 0.29999999999999999, 0.5]], Inherited}, {
        Inherited, Inherited}},
    CellFrameLabelMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["FirstPage", "NumberedHeads"]],
  
  Cell[StyleData["FirstPage", "Presentation"],
    CellMargins->{{47, 10}, {0, 0}},
    FontSize->14],
  
  Cell[StyleData["FirstPage", "Printout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8],
  
  Cell[StyleData["FirstPage", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LastPage"],
    CellMargins->{{36, 10}, {0, 0}},
    ConversionRules:>{"HTML" -> {
      "<p class=\"LastPage\"><span class=\"DkBlue\">Last page:</span> ", 
      "</p>"}},
    CellFrameLabels->{{
      Cell[ "Last page: ", FontColor -> RGBColor[ 
            0.20000000000000001, 0.29999999999999999, 0.5]], Inherited}, {
        Inherited, Inherited}},
    CellFrameLabelMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["LastPage", "NumberedHeads"]],
  
  Cell[StyleData["LastPage", "Presentation"],
    CellMargins->{{47, 10}, {0, 0}},
    FontSize->14],
  
  Cell[StyleData["LastPage", "Printout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8],
  
  Cell[StyleData["LastPage", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["URL"],
    CellMargins->{{36, 10}, {0, 0}},
    ConversionRules:>{"HTML" -> {
      "<p class=\"URL\"><span class=\"DkBlue\">URL:</span> ", "</p>"}},
    CellFrameLabels->{{
      Cell[ "URL: ", FontColor -> RGBColor[ 
            0.20000000000000001, 0.29999999999999999, 0.5]], Inherited}, {
        Inherited, Inherited}},
    CellFrameLabelMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["URL", "NumberedHeads"]],
  
  Cell[StyleData["URL", "Presentation"],
    CellMargins->{{47, 10}, {0, 0}},
    FontSize->14],
  
  Cell[StyleData["URL", "Printout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8],
  
  Cell[StyleData["URL", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DateReceived"],
    CellMargins->{{36, 10}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 20},
    ConversionRules:>{"HTML" -> {
      "<p class=\"DateReceived\"><span class=\"DkBlue\">Received:</span> ", 
      "</p>"}},
    CellFrameLabels->{{
      Cell[ "Received: ", FontColor -> RGBColor[ 
            0.20000000000000001, 0.29999999999999999, 0.5]], Inherited}, {
        Inherited, Inherited}},
    CellFrameLabelMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["DateReceived", "NumberedHeads"],
    CellMargins->{{54, 10}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 20},
    ConversionRules:>{"HTML" -> {"<p class=\"DateReceived\">Received: ", 
      "</p>"}},
    CellFrameLabels->{{
      Cell[ "Received: ", FontColor -> RGBColor[ 
            0.20000000000000001, 0.29999999999999999, 0.5]], Inherited}, {
        Inherited, Inherited}},
    CellFrameLabelMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["DateReceived", "Presentation"],
    CellMargins->{{47, 10}, {0, 18}},
    FontSize->14],
  
  Cell[StyleData["DateReceived", "Printout"],
    CellMargins->{{24, 2}, {0, 10}},
    FontSize->8],
  
  Cell[StyleData["DateReceived", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 10}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DateRevisionRequested"],
    CellMargins->{{36, 10}, {0, 0}},
    ConversionRules:>{"HTML" -> {
      "<p class=\"DateRevisionRequested\"><span class=\"DkBlue\">Revisions \
requested:</span> ", "</p>"}},
    CellFrameLabels->{{
      Cell[ "Revisions requested: ", FontColor -> RGBColor[ 
            0.20000000000000001, 0.29999999999999999, 0.5]], Inherited}, {
        Inherited, Inherited}},
    CellFrameLabelMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["DateRevisionRequested", "NumberedHeads"]],
  
  Cell[StyleData["DateRevisionRequested", "Presentation"],
    CellMargins->{{47, 10}, {0, 0}},
    FontSize->14],
  
  Cell[StyleData["DateRevisionRequested", "Printout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8],
  
  Cell[StyleData["DateRevisionRequested", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DateRevisionReceived"],
    CellMargins->{{36, 10}, {0, 0}},
    ConversionRules:>{"HTML" -> {
      "<p class=\"DateRevisionReceived\"><span \
class=\"DkBlue\">Revised:</span> ", "</p>"}},
    CellFrameLabels->{{
      Cell[ "Revised: ", FontColor -> RGBColor[ 
            0.20000000000000001, 0.29999999999999999, 0.5]], Inherited}, {
        Inherited, Inherited}},
    CellFrameLabelMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["DateRevisionReceived", "NumberedHeads"]],
  
  Cell[StyleData["DateRevisionReceived", "Presentation"],
    CellMargins->{{47, 10}, {0, 0}},
    FontSize->14],
  
  Cell[StyleData["DateRevisionReceived", "Printout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8],
  
  Cell[StyleData["DateRevisionReceived", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DateAccepted"],
    CellMargins->{{36, 10}, {0, 0}},
    ConversionRules:>{"HTML" -> {
      "<p class=\"DateAccepted\"><span class=\"DkBlue\">Accepted:</span> ", 
      "</p>"}},
    CellFrameLabels->{{
      Cell[ "Accepted: ", FontColor -> RGBColor[ 
            0.20000000000000001, 0.29999999999999999, 0.5]], Inherited}, {
        Inherited, Inherited}},
    CellFrameLabelMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["DateAccepted", "NumberedHeads"]],
  
  Cell[StyleData["DateAccepted", "Presentation"],
    CellMargins->{{47, 10}, {0, 0}},
    FontSize->14],
  
  Cell[StyleData["DateAccepted", "Printout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8],
  
  Cell[StyleData["DateAccepted", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DatePublished"],
    CellMargins->{{36, 10}, {0, 0}},
    ConversionRules:>{"HTML" -> {
      "<p class=\"DatePublished\"><span class=\"DkBlue\">Published:</span> ", 
      "</p>"}},
    CellFrameLabels->{{
      Cell[ "Published: ", FontColor -> RGBColor[ 
            0.20000000000000001, 0.29999999999999999, 0.5]], Inherited}, {
        Inherited, Inherited}},
    CellFrameLabelMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["DatePublished", "NumberedHeads"]],
  
  Cell[StyleData["DatePublished", "Presentation"],
    CellMargins->{{47, 10}, {0, 0}},
    FontSize->14],
  
  Cell[StyleData["DatePublished", "Printout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8],
  
  Cell[StyleData["DatePublished", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubjectClassification"],
    StyleMenuListing->None],
  
  Cell[StyleData["SubjectClassification", "NumberedHeads"]],
  
  Cell[StyleData["SubjectClassification", "Presentation"]],
  
  Cell[StyleData["SubjectClassification", "Printout"]],
  
  Cell[StyleData["SubjectClassification", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["KeywordGroup"],
    StyleMenuListing->None],
  
  Cell[StyleData["KeywordGroup", "NumberedHeads"]],
  
  Cell[StyleData["KeywordGroup", "Presentation"]],
  
  Cell[StyleData["KeywordGroup", "Printout"]],
  
  Cell[StyleData["KeywordGroup", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Keywords"],
    StyleMenuListing->None],
  
  Cell[StyleData["Keywords", "NumberedHeads"]],
  
  Cell[StyleData["Keywords", "Presentation"]],
  
  Cell[StyleData["Keywords", "Printout"]],
  
  Cell[StyleData["Keywords", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PreprintID"],
    StyleMenuListing->None],
  
  Cell[StyleData["PreprintID", "NumberedHeads"]],
  
  Cell[StyleData["PreprintID", "Presentation"]],
  
  Cell[StyleData["PreprintID", "Printout"]],
  
  Cell[StyleData["PreprintID", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Dedication", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Dedication"],
    CellMargins->{{12, 12}, {3, 5}},
    TextAlignment->Left,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Dedication", "NumberedHeads"]],
  
  Cell[StyleData["Dedication", "Presentation"],
    CellMargins->{{23, 12}, {5, 8}},
    FontSize->17],
  
  Cell[StyleData["Dedication", "Printout"],
    CellMargins->{{2, 2}, {1, 4}},
    LineSpacing->{1, 2},
    FontSize->10],
  
  Cell[StyleData["Dedication", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 4}},
    LineSpacing->{1, 2},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Table of Contents", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCTitle"],
    CellMargins->{{12, 12}, {24, 36}},
    CellGroupingRules->{"SectionGrouping", 20},
    PageBreakBelow->False,
    LineSpacing->{1, 2},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["TOCTitle", "NumberedHeads"]],
  
  Cell[StyleData["TOCTitle", "Printout"],
    CellMargins->{{2, 2}, {21, 30}},
    FontSize->21],
  
  Cell[StyleData["TOCTitle", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {21, 30}},
    FontSize->21]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCFrontmatterTitle"],
    CellMargins->{{12, 12}, {1, 1}},
    TabSpacings->43.7,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["TOCFrontmatterTitle", "NumberedHeads"]],
  
  Cell[StyleData["TOCFrontmatterTitle", "Printout"],
    CellMargins->{{2, 2}, {0, 0}},
    TabSpacings->48.2,
    FontSize->12],
  
  Cell[StyleData["TOCFrontmatterTitle", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {0, 0}},
    TabSpacings->48.2,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCBackmatterTitle"],
    CellMargins->{{12, 12}, {1, 1}},
    TabSpacings->43.7,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["TOCBackmatterTitle", "NumberedHeads"]],
  
  Cell[StyleData["TOCBackmatterTitle", "Printout"],
    CellMargins->{{2, 2}, {0, 0}},
    TabSpacings->48.2,
    FontSize->12],
  
  Cell[StyleData["TOCBackmatterTitle", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {0, 0}},
    TabSpacings->48.2,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCFrontBackTitle"],
    CellMargins->{{12, 12}, {1, 1}},
    TabSpacings->43.7,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["TOCFrontBackTitle", "NumberedHeads"]],
  
  Cell[StyleData["TOCFrontBackTitle", "Printout"],
    CellMargins->{{2, 2}, {0, 0}},
    TabSpacings->48.2,
    FontSize->12],
  
  Cell[StyleData["TOCFrontBackTitle", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {0, 0}},
    TabSpacings->48.2,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSpacer"],
    CellMargins->{{12, 12}, {0, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["TOCSpacer", "NumberedHeads"],
    CellMargins->{{12, 12}, {0, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["TOCSpacer", "Printout"],
    CellMargins->{{2, 2}, {0, 0}}],
  
  Cell[StyleData["TOCSpacer", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {0, 0}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSection"],
    CellMargins->{{12, 12}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 40},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "TOCSection"]}], "TOCSectionLabel", CellBaseline -> 
            Baseline], Inherited}, {Inherited, Inherited}},
    TabSpacings->41,
    CounterIncrements->"TOCSection",
    CounterAssignments->{{"TOCSubsection", 0}},
    StyleMenuListing->None,
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["TOCSection", "NumberedHeads"]],
  
  Cell[StyleData["TOCSection", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    PageBreakBelow->False,
    TabSpacings->45.6,
    FontSize->12],
  
  Cell[StyleData["TOCSection", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    PageBreakBelow->False,
    TabSpacings->45.6,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsection"],
    CellMargins->{{36, 12}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 50},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "TOCSection"], ".", 
              CounterBox[ "TOCSubsection"]}], "TOCSubsectionLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}},
    TabSpacings->36.8,
    CounterIncrements->"TOCSubsection",
    CounterAssignments->{{"TOCSubsubsection", 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["TOCSubsection", "NumberedHeads"]],
  
  Cell[StyleData["TOCSubsection", "Printout"],
    CellMargins->{{24, 2}, {1, 1}},
    PageBreakBelow->False,
    TabSpacings->41.3,
    FontSize->10],
  
  Cell[StyleData["TOCSubsection", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {1, 1}},
    PageBreakBelow->False,
    TabSpacings->41.3,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsubsection"],
    CellMargins->{{60, 12}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 60},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "TOCSection"], ".", 
              CounterBox[ "TOCSubsection"], ".", 
              CounterBox[ "TOCSubsubsection"]}], "TOCSubsubsectionLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}},
    TabSpacings->32.8,
    CounterIncrements->"TOCSubsubsection",
    StyleMenuListing->None],
  
  Cell[StyleData["TOCSubsubsection", "NumberedHeads"]],
  
  Cell[StyleData["TOCSubsubsection", "Printout"],
    CellMargins->{{48, 2}, {1, 1}},
    PageBreakBelow->False,
    TabSpacings->36.3,
    FontSize->10],
  
  Cell[StyleData["TOCSubsubsection", "NumberedHeadsPrintout"],
    CellMargins->{{48, 2}, {1, 1}},
    PageBreakBelow->False,
    TabSpacings->36.3,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSectionLabel"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], "\n\n"}},
    CellSize->{18, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None],
  
  Cell[StyleData["TOCSectionLabel", "NumberedHeads"]],
  
  Cell[StyleData["TOCSectionLabel", "Printout"],
    CellSize->{14, Inherited}],
  
  Cell[StyleData["TOCSectionLabel", "NumberedHeadsPrintout"],
    CellSize->{14, Inherited}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsectionLabel"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], "\n\n"}},
    CellSize->{32, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None],
  
  Cell[StyleData["TOCSubsectionLabel", "NumberedHeads"]],
  
  Cell[StyleData["TOCSubsectionLabel", "Printout"],
    CellSize->{24, Inherited}],
  
  Cell[StyleData["TOCSubsectionLabel", "NumberedHeadsPrintout"],
    CellSize->{24, Inherited}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsubsectionLabel"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], "\n\n"}},
    CellSize->{44, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None],
  
  Cell[StyleData["TOCSubsubsectionLabel", "NumberedHeads"]],
  
  Cell[StyleData["TOCSubsubsectionLabel", "Printout"],
    CellSize->{38, Inherited}],
  
  Cell[StyleData["TOCSubsubsectionLabel", "NumberedHeadsPrintout"],
    CellSize->{38, Inherited}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCPageNumber"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], "\n\n"}},
    CellSize->{24, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TOCPageNumber", "NumberedHeads"]],
  
  Cell[StyleData["TOCPageNumber", "Printout"],
    CellSize->{21, Inherited}],
  
  Cell[StyleData["TOCPageNumber", "NumberedHeadsPrintout"],
    CellSize->{21, Inherited}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCItem"],
    CellMargins->{{36, 12}, {1, 1}},
    CellFrameLabels->{{Cell[ 
            TextData[ 
              StyleBox[ 
                CounterBox[ "TOCItem"], "TOCItemNumber"]], "TOCItemLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}},
    TabSpacings->39.6,
    CounterIncrements->"TOCItem",
    StyleMenuListing->None],
  
  Cell[StyleData["TOCItem", "NumberedHeads"]],
  
  Cell[StyleData["TOCItem", "Printout"],
    CellMargins->{{24, 2}, {1, 1}},
    TabSpacings->43.6,
    FontSize->10],
  
  Cell[StyleData["TOCItem", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {1, 1}},
    TabSpacings->43.6,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCItemNumber"],
    StyleMenuListing->None],
  
  Cell[StyleData["TOCItemNumber", "NumberedHeads"]],
  
  Cell[StyleData["TOCItemNumber", "Printout"]],
  
  Cell[StyleData["TOCItemNumber", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCItemLabel"],
    StyleMenuListing->None],
  
  Cell[StyleData["TOCItemLabel", "NumberedHeads"]],
  
  Cell[StyleData["TOCItemLabel", "Printout"]],
  
  Cell[StyleData["TOCItemLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCLeader"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], "\n\n"}},
    TabFilling->". ",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain"],
  
  Cell[StyleData["TOCLeader", "NumberedHeads"]],
  
  Cell[StyleData["TOCLeader", "Printout"],
    FontSize->10],
  
  Cell[StyleData["TOCLeader", "NumberedHeadsPrintout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCIllustrations"],
    CellMargins->{{12, 12}, {24, 36}},
    CellGroupingRules->{"SectionGrouping", 20},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["TOCIllustrations", "NumberedHeads"]],
  
  Cell[StyleData["TOCIllustrations", "Printout"],
    CellMargins->{{2, 2}, {21, 30}},
    FontSize->21],
  
  Cell[StyleData["TOCIllustrations", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {21, 30}},
    FontSize->21]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCTables"],
    CellMargins->{{12, 12}, {24, 36}},
    CellGroupingRules->{"SectionGrouping", 20},
    CounterAssignments->{{"TOCItem", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["TOCTables", "NumberedHeads"]],
  
  Cell[StyleData["TOCTables", "Printout"],
    CellMargins->{{2, 2}, {21, 30}},
    FontSize->21],
  
  Cell[StyleData["TOCTables", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {21, 30}},
    FontSize->21]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["List of Abbreviations", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LOASection"],
    CellMargins->{{12, 12}, {24, 36}},
    CellGroupingRules->{"SectionGrouping", 20},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["LOASection", "NumberedHeads"]],
  
  Cell[StyleData["LOASection", "Printout"],
    CellMargins->{{2, 2}, {21, 30}},
    StyleMenuListing->None,
    FontSize->21],
  
  Cell[StyleData["LOASection", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {21, 30}},
    StyleMenuListing->None,
    FontSize->21]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LOAItem"],
    CellMargins->{{12, 12}, {4, 4}},
    CounterIncrements->"LOAItem",
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["LOAItem", "NumberedHeads"]],
  
  Cell[StyleData["LOAItem", "Printout"],
    CellMargins->{{2, 2}, {3, 3}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["LOAItem", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {3, 3}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LOAAbbreviation"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["LOAAbbreviation", "NumberedHeads"]],
  
  Cell[StyleData["LOAAbbreviation", "Printout"],
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["LOAAbbreviation", "NumberedHeadsPrintout"],
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LOADefinition"],
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["LOADefinition", "NumberedHeads"]],
  
  Cell[StyleData["LOADefinition", "Printout"],
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["LOADefinition", "NumberedHeadsPrintout"],
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LOAItemNumber"],
    StyleMenuListing->None],
  
  Cell[StyleData["LOAItemNumber", "NumberedHeads"]],
  
  Cell[StyleData["LOAItemNumber", "Printout"]],
  
  Cell[StyleData["LOAItemNumber", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LOAItemLabel"],
    StyleMenuListing->None],
  
  Cell[StyleData["LOAItemLabel", "NumberedHeads"]],
  
  Cell[StyleData["LOAItemLabel", "Printout"]],
  
  Cell[StyleData["LOAItemLabel", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Thesis Title Page", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TitleGroup"],
    CellMargins->{{12, 12}, {7, 24}},
    CellGroupingRules->{"SectionGrouping", 5},
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}, "HTML" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["TitleGroup", "NumberedHeads"]],
  
  Cell[StyleData["TitleGroup", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["TitleGroup", "NumberedHeadsPrintout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CopyrightGroup"],
    CellMargins->{{12, 12}, {7, 24}},
    CellGroupingRules->{"SectionGrouping", 5},
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}, "HTML" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["CopyrightGroup", "NumberedHeads"]],
  
  Cell[StyleData["CopyrightGroup", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["CopyrightGroup", "NumberedHeadsPrintout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PhDThesisTitle"],
    StyleMenuListing->None],
  
  Cell[StyleData["PhDThesisTitle", "NumberedHeads"]],
  
  Cell[StyleData["PhDThesisTitle", "Printout"]],
  
  Cell[StyleData["PhDThesisTitle", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MSThesisTitle"],
    StyleMenuListing->None],
  
  Cell[StyleData["MSThesisTitle", "NumberedHeads"]],
  
  Cell[StyleData["MSThesisTitle", "Printout"]],
  
  Cell[StyleData["MSThesisTitle", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ThesisSchools"],
    StyleMenuListing->None],
  
  Cell[StyleData["ThesisSchools", "NumberedHeads"]],
  
  Cell[StyleData["ThesisSchools", "Printout"]],
  
  Cell[StyleData["ThesisSchools", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ThesisAuthorField"],
    StyleMenuListing->None],
  
  Cell[StyleData["ThesisAuthorField", "NumberedHeads"]],
  
  Cell[StyleData["ThesisAuthorField", "Printout"]],
  
  Cell[StyleData["ThesisAuthorField", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ThesisDepartmentField"],
    StyleMenuListing->None],
  
  Cell[StyleData["ThesisDepartmentField", "NumberedHeads"]],
  
  Cell[StyleData["ThesisDepartmentField", "Printout"]],
  
  Cell[StyleData["ThesisDepartmentField", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ThesisCollegeField"],
    StyleMenuListing->None],
  
  Cell[StyleData["ThesisCollegeField", "NumberedHeads"]],
  
  Cell[StyleData["ThesisCollegeField", "Printout"]],
  
  Cell[StyleData["ThesisCollegeField", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ThesisDegreeYearFieldNoExport"],
    StyleMenuListing->None],
  
  Cell[StyleData["ThesisDegreeYearFieldNoExport", "NumberedHeads"]],
  
  Cell[StyleData["ThesisDegreeYearFieldNoExport", "Printout"]],
  
  Cell[StyleData["ThesisDegreeYearFieldNoExport", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ThesisDegreeYearField"],
    StyleMenuListing->None],
  
  Cell[StyleData["ThesisDegreeYearField", "NumberedHeads"]],
  
  Cell[StyleData["ThesisDegreeYearField", "Printout"]],
  
  Cell[StyleData["ThesisDegreeYearField", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ThesisAbbreviation"],
    StyleMenuListing->None],
  
  Cell[StyleData["ThesisAbbreviation", "NumberedHeads"]],
  
  Cell[StyleData["ThesisAbbreviation", "Printout"]],
  
  Cell[StyleData["ThesisAbbreviation", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ThesisAbbreviationDescription"],
    StyleMenuListing->None],
  
  Cell[StyleData["ThesisAbbreviationDescription", "NumberedHeads"]],
  
  Cell[StyleData["ThesisAbbreviationDescription", "Printout"]],
  
  Cell[StyleData["ThesisAbbreviationDescription", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Mainmatter", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainmatterGroup"],
    CellMargins->{{12, 12}, {7, 24}},
    CellGroupingRules->{"SectionGrouping", 1},
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}, "HTML" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["MainmatterGroup", "NumberedHeads"]],
  
  Cell[StyleData["MainmatterGroup", "Presentation"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["MainmatterGroup", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["MainmatterGroup", "NumberedHeadsPrintout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{12, 12}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    ConversionRules:>{"TeX" -> {"\n\n\\section{", "}"}, "HTML" -> {
      "<h3 class=\"Section\">", "</h3>"}},
    TaggingRules:>{"CounterSettings" -> {"CounterTarget" -> "Cell", 
      "XRefPrefix" -> "Section"}},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 0}, {3, 0}},
    TabSpacings->2.1,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}, {
        "Subsubsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "NumberedHeads"],
    CellFrame->False,
    CellFrameLabels->{{Cell[ 
            TextData[ 
              CounterBox[ "Section"], "."], "SectionLabel", CellBaseline -> 
            Baseline], Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Section", "Presentation"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{23, 12}, {6, 36}},
    CellFrameMargins->{{0, 0}, {5, 0}},
    FontSize->24],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 2}, {3, 18}},
    FontSize->14,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Section", "NumberedHeadsPrintout"],
    CellFrame->False,
    CellMargins->{{2, 2}, {3, 18}},
    CellFrameLabels->{{Cell[ 
            TextData[ 
              CounterBox[ "Section"], "."], "SectionLabel", CellBaseline -> 
            Baseline], Inherited}, {Inherited, Inherited}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->None,
    CellMargins->{{12, 12}, {3, 16}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    ConversionRules:>{"TeX" -> {"\n\n\\subsection{", "}"}, "HTML" -> {
      "<h4 class=\"Subsection\">", "</h4>"}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Section", ".", 
      "Subsection"}, "CounterTarget" -> "Cell", "XRefPrefix" -> "Section"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TabSpacings->1.7,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}, {"Subsubsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "NumberedHeads"],
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Section"], ".", 
              CounterBox[ "Subsection"], "."}], "SubsectionLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{23, 12}, {5, 24}},
    FontSize->21],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 2}, {2, 14}},
    FontSize->12,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Subsection", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {2, 14}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Section"], ".", 
              CounterBox[ "Subsection"], "."}], "SubsectionLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{12, 12}, {3, 9}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"TeX" -> {"\n\n\\subsubsection{", "}"}, "HTML" -> {
      "<h5 class=\"Subsubsection\">", "</h5>"}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Section", ".", 
      "Subsection", ".", "Subsubsection"}, "CounterTarget" -> "Cell", 
      "XRefPrefix" -> "Section"}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    CounterAssignments->{{"Subsubsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.200015],
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Subsubsection", "NumberedHeads"],
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Section"], ".", 
              CounterBox[ "Subsection"], ".", 
              CounterBox[ "Subsubsection"], "."}], "SubsubsectionLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{23, 12}, {5, 14}},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 2}, {2, 7}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Subsubsection", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {2, 7}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Section"], ".", 
              CounterBox[ "Subsection"], ".", 
              CounterBox[ "Subsubsection"], "."}], "SubsubsectionLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsubsection"],
    CellMargins->{{12, 12}, {3, 6}},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{{"TeX" -> {"\n\n\\paragraph{", "}"}}, {"HTML" -> {
      "<h6 class=\"Subsubsubsection\">", "</h6>"}}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Section", ".", 
      "Subsection", ".", "Subsubsection", ".", "Subsubsubsection"}, 
      "CounterTarget" -> "Cell", "XRefPrefix" -> "Section"}},
    CounterIncrements->"Subsubsubsection",
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.300008]],
  
  Cell[StyleData["Subsubsubsection", "NumberedHeads"]],
  
  Cell[StyleData["Subsubsubsection", "Presentation"],
    CellMargins->{{23, 12}, {5, 9}},
    FontSize->18],
  
  Cell[StyleData["Subsubsubsection", "Printout"],
    CellMargins->{{2, 2}, {2, 5}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Subsubsubsection", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {2, 5}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Section Heading Inline Cells", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionLabel"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    TextAlignment->Left,
    StyleMenuListing->None],
  
  Cell[StyleData["SectionLabel", "NumberedHeads"]],
  
  Cell[StyleData["SectionLabel", "Presentation"]],
  
  Cell[StyleData["SectionLabel", "Printout"]],
  
  Cell[StyleData["SectionLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionLabel"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    TextAlignment->Left,
    StyleMenuListing->None],
  
  Cell[StyleData["SubsectionLabel", "NumberedHeads"]],
  
  Cell[StyleData["SubsectionLabel", "Presentation"]],
  
  Cell[StyleData["SubsectionLabel", "Printout"]],
  
  Cell[StyleData["SubsectionLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionLabel"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None],
  
  Cell[StyleData["SubsubsectionLabel", "NumberedHeads"]],
  
  Cell[StyleData["SubsubsectionLabel", "Presentation"]],
  
  Cell[StyleData["SubsubsectionLabel", "Printout"]],
  
  Cell[StyleData["SubsubsectionLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsubsectionLabel"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None],
  
  Cell[StyleData["SubsubsubsectionLabel", "NumberedHeads"]],
  
  Cell[StyleData["SubsubsubsectionLabel", "Presentation"]],
  
  Cell[StyleData["SubsubsubsectionLabel", "Printout"]],
  
  Cell[StyleData["SubsubsubsectionLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionNumber"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None],
  
  Cell[StyleData["SectionNumber", "NumberedHeads"]],
  
  Cell[StyleData["SectionNumber", "Presentation"]],
  
  Cell[StyleData["SectionNumber", "Printout"]],
  
  Cell[StyleData["SectionNumber", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNumber"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None],
  
  Cell[StyleData["SubsectionNumber", "NumberedHeads"]],
  
  Cell[StyleData["SubsectionNumber", "Presentation"]],
  
  Cell[StyleData["SubsectionNumber", "Printout"]],
  
  Cell[StyleData["SubsectionNumber", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionNumber"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None],
  
  Cell[StyleData["SubsubsectionNumber", "NumberedHeads"]],
  
  Cell[StyleData["SubsubsectionNumber", "Presentation"]],
  
  Cell[StyleData["SubsubsectionNumber", "Printout"],
    StyleMenuListing->None],
  
  Cell[StyleData["SubsubsectionNumber", "NumberedHeadsPrintout"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsubsectionNumber"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None],
  
  Cell[StyleData["SubsubsubsectionNumber", "NumberedHeads"]],
  
  Cell[StyleData["SubsubsubsectionNumber", "Presentation"]],
  
  Cell[StyleData["SubsubsubsectionNumber", "Printout"],
    StyleMenuListing->None],
  
  Cell[StyleData["SubsubsubsectionNumber", "NumberedHeadsPrintout"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionText"],
    StyleMenuListing->None],
  
  Cell[StyleData["SubsectionText", "NumberedHeads"]],
  
  Cell[StyleData["SubsectionText", "Presentation"],
    CellMargins->{{23, 10}, {2, 6}},
    FontSize->17],
  
  Cell[StyleData["SubsectionText", "Printout"],
    CellMargins->{{2, 2}, {1, 3}},
    FontSize->10],
  
  Cell[StyleData["SubsectionText", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 3}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionText"],
    StyleMenuListing->None],
  
  Cell[StyleData["SubsubsectionText", "NumberedHeads"]],
  
  Cell[StyleData["SubsubsectionText", "Presentation"],
    CellMargins->{{23, 10}, {2, 6}},
    FontSize->17],
  
  Cell[StyleData["SubsubsectionText", "Printout"],
    CellMargins->{{2, 2}, {1, 2}},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionText", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsubsectionText"],
    StyleMenuListing->None],
  
  Cell[StyleData["SubsubsubsectionText", "NumberedHeads"]],
  
  Cell[StyleData["SubsubsubsectionText", "Presentation"],
    CellMargins->{{23, 10}, {2, 6}},
    FontSize->17],
  
  Cell[StyleData["SubsubsubsectionText", "Printout"],
    CellMargins->{{2, 2}, {1, 2}},
    FontSize->10],
  
  Cell[StyleData["SubsubsubsectionText", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 2}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Alternate Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionAlt"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{12, 12}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    ConversionRules:>{"TeX" -> {"\n\n\\section*{", "}"}, "HTML" -> {
      "<h3 class=\"SectionAlt\">", "</h3>"}},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 0}, {3, 0}},
    ParagraphIndent->-25,
    TabSpacings->2.1,
    CounterIncrements->"SectionAlt",
    CounterAssignments->{{"SubsectionAlt", 0}, {"SubsubsectionAlt", 0}, {
        "SubsubsubsectionAlt", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionAlt", "NumberedHeads"]],
  
  Cell[StyleData["SectionAlt", "Presentation"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{23, 12}, {6, 36}},
    CellFrameMargins->{{0, 0}, {5, 0}},
    FontSize->24],
  
  Cell[StyleData["SectionAlt", "Printout"],
    CellMargins->{{2, 2}, {3, 18}},
    FontSize->14,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["SectionAlt", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {3, 18}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionAlt"],
    CellDingbat->None,
    CellMargins->{{12, 12}, {3, 16}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    ConversionRules:>{"TeX" -> {"\n\n\\subsection*{", "}"}, "HTML" -> {
      "<h4 class=\"SubsectionAlt\">", "</h4>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    ParagraphIndent->-18,
    TabSpacings->1.7,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"SubsubsectionAlt", 0}, {"SubsubsubsectionAlt", 0}},
    
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionAlt", "NumberedHeads"]],
  
  Cell[StyleData["SubsectionAlt", "Presentation"],
    CellMargins->{{23, 12}, {5, 24}},
    FontSize->21],
  
  Cell[StyleData["SubsectionAlt", "Printout"],
    CellMargins->{{2, 2}, {2, 14}},
    FontSize->12,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["SubsectionAlt", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {2, 14}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionAlt"],
    CellMargins->{{12, 12}, {3, 9}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"TeX" -> {"\n\n\\subsubsection*{", "}"}, "HTML" -> {
      "<h5 class=\"SubsubsectionAlt\">", "</h5>"}},
    PageBreakBelow->False,
    CounterIncrements->"SubsubsectionAlt",
    CounterAssignments->{{"SubsubsubsectionAlt", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.200015],
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["SubsubsectionAlt", "NumberedHeads"]],
  
  Cell[StyleData["SubsubsectionAlt", "Presentation"],
    CellMargins->{{23, 12}, {5, 14}},
    FontSize->18],
  
  Cell[StyleData["SubsubsectionAlt", "Printout"],
    CellMargins->{{2, 2}, {2, 7}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["SubsubsectionAlt", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {2, 7}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsubsectionAlt"],
    CellMargins->{{12, 12}, {3, 6}},
    CellGroupingRules->{"SectionGrouping", 60},
    CounterIncrements->"SubsubsubsectionAlt",
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.300008]],
  
  Cell[StyleData["SubsubsubsectionAlt", "NumberedHeads"]],
  
  Cell[StyleData["SubsubsubsectionAlt", "Presentation"],
    CellMargins->{{23, 12}, {5, 9}},
    FontSize->18],
  
  Cell[StyleData["SubsubsubsectionAlt", "Printout"],
    CellMargins->{{2, 2}, {2, 5}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["SubsubsubsectionAlt", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {2, 5}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Body Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 12}, {3, 5}},
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TextAlignment->Left,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    CounterAssignments->{{"Item1Numbered", 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Text", "NumberedHeads"]],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{23, 12}, {5, 8}},
    FontSize->17],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {2, 4}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->10],
  
  Cell[StyleData["Text", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {2, 4}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextNoIndent"],
    CellMargins->{{12, 12}, {3, 5}},
    ConversionRules:>{"TeX" -> {{"\\noindent ", Automatic, ""}, {
      "\n\n\\noindent ", Automatic, ""}}},
    TaggingRules:>{"CounterSettings" -> {"CounterTarget" -> "CellGroup"}},
    TextAlignment->Left,
    LineSpacing->{1, 3},
    CounterIncrements->"TextNoIndent",
    CounterAssignments->{{"Item1Numbered", 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["TextNoIndent", "NumberedHeads"]],
  
  Cell[StyleData["TextNoIndent", "Presentation"],
    CellMargins->{{23, 12}, {5, 8}},
    FontSize->17],
  
  Cell[StyleData["TextNoIndent", "Printout"],
    CellMargins->{{2, 2}, {2, 4}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->10],
  
  Cell[StyleData["TextNoIndent", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {2, 4}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextContinuation"],
    CellMargins->{{12, 12}, {3, 5}},
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n", Automatic, ""}}},
    TaggingRules:>{"CounterSettings" -> {"CounterTarget" -> "CellGroup"}},
    TextAlignment->Left,
    LineSpacing->{1, 3},
    CounterIncrements->"TextNoIndent",
    CounterAssignments->{{"Item1Numbered", 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["TextContinuation", "NumberedHeads"]],
  
  Cell[StyleData["TextContinuation", "Presentation"],
    CellMargins->{{23, 12}, {5, 8}},
    FontSize->17],
  
  Cell[StyleData["TextContinuation", "Printout"],
    CellMargins->{{2, 2}, {2, 4}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->10],
  
  Cell[StyleData["TextContinuation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {2, 4}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->10]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Itemized Lists", "Section"],
  
  Cell[CellGroupData[{
  
  Cell["Bulleted Lists", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item1"],
    CellMargins->{{12, 12}, {1, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {"\n\\item ", ""}, "HTML" -> {"<li>", 
      "</li>"}},
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      30}, "TeX" -> {"CellGroupEnvironment" -> "itemize"}, "HTML" -> {
      "CellGroupEnvironment" -> "ul"}}},
    CellFrameLabels->{{
      Cell[ "\[FilledSmallCircle]", "Item1Label", CellBaseline -> Baseline], 
          Inherited}, {Inherited, Inherited}},
    CellFrameLabelMargins->4,
    CounterIncrements->"Item1",
    CounterAssignments->{{"Item2Numbered", 0}, {"Item3Numbered", 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Item1", "NumberedHeads"]],
  
  Cell[StyleData["Item1", "Presentation"],
    CellMargins->{{23, 12}, {2, 3}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["Item1", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Item1", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item2"],
    CellMargins->{{36, 12}, {1, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {"\n\\item ", ""}, "HTML" -> {"<li>", 
      "</li>"}},
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      40}, "TeX" -> {"CellGroupEnvironment" -> "itemize"}, "HTML" -> {
      "CellGroupEnvironment" -> "ul"}}},
    CellFrameLabels->{{
      Cell[ "\[FilledSmallCircle]", "Item2Label", CellBaseline -> Baseline], 
          Inherited}, {Inherited, Inherited}},
    CellFrameLabelMargins->4,
    CounterIncrements->"Item2",
    CounterAssignments->{{"Item3Numbered", 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Item2", "NumberedHeads"]],
  
  Cell[StyleData["Item2", "Presentation"],
    CellMargins->{{59, 12}, {2, 3}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["Item2", "Printout"],
    CellMargins->{{20, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Item2", "NumberedHeadsPrintout"],
    CellMargins->{{20, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item3"],
    CellMargins->{{60, 12}, {1, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {"\n\\item ", ""}, "HTML" -> {"<li>", 
      "</li>"}},
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      50}, "TeX" -> {"CellGroupEnvironment" -> "itemize"}, "HTML" -> {
      "CellGroupEnvironment" -> "ul"}}},
    CellFrameLabels->{{
      Cell[ "\[FilledSmallCircle]", "Item3Label", CellBaseline -> Baseline], 
          Inherited}, {Inherited, Inherited}},
    CellFrameLabelMargins->4,
    CounterIncrements->"Item3",
    StyleMenuListing->None],
  
  Cell[StyleData["Item3", "NumberedHeads"]],
  
  Cell[StyleData["Item3", "Presentation"],
    CellMargins->{{95, 12}, {2, 3}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["Item3", "Printout"],
    CellMargins->{{40, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Item3", "NumberedHeadsPrintout"],
    CellMargins->{{40, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item1Label"],
    ConversionRules:>{{"TeX" -> {"", 
      NoOutput[ ], ""}}, {"HTML" -> {"", 
      NoOutput[ ], ""}}},
    CellSize->{24, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Item1Label", "NumberedHeads"]],
  
  Cell[StyleData["Item1Label", "Presentation"],
    CellSize->{36, Inherited},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["Item1Label", "Printout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Item1Label", "NumberedHeadsPrintout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item2Label"],
    ConversionRules:>{{"TeX" -> {"", 
      NoOutput[ ], ""}}, {"HTML" -> {"", 
      NoOutput[ ], ""}}},
    CellSize->{24, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Item2Label", "NumberedHeads"]],
  
  Cell[StyleData["Item2Label", "Presentation"],
    CellSize->{36, Inherited},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["Item2Label", "Printout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None],
  
  Cell[StyleData["Item2Label", "NumberedHeadsPrintout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item3Label"],
    ConversionRules:>{{"TeX" -> {"", 
      NoOutput[ ], ""}}, {"HTML" -> {"", 
      NoOutput[ ], ""}}},
    CellSize->{24, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Item3Label", "NumberedHeads"]],
  
  Cell[StyleData["Item3Label", "Presentation"],
    CellSize->{36, Inherited},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["Item3Label", "Printout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None],
  
  Cell[StyleData["Item3Label", "NumberedHeadsPrintout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Numbered Lists", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item1Numbered"],
    CellMargins->{{12, 12}, {1, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {"\n\\item ", ""}, "HTML" -> {"<li>", 
      "</li>"}},
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      30}, "TeX" -> {"CellGroupEnvironment" -> "enumerate"}, "HTML" -> {
      "CellGroupEnvironment" -> "ol"}}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Item1Numbered"], "."}], "Item1NumberedLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}},
    CellFrameLabelMargins->4,
    CounterIncrements->"Item1Numbered",
    CounterAssignments->{{"Item2Numbered", 0}, {"Item3Numbered", 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Item1Numbered", "NumberedHeads"]],
  
  Cell[StyleData["Item1Numbered", "Presentation"],
    CellMargins->{{23, 12}, {2, 3}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["Item1Numbered", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Item1Numbered", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item2Numbered"],
    CellMargins->{{36, 12}, {1, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {"\n\\item ", ""}, "HTML" -> {"<li>", 
      "</li>"}},
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      40}, "TeX" -> {"CellGroupEnvironment" -> "enumerate"}, "HTML" -> {
      "CellGroupEnvironment" -> "ol"}}},
    CellFrameLabels->{{Cell[ 
            TextData[ {"(", 
              CounterBox[ "Item2Numbered"], ")"}], "Item2NumberedLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}},
    CellFrameLabelMargins->4,
    CounterIncrements->"Item2Numbered",
    CounterAssignments->{{"Item3Numbered", 0}},
    StyleMenuListing->None,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Item2Numbered", "NumberedHeads"]],
  
  Cell[StyleData["Item2Numbered", "Presentation"],
    CellMargins->{{59, 12}, {2, 2}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["Item2Numbered", "Printout"],
    CellMargins->{{20, 2}, {1, 2}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Item2Numbered", "NumberedHeadsPrintout"],
    CellMargins->{{20, 2}, {1, 2}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item3Numbered"],
    CellMargins->{{60, 12}, {1, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {"\n\\item ", ""}, "HTML" -> {"<li>", 
      "</li>"}},
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      50}, "TeX" -> {"CellGroupEnvironment" -> "enumerate"}, "HTML" -> {
      "CellGroupEnvironment" -> "ol"}}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Item3Numbered"], "."}], "Item3NumberedLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}},
    CellFrameLabelMargins->4,
    CounterIncrements->"Item3Numbered",
    StyleMenuListing->None,
    CounterBoxOptions->{CounterFunction:>RomanNumeral}],
  
  Cell[StyleData["Item3Numbered", "NumberedHeads"]],
  
  Cell[StyleData["Item3Numbered", "Presentation"],
    CellMargins->{{95, 12}, {2, 3}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["Item3Numbered", "Printout"],
    CellMargins->{{40, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Item3Numbered", "NumberedHeadsPrintout"],
    CellMargins->{{40, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item1NumberedLabel"],
    ConversionRules:>{{"TeX" -> {"", 
      NoOutput[ ], ""}}, {"HTML" -> {"<!--", "-->"}}},
    CellSize->{24, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Item1NumberedLabel", "NumberedHeads"]],
  
  Cell[StyleData["Item1NumberedLabel", "Presentation"],
    CellSize->{36, Inherited},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["Item1NumberedLabel", "Printout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Item1NumberedLabel", "NumberedHeadsPrintout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item2NumberedLabel"],
    ConversionRules:>{{"TeX" -> {"", 
      NoOutput[ ], ""}}, {"HTML" -> {"<!--", "-->"}}},
    CellSize->{24, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Item2NumberedLabel", "NumberedHeads"]],
  
  Cell[StyleData["Item2NumberedLabel", "Presentation"],
    CellSize->{36, Inherited},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["Item2NumberedLabel", "Printout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None],
  
  Cell[StyleData["Item2NumberedLabel", "NumberedHeadsPrintout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item3NumberedLabel"],
    ConversionRules:>{{"TeX" -> {"", 
      NoOutput[ ], ""}}, {"HTML" -> {"<!--", "-->"}}},
    CellSize->{24, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Item3NumberedLabel", "NumberedHeads"]],
  
  Cell[StyleData["Item3NumberedLabel", "Presentation"],
    CellSize->{36, Inherited},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["Item3NumberedLabel", "Printout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None],
  
  Cell[StyleData["Item3NumberedLabel", "NumberedHeadsPrintout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["List Paragraphs", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item1Paragraph"],
    CellMargins->{{40, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 1, 
      "CellGroupEnvironment" -> "enumerate"}}},
    CounterAssignments->{{"Item2Numbered", 0}, {"Item3Numbered", 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Item1Paragraph", "NumberedHeads"]],
  
  Cell[StyleData["Item1Paragraph", "Presentation"],
    CellMargins->{{63, 12}, {2, 2}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["Item1Paragraph", "Printout"],
    CellMargins->{{24, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Item1Paragraph", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item2Paragraph"],
    CellMargins->{{64, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 2, 
      "CellGroupEnvironment" -> "enumerate"}}},
    CounterAssignments->{{"Item3Numbered", 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Item2Paragraph", "NumberedHeads"]],
  
  Cell[StyleData["Item2Paragraph", "Presentation"],
    CellMargins->{{99, 12}, {2, 2}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["Item2Paragraph", "Printout"],
    CellMargins->{{42, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Item2Paragraph", "NumberedHeadsPrintout"],
    CellMargins->{{42, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item3Paragraph"],
    CellMargins->{{88, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 3, 
      "CellGroupEnvironment" -> "enumerate"}}},
    StyleMenuListing->None],
  
  Cell[StyleData["Item3Paragraph", "NumberedHeads"]],
  
  Cell[StyleData["Item3Paragraph", "Presentation"],
    CellMargins->{{135, 12}, {2, 2}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["Item3Paragraph", "Printout"],
    CellMargins->{{62, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Item3Paragraph", "NumberedHeadsPrintout"],
    CellMargins->{{62, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Illustrations and Examples", "Section"],
  
  Cell[CellGroupData[{
  
  Cell["Figure", "Subsection"],
  
  Cell["\<\
When changing settings that affect rendering of \"Figure\", apply the same \
settings to \"Graphics\" in the conformance group to avoid jumpiness on \
import:\
\>", "Text",
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.500008]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Figure"],
    Editable->False,
    CellMargins->{{12, Inherited}, {0, 7}},
    CellGroupingRules->"InputGrouping",
    ConversionRules:>{"TeX" -> {"\n\\begin{center}", 
      ExtractFigure[ ], "\n\\end{center}"}},
    TaggingRules:>{"CounterSettings" -> {"CounterTarget" -> 
      "Style:FigureCaption"}, "ExtraConversionRules" -> {"General" -> {
      "NestingLevel" -> 90, "AlwaysStartEnvironment" -> True}, "TeX" -> {
      "CellGroupEnvironment" -> {"figure", "[h]"}}}},
    CounterIncrements->"Figure",
    StyleMenuListing->None],
  
  Cell[StyleData["Figure", "NumberedHeads"]],
  
  Cell[StyleData["Figure", "Presentation"],
    CellMargins->{{12, Inherited}, {0, 11}},
    FontSize->18,
    Magnification->1.5],
  
  Cell[StyleData["Figure", "Printout"],
    CellMargins->{{2, Inherited}, {0, 5}},
    Magnification->0.8],
  
  Cell[StyleData["Figure", "NumberedHeadsPrintout"],
    CellMargins->{{2, Inherited}, {0, 5}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FigureCaption"],
    CellMargins->{{12, 10}, {6, 2}},
    CellGroupingRules->"OutputGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\\caption{", 
      "}\n"}}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Figure"}, 
      "CounterTarget" -> "Cell", "XRefPrefix" -> "Figure"}, 
      "ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 90}, 
      "TeX" -> {"CellGroupEnvironment" -> {"figure", "[h]"}}}},
    PageBreakAbove->False,
    Hyphenation->True,
    CounterIncrements->"FigureCaption",
    CounterAssignments->{{"Nil", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["FigureCaption", "NumberedHeads"]],
  
  Cell[StyleData["FigureCaption", "Presentation"],
    CellMargins->{{23, 10}, {9, 3}},
    FontSize->14],
  
  Cell[StyleData["FigureCaption", "Printout"],
    CellMargins->{{2, 12}, {2, 4}},
    FontSize->7],
  
  Cell[StyleData["FigureCaption", "NumberedHeadsPrintout"],
    CellMargins->{{2, 12}, {2, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FigureCaptionLabel"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FigureCaptionLabel", "NumberedHeads"]],
  
  Cell[StyleData["FigureCaptionLabel", "Presentation"]],
  
  Cell[StyleData["FigureCaptionLabel", "Printout"]],
  
  Cell[StyleData["FigureCaptionLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FigureNumber"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FigureNumber", "NumberedHeads"]],
  
  Cell[StyleData["FigureNumber", "Presentation"]],
  
  Cell[StyleData["FigureNumber", "Printout"]],
  
  Cell[StyleData["FigureNumber", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FigureText"],
    CellMargins->{{12, 10}, {12, 0}},
    CellGroupingRules->"OutputGrouping",
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Figure"}, 
      "CounterTarget" -> "CellGroup"}},
    PageBreakAbove->False,
    Hyphenation->True,
    CounterIncrements->"FigureText",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9],
  
  Cell[StyleData["FigureText", "NumberedHeads"]],
  
  Cell[StyleData["FigureText", "Presentation"],
    CellMargins->{{23, 10}, {18, 0}},
    FontSize->14],
  
  Cell[StyleData["FigureText", "Printout"],
    CellMargins->{{2, 12}, {12, 0}},
    TextJustification->1,
    FontSize->7],
  
  Cell[StyleData["FigureText", "NumberedHeadsPrintout"],
    CellMargins->{{2, 12}, {12, 0}},
    TextJustification->1,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FigureFile"],
    Deletable->False,
    CellMargins->{{12, 10}, {7, 2}},
    CellGroupingRules->"OutputGrouping",
    StyleMenuListing->None,
    Background->RGBColor[0.776471, 0.776471, 0.92549]],
  
  Cell[StyleData["FigureFile", "NumberedHeads"]],
  
  Cell[StyleData["FigureFile", "Presentation"],
    CellMargins->{{23, 10}, {11, 3}},
    FontSize->17],
  
  Cell[StyleData["FigureFile", "Printout"],
    CellMargins->{{2, 2}, {6, 1}},
    FontSize->10,
    Background->GrayLevel[0.8]],
  
  Cell[StyleData["FigureFile", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 1}},
    FontSize->10,
    Background->GrayLevel[0.8]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Supplemental Material", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SupplementalCaptionLabel"],
    Deletable->False,
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{12, 10}, {1, 7}},
    CellGroupingRules->"InputGrouping",
    TaggingRules:>{"CellGroupDeletable" -> True, "CounterSettings" -> {
      "CounterFormat" -> {"Supplemental"}, "CounterTarget" -> "CellGroup", 
      "XRefPrefix" -> "Supplemental File"}},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CounterIncrements->"SupplementalCaptionLabel",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold"],
  
  Cell[StyleData["SupplementalCaptionLabel", "NumberedHeads"]],
  
  Cell[StyleData["SupplementalCaptionLabel", "Presentation"],
    CellMargins->{{23, 10}, {2, 11}},
    FontSize->17],
  
  Cell[StyleData["SupplementalCaptionLabel", "Printout"],
    CellMargins->{{2, 2}, {0, 6}},
    FontSize->9],
  
  Cell[StyleData["SupplementalCaptionLabel", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {0, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SupplementalCaption"],
    Deletable->False,
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{12, 10}, {8, 4}},
    CellGroupingRules->"OutputGrouping",
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Supplemental"}, 
      "CounterTarget" -> "CellGroup"}},
    PageBreakBelow->False,
    CellFrameMargins->2,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold"],
  
  Cell[StyleData["SupplementalCaption", "NumberedHeads"]],
  
  Cell[StyleData["SupplementalCaption", "Presentation"],
    CellMargins->{{23, 10}, {12, 6}},
    FontSize->17],
  
  Cell[StyleData["SupplementalCaption", "Printout"],
    CellMargins->{{2, 2}, {6, 3}},
    FontSize->9],
  
  Cell[StyleData["SupplementalCaption", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 3}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SupplementalText"],
    Deletable->False,
    CellMargins->{{12, 10}, {7, 4}},
    CellGroupingRules->"OutputGrouping",
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Supplemental"}, 
      "CounterTarget" -> "CellGroup"}},
    PageBreakBelow->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11],
  
  Cell[StyleData["SupplementalText", "NumberedHeads"]],
  
  Cell[StyleData["SupplementalText", "Presentation"],
    CellMargins->{{23, 10}, {11, 6}},
    FontSize->17],
  
  Cell[StyleData["SupplementalText", "Printout"],
    CellMargins->{{2, 2}, {6, 3}},
    FontSize->9],
  
  Cell[StyleData["SupplementalText", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 3}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Supplemental"],
    Deletable->False,
    CellMargins->{{12, 10}, {7, 2}},
    CellGroupingRules->"OutputGrouping",
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Supplemental"}, 
      "CounterTarget" -> "CellGroup"}, "AllowedToFollow" -> {"Text"}},
    TextAlignment->Center,
    CounterIncrements->"Supplemental",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    Background->RGBColor[0.776471, 0.776471, 0.92549]],
  
  Cell[StyleData["Supplemental", "NumberedHeads"]],
  
  Cell[StyleData["Supplemental", "Presentation"],
    CellMargins->{{23, 10}, {11, 3}},
    FontSize->17],
  
  Cell[StyleData["Supplemental", "Printout"],
    CellMargins->{{2, 2}, {6, 1}},
    FontSize->9,
    Background->GrayLevel[0.8]],
  
  Cell[StyleData["Supplemental", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 1}},
    FontSize->9,
    Background->GrayLevel[0.8]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Picture", "Subsection"],
  
  Cell["\<\
When changing settings that affect rendering of \"Picture\", apply the same \
settings to \"Graphics\" in the conformance group to avoid jumpiness on \
import:\
\>", "Text",
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.500008]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    Editable->False,
    CellMargins->{{12, Inherited}, {0, 7}},
    CellGroupingRules->"InputGrouping",
    ConversionRules:>{"TeX" -> {"\n\\begin{center}", 
      ExtractFigure[ ], "\n\\end{center}"}},
    TaggingRules:>{"CounterSettings" -> {"CounterTarget" -> 
      "Style:PictureCaption"}, "ExtraConversionRules" -> {"General" -> {
      "NestingLevel" -> 90, "AlwaysStartEnvironment" -> True}, "TeX" -> {
      "CellGroupEnvironment" -> {"figure", "[h]"}}}},
    CounterIncrements->"Picture",
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "NumberedHeads"]],
  
  Cell[StyleData["Picture", "Presentation"],
    CellMargins->{{12, Inherited}, {0, 11}},
    Magnification->1.5],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 5}},
    Magnification->0.8],
  
  Cell[StyleData["Picture", "NumberedHeadsPrintout"],
    CellMargins->{{2, Inherited}, {0, 5}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureCaption"],
    CellMargins->{{12, 10}, {6, 2}},
    CellGroupingRules->"OutputGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\\caption{", 
      "}\n"}}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Picture"}, 
      "CounterTarget" -> "Cell", "XRefPrefix" -> "Picture"}, 
      "ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 90}, 
      "TeX" -> {"CellGroupEnvironment" -> {"figure", "[h]"}}}},
    PageBreakAbove->False,
    Hyphenation->True,
    CounterIncrements->"PictureCaption",
    CounterAssignments->{{"Nil", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["PictureCaption", "NumberedHeads"]],
  
  Cell[StyleData["PictureCaption", "Presentation"],
    CellMargins->{{23, 10}, {9, 3}},
    FontSize->14],
  
  Cell[StyleData["PictureCaption", "Printout"],
    CellMargins->{{2, 12}, {2, 4}},
    FontSize->7],
  
  Cell[StyleData["PictureCaption", "NumberedHeadsPrintout"],
    CellMargins->{{2, 12}, {2, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureCaptionLabel"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["PictureCaptionLabel", "NumberedHeads"]],
  
  Cell[StyleData["PictureCaptionLabel", "Presentation"]],
  
  Cell[StyleData["PictureCaptionLabel", "Printout"]],
  
  Cell[StyleData["PictureCaptionLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureNumber"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["PictureNumber", "NumberedHeads"]],
  
  Cell[StyleData["PictureNumber", "Presentation"]],
  
  Cell[StyleData["PictureNumber", "Printout"]],
  
  Cell[StyleData["PictureNumber", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureText"],
    CellMargins->{{12, 10}, {12, 0}},
    CellGroupingRules->"OutputGrouping",
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Picture"}, 
      "CounterTarget" -> "CellGroup"}},
    PageBreakAbove->False,
    Hyphenation->True,
    CounterIncrements->"PictureText",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9],
  
  Cell[StyleData["PictureText", "NumberedHeads"]],
  
  Cell[StyleData["PictureText", "Presentation"],
    CellMargins->{{23, 10}, {18, 0}},
    FontSize->14],
  
  Cell[StyleData["PictureText", "Printout"],
    CellMargins->{{2, 12}, {12, 0}},
    TextJustification->1,
    FontSize->7],
  
  Cell[StyleData["PictureText", "NumberedHeadsPrintout"],
    CellMargins->{{2, 12}, {12, 0}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Illustration", "Subsection"],
  
  Cell["\<\
When changing settings that affect rendering of \"Illustration\", apply the \
same settings to \"Graphics\" in the conformance group to avoid jumpiness on \
import:\
\>", "Text",
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.500008]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Illustration"],
    Editable->False,
    CellMargins->{{12, Inherited}, {0, 7}},
    CellGroupingRules->"InputGrouping",
    ConversionRules:>{"TeX" -> {"\n\\begin{center}", 
      ExtractFigure[ ], "\n\\end{center}"}},
    TaggingRules:>{"CounterSettings" -> {"CounterTarget" -> 
      "Style:IllustrationCaption"}, "ExtraConversionRules" -> {"General" -> {
      "NestingLevel" -> 90, "AlwaysStartEnvironment" -> True}, "TeX" -> {
      "CellGroupEnvironment" -> {"figure", "[h]"}}}},
    CounterIncrements->"Illustration",
    StyleMenuListing->None],
  
  Cell[StyleData["Illustration", "NumberedHeads"]],
  
  Cell[StyleData["Illustration", "Presentation"],
    CellMargins->{{12, Inherited}, {0, 11}},
    Magnification->1.5],
  
  Cell[StyleData["Illustration", "Printout"],
    CellMargins->{{2, Inherited}, {0, 5}},
    Magnification->0.8],
  
  Cell[StyleData["Illustration", "NumberedHeadsPrintout"],
    CellMargins->{{2, Inherited}, {0, 5}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IllustrationCaption"],
    CellMargins->{{12, 10}, {6, 2}},
    CellGroupingRules->"OutputGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\\caption{", 
      "}\n"}}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Illustration"}, 
      "CounterTarget" -> "Cell", "XRefPrefix" -> "Illustration"}, 
      "ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 90}, 
      "TeX" -> {"CellGroupEnvironment" -> {"figure", "[h]"}}}},
    PageBreakAbove->False,
    Hyphenation->True,
    CounterIncrements->"IllustrationCaption",
    CounterAssignments->{{"Nil", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["IllustrationCaption", "NumberedHeads"]],
  
  Cell[StyleData["IllustrationCaption", "Presentation"],
    CellMargins->{{23, 10}, {9, 3}},
    FontSize->14],
  
  Cell[StyleData["IllustrationCaption", "Printout"],
    CellMargins->{{2, 12}, {2, 4}},
    FontSize->7],
  
  Cell[StyleData["IllustrationCaption", "NumberedHeadsPrintout"],
    CellMargins->{{2, 12}, {2, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IllustrationCaptionLabel"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IllustrationCaptionLabel", "NumberedHeads"]],
  
  Cell[StyleData["IllustrationCaptionLabel", "Presentation"]],
  
  Cell[StyleData["IllustrationCaptionLabel", "Printout"]],
  
  Cell[StyleData["IllustrationCaptionLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IllustrationNumber"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IllustrationNumber", "NumberedHeads"]],
  
  Cell[StyleData["IllustrationNumber", "Presentation"]],
  
  Cell[StyleData["IllustrationNumber", "Printout"]],
  
  Cell[StyleData["IllustrationNumber", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IllustrationText"],
    CellMargins->{{12, 10}, {12, 0}},
    CellGroupingRules->"OutputGrouping",
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Illustration"}, 
      "CounterTarget" -> "CellGroup"}},
    PageBreakAbove->False,
    Hyphenation->True,
    CounterIncrements->"IllustrationText",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9],
  
  Cell[StyleData["IllustrationText", "NumberedHeads"]],
  
  Cell[StyleData["IllustrationText", "Presentation"],
    CellMargins->{{12, 10}, {18, 0}},
    FontSize->14],
  
  Cell[StyleData["IllustrationText", "Printout"],
    CellMargins->{{2, 12}, {12, 0}},
    TextJustification->1,
    FontSize->7],
  
  Cell[StyleData["IllustrationText", "NumberedHeadsPrintout"],
    CellMargins->{{2, 12}, {12, 0}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Program/Script", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {1, 1}},
    CellMargins->{{12, 0}, {2, 7}},
    CellGroupingRules->"InputGrouping",
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Program"}, 
      "CounterTarget" -> "Cell", "XRefPrefix" -> "Program"}},
    CellFrameMargins->{{12, 10}, {7, 5}},
    CounterIncrements->"Program",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "NumberedHeads"]],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{23, 0}, {3, 11}},
    FontSize->18],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {5, 5}},
    StyleMenuListing->None,
    FontSize->9.5],
  
  Cell[StyleData["Program", "NumberedHeadsPrintout"],
    CellMargins->{{2, 0}, {5, 5}},
    StyleMenuListing->None,
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramCaption"],
    CellMargins->{{12, 10}, {6, 2}},
    CellGroupingRules->"OutputGrouping",
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Program"}, 
      "CounterTarget" -> "CellGroup"}},
    PageBreakAbove->False,
    Hyphenation->True,
    CounterIncrements->"ProgramCaption",
    CounterAssignments->{{"Nil", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["ProgramCaption", "NumberedHeads"]],
  
  Cell[StyleData["ProgramCaption", "Presentation"],
    CellMargins->{{23, 10}, {9, 3}},
    FontSize->14],
  
  Cell[StyleData["ProgramCaption", "Printout"],
    CellMargins->{{2, 12}, {2, 4}},
    FontSize->7],
  
  Cell[StyleData["ProgramCaption", "NumberedHeadsPrintout"],
    CellMargins->{{2, 12}, {2, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramCaptionLabel"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["ProgramCaptionLabel", "NumberedHeads"]],
  
  Cell[StyleData["ProgramCaptionLabel", "Presentation"]],
  
  Cell[StyleData["ProgramCaptionLabel", "Printout"],
    StyleMenuListing->None],
  
  Cell[StyleData["ProgramCaptionLabel", "NumberedHeadsPrintout"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramNumber"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["ProgramNumber", "NumberedHeads"]],
  
  Cell[StyleData["ProgramNumber", "Presentation"]],
  
  Cell[StyleData["ProgramNumber", "Printout"]],
  
  Cell[StyleData["ProgramNumber", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramText"],
    CellMargins->{{12, 10}, {12, 0}},
    CellGroupingRules->"OutputGrouping",
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Program"}, 
      "CounterTarget" -> "CellGroup"}},
    PageBreakAbove->False,
    Hyphenation->True,
    CounterIncrements->"ProgramText",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9],
  
  Cell[StyleData["ProgramText", "NumberedHeads"]],
  
  Cell[StyleData["ProgramText", "Presentation"],
    CellMargins->{{23, 10}, {18, 0}},
    FontSize->14],
  
  Cell[StyleData["ProgramText", "Printout"],
    CellMargins->{{2, 12}, {12, 0}},
    TextJustification->1,
    FontSize->7],
  
  Cell[StyleData["ProgramText", "NumberedHeadsPrintout"],
    CellMargins->{{2, 12}, {12, 0}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableTitle"],
    PageWidth->WindowWidth,
    CellMargins->{{12, 10}, {1, 7}},
    CellGroupingRules->"InputGrouping",
    ConversionRules:>{"TeX" -> {"\n\\caption{", Automatic, "}"}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"TableTitle"}, 
      "CounterTarget" -> "Cell", "XRefPrefix" -> "Table"}, 
      "ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 90, 
      "AlwaysStartEnvironment" -> True}, "TeX" -> {"CellGroupEnvironment" -> 
      "table"}}},
    LineSpacing->{1, 2},
    CounterIncrements->"TableTitle",
    CounterAssignments->{{"Nil", 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    GridBoxOptions->{ColumnWidths->40,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TableTitle", "NumberedHeads"]],
  
  Cell[StyleData["TableTitle", "Presentation"],
    CellMargins->{{23, 10}, {2, 11}},
    FontSize->17],
  
  Cell[StyleData["TableTitle", "Printout"],
    CellMargins->{{2, 10}, {1, 5}},
    FontSize->10],
  
  Cell[StyleData["TableTitle", "NumberedHeadsPrintout"],
    CellMargins->{{2, 10}, {1, 5}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableTitleLabel"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    LineSpacing->{1, 2},
    CounterIncrements->"TableTitleLabel",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    GridBoxOptions->{ColumnWidths->40,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TableTitleLabel", "NumberedHeads"]],
  
  Cell[StyleData["TableTitleLabel", "Presentation"]],
  
  Cell[StyleData["TableTitleLabel", "Printout"],
    FontSize->10],
  
  Cell[StyleData["TableTitleLabel", "NumberedHeadsPrintout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Table"],
    Editable->False,
    PageWidth->WindowWidth,
    CellMargins->{{12, 10}, {4, 1}},
    CellGroupingRules->"OutputGrouping",
    ConversionRules:>{"TeX" -> {"\n\\begin{center}", Automatic, 
      "\n\\end{center}"}, "HTML" -> {{"", Automatic, ""}, {"", Automatic, 
      ""}}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"TableTitle"}, 
      "CounterTarget" -> "CellGroup"}, "ExtraConversionRules" -> {
      "General" -> {"NestingLevel" -> 90}, "TeX" -> {"CellGroupEnvironment" -> 
      "table"}}},
    CellHorizontalScrolling->True,
    CounterIncrements->"Table",
    CounterAssignments->{{"TableNote", 0}},
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.503,
    RowAlignments->Center,
    ColumnAlignments->{Left},
    GridFrame->{{0, 0}, {0.5, 2}},
    GridDefaultElement:>Cell[ "Data", "TableText"]}],
  
  Cell[StyleData["Table", "NumberedHeads"]],
  
  Cell[StyleData["Table", "Presentation"],
    CellMargins->{{23, 10}, {6, 2}},
    FontSize->17],
  
  Cell[StyleData["Table", "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{2, 10}, {3, 1}},
    FontSize->10],
  
  Cell[StyleData["Table", "NumberedHeadsPrintout"],
    PageWidth->PaperWidth,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableNumber"],
    StyleMenuListing->None],
  
  Cell[StyleData["TableNumber", "NumberedHeads"]],
  
  Cell[StyleData["TableNumber", "Presentation"]],
  
  Cell[StyleData["TableNumber", "Printout"]],
  
  Cell[StyleData["TableNumber", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableNote"],
    Editable->False,
    PageWidth->WindowWidth,
    CellMargins->{{12, 10}, {7, -3}},
    CellGroupingRules->"OutputGrouping",
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Table"}, 
      "CounterTarget" -> "CellGroup"}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0.3, 0},
    CounterIncrements->"TableNote",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10,
    FontColor->GrayLevel[0.300008]],
  
  Cell[StyleData["TableNote", "NumberedHeads"]],
  
  Cell[StyleData["TableNote", "Presentation"],
    CellMargins->{{23, 10}, {11, -5}},
    FontSize->15],
  
  Cell[StyleData["TableNote", "Printout"],
    CellMargins->{{2, 10}, {5, -2}},
    FontSize->9],
  
  Cell[StyleData["TableNote", "NumberedHeadsPrintout"],
    CellMargins->{{2, 10}, {5, -2}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableNoteLabel"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["TableNoteLabel", "NumberedHeads"]],
  
  Cell[StyleData["TableNoteLabel", "Presentation"]],
  
  Cell[StyleData["TableNoteLabel", "Printout"]],
  
  Cell[StyleData["TableNoteLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableSpacer"],
    StyleMenuListing->None],
  
  Cell[StyleData["TableSpacer", "NumberedHeads"]],
  
  Cell[StyleData["TableSpacer", "Presentation"]],
  
  Cell[StyleData["TableSpacer", "Printout"],
    StyleMenuListing->None],
  
  Cell[StyleData["TableSpacer", "NumberedHeadsPrintout"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Table Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableColumnHead"],
    Editable->True,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSlant->"Italic",
    GridBoxOptions->{GridBaseline->Axis,
    RowSpacings->1,
    ColumnSpacings->0.8,
    ColumnWidths->Automatic,
    RowAlignments->Baseline,
    ColumnAlignments->{Center},
    GridFrame->False,
    GridFrameMargins->{{0.4, 0.4}, {0.5, 0.5}},
    RowLines->False,
    ColumnLines->False,
    RowMinHeight->1,
    RowsEqual->False,
    ColumnsEqual->False,
    GridDefaultElement:>"\[Placeholder]"}],
  
  Cell[StyleData["TableColumnHead", "NumberedHeads"]],
  
  Cell[StyleData["TableColumnHead", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["TableColumnHead", "Printout"],
    FontSize->10],
  
  Cell[StyleData["TableColumnHead", "NumberedHeadsPrintout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableSpanHead"],
    Editable->True,
    TextAlignment->Center,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSlant->"Italic",
    GridBoxOptions->{GridBaseline->Axis,
    RowSpacings->1,
    ColumnSpacings->0.8,
    ColumnWidths->Automatic,
    RowAlignments->Baseline,
    ColumnAlignments->{Center},
    GridFrame->False,
    GridFrameMargins->{{0.4, 0.4}, {0.5, 0.5}},
    RowLines->False,
    ColumnLines->False,
    RowMinHeight->1,
    RowsEqual->False,
    ColumnsEqual->False,
    GridDefaultElement:>"\[Placeholder]"}],
  
  Cell[StyleData["TableSpanHead", "NumberedHeads"]],
  
  Cell[StyleData["TableSpanHead", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["TableSpanHead", "Printout"],
    FontSize->10],
  
  Cell[StyleData["TableSpanHead", "NumberedHeadsPrintout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableText"],
    Editable->True,
    TextAlignment->Left,
    LineSpacing->{1, 1},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    GridBoxOptions->{GridBaseline->Axis,
    RowSpacings->1,
    ColumnSpacings->0.8,
    ColumnWidths->Automatic,
    RowAlignments->Baseline,
    ColumnAlignments->{Center},
    GridFrame->False,
    GridFrameMargins->{{0.4, 0.4}, {0.5, 0.5}},
    RowLines->False,
    ColumnLines->False,
    RowMinHeight->1,
    RowsEqual->False,
    ColumnsEqual->False,
    GridDefaultElement:>"\[Placeholder]"}],
  
  Cell[StyleData["TableText", "NumberedHeads"]],
  
  Cell[StyleData["TableText", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["TableText", "Printout"],
    FontSize->10],
  
  Cell[StyleData["TableText", "NumberedHeadsPrintout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableSpanText"],
    Editable->True,
    TextAlignment->Left,
    LineSpacing->{1, 1},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    GridBoxOptions->{ColumnSpacings->0,
    ColumnAlignments->{Left},
    GridFrame->False,
    RowLines->False}],
  
  Cell[StyleData["TableSpanText", "NumberedHeads"]],
  
  Cell[StyleData["TableSpanText", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["TableSpanText", "Printout"],
    FontSize->10],
  
  Cell[StyleData["TableSpanText", "NumberedHeadsPrintout"],
    FontSize->10]
  }, Closed]],
  
  Cell[StyleData["TableSubGrid"],
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->0.7,
    ColumnSpacings->0.8,
    ColumnAlignments->{Left, Center},
    GridFrame->False,
    RowLines->False,
    RowMinHeight->0.1,
    GridDefaultElement:>Cell[ "Data", "TableText"]}],
  
  Cell[StyleData["TableMasterGrid"],
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->0.01,
    ColumnWidths->0.999}],
  
  Cell[StyleData["TableLineElement"],
    Editable->False,
    CellFrame->{{0, 0}, {0.5, 0}},
    CellElementSpacings->{"CellMinHeight"->1},
    ConversionRules:>{"HTML" -> {{"&nbsp;", 
      NoOutput[ ], ""}, {"", Automatic, ""}}},
    CellSize->{Inherited, 1.25},
    TabFilling->" ",
    TabSpacings->1000,
    StyleMenuListing->None,
    FontSize->1],
  
  Cell[StyleData["TableBlankElement"],
    Editable->False,
    CellElementSpacings->{"CellMinHeight"->1},
    CellSize->{Inherited, 1.25},
    StyleMenuListing->None,
    FontSize->1],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SpanLeft"],
    Editable->False,
    StyleMenuListing->None,
    FontSize->16,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SpanLeft", "NumberedHeads"]],
  
  Cell[StyleData["SpanLeft", "Printout"],
    FontSize->14],
  
  Cell[StyleData["SpanLeft", "Presentation"]],
  
  Cell[StyleData["SpanLeft", "NumberedHeadsPrintout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SpanCenter"],
    Editable->False,
    StyleMenuListing->None,
    FontSize->16,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SpanCenter", "NumberedHeads"]],
  
  Cell[StyleData["SpanCenter", "Presentation"]],
  
  Cell[StyleData["SpanCenter", "Printout"],
    FontSize->14],
  
  Cell[StyleData["SpanCenter", "NumberedHeadsPrintout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SpanRight"],
    Editable->False,
    StyleMenuListing->None,
    FontSize->16,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SpanRight", "NumberedHeads"]],
  
  Cell[StyleData["SpanRight", "Presentation"]],
  
  Cell[StyleData["SpanRight", "Printout"],
    FontSize->14],
  
  Cell[StyleData["SpanRight", "NumberedHeadsPrintout"],
    FontSize->14]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Caption", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{12, 10}, {6, 2}},
    CellGroupingRules->"OutputGrouping",
    TaggingRules:>{"CounterSettings" -> {"CounterTarget" -> "CellGroup"}},
    PageBreakAbove->False,
    Hyphenation->True,
    CounterIncrements->"Caption",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "NumberedHeads"]],
  
  Cell[StyleData["Caption", "Presentation"],
    CellMargins->{{23, 10}, {9, 3}},
    FontSize->14],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 12}, {2, 4}},
    FontSize->7],
  
  Cell[StyleData["Caption", "NumberedHeadsPrintout"],
    CellMargins->{{2, 12}, {2, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CaptionLabel"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["CaptionLabel", "NumberedHeads"]],
  
  Cell[StyleData["CaptionLabel", "Presentation"]],
  
  Cell[StyleData["CaptionLabel", "Printout"],
    StyleMenuListing->None],
  
  Cell[StyleData["CaptionLabel", "NumberedHeadsPrintout"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CaptionNumber"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["CaptionNumber", "NumberedHeads"]],
  
  Cell[StyleData["CaptionNumber", "Presentation"]],
  
  Cell[StyleData["CaptionNumber", "Printout"]],
  
  Cell[StyleData["CaptionNumber", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CaptionText"],
    CellMargins->{{12, 10}, {12, 0}},
    CellGroupingRules->"OutputGrouping",
    PageBreakAbove->False,
    Hyphenation->True,
    CounterIncrements->"CaptionText",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9],
  
  Cell[StyleData["CaptionText", "NumberedHeads"]],
  
  Cell[StyleData["CaptionText", "Presentation"],
    CellMargins->{{23, 10}, {18, 0}},
    FontSize->14],
  
  Cell[StyleData["CaptionText", "Printout"],
    CellMargins->{{2, 12}, {12, 0}},
    TextJustification->1,
    FontSize->7],
  
  Cell[StyleData["CaptionText", "NumberedHeadsPrintout"],
    CellMargins->{{2, 12}, {12, 0}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text Extract", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Extract"],
    CellMargins->{{24, 22}, {8, 8}},
    LineSpacing->{1, 2},
    StyleMenuListing->None,
    FontSize->11],
  
  Cell[StyleData["Extract", "NumberedHeads"]],
  
  Cell[StyleData["Extract", "Presentation"],
    CellMargins->{{35, 22}, {12, 12}},
    FontSize->17],
  
  Cell[StyleData["Extract", "Printout"],
    CellMargins->{{12, 24}, {4, 4}},
    TextJustification->1,
    FontSize->9],
  
  Cell[StyleData["Extract", "NumberedHeadsPrintout"],
    CellMargins->{{12, 24}, {4, 4}},
    TextJustification->1,
    FontSize->9]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Mathematics", "Section"],
  
  Cell[CellGroupData[{
  
  Cell["Equations", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Equation"],
    CellMargins->{{12, 32}, {7, 7}},
    ConversionRules:>{"HTML" -> {{"", ""}, {"<p class=\"Equation\">", 
      "</p>"}}},
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      90}}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    InputAutoReplacements->{},
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    CounterIncrements->"Equation",
    StyleMenuListing->None],
  
  Cell[StyleData["Equation", "NumberedHeads"]],
  
  Cell[StyleData["Equation", "Presentation"],
    CellMargins->{{23, 32}, {11, 11}},
    FontSize->19],
  
  Cell[StyleData["Equation", "Printout"],
    CellMargins->{{2, 20}, {5, 5}},
    FontSize->10],
  
  Cell[StyleData["Equation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 20}, {5, 5}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationWide"],
    CellMargins->{{12, 32}, {7, 7}},
    ConversionRules:>{"HTML" -> {{"", ""}, {"<p class=\"EquationWide\">", 
      "</p>"}}},
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      90}}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    InputAutoReplacements->{},
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    CounterIncrements->"Equation",
    StyleMenuListing->None],
  
  Cell[StyleData["EquationWide", "NumberedHeads"]],
  
  Cell[StyleData["EquationWide", "Presentation"],
    CellMargins->{{23, 32}, {11, 11}},
    FontSize->19],
  
  Cell[StyleData["EquationWide", "Printout"],
    CellMargins->{{2, 20}, {5, 5}},
    FontSize->10],
  
  Cell[StyleData["EquationWide", "NumberedHeadsPrintout"],
    CellMargins->{{2, 20}, {5, 5}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationGroup"],
    CellMargins->{{12, 32}, {0, 2}},
    CellGroupingRules->"GraphicsGrouping",
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      90, "Numbered" -> False}, "TeX" -> {"CellGroupEnvironment" -> 
      "gather*"}}},
    DefaultFormatType->DefaultInputFormatType,
    StyleMenuListing->None],
  
  Cell[StyleData["EquationGroup", "NumberedHeads"]],
  
  Cell[StyleData["EquationGroup", "Presentation"],
    CellMargins->{{23, 32}, {0, 3}},
    FontSize->19],
  
  Cell[StyleData["EquationGroup", "Printout"],
    CellMargins->{{2, 20}, {0, 1}},
    FontSize->10],
  
  Cell[StyleData["EquationGroup", "NumberedHeadsPrintout"],
    CellMargins->{{2, 20}, {0, 1}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationGroupAligned"],
    CellMargins->{{12, 42}, {0, 2}},
    CellGroupingRules->"GraphicsGrouping",
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      90, "Numbered" -> False}, "TeX" -> {"CellGroupEnvironment" -> 
      "align*"}}},
    DefaultFormatType->DefaultInputFormatType,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->False},
    UnderscriptBoxOptions->{LimitsPositioning->False},
    OverscriptBoxOptions->{LimitsPositioning->False},
    GridBoxOptions->{AllowScriptLevelChange->False}],
  
  Cell[StyleData["EquationGroupAligned", "NumberedHeads"]],
  
  Cell[StyleData["EquationGroupAligned", "Presentation"],
    CellMargins->{{23, 55}, {0, 3}},
    FontSize->19],
  
  Cell[StyleData["EquationGroupAligned", "Printout"],
    CellMargins->{{2, 28}, {0, 1}},
    FontSize->10],
  
  Cell[StyleData["EquationGroupAligned", "NumberedHeadsPrintout"],
    CellMargins->{{2, 28}, {0, 1}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Numbered Equations", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumbered"],
    CellMargins->{{12, 12}, {7, 7}},
    ConversionRules:>{"HTML" -> {{"", ""}, {
      "<table class='EquationNumbered'><tr><td>", Automatic, 
      IncludeCount[ 
      "</td><td class='EquationNumberedLabel'>(`1`)</td></tr></table>", 
        "EquationNumbered"]}}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {
      "EquationNumbered"}, "CounterTarget" -> "Cell", "XRefPrefix" -> 
      "Equation"}, "ExtraConversionRules" -> {"General" -> {"Numbered" -> 
      True, "NestingLevel" -> 90}}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "EquationNumbered"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    InputAutoReplacements->{},
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    CounterIncrements->"EquationNumbered",
    StyleMenuListing->None],
  
  Cell[StyleData["EquationNumbered", "NumberedHeads"]],
  
  Cell[StyleData["EquationNumbered", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    FontSize->19],
  
  Cell[StyleData["EquationNumbered", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->10],
  
  Cell[StyleData["EquationNumbered", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationWideNumbered"],
    CellMargins->{{12, 12}, {7, 7}},
    ConversionRules:>{"HTML" -> {{"", ""}, {
      "<table class='EquationGroupNumbered'><tr><td>", Automatic, 
      IncludeCount[ 
      "</td><td class='EquationGroupNumberedLabel'>(`1`)</td></tr></table>", 
        "EquationNumbered"]}}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {
      "EquationNumbered"}, "CounterTarget" -> "Cell", "XRefPrefix" -> 
      "Equation"}, "ExtraConversionRules" -> {"General" -> {"Numbered" -> 
      True, "NestingLevel" -> 90}}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "EquationNumbered"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    InputAutoReplacements->{},
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    CounterIncrements->"EquationNumbered",
    StyleMenuListing->None],
  
  Cell[StyleData["EquationWideNumbered", "NumberedHeads"]],
  
  Cell[StyleData["EquationWideNumbered", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    FontSize->19],
  
  Cell[StyleData["EquationWideNumbered", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->10],
  
  Cell[StyleData["EquationWideNumbered", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationGroupNumbered"],
    CellMargins->{{12, 6}, {0, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"HTML" -> {{"", ""}, {
      "<table class='EquationGroupNumbered'><tr><td>", Automatic, 
      IncludeCount[ 
      "</td><td class='EquationGroupNumberedLabel'>(`1`)</td></tr></table>", 
        "EquationNumbered"]}}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {
      "EquationNumbered"}, "CounterTarget" -> "Cell", "XRefPrefix" -> 
      "Equation"}, "ExtraConversionRules" -> {"General" -> {"Numbered" -> 
      True, "NestingLevel" -> 90}, "TeX" -> {"CellGroupEnvironment" -> 
      "gather"}}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "EquationNumbered"], ")"}], "EquationNumber"]}, {
        None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"EquationNumbered",
    StyleMenuListing->None],
  
  Cell[StyleData["EquationGroupNumbered", "NumberedHeads"]],
  
  Cell[StyleData["EquationGroupNumbered", "Presentation"],
    CellMargins->{{23, 6}, {0, 3}},
    FontSize->19],
  
  Cell[StyleData["EquationGroupNumbered", "Printout"],
    CellMargins->{{2, 2}, {0, 1}},
    FontSize->10],
  
  Cell[StyleData["EquationGroupNumbered", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {0, 1}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationGroupAlignedNumbered"],
    CellMargins->{{12, 6}, {0, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"HTML" -> {{"", ""}, {
      "<table class='EquationGroupAlignedNumbered'><tr><td>", Automatic, 
      IncludeCount[ 
      "</td><td \
class='EquationGroupAlignedNumberedLabel'>(`1`)</td></tr></table>", 
        "EquationNumbered"]}}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {
      "EquationNumbered"}, "CounterTarget" -> "Cell", "XRefPrefix" -> 
      "Equation"}, "ExtraConversionRules" -> {"General" -> {"Numbered" -> 
      True, "NestingLevel" -> 90}, "TeX" -> {"CellGroupEnvironment" -> 
      "align"}}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "EquationNumbered"], ")"}], "EquationNumber"]}, {
        None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"EquationNumbered",
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->False},
    UnderscriptBoxOptions->{LimitsPositioning->False},
    OverscriptBoxOptions->{LimitsPositioning->False},
    GridBoxOptions->{AllowScriptLevelChange->False}],
  
  Cell[StyleData["EquationGroupAlignedNumbered", "NumberedHeads"]],
  
  Cell[StyleData["EquationGroupAlignedNumbered", "Presentation"],
    CellMargins->{{23, 6}, {0, 3}},
    FontSize->19],
  
  Cell[StyleData["EquationGroupAlignedNumbered", "Printout"],
    CellMargins->{{2, 2}, {0, 1}},
    FontSize->10],
  
  Cell[StyleData["EquationGroupAlignedNumbered", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {0, 1}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubequationNumbered"],
    CellMargins->{{12, 6}, {0, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"HTML" -> {{"", ""}, {
      "<table class='SubequationNumbered'><tr><td>", Automatic, 
      IncludeCount[ 
      "</td><td class='SubequationNumberedLabel'>(`1``2`)</td></tr></table>", 
        "EquationNumbered", "SubequationNumbered"]}}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {
      "EquationNumbered", "", "SubequationNumbered"}, "CounterTarget" -> 
      "Cell", "XRefPrefix" -> "Equation"}, "ExtraConversionRules" -> {
      "General" -> {"Numbered" -> True, "NestingLevel" -> 90, "Subequation" -> 
      True}, "TeX" -> {"CellGroupEnvironment" -> "gather"}}},
    CellFrameLabels->{{Inherited, Cell[ 
            TextData[ {"(", 
              CounterBox[ "EquationNumbered", CounterFunction :> Identity], 
              CounterBox[ "SubequationNumbered"], ")"}], 
            "SubequationNumber"]}, {Inherited, Inherited}},
    CounterIncrements->"SubequationNumbered",
    StyleMenuListing->None,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["SubequationNumbered", "NumberedHeads"]],
  
  Cell[StyleData["SubequationNumbered", "Presentation"],
    CellMargins->{{23, 6}, {0, 3}},
    FontSize->19],
  
  Cell[StyleData["SubequationNumbered", "Printout"],
    CellMargins->{{2, 2}, {0, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["SubequationNumbered", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {0, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubequationAlignedNumbered"],
    CellMargins->{{12, 6}, {0, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"HTML" -> {{"", ""}, {
      "<table class='SubequationAlignedNumbered'><tr><td>", Automatic, 
      IncludeCount[ 
      "</td><td \
class='SubequationAlignedNumberedLabel'>(`1``2`)</td></tr></table>", 
        "EquationNumbered", "SubequationNumbered"]}}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {
      "EquationNumbered", "", "SubequationNumbered"}, "CounterTarget" -> 
      "Cell", "XRefPrefix" -> "Equation"}, "ExtraConversionRules" -> {
      "General" -> {"Numbered" -> True, "NestingLevel" -> 90, "Subequation" -> 
      True}, "TeX" -> {"CellGroupEnvironment" -> "align"}}},
    CellFrameLabels->{{Inherited, Cell[ 
            TextData[ {"(", 
              CounterBox[ "EquationNumbered", CounterFunction :> Identity], 
              CounterBox[ "SubequationNumbered"], ")"}], 
            "SubequationNumber"]}, {Inherited, Inherited}},
    CounterIncrements->"SubequationNumbered",
    StyleMenuListing->None,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)},
    UnderoverscriptBoxOptions->{LimitsPositioning->False},
    UnderscriptBoxOptions->{LimitsPositioning->False},
    OverscriptBoxOptions->{LimitsPositioning->False},
    GridBoxOptions->{AllowScriptLevelChange->False}],
  
  Cell[StyleData["SubequationAlignedNumbered", "NumberedHeads"]],
  
  Cell[StyleData["SubequationAlignedNumbered", "Presentation"],
    CellMargins->{{24, 6}, {0, 3}},
    FontSize->19],
  
  Cell[StyleData["SubequationAlignedNumbered", "Printout"],
    CellMargins->{{2, 2}, {0, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["SubequationAlignedNumbered", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {0, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    CellSize->{30, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None],
  
  Cell[StyleData["EquationNumber", "NumberedHeads"]],
  
  Cell[StyleData["EquationNumber", "Presentation"],
    CellSize->{45, Inherited}],
  
  Cell[StyleData["EquationNumber", "Printout"],
    CellSize->{27, Inherited}],
  
  Cell[StyleData["EquationNumber", "NumberedHeadsPrintout"],
    CellSize->{27, Inherited}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubequationNumber"],
    CellSize->{30, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None],
  
  Cell[StyleData["SubequationNumber", "NumberedHeads"]],
  
  Cell[StyleData["SubequationNumber", "Presentation"],
    CellSize->{45, Inherited}],
  
  Cell[StyleData["SubequationNumber", "Printout"],
    CellSize->{27, Inherited}],
  
  Cell[StyleData["SubequationNumber", "NumberedHeadsPrintout"],
    CellSize->{27, Inherited}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Equation Grid Tag Styles", "Subsection"],
  
  Cell[StyleData["EquationGrid"],
    StyleMenuListing->None],
  
  Cell[StyleData["SplitEquation"],
    StyleMenuListing->None],
  
  Cell[StyleData["Piecewise"],
    StyleMenuListing->None],
  
  Cell[StyleData["Matrix"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Enunciations", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell["Theorem", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Section", ".", 
      "Theorem"}, "CounterTarget" -> "Cell"}, "ExtraConversionRules" -> {
      "TeX" -> {"NestingLevel" -> 10, "CellGroupEnvironment" -> "theorem"}}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->14,
    CounterIncrements->"Theorem",
    CounterAssignments->{{"EnunciationItem1Numbered", 0}, {
        "Item1Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["Theorem", "NumberedHeads"]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    ParagraphIndent->21,
    FontSize->17],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10],
  
  Cell[StyleData["Theorem", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TheoremLabel"],
    ConversionRules:>{"TeX" -> {{"", 
      NoOutput[ ], ""}, {"", Automatic, ""}}},
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TheoremLabel", "NumberedHeads"]],
  
  Cell[StyleData["TheoremLabel", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["TheoremLabel", "Printout"],
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["TheoremLabel", "NumberedHeadsPrintout"],
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TheoremContinuation"],
    CellMargins->{{12, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"", Automatic, ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "theorem"}}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->0,
    CounterIncrements->"TheoremContinuation",
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TheoremContinuation", "NumberedHeads"]],
  
  Cell[StyleData["TheoremContinuation", "Presentation"],
    CellMargins->{{23, 12}, {2, 2}},
    FontSize->17],
  
  Cell[StyleData["TheoremContinuation", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10],
  
  Cell[StyleData["TheoremContinuation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Corollary", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Corollary"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "corollary"}}, "CounterSettings" -> {
      "CounterFormat" -> {"Section", ".", "Theorem"}, "CounterTarget" -> 
      "Cell"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->14,
    CounterIncrements->"Theorem",
    CounterAssignments->{{"EnunciationItem1Numbered", 0}, {
        "Item1Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["Corollary", "NumberedHeads"]],
  
  Cell[StyleData["Corollary", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    ParagraphIndent->21,
    FontSize->17],
  
  Cell[StyleData["Corollary", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10],
  
  Cell[StyleData["Corollary", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CorollaryLabel"],
    ConversionRules:>{"TeX" -> {{"", 
      NoOutput[ ], ""}, {"", Automatic, ""}}},
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["CorollaryLabel", "NumberedHeads"]],
  
  Cell[StyleData["CorollaryLabel", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["CorollaryLabel", "Printout"],
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CorollaryLabel", "NumberedHeadsPrintout"],
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CorollaryContinuation"],
    CellMargins->{{12, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"", Automatic, ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "corollary"}}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->0,
    CounterIncrements->"CorollaryContinuation",
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["CorollaryContinuation", "NumberedHeads"]],
  
  Cell[StyleData["CorollaryContinuation", "Presentation"],
    CellMargins->{{23, 12}, {2, 2}},
    FontSize->17],
  
  Cell[StyleData["CorollaryContinuation", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10],
  
  Cell[StyleData["CorollaryContinuation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Lemma", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Lemma"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "lemma"}}, "CounterSettings" -> {
      "CounterFormat" -> {"Section", ".", "Theorem"}, "CounterTarget" -> 
      "Cell"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->14,
    CounterIncrements->"Theorem",
    CounterAssignments->{{"EnunciationItem1Numbered", 0}, {
        "Item1Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["Lemma", "NumberedHeads"]],
  
  Cell[StyleData["Lemma", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    ParagraphIndent->21,
    FontSize->17],
  
  Cell[StyleData["Lemma", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10],
  
  Cell[StyleData["Lemma", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LemmaLabel"],
    ConversionRules:>{"TeX" -> {{"", 
      NoOutput[ ], ""}, {"", Automatic, ""}}},
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["LemmaLabel", "NumberedHeads"]],
  
  Cell[StyleData["LemmaLabel", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["LemmaLabel", "Printout"],
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["LemmaLabel", "NumberedHeadsPrintout"],
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LemmaContinuation"],
    CellMargins->{{12, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"", Automatic, ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "lemma"}}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->0,
    CounterIncrements->"LemmaContinuation",
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["LemmaContinuation", "NumberedHeads"]],
  
  Cell[StyleData["LemmaContinuation", "Presentation"],
    CellMargins->{{23, 12}, {2, 2}},
    FontSize->17],
  
  Cell[StyleData["LemmaContinuation", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10],
  
  Cell[StyleData["LemmaContinuation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Proposition", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Proposition"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "proposition"}}, "CounterSettings" -> {
      "CounterFormat" -> {"Section", ".", "Theorem"}, "CounterTarget" -> 
      "Cell"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->14,
    CounterIncrements->"Theorem",
    CounterAssignments->{{"EnunciationItem1Numbered", 0}, {
        "Item1Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["Proposition", "NumberedHeads"]],
  
  Cell[StyleData["Proposition", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    ParagraphIndent->21,
    FontSize->17],
  
  Cell[StyleData["Proposition", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10],
  
  Cell[StyleData["Proposition", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PropositionLabel"],
    ConversionRules:>{"TeX" -> {{"", 
      NoOutput[ ], ""}, {"", Automatic, ""}}},
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["PropositionLabel", "NumberedHeads"]],
  
  Cell[StyleData["PropositionLabel", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["PropositionLabel", "Printout"],
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["PropositionLabel", "NumberedHeadsPrintout"],
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PropositionContinuation"],
    CellMargins->{{12, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"", Automatic, ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "proposition"}}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->0,
    CounterIncrements->"PropositionContinuation",
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["PropositionContinuation", "NumberedHeads"]],
  
  Cell[StyleData["PropositionContinuation", "Presentation"],
    CellMargins->{{23, 12}, {2, 2}},
    FontSize->17],
  
  Cell[StyleData["PropositionContinuation", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10],
  
  Cell[StyleData["PropositionContinuation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Conjecture", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Conjecture"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "conjecture"}}, "CounterSettings" -> {
      "CounterFormat" -> {"Section", ".", "Theorem"}, "CounterTarget" -> 
      "Cell"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->14,
    CounterIncrements->"Theorem",
    CounterAssignments->{{"EnunciationItem1Numbered", 0}, {
        "Item1Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["Conjecture", "NumberedHeads"]],
  
  Cell[StyleData["Conjecture", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    ParagraphIndent->21,
    FontSize->17],
  
  Cell[StyleData["Conjecture", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10],
  
  Cell[StyleData["Conjecture", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ConjectureLabel"],
    ConversionRules:>{"TeX" -> {{"", 
      NoOutput[ ], ""}, {"", Automatic, ""}}},
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["ConjectureLabel", "NumberedHeads"]],
  
  Cell[StyleData["ConjectureLabel", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["ConjectureLabel", "Printout"],
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["ConjectureLabel", "NumberedHeadsPrintout"],
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ConjectureContinuation"],
    CellMargins->{{12, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"", Automatic, ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "conjecture"}}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->0,
    CounterIncrements->"ConjectureContinuation",
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["ConjectureContinuation", "NumberedHeads"]],
  
  Cell[StyleData["ConjectureContinuation", "Presentation"],
    CellMargins->{{23, 12}, {2, 2}},
    FontSize->17],
  
  Cell[StyleData["ConjectureContinuation", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10],
  
  Cell[StyleData["ConjectureContinuation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Definition", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "definition"}}, "CounterSettings" -> {
      "CounterFormat" -> {"Section", ".", "Theorem"}, "CounterTarget" -> 
      "Cell"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->14,
    CounterIncrements->"Theorem",
    CounterAssignments->{{"EnunciationItem1Numbered", 0}, {
        "Item1Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Plain"],
  
  Cell[StyleData["Definition", "NumberedHeads"]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    ParagraphIndent->21,
    FontSize->17],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10],
  
  Cell[StyleData["Definition", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionLabel"],
    ConversionRules:>{"TeX" -> {{"", 
      NoOutput[ ], ""}, {"", Automatic, ""}}},
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["DefinitionLabel", "NumberedHeads"]],
  
  Cell[StyleData["DefinitionLabel", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["DefinitionLabel", "Printout"],
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["DefinitionLabel", "NumberedHeadsPrintout"],
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionContinuation"],
    CellMargins->{{12, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"", Automatic, ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "definition"}}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->0,
    CounterIncrements->"DefinitionContinuation",
    StyleMenuListing->None],
  
  Cell[StyleData["DefinitionContinuation", "NumberedHeads"]],
  
  Cell[StyleData["DefinitionContinuation", "Presentation"],
    CellMargins->{{23, 12}, {2, 2}},
    FontSize->17],
  
  Cell[StyleData["DefinitionContinuation", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10],
  
  Cell[StyleData["DefinitionContinuation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Axiom", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Axiom"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "axiom"}}, "CounterSettings" -> {
      "CounterFormat" -> {"Section", ".", "Theorem"}, "CounterTarget" -> 
      "Cell"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->14,
    CounterIncrements->"Theorem",
    CounterAssignments->{{"EnunciationItem1Numbered", 0}, {
        "Item1Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Plain"],
  
  Cell[StyleData["Axiom", "NumberedHeads"]],
  
  Cell[StyleData["Axiom", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    ParagraphIndent->21,
    FontSize->17],
  
  Cell[StyleData["Axiom", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10],
  
  Cell[StyleData["Axiom", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AxiomLabel"],
    ConversionRules:>{"TeX" -> {{"", 
      NoOutput[ ], ""}, {"", Automatic, ""}}},
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["AxiomLabel", "NumberedHeads"]],
  
  Cell[StyleData["AxiomLabel", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["AxiomLabel", "Printout"],
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["AxiomLabel", "NumberedHeadsPrintout"],
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AxiomContinuation"],
    CellMargins->{{12, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"", Automatic, ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "axiom"}}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->0,
    CounterIncrements->"AxiomContinuation",
    StyleMenuListing->None],
  
  Cell[StyleData["AxiomContinuation", "NumberedHeads"]],
  
  Cell[StyleData["AxiomContinuation", "Presentation"],
    CellMargins->{{23, 12}, {2, 2}},
    FontSize->17],
  
  Cell[StyleData["AxiomContinuation", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10],
  
  Cell[StyleData["AxiomContinuation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Example", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "example"}}, "CounterSettings" -> {
      "CounterFormat" -> {"Section", ".", "Theorem"}, "CounterTarget" -> 
      "Cell"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->14,
    CounterIncrements->"Theorem",
    CounterAssignments->{{"EnunciationItem1Numbered", 0}, {
        "Item1Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Plain"],
  
  Cell[StyleData["Example", "NumberedHeads"]],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    ParagraphIndent->21,
    FontSize->17],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10],
  
  Cell[StyleData["Example", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleLabel"],
    ConversionRules:>{"TeX" -> {{"", 
      NoOutput[ ], ""}, {"", Automatic, ""}}},
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["ExampleLabel", "NumberedHeads"]],
  
  Cell[StyleData["ExampleLabel", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["ExampleLabel", "Printout"],
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["ExampleLabel", "NumberedHeadsPrintout"],
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleContinuation"],
    CellMargins->{{12, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"", Automatic, ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "example"}}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->0,
    CounterIncrements->"ExampleContinuation",
    StyleMenuListing->None],
  
  Cell[StyleData["ExampleContinuation", "NumberedHeads"]],
  
  Cell[StyleData["ExampleContinuation", "Presentation"],
    CellMargins->{{23, 12}, {2, 2}},
    FontSize->17],
  
  Cell[StyleData["ExampleContinuation", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10],
  
  Cell[StyleData["ExampleContinuation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Remark", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Remark"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "remark"}}, "CounterSettings" -> {
      "CounterFormat" -> {"Section", ".", "Theorem"}, "CounterTarget" -> 
      "Cell"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->14,
    CounterIncrements->"Theorem",
    CounterAssignments->{{"EnunciationItem1Numbered", 0}, {
        "Item1Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Plain"],
  
  Cell[StyleData["Remark", "NumberedHeads"]],
  
  Cell[StyleData["Remark", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    ParagraphIndent->21,
    FontSize->17],
  
  Cell[StyleData["Remark", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10],
  
  Cell[StyleData["Remark", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RemarkLabel"],
    ConversionRules:>{"TeX" -> {{"", 
      NoOutput[ ], ""}, {"", Automatic, ""}}},
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["RemarkLabel", "NumberedHeads"]],
  
  Cell[StyleData["RemarkLabel", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["RemarkLabel", "Printout"],
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["RemarkLabel", "NumberedHeadsPrintout"],
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RemarkContinuation"],
    CellMargins->{{12, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"", Automatic, ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "remark"}}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->0,
    CounterIncrements->"RemarkContinuation",
    StyleMenuListing->None],
  
  Cell[StyleData["RemarkContinuation", "NumberedHeads"]],
  
  Cell[StyleData["RemarkContinuation", "Presentation"],
    CellMargins->{{23, 12}, {2, 2}},
    FontSize->17],
  
  Cell[StyleData["RemarkContinuation", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10],
  
  Cell[StyleData["RemarkContinuation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Proof", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Proof"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "proof"}}, "CounterSettings" -> {
      "CounterTarget" -> "Cell"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->14,
    CounterIncrements->"Theorem",
    CounterAssignments->{{"EnunciationItem1Numbered", 0}, {
        "Item1Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Plain"],
  
  Cell[StyleData["Proof", "NumberedHeads"]],
  
  Cell[StyleData["Proof", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    ParagraphIndent->21,
    FontSize->17],
  
  Cell[StyleData["Proof", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10],
  
  Cell[StyleData["Proof", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProofLabel"],
    ConversionRules:>{"TeX" -> {{"", 
      NoOutput[ ], ""}, {"", Automatic, ""}}},
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["ProofLabel", "NumberedHeads"]],
  
  Cell[StyleData["ProofLabel", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["ProofLabel", "Printout"],
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["ProofLabel", "NumberedHeadsPrintout"],
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProofContinuation"],
    CellMargins->{{12, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"", Automatic, ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "proof"}}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->0,
    CounterIncrements->"ProofContinuation",
    StyleMenuListing->None],
  
  Cell[StyleData["ProofContinuation", "NumberedHeads"]],
  
  Cell[StyleData["ProofContinuation", "Presentation"],
    CellMargins->{{23, 12}, {2, 2}},
    FontSize->17],
  
  Cell[StyleData["ProofContinuation", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10],
  
  Cell[StyleData["ProofContinuation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProofSection"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["ProofSection", "NumberedHeads"]],
  
  Cell[StyleData["ProofSection", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    FontSize->17],
  
  Cell[StyleData["ProofSection", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["ProofSection", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[StyleData["QED"],
    ConversionRules:>{"TeX" -> {{"", 
      NoOutput[ ], ""}, {"", Automatic, ""}}},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Case", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Case"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Theorem"}, 
      "CounterTarget" -> "Cell"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->14,
    CounterIncrements->"Theorem",
    CounterAssignments->{{"EnunciationItem1Numbered", 0}, {
        "Item1Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Plain"],
  
  Cell[StyleData["Case", "NumberedHeads"]],
  
  Cell[StyleData["Case", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    ParagraphIndent->21,
    FontSize->17],
  
  Cell[StyleData["Case", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10],
  
  Cell[StyleData["Case", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CaseLabel"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["CaseLabel", "NumberedHeads"]],
  
  Cell[StyleData["CaseLabel", "Presentation"]],
  
  Cell[StyleData["CaseLabel", "Printout"],
    FontSize->10],
  
  Cell[StyleData["CaseLabel", "NumberedHeadsPrintout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CaseContinuation"],
    CellMargins->{{12, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"", Automatic, ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 1, 
      "CellGroupEnvironment" -> "case"}}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->0,
    CounterIncrements->"CaseContinuation",
    StyleMenuListing->None],
  
  Cell[StyleData["CaseContinuation", "NumberedHeads"]],
  
  Cell[StyleData["CaseContinuation", "Presentation"],
    CellMargins->{{23, 12}, {2, 2}},
    FontSize->17],
  
  Cell[StyleData["CaseContinuation", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10],
  
  Cell[StyleData["CaseContinuation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CaseSection"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["CaseSection", "NumberedHeads"]],
  
  Cell[StyleData["CaseSection", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    FontSize->17],
  
  Cell[StyleData["CaseSection", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CaseSection", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Problems", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Problems"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Theorem"}, 
      "CounterTarget" -> "Cell"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->14,
    CounterIncrements->"Theorem",
    CounterAssignments->{{"EnunciationItem1Numbered", 0}, {
        "Item1Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Plain"],
  
  Cell[StyleData["Problems", "NumberedHeads"]],
  
  Cell[StyleData["Problems", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    ParagraphIndent->21,
    FontSize->17],
  
  Cell[StyleData["Problems", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10],
  
  Cell[StyleData["Problems", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProblemsLabel"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["ProblemsLabel", "NumberedHeads"]],
  
  Cell[StyleData["ProblemsLabel", "Presentation"]],
  
  Cell[StyleData["ProblemsLabel", "Printout"],
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["ProblemsLabel", "NumberedHeadsPrintout"],
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProblemsContinuation"],
    CellMargins->{{12, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"", Automatic, ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 1, 
      "CellGroupEnvironment" -> "problems"}}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->0,
    CounterIncrements->"ProblemsContinuation",
    StyleMenuListing->None],
  
  Cell[StyleData["ProblemsContinuation", "NumberedHeads"]],
  
  Cell[StyleData["ProblemsContinuation", "Presentation"],
    CellMargins->{{23, 12}, {2, 2}},
    FontSize->17],
  
  Cell[StyleData["ProblemsContinuation", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10],
  
  Cell[StyleData["ProblemsContinuation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProblemsSection"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["ProblemsSection", "NumberedHeads"]],
  
  Cell[StyleData["ProblemsSection", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    FontSize->17],
  
  Cell[StyleData["ProblemsSection", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["ProblemsSection", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Question", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Question"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {"Section", ".", 
      "Theorem"}, "CounterTarget" -> "Cell"}, "ExtraConversionRules" -> {
      "TeX" -> {"NestingLevel" -> 10, "CellGroupEnvironment" -> "question"}}},
    
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->14,
    CounterIncrements->"Theorem",
    StyleMenuListing->None],
  
  Cell[StyleData["Question", "NumberedHeads"]],
  
  Cell[StyleData["Question", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    ParagraphIndent->21,
    FontSize->17],
  
  Cell[StyleData["Question", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10],
  
  Cell[StyleData["Question", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    ParagraphIndent->10,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["QuestionLabel"],
    ConversionRules:>{"TeX" -> {{"", 
      NoOutput[ ], ""}, {"", Automatic, ""}}},
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["QuestionLabel", "NumberedHeads"]],
  
  Cell[StyleData["QuestionLabel", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["QuestionLabel", "Printout"],
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["QuestionLabel", "NumberedHeadsPrintout"],
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["QuestionContinuation"],
    CellMargins->{{12, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"", Automatic, ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 10, 
      "CellGroupEnvironment" -> "question"}}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->0,
    CounterIncrements->"QuestionContinuation",
    StyleMenuListing->None],
  
  Cell[StyleData["QuestionContinuation", "NumberedHeads"]],
  
  Cell[StyleData["QuestionContinuation", "Presentation"],
    CellMargins->{{23, 12}, {2, 2}},
    FontSize->17],
  
  Cell[StyleData["QuestionContinuation", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10],
  
  Cell[StyleData["QuestionContinuation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Enunciation-Specific Itemized Lists", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell["Bulleted Lists", "Subsubsubsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EnunciationItem1"],
    CellMargins->{{12, 12}, {1, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {"\n\\item ", ""}, "HTML" -> {"<li>", 
      "</li>"}},
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      30}, "TeX" -> {"CellGroupEnvironment" -> "itemize"}, "HTML" -> {Null, 
      "CellGroupEnvironment" -> "ul"}}},
    CellFrameLabels->{{
      Cell[ "\[FilledSmallCircle]", "Item1Label", CellBaseline -> Baseline], 
          Inherited}, {Inherited, Inherited}},
    CellFrameLabelMargins->4,
    CounterIncrements->"Item1",
    CounterAssignments->{{"Item2Numbered", 0}, {"Item3Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["EnunciationItem1", "NumberedHeads"]],
  
  Cell[StyleData["EnunciationItem1", "Presentation"],
    CellMargins->{{23, 12}, {2, 3}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["EnunciationItem1", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["EnunciationItem1", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EnunciationItem2"],
    CellMargins->{{36, 12}, {1, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {"\n\\item ", ""}, "HTML" -> {"<li>", 
      "</li>"}},
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      40}, "TeX" -> {"CellGroupEnvironment" -> "itemize"}, "HTML" -> {
      "CellGroupEnvironment" -> "ul"}}},
    CellFrameLabels->{{
      Cell[ "\[FilledSmallCircle]", "Item2Label", CellBaseline -> Baseline], 
          Inherited}, {Inherited, Inherited}},
    CellFrameLabelMargins->4,
    CounterIncrements->"Item2",
    CounterAssignments->{{"Item3Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["EnunciationItem2", "NumberedHeads"]],
  
  Cell[StyleData["EnunciationItem2", "Presentation"],
    CellMargins->{{59, 12}, {2, 3}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["EnunciationItem2", "Printout"],
    CellMargins->{{20, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["EnunciationItem2", "NumberedHeadsPrintout"],
    CellMargins->{{20, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EnunciationItem3"],
    CellMargins->{{60, 12}, {1, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {"\n\\item ", ""}, "HTML" -> {"<li>", 
      "</li>"}},
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      50}, "TeX" -> {"CellGroupEnvironment" -> "itemize"}, "HTML" -> {
      "CellGroupEnvironment" -> "ul"}}},
    CellFrameLabels->{{
      Cell[ "\[FilledSmallCircle]", "Item3Label", CellBaseline -> Baseline], 
          Inherited}, {Inherited, Inherited}},
    CellFrameLabelMargins->4,
    CounterIncrements->"Item3",
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["EnunciationItem3", "NumberedHeads"]],
  
  Cell[StyleData["EnunciationItem3", "Presentation"],
    CellMargins->{{95, 12}, {2, 3}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["EnunciationItem3", "Printout"],
    CellMargins->{{40, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["EnunciationItem3", "NumberedHeadsPrintout"],
    CellMargins->{{40, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EnunciationItem1Label"],
    ConversionRules:>{{"TeX" -> {"", 
      NoOutput[ ], ""}}, {"HTML" -> {"", 
      NoOutput[ ], ""}}},
    CellSize->{24, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["EnunciationItem1Label", "NumberedHeads"]],
  
  Cell[StyleData["EnunciationItem1Label", "Presentation"],
    CellSize->{36, Inherited},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["EnunciationItem1Label", "Printout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["EnunciationItem1Label", "NumberedHeadsPrintout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EnunciationItem2Label"],
    ConversionRules:>{{"TeX" -> {"", 
      NoOutput[ ], ""}}, {"HTML" -> {"", 
      NoOutput[ ], ""}}},
    CellSize->{24, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["EnunciationItem2Label", "NumberedHeads"]],
  
  Cell[StyleData["EnunciationItem2Label", "Presentation"],
    CellSize->{36, Inherited},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["EnunciationItem2Label", "Printout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None],
  
  Cell[StyleData["EnunciationItem2Label", "NumberedHeadsPrintout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EnunciationItem3Label"],
    ConversionRules:>{{"TeX" -> {"", 
      NoOutput[ ], ""}}, {"HTML" -> {"", 
      NoOutput[ ], ""}}},
    CellSize->{24, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["EnunciationItem3Label", "NumberedHeads"]],
  
  Cell[StyleData["EnunciationItem3Label", "Presentation"],
    CellSize->{36, Inherited},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["EnunciationItem3Label", "Printout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None],
  
  Cell[StyleData["EnunciationItem3Label", "NumberedHeadsPrintout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Numbered Lists", "Subsubsubsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EnunciationItem1Numbered"],
    CellMargins->{{12, 12}, {1, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {"\n\\item ", ""}, "HTML" -> {"<li>", 
      "</li>"}},
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      30}, "TeX" -> {"CellGroupEnvironment" -> "enumerate"}, "HTML" -> {
      "CellGroupEnvironment" -> "ol"}}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Item1Numbered"], "."}], "Item1NumberedLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}},
    CellFrameLabelMargins->4,
    CounterIncrements->"Item1Numbered",
    CounterAssignments->{{"Item2Numbered", 0}, {"Item3Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["EnunciationItem1Numbered", "NumberedHeads"]],
  
  Cell[StyleData["EnunciationItem1Numbered", "Presentation"],
    CellMargins->{{23, 12}, {2, 3}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["EnunciationItem1Numbered", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["EnunciationItem1Numbered", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EnunciationItem2Numbered"],
    CellMargins->{{36, 12}, {1, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {"\n\\item ", ""}, "HTML" -> {"<li>", 
      "</li>"}},
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      40}, "TeX" -> {"CellGroupEnvironment" -> "enumerate"}, "HTML" -> {
      "CellGroupEnvironment" -> "ol"}}},
    CellFrameLabels->{{Cell[ 
            TextData[ {"(", 
              CounterBox[ "Item2Numbered"], ")"}], "Item2NumberedLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}},
    CellFrameLabelMargins->4,
    CounterIncrements->"Item2Numbered",
    CounterAssignments->{{"Item3Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Italic",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["EnunciationItem2Numbered", "NumberedHeads"]],
  
  Cell[StyleData["EnunciationItem2Numbered", "Presentation"],
    CellMargins->{{59, 12}, {2, 2}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["EnunciationItem2Numbered", "Printout"],
    CellMargins->{{20, 2}, {1, 2}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["EnunciationItem2Numbered", "NumberedHeadsPrintout"],
    CellMargins->{{20, 2}, {1, 2}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EnunciationItem3Numbered"],
    CellMargins->{{60, 12}, {1, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {"\n\\item ", ""}, "HTML" -> {"<li>", 
      "</li>"}},
    TaggingRules:>{"ExtraConversionRules" -> {"General" -> {"NestingLevel" -> 
      50}, "TeX" -> {"CellGroupEnvironment" -> "enumerate"}, "HTML" -> {
      "CellGroupEnvironment" -> "ol"}}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Item3Numbered"], "."}], "Item3NumberedLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}},
    CellFrameLabelMargins->4,
    CounterIncrements->"Item3Numbered",
    StyleMenuListing->None,
    FontSlant->"Italic",
    CounterBoxOptions->{CounterFunction:>RomanNumeral}],
  
  Cell[StyleData["EnunciationItem3Numbered", "NumberedHeads"]],
  
  Cell[StyleData["EnunciationItem3Numbered", "Presentation"],
    CellMargins->{{95, 12}, {2, 3}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["EnunciationItem3Numbered", "Printout"],
    CellMargins->{{40, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["EnunciationItem3Numbered", "NumberedHeadsPrintout"],
    CellMargins->{{40, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EnunciationItem1NumberedLabel"],
    ConversionRules:>{{"TeX" -> {"", 
      NoOutput[ ], ""}}, {"HTML" -> {"<!--", "-->"}}},
    CellSize->{24, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["EnunciationItem1NumberedLabel", "NumberedHeads"]],
  
  Cell[StyleData["EnunciationItem1NumberedLabel", "Presentation"],
    CellSize->{36, Inherited},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["EnunciationItem1NumberedLabel", "Printout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["EnunciationItem1NumberedLabel", "NumberedHeadsPrintout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EnunciationItem2NumberedLabel"],
    ConversionRules:>{{"TeX" -> {"", 
      NoOutput[ ], ""}}, {"HTML" -> {"<!--", "-->"}}},
    CellSize->{24, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["EnunciationItem2NumberedLabel", "NumberedHeads"]],
  
  Cell[StyleData["EnunciationItem2NumberedLabel", "Presentation"],
    CellSize->{36, Inherited},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["EnunciationItem2NumberedLabel", "Printout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None],
  
  Cell[StyleData["EnunciationItem2NumberedLabel", "NumberedHeadsPrintout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EnunciationItem3NumberedLabel"],
    ConversionRules:>{{"TeX" -> {"", 
      NoOutput[ ], ""}}, {"HTML" -> {"<!--", "-->"}}},
    CellSize->{24, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["EnunciationItem3NumberedLabel", "NumberedHeads"]],
  
  Cell[StyleData["EnunciationItem3NumberedLabel", "Presentation"],
    CellSize->{36, Inherited},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["EnunciationItem3NumberedLabel", "Printout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None],
  
  Cell[StyleData["EnunciationItem3NumberedLabel", "NumberedHeadsPrintout"],
    CellSize->{18, Inherited},
    StyleMenuListing->None]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["List Paragraphs", "Subsubsubsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EnunciationItem1Paragraph"],
    CellMargins->{{40, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 1, 
      "CellGroupEnvironment" -> "enumerate"}}},
    CounterAssignments->{{"Item2Numbered", 0}, {"Item3Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["EnunciationItem1Paragraph", "NumberedHeads"]],
  
  Cell[StyleData["EnunciationItem1Paragraph", "Presentation"],
    CellMargins->{{63, 12}, {2, 2}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["EnunciationItem1Paragraph", "Printout"],
    CellMargins->{{24, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["EnunciationItem1Paragraph", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EnunciationItem2Paragraph"],
    CellMargins->{{64, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 2, 
      "CellGroupEnvironment" -> "enumerate"}}},
    CounterAssignments->{{"Item3Numbered", 0}},
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["EnunciationItem2Paragraph", "NumberedHeads"]],
  
  Cell[StyleData["EnunciationItem2Paragraph", "Presentation"],
    CellMargins->{{99, 12}, {2, 2}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["EnunciationItem2Paragraph", "Printout"],
    CellMargins->{{42, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["EnunciationItem2Paragraph", "NumberedHeadsPrintout"],
    CellMargins->{{42, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EnunciationItem3Paragraph"],
    CellMargins->{{88, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 3, 
      "CellGroupEnvironment" -> "enumerate"}}},
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["EnunciationItem3Paragraph", "NumberedHeads"]],
  
  Cell[StyleData["EnunciationItem3Paragraph", "Presentation"],
    CellMargins->{{135, 12}, {2, 2}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["EnunciationItem3Paragraph", "Printout"],
    CellMargins->{{62, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["EnunciationItem3Paragraph", "NumberedHeadsPrintout"],
    CellMargins->{{62, 2}, {1, 1}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]]
  }, Closed]]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Cross-References", "Section",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["XRef"],
    ConversionRules:>{"TeX" -> {"\\ref{", 
      ExtractButtonData[ "CounterTag"], "}"}, "HTML" -> {"", 
      XRefToHtmlHyperlink, ""}},
    StyleMenuListing->None],
  
  Cell[StyleData["XRef", "NumberedHeads"]],
  
  Cell[StyleData["XRef", "Presentation"]],
  
  Cell[StyleData["XRef", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["XRef", "NumberedHeadsPrintout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableXRef"],
    StyleMenuListing->None],
  
  Cell[StyleData["TableXRef", "NumberedHeads"]],
  
  Cell[StyleData["TableXRef", "Presentation"]],
  
  Cell[StyleData["TableXRef", "Printout"]],
  
  Cell[StyleData["TableXRef", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FigureXRef"],
    StyleMenuListing->None],
  
  Cell[StyleData["FigureXRef", "NumberedHeads"]],
  
  Cell[StyleData["FigureXRef", "Presentation"]],
  
  Cell[StyleData["FigureXRef", "Printout"]],
  
  Cell[StyleData["FigureXRef", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageRef"],
    StyleMenuListing->None],
  
  Cell[StyleData["PageRef", "NumberedHeads"]],
  
  Cell[StyleData["PageRef", "Presentation"]],
  
  Cell[StyleData["PageRef", "Printout"]],
  
  Cell[StyleData["PageRef", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Backmatter", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BackmatterGroup"],
    CellMargins->{{12, 12}, {7, 24}},
    CellGroupingRules->{"SectionGrouping", 1},
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}, "HTML" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["BackmatterGroup", "NumberedHeads"]],
  
  Cell[StyleData["BackmatterGroup", "Presentation"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["BackmatterGroup", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["BackmatterGroup", "NumberedHeadsPrintout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Acknowledgments", "Subsection",
    StyleMenuListing->None,
    ButtonStyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AcknowledgmentsSection"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{12, 12}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    ConversionRules:>{"TeX" -> {"\n\n\\section{", Automatic, "}"}, "HTML" -> {
      "<h3 class=\"AcknowledgmentsSection\">", "</h3>"}},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 0}, {3, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["AcknowledgmentsSection", "NumberedHeads"]],
  
  Cell[StyleData["AcknowledgmentsSection", "Presentation"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{23, 12}, {6, 36}},
    CellFrameMargins->{{0, 0}, {5, 0}},
    FontSize->24],
  
  Cell[StyleData["AcknowledgmentsSection", "Printout"],
    CellMargins->{{0, 12}, {3, 18}},
    FontSize->12],
  
  Cell[StyleData["AcknowledgmentsSection", "NumberedHeadsPrintout"],
    CellMargins->{{0, 12}, {3, 18}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Acknowledgments"],
    CellMargins->{{12, 10}, {3, 5}},
    TextAlignment->Left,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Acknowledgments", "NumberedHeads"]],
  
  Cell[StyleData["Acknowledgments", "Presentation"],
    CellMargins->{{23, 10}, {5, 8}},
    FontSize->17],
  
  Cell[StyleData["Acknowledgments", "Printout"],
    CellMargins->{{0, 12}, {2, 4}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->10],
  
  Cell[StyleData["Acknowledgments", "NumberedHeadsPrintout"],
    CellMargins->{{0, 12}, {2, 4}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Appendix", "Subsection",
    StyleMenuListing->None,
    ButtonStyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AppendixGroup"],
    CellMargins->{{12, 12}, {7, 24}},
    CellGroupingRules->{"SectionGrouping", 1},
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}, "HTML" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["AppendixGroup", "NumberedHeads"],
    CellMargins->{{12, 12}, {7, 24}},
    CellGroupingRules->{"SectionGrouping", 1},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["AppendixGroup", "Presentation"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["AppendixGroup", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["AppendixGroup", "NumberedHeadsPrintout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AppendixSection"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{12, 12}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    ConversionRules:>{"TeX" -> {"\n\n\\section{", "}"}, "HTML" -> {
      "<h3 class=\"AppendixSection\">", "</h3>"}},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 0}, {3, 0}},
    CounterIncrements->"AppendixSection",
    CounterAssignments->{{"AppendixEquation", 0}, {"Appendix", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["AppendixSection", "NumberedHeads"],
    CellFrame->False,
    CellFrameLabels->{{Cell[ 
            TextData[ 
              CounterBox[ "AppendixSection"], "."], "SectionLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["AppendixSection", "Presentation"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{23, 12}, {6, 36}},
    CellFrameMargins->{{0, 0}, {5, 0}},
    FontSize->24],
  
  Cell[StyleData["AppendixSection", "Printout"],
    CellMargins->{{0, 12}, {3, 18}},
    FontSize->12],
  
  Cell[StyleData["AppendixSection", "NumberedHeadsPrintout"],
    CellMargins->{{0, 12}, {3, 18}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AppendixSectionLabel"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->None],
  
  Cell[StyleData["AppendixSectionLabel", "NumberedHeads"]],
  
  Cell[StyleData["AppendixSectionLabel", "Presentation"]],
  
  Cell[StyleData["AppendixSectionLabel", "Printout"]],
  
  Cell[StyleData["AppendixSectionLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AppendixSectionNumber"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None],
  
  Cell[StyleData["AppendixSectionNumber", "NumberedHeads"]],
  
  Cell[StyleData["AppendixSectionNumber", "Presentation"]],
  
  Cell[StyleData["AppendixSectionNumber", "Printout"]],
  
  Cell[StyleData["AppendixSectionNumber", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AppendixEquation"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"HTML" -> {{"", ""}, {
      "<table class='AppendixEquation'><tr><td>", Automatic, 
      IncludeCount[ 
      "</td><td class='AppendixEquationLabel'>(`1`.`2`)</td></tr></table>", 
        "AppendixSection", "AppendixEquation"]}}},
    TaggingRules:>{"CounterSettings" -> {"CounterFormat" -> {
      "AppendixSection", ".", "AppendixEquation"}, "CounterTarget" -> "Cell", 
      "XRefPrefix" -> "Equation"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "AppendixSection"], ".", 
              CounterBox[ "AppendixEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    InputAutoReplacements->{},
    CounterIncrements->"AppendixEquation",
    StyleMenuListing->None],
  
  Cell[StyleData["AppendixEquation", "NumberedHeads"]],
  
  Cell[StyleData["AppendixEquation", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    FontSize->19],
  
  Cell[StyleData["AppendixEquation", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->10],
  
  Cell[StyleData["AppendixEquation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Appendix"],
    CellMargins->{{12, 12}, {3, 5}},
    CellGroupingRules->"GraphicsGrouping",
    StyleMenuListing->None,
    ButtonStyleMenuListing->None],
  
  Cell[StyleData["Appendix", "NumberedHeads"]],
  
  Cell[StyleData["Appendix", "Presentation"],
    CellMargins->{{23, 12}, {5, 8}},
    FontSize->17],
  
  Cell[StyleData["Appendix", "Printout"],
    CellMargins->{{2, 2}, {2, 4}},
    FontSize->10],
  
  Cell[StyleData["Appendix", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {2, 4}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Endnotes", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndnoteSection"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{12, 12}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}, "HTML" -> {"<h3 class=\"EndnoteSection\">", "</h3>"}},
    
    PageBreakBelow->False,
    CellFrameMargins->{{0, 0}, {3, 0}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}, {
        "Endnote", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["EndnoteSection", "NumberedHeads"]],
  
  Cell[StyleData["EndnoteSection", "Presentation"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{23, 12}, {6, 36}},
    CellFrameMargins->{{0, 0}, {5, 0}},
    FontSize->24],
  
  Cell[StyleData["EndnoteSection", "Printout"],
    CellMargins->{{0, 12}, {3, 18}},
    FontSize->14],
  
  Cell[StyleData["EndnoteSection", "NumberedHeadsPrintout"],
    CellMargins->{{0, 12}, {3, 18}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Endnote"],
    CellMargins->{{12, 12}, {2, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}, "HTML" -> {
      "<table class=\"Endnote\"><tr valign=\"top\">", "</td></tr></table>"}},
    LineSpacing->{1, 2},
    ParagraphSpacing->{0, 0},
    ParagraphIndent->-36,
    TabSpacings->5.5,
    CounterIncrements->"Endnote",
    StyleMenuListing->None],
  
  Cell[StyleData["Endnote", "NumberedHeads"]],
  
  Cell[StyleData["Endnote", "Presentation"],
    CellMargins->{{23, 12}, {3, 3}},
    ParagraphIndent->-54,
    FontSize->17],
  
  Cell[StyleData["Endnote", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Endnote", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndnoteLabel"],
    ConversionRules:>{"HTML" -> {
      "<td class=\"EndnoteLabel\" align=\"right\">", "&nbsp;</td><td>"}},
    CellSize->{36, Inherited},
    TextAlignment->Right,
    CounterIncrements->"EndnoteLabel",
    StyleMenuListing->None],
  
  Cell[StyleData["EndnoteLabel", "NumberedHeads"]],
  
  Cell[StyleData["EndnoteLabel", "Presentation"],
    CellSize->{54, Inherited}],
  
  Cell[StyleData["EndnoteLabel", "Printout"]],
  
  Cell[StyleData["EndnoteLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndnoteNumber"],
    CellSize->{36, Inherited},
    TextAlignment->Right,
    CounterIncrements->"EndnoteNumber",
    StyleMenuListing->None],
  
  Cell[StyleData["EndnoteNumber", "NumberedHeads"]],
  
  Cell[StyleData["EndnoteNumber", "Presentation"],
    CellSize->{54, Inherited}],
  
  Cell[StyleData["EndnoteNumber", "Printout"]],
  
  Cell[StyleData["EndnoteNumber", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NoteKey"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.500008],
    ButtonBoxOptions->{ButtonFunction:>(EditNote[ #]&),
    ButtonEvaluator->Automatic,
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["NoteKey", "NumberedHeads"]],
  
  Cell[StyleData["NoteKey", "Presentation"]],
  
  Cell[StyleData["NoteKey", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["NoteKey", "NumberedHeadsPrintout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndnoteReturnLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.500008],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["EndnoteReturnLink", "NumberedHeads"]],
  
  Cell[StyleData["EndnoteReturnLink", "Presentation"]],
  
  Cell[StyleData["EndnoteReturnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["EndnoteReturnLink", "NumberedHeadsPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableNoteKey"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.500008],
    ButtonBoxOptions->{ButtonFunction:>(EditTableNote[ #, #2]&),
    ButtonEvaluator->Automatic,
    Active->True,
    ButtonSource->ButtonContents,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TableNoteKey", "NumberedHeads"]],
  
  Cell[StyleData["TableNoteKey", "Presentation"]],
  
  Cell[StyleData["TableNoteKey", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["TableNoteKey", "NumberedHeadsPrintout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    Editable->False,
    Deletable->False,
    ConversionRules:>{"TeX" -> {{"\\footnote{", Convert[ 
        ExtractElement[ ][ 
          ExtractButtonData[ ][ #]]]&, "}"}, {"", Automatic, ""}}},
    ScriptMinSize->10,
    StyleMenuListing->None,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Note", "NumberedHeads"]],
  
  Cell[StyleData["Note", "Presentation"]],
  
  Cell[StyleData["Note", "Printout"],
    ScriptMinSize->8],
  
  Cell[StyleData["Note", "NumberedHeadsPrintout"],
    ScriptMinSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["References", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceSection"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{12, 12}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}, "HTML" -> {"<h3 class=\"ReferenceSection\">", 
      "</h3>"}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 1, 
      "CellGroupEnvironment" -> {"thebibliography", "{000}"}}}},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 0}, {3, 0}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    CounterAssignments->{{"Reference", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ReferenceSection", "NumberedHeads"]],
  
  Cell[StyleData["ReferenceSection", "Presentation"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{23, 12}, {6, 36}},
    CellFrameMargins->{{0, 0}, {5, 0}},
    FontSize->24],
  
  Cell[StyleData["ReferenceSection", "Printout"],
    CellMargins->{{0, 12}, {3, 18}},
    StyleMenuListing->None,
    FontSize->14],
  
  Cell[StyleData["ReferenceSection", "NumberedHeadsPrintout"],
    CellMargins->{{0, 12}, {3, 18}},
    StyleMenuListing->None,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{12, 12}, {2, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{"TeX" -> {"", ""}, "HTML" -> {
      "<table class=\"Reference\"><tr valign=\"top\">", 
      "</td></tr></table>"}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 1, 
      "CellGroupEnvironment" -> {"thebibliography", "{000}"}}}},
    Hyphenation->True,
    LineSpacing->{1, 2},
    ParagraphIndent->-36,
    CounterIncrements->"Reference",
    StyleMenuListing->None],
  
  Cell[StyleData["Reference", "NumberedHeads"]],
  
  Cell[StyleData["Reference", "Presentation"],
    CellMargins->{{23, 12}, {3, 3}},
    ParagraphIndent->-54,
    FontSize->17],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Reference", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceLabel"],
    ConversionRules:>{"HTML" -> {
      "<td class=\"ReferenceLabel\" align=\"right\">", "&nbsp;</td><td>"}},
    CellSize->{36, Inherited},
    TextAlignment->Right,
    CounterIncrements->"ReferenceLabel",
    StyleMenuListing->None],
  
  Cell[StyleData["ReferenceLabel", "NumberedHeads"]],
  
  Cell[StyleData["ReferenceLabel", "Presentation"],
    CellSize->{54, Inherited}],
  
  Cell[StyleData["ReferenceLabel", "Printout"]],
  
  Cell[StyleData["ReferenceLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceNumber"],
    StyleMenuListing->None],
  
  Cell[StyleData["ReferenceNumber", "NumberedHeads"]],
  
  Cell[StyleData["ReferenceNumber", "Presentation"]],
  
  Cell[StyleData["ReferenceNumber", "Printout"]],
  
  Cell[StyleData["ReferenceNumber", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefSep"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None],
  
  Cell[StyleData["RefSep", "NumberedHeads"]],
  
  Cell[StyleData["RefSep", "Presentation"]],
  
  Cell[StyleData["RefSep", "Printout"]],
  
  Cell[StyleData["RefSep", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefReturnLink"],
    ConversionRules:>{"TeX" -> {"\n\\bibitem{", DeleteCharacter[ 5][ 
        ExtractButtonData[ ][ #]]&, "}"}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Times",
    FontColor->RGBColor[0, 0, 0.500008],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefReturnLink", "NumberedHeads"]],
  
  Cell[StyleData["RefReturnLink", "Presentation"]],
  
  Cell[StyleData["RefReturnLink", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["RefReturnLink", "NumberedHeadsPrintout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefReturnPointer"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Mathematica4",
    FontColor->RGBColor[0, 0, 0.500008],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefReturnPointer", "NumberedHeads"]],
  
  Cell[StyleData["RefReturnPointer", "Presentation"]],
  
  Cell[StyleData["RefReturnPointer", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["RefReturnPointer", "NumberedHeadsPrintout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceSourceLink"],
    ConversionRules:>{{"TeX" -> {"", 
      NoOutput[ ], ""}}, {"HTML" -> {"<!--", "-->"}}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Mathematica4",
    FontSize->1,
    FontColor->GrayLevel[1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["ReferenceSourceLink", "NumberedHeads"]],
  
  Cell[StyleData["ReferenceSourceLink", "Presentation"]],
  
  Cell[StyleData["ReferenceSourceLink", "Printout"],
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["ReferenceSourceLink", "NumberedHeadsPrintout"],
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[StyleData["ReferenceSourceURL"],
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Citation"],
    ConversionRules:>{"TeX" -> {"\\cite{", 
      ExtractButtonData[ ], "}"}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.500008],
    ButtonBoxOptions->{ButtonFunction:>(ListDataLink[ #2]&),
    ButtonEvaluator->Automatic,
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["Citation", "NumberedHeads"]],
  
  Cell[StyleData["Citation", "Presentation"]],
  
  Cell[StyleData["Citation", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Citation", "NumberedHeadsPrintout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefKey"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.500008],
    ButtonBoxOptions->{ButtonFunction:>(EditRef[ #]&),
    ButtonEvaluator->Automatic,
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefKey", "NumberedHeads"]],
  
  Cell[StyleData["RefKey", "Presentation"]],
  
  Cell[StyleData["RefKey", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["RefKey", "NumberedHeadsPrintout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["References Templates", "Subsubsection",
    StyleMenuListing->None],
  
  Cell["FirstAuthor:<Last>, <FirstInitial>. <MiddleInitial>.", 
    "ReferenceTemplate"],
  
  Cell["OtherAuthors:, <Last>, <FirstInitial>. <MiddleInitial>.", 
    "ReferenceTemplate"],
  
  Cell["LastAuthor:, & <Last>, <FirstInitial>. <MiddleInitial>.", 
    "ReferenceTemplate"],
  
  Cell["FirstEditor:<FirstInitial>. <MiddleInitial>. <Last>", 
    "ReferenceTemplate"],
  
  Cell["OtherEditors:, <FirstInitial>. <MiddleInitial>. <Last>", 
    "ReferenceTemplate"],
  
  Cell["LastEditor: & <FirstInitial>. <MiddleInitial>. <Last>", 
    "ReferenceTemplate"],
  
  Cell["Sorting:None", "ReferenceTemplate"],
  
  Cell["ReferenceAuthorMax:4", "ReferenceTemplate"],
  
  Cell["ReferenceEditorMax:4", "ReferenceTemplate"],
  
  Cell["ReferenceAuthorMin:1", "ReferenceTemplate"],
  
  Cell["ReferenceEditorMin:1", "ReferenceTemplate"],
  
  Cell["AbbreviatedAuthors:, et al.", "ReferenceTemplate"],
  
  Cell["AbbreviatedEditors:, et al.", "ReferenceTemplate"],
  
  Cell[CellGroupData[{
  
  Cell["Article Templates", "Subsubsubsection"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month> <Day>). <Title>. <JournalTitle>, \
<JournalVolume>(<JournalNumber>), <PageRange>. Retrieved <RetrievalDate> from \
<URL>\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month> <Day>). <Title>. <JournalTitle>, \
<JournalVolume>(<JournalNumber>), <PageRange>.\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month> <Day>). <Title>. <JournalTitle>, \
<JournalVolume>(<JournalNumber>).  Retrieved <RetrievalDate> from <URL>\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month> <Day>). <Title>. <JournalTitle>, \
<JournalVolume>(<JournalNumber>).\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month> <Day>). <Title>. <JournalTitle>, \
<JournalVolume>, <PageRange>. Retrieved <RetrievalDate> from <URL>\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month> <Day>). <Title>. <JournalTitle>, \
<JournalVolume>, <PageRange>. \
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month> <Day>). <Title>. <JournalTitle>, \
<JournalVolume>. Retrieved <RetrievalDate> from <URL>\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month> <Day>). <Title>. <JournalTitle>, \
<JournalVolume>. \
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month>). <Title>. <JournalTitle>, \
<JournalVolume>(<JournalNumber>), <PageRange>. Retrieved <RetrievalDate> from \
<URL>\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month>). <Title>. <JournalTitle>, \
<JournalVolume>(<JournalNumber>), <PageRange>.\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month>). <Title>. <JournalTitle>, \
<JournalVolume>(<JournalNumber>).  Retrieved <RetrievalDate> from <URL>\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month>). <Title>. <JournalTitle>, \
<JournalVolume>(<JournalNumber>).\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month>). <Title>. <JournalTitle>, <JournalVolume>, \
<PageRange>. Retrieved <RetrievalDate> from <URL>\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month>). <Title>. <JournalTitle>, <JournalVolume>, \
<PageRange>. \
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month>). <Title>. <JournalTitle>, <JournalVolume>. \
Retrieved <RetrievalDate> from <URL>\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month>). <Title>. <JournalTitle>, <JournalVolume>. \
\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>). <Title>. <JournalTitle>, \
<JournalVolume>(<JournalNumber>), <PageRange>. Retrieved <RetrievalDate> from \
<URL>\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>). <Title>. <JournalTitle>, \
<JournalVolume>(<JournalNumber>), <PageRange>.\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>). <Title>. <JournalTitle>, \
<JournalVolume>(<JournalNumber>).  Retrieved <RetrievalDate> from <URL>\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>). <Title>. <JournalTitle>, \
<JournalVolume>(<JournalNumber>).\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>). <Title>. <JournalTitle>, <JournalVolume>, \
<PageRange>. Retrieved <RetrievalDate> from <URL>\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>). <Title>. <JournalTitle>, <JournalVolume>, \
<PageRange>. \
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>). <Title>. <JournalTitle>, <JournalVolume>. \
Retrieved <RetrievalDate> from <URL>\
\>", "ReferenceTemplate"],
  
  Cell["\<\
Article:<Author> (<Year>). <Title>. <JournalTitle>, <JournalVolume>. \
\>", "ReferenceTemplate"],
  
  Cell["\<\
(The following template is the default template for \"Article\" references \
that don't match any of the above templates.)\
\>", "Text"],
  
  Cell["\<\
Article:<Author> (<Year>, <Month> <Day>). <Title>. <JournalTitle>, \
<JournalVolume>(<JournalNumber>), <PageRange>.\
\>", "ReferenceTemplate"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["In Book Templates", "Subsubsubsection"],
  
  Cell["\<\
(The following template is the default template for \"InBook\" references.)\
\>", "Text"],
  
  Cell["\<\
InBook:<Author> (<Year>). <Title>. In <Editor> (Ed.), <BookTitle> (pp. \
<PageRange>). <City>: <Publisher>.\
\>", "ReferenceTemplate"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Whole Book Templates", "Subsubsubsection"],
  
  Cell["\<\
WholeBook:<Author> (<Year>). <BookTitle>. <City>: <Publisher>. Retrieved \
<RetrievalDate> from <URL>\
\>", "ReferenceTemplate"],
  
  Cell["\<\
WholeBook:<Author> (<Year>). <BookTitle>. <City>: <Publisher>.\
\>", "ReferenceTemplate"],
  
  Cell["\<\
WholeBook:<Author> (<Year>). <BookTitle>. Retrieved <RetrievalDate> from \
<URL>\
\>", "ReferenceTemplate"],
  
  Cell["\<\
(The following template is the default template for \"Book\" references that \
don't match any of the above templates.)\
\>", "Text"],
  
  Cell["\<\
WholeBook:<Author> (<Year>). <BookTitle>. <City>: <Publisher>.\
\>", "ReferenceTemplate"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Thesis Templates", "Subsubsubsection"],
  
  Cell["\<\
PhdThesis:<Author> (<Year>). <Title> (Doctoral Dissertation, <School>, \
<City>). <SourceOfAbstract>, <JournalVolume>, <PageRange>.\
\>", "ReferenceTemplate"],
  
  Cell["\<\
PhdThesis:<Author> (<Year>). <BookTitle>. Unpublished doctoral dissertation, \
<School>, <City>.\
\>", "ReferenceTemplate"],
  
  Cell["\<\
(The following template is the default template for \"PhdThesis\" references \
that don't match any of the above templates.)\
\>", "Text"],
  
  Cell["\<\
PhdThesis:<Author> (<Year>). <Title> (Doctoral Dissertation, <School>, \
<City>). <SourceOfAbstract>, <JournalVolume>, <PageRange>.\
\>", "ReferenceTemplate"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Technical Report Templates", "Subsubsubsection"],
  
  Cell["\<\
(The following template is the default template for \"TechReport\" \
references.)\
\>", "Text"],
  
  Cell["\<\
TechReport:<Author> (<Year>). <Title>. <School>, <City>. <ReportNumber>, \
<Submittedby>\
\>", "ReferenceTemplate"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Online Source Templates", "Subsubsubsection"],
  
  Cell["\<\
(The following template is the default template for \"OnlineSource\" \
references.)\
\>", "Text"],
  
  Cell["\<\
OnlineSource:<Author>, <Title>. Retrieved <RetrievalDate> from <URL>\
\>", "ReferenceTemplate"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Preprint Templates", "Subsubsubsection"],
  
  Cell["\<\
(The following template is the default template for \"Preprint\" references.)\
\
\>", "Text"],
  
  Cell["Preprint:<Author> (<Year>). <Title>. <PublicationStatus>", 
    "ReferenceTemplate"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Plain Insertion Template", "Subsubsubsection"],
  
  Cell["\<\
(The following template is the default template for \
\[OpenCurlyDoubleQuote]PlainInsert\" references.)\
\>", "Text"],
  
  Cell["PlainInsert:<InsertedBibText>", "ReferenceTemplate"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Note Templates", "Subsubsubsection"],
  
  Cell["\<\
(The following template is the default template for \"Note\" references.)\
\>", "Text"],
  
  Cell["Note:<NoteText>", "ReferenceTemplate"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Common Data Field Styles", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[StyleData["RefTitle"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["RefType"],
    CellSize->{0, 12},
    StyleMenuListing->None],
  
  Cell[StyleData["RefURL"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefRetrievalDate"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefSourceOfAbstract"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefInsertedBibText"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefNote"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefReviewVolume"],
    ConversionRules:>{"TeX" -> {"\\textbf{", "}"}},
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["RefReviewNumber"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefDatabase"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefVolume"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Book Data Field Styles", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[StyleData["RefBookTitle"],
    ConversionRules:>{"TeX" -> {"\\textit{", "}"}},
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["RefBookSubTitle"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefBookSubsubTitle"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefBookEdition"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Journal Data Field Styles", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[StyleData["RefJournalTitle"],
    ConversionRules:>{"TeX" -> {"\\textit{", "}"}},
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["RefJournalVolume"],
    ConversionRules:>{"TeX" -> {"\\textbf{", #&, "}"}},
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["RefJournalNumber"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Publisher Data Field Styles", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[StyleData["RefPublisher"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefAddress"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefCity"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefState"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefCountry"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Author Data Field Styles", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[StyleData["RefAuthorGroup"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefAuthorFN"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefAuthorLN"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefAuthorMN"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefInstitution"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Editor Data Field Styles", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[StyleData["RefEditorGroup"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefEditorFN"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefEditorMN"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefEditorLN"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["School Data Field Styles", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[StyleData["RefSchool"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefSchoolDept"],
    ConversionRules:>{"TeX" -> {"\\textit{", "}"}},
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["RefSchoolAddress"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Publication Date Data Field Styles", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[StyleData["RefDay"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefMonth"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefYear"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefPublicationStatus"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Data Field Styles: Auto Generated and Contiguous Pages", 
    "Subsubsection",
    StyleMenuListing->None],
  
  Cell[StyleData["RefPageRange"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefFirstPage"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefLastPage"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Data Field Styles: Noncontiguous Pages", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[StyleData["RefDiscretePageList"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["In Note RefType", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[StyleData["RefNoteText"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["In TechReport RefType", "Subsubsection",
    StyleMenuListing->None],
  
  Cell[StyleData["RefReportNumber"],
    StyleMenuListing->None],
  
  Cell[StyleData["RefSubmittedby"],
    StyleMenuListing->None]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Index", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{12, 12}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}, "HTML" -> {"<h3 class=\"IndexSection\">", "</h3>"}},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 0}, {3, 0}},
    DefaultNewInlineCellStyle->"None",
    LineSpacing->{1, 7},
    LanguageCategory->"NaturalLanguage",
    CounterAssignments->{{"IndexEntry", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "NumberedHeads"]],
  
  Cell[StyleData["IndexSection", "Presentation"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{23, 12}, {6, 36}},
    CellFrameMargins->{{0, 0}, {5, 0}},
    FontSize->24],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{0, 12}, {3, 18}},
    StyleMenuListing->None,
    FontSize->14],
  
  Cell[StyleData["IndexSection", "NumberedHeadsPrintout"],
    CellMargins->{{0, 12}, {3, 18}},
    StyleMenuListing->None,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexEntry"],
    CellMargins->{{12, 12}, {2, 0}},
    CellGroupingRules->"GraphicsGrouping",
    ParagraphIndent->-24,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->11],
  
  Cell[StyleData["IndexEntry", "NumberedHeads"]],
  
  Cell[StyleData["IndexEntry", "Presentation"],
    CellMargins->{{23, 12}, {3, 0}},
    ParagraphIndent->-36,
    FontSize->17],
  
  Cell[StyleData["IndexEntry", "Printout"],
    CellMargins->{{2, 2}, {1, 0}},
    StyleMenuListing->None,
    FontSize->9],
  
  Cell[StyleData["IndexEntry", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 0}},
    StyleMenuListing->None,
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{24, 12}, {2, 0}},
    CellGroupingRules->"GraphicsGrouping",
    ParagraphIndent->-12,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->11],
  
  Cell[StyleData["IndexSubentry", "NumberedHeads"]],
  
  Cell[StyleData["IndexSubentry", "Presentation"],
    CellMargins->{{35, 12}, {3, 0}},
    ParagraphIndent->-18,
    FontSize->17],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{18, 2}, {1, 0}},
    StyleMenuListing->None,
    FontSize->9],
  
  Cell[StyleData["IndexSubentry", "NumberedHeadsPrintout"],
    CellMargins->{{18, 2}, {1, 0}},
    StyleMenuListing->None,
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubsubentry"],
    CellMargins->{{36, 12}, {2, 0}},
    CellGroupingRules->"GraphicsGrouping",
    ParagraphIndent->-12,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->11],
  
  Cell[StyleData["IndexSubsubentry", "NumberedHeads"]],
  
  Cell[StyleData["IndexSubsubentry", "Presentation"],
    CellMargins->{{47, 12}, {3, 0}},
    ParagraphIndent->-18,
    FontSize->17],
  
  Cell[StyleData["IndexSubsubentry", "Printout"],
    CellMargins->{{30, 2}, {1, 0}},
    StyleMenuListing->None,
    FontSize->9],
  
  Cell[StyleData["IndexSubsubentry", "NumberedHeadsPrintout"],
    CellMargins->{{30, 2}, {1, 0}},
    StyleMenuListing->None,
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexNote"],
    CellMargins->{{12, 12}, {2, 0}},
    CellGroupingRules->"GraphicsGrouping",
    TextAlignment->Left,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->11,
    FontSlant->"Italic"],
  
  Cell[StyleData["IndexNote", "NumberedHeads"]],
  
  Cell[StyleData["IndexNote", "Presentation"],
    CellMargins->{{23, 12}, {3, 0}},
    FontSize->17],
  
  Cell[StyleData["IndexNote", "Printout"],
    CellMargins->{{2, 2}, {1, 0}},
    StyleMenuListing->None,
    FontSize->9],
  
  Cell[StyleData["IndexNote", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 0}},
    StyleMenuListing->None,
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSpacer"],
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSpacer", "NumberedHeads"]],
  
  Cell[StyleData["IndexSpacer", "Presentation"]],
  
  Cell[StyleData["IndexSpacer", "Printout"]],
  
  Cell[StyleData["IndexSpacer", "Printout"]]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Book Elements", "Section",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell["Book Frontmatter", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FrontMatterTitle"],
    StyleMenuListing->None],
  
  Cell[StyleData["FrontMatterTitle", "NumberedHeads"]],
  
  Cell[StyleData["FrontMatterTitle", "Presentation"]],
  
  Cell[StyleData["FrontMatterTitle", "Printout"]],
  
  Cell[StyleData["FrontMatterTitle", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["BookHalfTitle Page", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["HalfTitle"],
    StyleMenuListing->None],
  
  Cell[StyleData["HalfTitle", "NumberedHeads"]],
  
  Cell[StyleData["HalfTitle", "Presentation"]],
  
  Cell[StyleData["HalfTitle", "Printout"]],
  
  Cell[StyleData["HalfTitle", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Book Series Information", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Series"],
    StyleMenuListing->None],
  
  Cell[StyleData["Series", "NumberedHeads"]],
  
  Cell[StyleData["Series", "Presentation"]],
  
  Cell[StyleData["Series", "Printout"]],
  
  Cell[StyleData["Series", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SeriesVolume"],
    StyleMenuListing->None],
  
  Cell[StyleData["SeriesVolume", "NumberedHeads"]],
  
  Cell[StyleData["SeriesVolume", "Presentation"]],
  
  Cell[StyleData["SeriesVolume", "Printout"]],
  
  Cell[StyleData["SeriesVolume", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SeriesEditor"],
    StyleMenuListing->None],
  
  Cell[StyleData["SeriesEditor", "NumberedHeads"]],
  
  Cell[StyleData["SeriesEditor", "Presentation"]],
  
  Cell[StyleData["SeriesEditor", "Printout"]],
  
  Cell[StyleData["SeriesEditor", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Book Symposium Information", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Symposium"],
    StyleMenuListing->None],
  
  Cell[StyleData["Symposium", "NumberedHeads"]],
  
  Cell[StyleData["Symposium", "Presentation"]],
  
  Cell[StyleData["Symposium", "Printout"]],
  
  Cell[StyleData["Symposium", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SymposiumCity"],
    StyleMenuListing->None],
  
  Cell[StyleData["SymposiumCity", "NumberedHeads"]],
  
  Cell[StyleData["SymposiumCity", "Presentation"]],
  
  Cell[StyleData["SymposiumCity", "Printout"]],
  
  Cell[StyleData["SymposiumCity", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SymposiumDate"],
    StyleMenuListing->None],
  
  Cell[StyleData["SymposiumDate", "NumberedHeads"]],
  
  Cell[StyleData["SymposiumDate", "Presentation"]],
  
  Cell[StyleData["SymposiumDate", "Printout"]],
  
  Cell[StyleData["SymposiumDate", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SymposiumEditor"],
    StyleMenuListing->None],
  
  Cell[StyleData["SymposiumEditor", "NumberedHeads"]],
  
  Cell[StyleData["SymposiumEditor", "Presentation"]],
  
  Cell[StyleData["SymposiumEditor", "Printout"]],
  
  Cell[StyleData["SymposiumEditor", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SymposiumSponsor"],
    StyleMenuListing->None],
  
  Cell[StyleData["SymposiumSponsor", "NumberedHeads"]],
  
  Cell[StyleData["SymposiumSponsor", "Presentation"]],
  
  Cell[StyleData["SymposiumSponsor", "Printout"]],
  
  Cell[StyleData["SymposiumSponsor", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Book Author's Previous Publications", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AuthorsPreviousPublications"],
    StyleMenuListing->None],
  
  Cell[StyleData["AuthorsPreviousPublications", "NumberedHeads"]],
  
  Cell[StyleData["AuthorsPreviousPublications", "Presentation"]],
  
  Cell[StyleData["AuthorsPreviousPublications", "Printout"]],
  
  Cell[StyleData["AuthorsPreviousPublications", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Book Title Page", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell["Book Editor", "Subsubsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EditorFirstName"],
    StyleMenuListing->None],
  
  Cell[StyleData["EditorFirstName", "NumberedHeads"]],
  
  Cell[StyleData["EditorFirstName", "Presentation"]],
  
  Cell[StyleData["EditorFirstName", "Printout"]],
  
  Cell[StyleData["EditorFirstName", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EditorMiddleName"],
    StyleMenuListing->None],
  
  Cell[StyleData["EditorMiddleName", "NumberedHeads"]],
  
  Cell[StyleData["EditorMiddleName", "Presentation"]],
  
  Cell[StyleData["EditorMiddleName", "Printout"]],
  
  Cell[StyleData["EditorMiddleName", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EditorLastName"],
    StyleMenuListing->None],
  
  Cell[StyleData["EditorLastName", "NumberedHeads"]],
  
  Cell[StyleData["EditorLastName", "Presentation"]],
  
  Cell[StyleData["EditorLastName", "Printout"]],
  
  Cell[StyleData["EditorLastName", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EditorNameSuffix"],
    StyleMenuListing->None],
  
  Cell[StyleData["EditorNameSuffix", "NumberedHeads"]],
  
  Cell[StyleData["EditorNameSuffix", "Presentation"]],
  
  Cell[StyleData["EditorNameSuffix", "Printout"]],
  
  Cell[StyleData["EditorNameSuffix", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EditorInstitution"],
    StyleMenuListing->None],
  
  Cell[StyleData["EditorInstitution", "NumberedHeads"]],
  
  Cell[StyleData["EditorInstitution", "Presentation"]],
  
  Cell[StyleData["EditorInstitution", "Printout"]],
  
  Cell[StyleData["EditorInstitution", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EditorAltInstitution"],
    StyleMenuListing->None],
  
  Cell[StyleData["EditorAltInstitution", "NumberedHeads"]],
  
  Cell[StyleData["EditorAltInstitution", "Presentation"]],
  
  Cell[StyleData["EditorAltInstitution", "Printout"]],
  
  Cell[StyleData["EditorAltInstitution", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Book Translator", "Subsubsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TranslatorFirstName"],
    StyleMenuListing->None],
  
  Cell[StyleData["TranslatorFirstName", "NumberedHeads"]],
  
  Cell[StyleData["TranslatorFirstName", "Presentation"]],
  
  Cell[StyleData["TranslatorFirstName", "Printout"]],
  
  Cell[StyleData["TranslatorFirstName", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TranslatorMiddleName"],
    StyleMenuListing->None],
  
  Cell[StyleData["TranslatorMiddleName", "NumberedHeads"]],
  
  Cell[StyleData["TranslatorMiddleName", "Presentation"]],
  
  Cell[StyleData["TranslatorMiddleName", "Printout"]],
  
  Cell[StyleData["TranslatorMiddleName", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TranslatorLastName"],
    StyleMenuListing->None],
  
  Cell[StyleData["TranslatorLastName", "NumberedHeads"]],
  
  Cell[StyleData["TranslatorLastName", "Presentation"]],
  
  Cell[StyleData["TranslatorLastName", "Printout"]],
  
  Cell[StyleData["TranslatorLastName", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TranslatorNameSuffix"],
    StyleMenuListing->None],
  
  Cell[StyleData["TranslatorNameSuffix", "NumberedHeads"]],
  
  Cell[StyleData["TranslatorNameSuffix", "Presentation"]],
  
  Cell[StyleData["TranslatorNameSuffix", "Printout"]],
  
  Cell[StyleData["TranslatorNameSuffix", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TranslatorInstitution"],
    StyleMenuListing->None],
  
  Cell[StyleData["TranslatorInstitution", "NumberedHeads"]],
  
  Cell[StyleData["TranslatorInstitution", "Presentation"]],
  
  Cell[StyleData["TranslatorInstitution", "Printout"]],
  
  Cell[StyleData["TranslatorInstitution", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TranslatorAltInstitution"],
    StyleMenuListing->None],
  
  Cell[StyleData["TranslatorAltInstitution", "NumberedHeads"]],
  
  Cell[StyleData["TranslatorAltInstitution", "Presentation"]],
  
  Cell[StyleData["TranslatorAltInstitution", "Printout"]],
  
  Cell[StyleData["TranslatorAltInstitution", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Book Publication Information", "Subsubsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Publisher"],
    StyleMenuListing->None],
  
  Cell[StyleData["Publisher", "NumberedHeads"]],
  
  Cell[StyleData["Publisher", "Presentation"]],
  
  Cell[StyleData["Publisher", "Printout"]],
  
  Cell[StyleData["Publisher", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PublisherCities"],
    StyleMenuListing->None],
  
  Cell[StyleData["PublisherCities", "NumberedHeads"]],
  
  Cell[StyleData["PublisherCities", "Presentation"]],
  
  Cell[StyleData["PublisherCities", "Printout"]],
  
  Cell[StyleData["PublisherCities", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PublisherURL"],
    StyleMenuListing->None],
  
  Cell[StyleData["PublisherURL", "NumberedHeads"]],
  
  Cell[StyleData["PublisherURL", "Presentation"]],
  
  Cell[StyleData["PublisherURL", "Printout"]],
  
  Cell[StyleData["PublisherURL", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PublicationYear"],
    StyleMenuListing->None],
  
  Cell[StyleData["PublicationYear", "NumberedHeads"]],
  
  Cell[StyleData["PublicationYear", "Presentation"]],
  
  Cell[StyleData["PublicationYear", "Printout"]],
  
  Cell[StyleData["PublicationYear", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Book Copyright Page", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CopyrightNotice"],
    StyleMenuListing->None],
  
  Cell[StyleData["CopyrightNotice", "NumberedHeads"]],
  
  Cell[StyleData["CopyrightNotice", "Presentation"]],
  
  Cell[StyleData["CopyrightNotice", "Printout"]],
  
  Cell[StyleData["CopyrightNotice", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PublishingHistory"],
    StyleMenuListing->None],
  
  Cell[StyleData["PublishingHistory", "NumberedHeads"]],
  
  Cell[StyleData["PublishingHistory", "Presentation"]],
  
  Cell[StyleData["PublishingHistory", "Printout"]],
  
  Cell[StyleData["PublishingHistory", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CountryWherePrinted"],
    StyleMenuListing->None],
  
  Cell[StyleData["CountryWherePrinted", "NumberedHeads"]],
  
  Cell[StyleData["CountryWherePrinted", "Presentation"]],
  
  Cell[StyleData["CountryWherePrinted", "Printout"]],
  
  Cell[StyleData["CountryWherePrinted", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PublisherAddress"],
    StyleMenuListing->None],
  
  Cell[StyleData["PublisherAddress", "NumberedHeads"]],
  
  Cell[StyleData["PublisherAddress", "Presentation"]],
  
  Cell[StyleData["PublisherAddress", "Printout"]],
  
  Cell[StyleData["PublisherAddress", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LibraryofCongressCIPDataSection"],
    StyleMenuListing->None],
  
  Cell[StyleData["LibraryofCongressCIPDataSection", "NumberedHeads"]],
  
  Cell[StyleData["LibraryofCongressCIPDataSection", "Presentation"]],
  
  Cell[StyleData["LibraryofCongressCIPDataSection", "Printout"]],
  
  Cell[StyleData["LibraryofCongressCIPDataSection", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LibraryofCongressCIPData"],
    StyleMenuListing->None],
  
  Cell[StyleData["LibraryofCongressCIPData", "NumberedHeads"]],
  
  Cell[StyleData["LibraryofCongressCIPData", "Presentation"]],
  
  Cell[StyleData["LibraryofCongressCIPData", "Printout"]],
  
  Cell[StyleData["LibraryofCongressCIPData", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ISBN"],
    StyleMenuListing->None],
  
  Cell[StyleData["ISBN", "NumberedHeads"]],
  
  Cell[StyleData["ISBN", "Presentation"]],
  
  Cell[StyleData["ISBN", "Printout"]],
  
  Cell[StyleData["ISBN", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrintingNumbers"],
    StyleMenuListing->None],
  
  Cell[StyleData["PrintingNumbers", "NumberedHeads"]],
  
  Cell[StyleData["PrintingNumbers", "Presentation"]],
  
  Cell[StyleData["PrintingNumbers", "Printout"]],
  
  Cell[StyleData["PrintingNumbers", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Book Frontmatter Epigraph", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FrontMatterEpigraph"],
    StyleMenuListing->None],
  
  Cell[StyleData["FrontMatterEpigraph", "NumberedHeads"]],
  
  Cell[StyleData["FrontMatterEpigraph", "Presentation"]],
  
  Cell[StyleData["FrontMatterEpigraph", "Printout"]],
  
  Cell[StyleData["FrontMatterEpigraph", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FrontMatterEpigraphAuthor"],
    TextAlignment->Right,
    StyleMenuListing->None],
  
  Cell[StyleData["FrontMatterEpigraphAuthor", "NumberedHeads"]],
  
  Cell[StyleData["FrontMatterEpigraphAuthor", "Presentation"]],
  
  Cell[StyleData["FrontMatterEpigraphAuthor", "Printout"]],
  
  Cell[StyleData["FrontMatterEpigraphAuthor", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FrontMatterEpigraphSource"],
    TextAlignment->Right,
    StyleMenuListing->None],
  
  Cell[StyleData["FrontMatterEpigraphSource", "NumberedHeads"]],
  
  Cell[StyleData["FrontMatterEpigraphSource", "Presentation"]],
  
  Cell[StyleData["FrontMatterEpigraphSource", "Printout"]],
  
  Cell[StyleData["FrontMatterEpigraphSource", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Book Table of Contents", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCBookPartTitle"],
    StyleMenuListing->None],
  
  Cell[StyleData["TOCBookPartTitle", "NumberedHeads"]],
  
  Cell[StyleData["TOCBookPartTitle", "Presentation"]],
  
  Cell[StyleData["TOCBookPartTitle", "Printout"]],
  
  Cell[StyleData["TOCBookPartTitle", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCBookPartLabel"],
    StyleMenuListing->None],
  
  Cell[StyleData["TOCBookPartLabel", "NumberedHeads"]],
  
  Cell[StyleData["TOCBookPartLabel", "Presentation"]],
  
  Cell[StyleData["TOCBookPartLabel", "Printout"]],
  
  Cell[StyleData["TOCBookPartLabel", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCBookChapterTitle"],
    StyleMenuListing->None],
  
  Cell[StyleData["TOCBookChapterTitle", "NumberedHeads"]],
  
  Cell[StyleData["TOCBookChapterTitle", "Presentation"]],
  
  Cell[StyleData["TOCBookChapterTitle", "Printout"]],
  
  Cell[StyleData["TOCBookChapterTitle", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCBookChapterLabel"],
    StyleMenuListing->None],
  
  Cell[StyleData["TOCBookChapterLabel", "NumberedHeads"]],
  
  Cell[StyleData["TOCBookChapterLabel", "Presentation"]],
  
  Cell[StyleData["TOCBookChapterLabel", "Printout"]],
  
  Cell[StyleData["TOCBookChapterLabel", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Book Preface", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrefaceSection"],
    StyleMenuListing->None],
  
  Cell[StyleData["PrefaceSection", "NumberedHeads"]],
  
  Cell[StyleData["PrefaceSection", "Presentation"]],
  
  Cell[StyleData["PrefaceSection", "Printout"]],
  
  Cell[StyleData["PrefaceSection", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Preface"],
    StyleMenuListing->None],
  
  Cell[StyleData["Preface", "NumberedHeads"]],
  
  Cell[StyleData["Preface", "Presentation"]],
  
  Cell[StyleData["Preface", "Printout"]],
  
  Cell[StyleData["Preface", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrefaceAuthor"],
    StyleMenuListing->None],
  
  Cell[StyleData["PrefaceAuthor", "NumberedHeads"]],
  
  Cell[StyleData["PrefaceAuthor", "Presentation"]],
  
  Cell[StyleData["PrefaceAuthor", "Printout"]],
  
  Cell[StyleData["PrefaceAuthor", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Book Foreword", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Foreword"],
    StyleMenuListing->None],
  
  Cell[StyleData["Foreword", "NumberedHeads"]],
  
  Cell[StyleData["Foreword", "Presentation"]],
  
  Cell[StyleData["Foreword", "Printout"]],
  
  Cell[StyleData["Foreword", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ForewordAuthor"],
    StyleMenuListing->None],
  
  Cell[StyleData["ForewordAuthor", "NumberedHeads"]],
  
  Cell[StyleData["ForewordAuthor", "Presentation"]],
  
  Cell[StyleData["ForewordAuthor", "Printout"]],
  
  Cell[StyleData["ForewordAuthor", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Part", "Subsection",
    GeneratedCell->False,
    CellAutoOverwrite->False,
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BookPartLabel"],
    CellMargins->{{54, 54}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 10},
    TextAlignment->Center,
    CounterIncrements->"Part",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->27,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}],
  
  Cell[StyleData["BookPartLabel", "NumberedHeads"]],
  
  Cell[StyleData["BookPartLabel", "Presentation"],
    CellMargins->{{54, 54}, {11, 11}},
    FontSize->41],
  
  Cell[StyleData["BookPartLabel", "Printout"],
    CellMargins->{{48, 48}, {6, 6}},
    StyleMenuListing->None,
    FontSize->24],
  
  Cell[StyleData["BookPartLabel", "NumberedHeadsPrintout"],
    CellMargins->{{48, 48}, {6, 6}},
    StyleMenuListing->None,
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BookPartNumber"],
    CellMargins->{{54, 54}, {7, 7}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->27,
    FontWeight->"Bold"],
  
  Cell[StyleData["BookPartNumber", "NumberedHeads"]],
  
  Cell[StyleData["BookPartNumber", "Presentation"],
    CellMargins->{{54, 54}, {11, 11}},
    FontSize->41],
  
  Cell[StyleData["BookPartNumber", "Printout"],
    CellMargins->{{48, 48}, {6, 6}},
    TextAlignment->Center,
    StyleMenuListing->None,
    FontSize->24],
  
  Cell[StyleData["BookPartNumber", "NumberedHeadsPrintout"],
    CellMargins->{{48, 48}, {6, 6}},
    TextAlignment->Center,
    StyleMenuListing->None,
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BookPartTitle"],
    CellMargins->{{54, 54}, {12, 7}},
    TextAlignment->Center,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["BookPartTitle", "NumberedHeads"]],
  
  Cell[StyleData["BookPartTitle", "Presentation"],
    CellMargins->{{54, 54}, {18, 11}},
    FontSize->54],
  
  Cell[StyleData["BookPartTitle", "Printout"],
    CellMargins->{{48, 48}, {10, 6}},
    StyleMenuListing->None,
    FontSize->30],
  
  Cell[StyleData["BookPartTitle", "NumberedHeadsPrintout"],
    CellMargins->{{48, 48}, {10, 6}},
    StyleMenuListing->None,
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BookPartSubtitle"],
    CellMargins->{{54, 54}, {12, 7}},
    TextAlignment->Center,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["BookPartSubtitle", "NumberedHeads"]],
  
  Cell[StyleData["BookPartSubtitle", "Presentation"],
    CellMargins->{{54, 54}, {18, 11}},
    FontSize->36],
  
  Cell[StyleData["BookPartSubtitle", "Printout"],
    CellMargins->{{48, 48}, {10, 6}},
    StyleMenuListing->None,
    FontSize->21],
  
  Cell[StyleData["BookPartSubtitle", "NumberedHeadsPrintout"],
    CellMargins->{{48, 48}, {10, 6}},
    StyleMenuListing->None,
    FontSize->21]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BookPartSubsubtitle"],
    CellMargins->{{54, 54}, {12, Inherited}},
    TextAlignment->Center,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain"],
  
  Cell[StyleData["BookPartSubsubtitle", "NumberedHeads"]],
  
  Cell[StyleData["BookPartSubsubtitle", "Presentation"],
    CellMargins->{{54, 54}, {18, Inherited}},
    FontSize->27],
  
  Cell[StyleData["BookPartSubsubtitle", "Printout"],
    CellMargins->{{48, 48}, {10, Inherited}},
    StyleMenuListing->None,
    FontSize->16],
  
  Cell[StyleData["BookPartSubsubtitle", "NumberedHeadsPrintout"],
    CellMargins->{{48, 48}, {10, Inherited}},
    StyleMenuListing->None,
    FontSize->16]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BookPartText"],
    CellMargins->{{72, 72}, {7, 7}},
    TextJustification->1,
    ParagraphIndent->12,
    StyleMenuListing->None],
  
  Cell[StyleData["BookPartText", "NumberedHeads"]],
  
  Cell[StyleData["BookPartText", "Presentation"],
    CellMargins->{{72, 72}, {11, 11}},
    ParagraphIndent->17,
    FontSize->17],
  
  Cell[StyleData["BookPartText", "Printout"],
    CellMargins->{{60, 60}, {5, 5}},
    ParagraphIndent->10,
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["BookPartText", "NumberedHeadsPrintout"],
    CellMargins->{{60, 60}, {5, 5}},
    ParagraphIndent->10,
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BookPartTextNoIndent"],
    CellMargins->{{72, 72}, {7, 7}},
    TextJustification->1,
    StyleMenuListing->None],
  
  Cell[StyleData["BookPartTextNoIndent", "NumberedHeads"]],
  
  Cell[StyleData["BookPartTextNoIndent", "Presentation"],
    CellMargins->{{72, 72}, {11, 11}},
    FontSize->17],
  
  Cell[StyleData["BookPartTextNoIndent", "Printout"],
    CellMargins->{{60, 60}, {5, 5}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["BookPartTextNoIndent", "NumberedHeadsPrintout"],
    CellMargins->{{60, 60}, {5, 5}},
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Chapter", "Subsection",
    GeneratedCell->False,
    CellAutoOverwrite->False,
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BookChapterLabel"],
    CellMargins->{{12, 12}, {4, 72}},
    CellGroupingRules->{"SectionGrouping", 20},
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    PageBreakAbove->True,
    PageBreakBelow->False,
    CellFrameMargins->1,
    LineSpacing->{1, 2},
    CounterIncrements->"Chapter",
    CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}, {"EquationNumbered", 0}, {"FigureCaption", 0}, {
        "PictureCaption", 0}, {"ProgramCaption", 0}, {"TableTitle", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Plain"],
  
  Cell[StyleData["BookChapterLabel", "NumberedHeads"]],
  
  Cell[StyleData["BookChapterLabel", "Presentation"],
    CellMargins->{{23, 12}, {6, 108}},
    PageBreakAbove->False,
    FontSize->20],
  
  Cell[StyleData["BookChapterLabel", "Printout"],
    CellMargins->{{2, 2}, {3, 60}},
    FontSize->11],
  
  Cell[StyleData["BookChapterLabel", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {3, 60}},
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BookChapterNumber"],
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->19,
    FontWeight->"Bold"],
  
  Cell[StyleData["BookChapterNumber", "NumberedHeads"]],
  
  Cell[StyleData["BookChapterNumber", "Presentation"],
    FontSize->29],
  
  Cell[StyleData["BookChapterNumber", "Printout"],
    FontSize->17],
  
  Cell[StyleData["BookChapterNumber", "NumberedHeadsPrintout"],
    FontSize->17]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BookChapterTitle"],
    CellMargins->{{12, 12}, {24, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["BookChapterTitle", "NumberedHeads"]],
  
  Cell[StyleData["BookChapterTitle", "Presentation"],
    CellMargins->{{23, 12}, {36, 6}},
    FontSize->36],
  
  Cell[StyleData["BookChapterTitle", "Printout"],
    CellMargins->{{2, 2}, {21, 3}},
    StyleMenuListing->None,
    FontSize->21],
  
  Cell[StyleData["BookChapterTitle", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {21, 3}},
    StyleMenuListing->None,
    FontSize->21]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BookChapterSubtitle"],
    StyleMenuListing->None],
  
  Cell[StyleData["BookChapterSubtitle", "NumberedHeads"]],
  
  Cell[StyleData["BookChapterSubtitle", "Presentation"]],
  
  Cell[StyleData["BookChapterSubtitle", "Printout"]],
  
  Cell[StyleData["BookChapterSubtitle", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BookChapterSubsubtitle"],
    StyleMenuListing->None],
  
  Cell[StyleData["BookChapterSubsubtitle", "NumberedHeads"]],
  
  Cell[StyleData["BookChapterSubsubtitle", "Presentation"]],
  
  Cell[StyleData["BookChapterSubsubtitle", "Printout"]],
  
  Cell[StyleData["BookChapterSubsubtitle", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Epigraph", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Epigraph"],
    CellMargins->{{54, 54}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["Epigraph", "NumberedHeads"]],
  
  Cell[StyleData["Epigraph", "Presentation"],
    FontSize->17],
  
  Cell[StyleData["Epigraph", "Printout"],
    CellMargins->{{48, 48}, {0, 0}},
    FontSize->10],
  
  Cell[StyleData["Epigraph", "NumberedHeadsPrintout"],
    CellMargins->{{48, 48}, {0, 0}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EpigraphAuthor"],
    CellMargins->{{54, 54}, {24, 12}},
    CellGroupingRules->"GraphicsGrouping",
    StyleMenuListing->None],
  
  Cell[StyleData["EpigraphAuthor", "NumberedHeads"]],
  
  Cell[StyleData["EpigraphAuthor", "Presentation"],
    CellMargins->{{54, 54}, {36, 18}},
    FontSize->17],
  
  Cell[StyleData["EpigraphAuthor", "Printout"],
    CellMargins->{{48, 48}, {21, 10}},
    FontSize->10],
  
  Cell[StyleData["EpigraphAuthor", "NumberedHeadsPrintout"],
    CellMargins->{{48, 48}, {21, 10}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Book Backmatter", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell["Glossary", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GlossarySection"],
    StyleMenuListing->None],
  
  Cell[StyleData["GlossarySection", "NumberedHeads"]],
  
  Cell[StyleData["GlossarySection", "Presentation"]],
  
  Cell[StyleData["GlossarySection", "Printout"]],
  
  Cell[StyleData["GlossarySection", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GlossaryEntry"],
    StyleMenuListing->None],
  
  Cell[StyleData["GlossaryEntry", "NumberedHeads"]],
  
  Cell[StyleData["GlossaryEntry", "Presentation"]],
  
  Cell[StyleData["GlossaryEntry", "Printout"]],
  
  Cell[StyleData["GlossaryEntry", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Book Frontmatter or Backmatter", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Colophon"],
    StyleMenuListing->None],
  
  Cell[StyleData["Colophon", "NumberedHeads"]],
  
  Cell[StyleData["Colophon", "Presentation"]],
  
  Cell[StyleData["Colophon", "Printout"]],
  
  Cell[StyleData["Colophon", "NumberedHeadsPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AcknowledgmentsAuthor"],
    StyleMenuListing->None],
  
  Cell[StyleData["AcknowledgmentsAuthor", "NumberedHeads"]],
  
  Cell[StyleData["AcknowledgmentsAuthor", "Presentation"]],
  
  Cell[StyleData["AcknowledgmentsAuthor", "Printout"]],
  
  Cell[StyleData["AcknowledgmentsAuthor", "NumberedHeadsPrintout"]]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Miscellaneous", "Section"],
  
  Cell[StyleData["TextSuperscript"],
    ConversionRules:>{"TeX" -> {{"", 
      ConvertTextSuperscriptToLaTeX[ ], ""}, {"", Automatic, ""}}},
    ScriptMinSize->10,
    SingleLetterItalics->False,
    StyleMenuListing->None],
  
  Cell[StyleData["TextSubscript"],
    ScriptMinSize->10,
    SingleLetterItalics->False,
    StyleMenuListing->None],
  
  Cell[StyleData["Nil"],
    StyleMenuListing->None],
  
  Cell[StyleData["Verbatim"],
    StyleMenuListing->None,
    FontSize->12],
  
  Cell[StyleData["TeXName"],
    ConversionRules:>{"TeX" -> {"\\TeX\\", 
      NoOutput[ ], ""}},
    StyleMenuListing->None],
  
  Cell[StyleData["LaTeXName"],
    ConversionRules:>{"TeX" -> {"\\LaTeX\\", 
      NoOutput[ ], ""}},
    StyleMenuListing->None],
  
  Cell[StyleData["LaTeXeName"],
    ConversionRules:>{"TeX" -> {"\\LaTeXe\\", 
      NoOutput[ ], ""}},
    StyleMenuListing->None],
  
  Cell[StyleData["ChemicalElement"],
    SingleLetterItalics->False,
    ZeroWidthTimes->True,
    StyleMenuListing->None],
  
  Cell[StyleData["CustomCharacter"],
    SingleLetterItalics->False,
    StyleMenuListing->None],
  
  Cell[StyleData["Palette"],
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageBreak"],
    Editable->False,
    CellMargins->{{0, 0}, {1, 1}},
    CellBracketOptions->{"Thickness"->1,
    "Color"->RGBColor[0.500008, 0.500008, 1],
    "Margins"->{Inherited, 3},
    "Widths"->{5, 5}},
    CellElementSpacings->{"CellMinHeight"->1},
    ConversionRules:>{"TeX" -> {"\n\n\\pagebreak", 
      NoOutput[ ], ""}, "HTML" -> {"<br class=\"PageBreak\">", 
      NoOutput[ ], ""}},
    PageBreakAbove->True,
    CellSize->{Inherited, 6},
    TabFilling->"- ",
    TabSpacings->1000,
    StyleMenuListing->None,
    FontSize->6,
    FontColor->GrayLevel[0.700008]],
  
  Cell[StyleData["PageBreak", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    CellSize->{Inherited, 2},
    TabFilling->""]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CreationDate"],
    CellFrame->0.5,
    CellMargins->{{10, 10}, {4, 4}},
    TextAlignment->Center,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["CreationDate", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 1},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Lines and Spacers", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SingleLine"],
    CellMargins->{{2, 10}, {1, 1}},
    CellGroupingRules->{"GraphicsGrouping", 0},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["SingleLine", "Printout"],
    CellMargins->{{2, 10}, {1, 1}},
    CellGroupingRules->{"GraphicsGrouping", 0},
    FontSize->2]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleLine"],
    Editable->False,
    PageWidth->400,
    CellFrame->{{0, 0}, {0.25, 0.25}},
    CellMargins->{{12, 10}, {1, 1}},
    CellElementSpacings->{"CellMinHeight"->0},
    CellFrameMargins->{{2, 10}, {0, 0}},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["DoubleLine", "Printout"],
    CellMargins->{{2, 10}, {1, 1}},
    FontSize->2]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ThinLine"],
    Editable->False,
    Selectable->False,
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowCellBracket->False,
    CellMargins->{{12, 10}, {2, 2}},
    CellElementSpacings->{"CellMinHeight"->1},
    CellFrameMargins->False,
    CellSize->{Inherited, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ThinLine", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MediumLine"],
    Editable->False,
    Selectable->False,
    CellFrame->{{0, 0}, {0, 2}},
    ShowCellBracket->False,
    CellMargins->{{12, 10}, {2, 2}},
    CellElementSpacings->{"CellMinHeight"->1},
    CellFrameMargins->False,
    CellSize->{Inherited, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["MediumLine", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ThickLine"],
    Editable->False,
    Selectable->False,
    CellFrame->{{0, 0}, {0, 3}},
    ShowCellBracket->False,
    CellMargins->{{12, 10}, {2, 2}},
    CellElementSpacings->{"CellMinHeight"->1},
    CellFrameMargins->False,
    CellSize->{Inherited, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ThickLine", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Spacer"],
    CellMargins->{{Inherited, Inherited}, {4, 4}},
    StyleMenuListing->None],
  
  Cell[StyleData["Spacer", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSpacer"],
    StyleMenuListing->None],
  
  Cell[StyleData["TextSpacer", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionSpacer"],
    StyleMenuListing->None],
  
  Cell[StyleData["SectionSpacer", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GraphicsSpacer"],
    StyleMenuListing->None],
  
  Cell[StyleData["GraphicsSpacer", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Vita", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["VitaGroup"],
    CellMargins->{{12, 12}, {7, 24}},
    CellGroupingRules->{"SectionGrouping", 1},
    ConversionRules:>{"TeX" -> {"", 
      NoOutput[ ], ""}, "HTML" -> {"", 
      NoOutput[ ], ""}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["VitaGroup", "NumberedHeads"]],
  
  Cell[StyleData["VitaGroup", "Presentation"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["VitaGroup", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["VitaGroup", "NumberedHeadsPrintout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["VitaAuthor"],
    CellMargins->{{12, 12}, {7, 7}},
    StyleMenuListing->None],
  
  Cell[StyleData["VitaAuthor", "NumberedHeads"]],
  
  Cell[StyleData["VitaAuthor", "Presentation"],
    CellMargins->{{23, 12}, {11, 11}},
    StyleMenuListing->None,
    FontSize->17],
  
  Cell[StyleData["VitaAuthor", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->10],
  
  Cell[StyleData["VitaAuthor", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["VitaContactInformation"],
    CellMargins->{{12, 12}, {7, 7}},
    StyleMenuListing->None],
  
  Cell[StyleData["VitaContactInformation", "NumberedHeads"]],
  
  Cell[StyleData["VitaContactInformation", "Presentation"],
    CellMargins->{{23, 12}, {7, 7}},
    FontSize->17],
  
  Cell[StyleData["VitaContactInformation", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->10],
  
  Cell[StyleData["VitaContactInformation", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["VitaSection"],
    CellMargins->{{12, 12}, {24, 4}},
    CellGroupingRules->{"SectionGrouping", 7},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["VitaSection", "NumberedHeads"]],
  
  Cell[StyleData["VitaSection", "Presentation"],
    CellMargins->{{23, 12}, {36, 6}},
    FontSize->36],
  
  Cell[StyleData["VitaSection", "Printout"],
    CellMargins->{{2, 2}, {21, 3}},
    FontSize->21],
  
  Cell[StyleData["VitaSection", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {21, 3}},
    FontSize->21]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["VitaSubsection"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{12, 12}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 10},
    CellFrameMargins->{{0, 0}, {3, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["VitaSubsection", "NumberedHeads"]],
  
  Cell[StyleData["VitaSubsection", "Presentation"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{23, 12}, {6, 36}},
    CellFrameMargins->{{0, 0}, {5, 0}},
    FontSize->24],
  
  Cell[StyleData["VitaSubsection", "Printout"],
    CellMargins->{{2, 2}, {3, 21}},
    FontSize->14],
  
  Cell[StyleData["VitaSubsection", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {3, 21}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["VitaItem"],
    CellMargins->{{12, 12}, {1, 2}},
    CellGroupingRules->"GraphicsGrouping",
    ConversionRules:>{{"TeX" -> {"\\item ", ""}}, {"HTML" -> {"<li>", 
      "</li>"}}},
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 1, 
      "CellGroupEnvironment" -> "itemize"}, "HTML" -> {"NestingLevel" -> 1, 
      "CellGroupEnvironment" -> "ul"}}},
    CellFrameLabels->{{
      Cell[ "\[FilledSmallCircle]", "VitaItemLabel", CellBaseline -> 
            Baseline], Inherited}, {Inherited, Inherited}},
    CellFrameLabelMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["VitaItem", "NumberedHeads"]],
  
  Cell[StyleData["VitaItem", "Presentation"],
    CellMargins->{{23, 12}, {2, 3}},
    CellFrameLabelMargins->6,
    FontSize->17],
  
  Cell[StyleData["VitaItem", "Printout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10],
  
  Cell[StyleData["VitaItem", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["VitaItemLabel"],
    ConversionRules:>{{"TeX" -> {"", 
      NoOutput[ ], ""}}, {"HTML" -> {"", 
      NoOutput[ ], ""}}},
    CellSize->{24, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["VitaItemLabel", "NumberedHeads"]],
  
  Cell[StyleData["VitaItemLabel", "Presentation"]],
  
  Cell[StyleData["VitaItemLabel", "Printout"],
    CellSize->{18, Inherited},
    FontSize->10],
  
  Cell[StyleData["VitaItemLabel", "NumberedHeadsPrintout"],
    CellSize->{18, Inherited},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["VitaItemParagraph"],
    CellMargins->{{40, 12}, {1, 1}},
    CellGroupingRules->"GraphicsGrouping",
    TaggingRules:>{"ExtraConversionRules" -> {"TeX" -> {"NestingLevel" -> 1, 
      "CellGroupEnvironment" -> "enumerate"}}},
    CounterAssignments->{{"Item2Numbered", 0}, {"Item3Numbered", 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["VitaItemParagraph", "NumberedHeads"]],
  
  Cell[StyleData["VitaItemParagraph", "Presentation"],
    CellMargins->{{54, 12}, {2, 2}},
    FontSize->17],
  
  Cell[StyleData["VitaItemParagraph", "Printout"],
    CellMargins->{{24, 2}, {1, 1}},
    FontSize->10],
  
  Cell[StyleData["VitaItemParagraph", "NumberedHeadsPrintout"],
    CellMargins->{{24, 2}, {1, 1}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Vita"],
    CellMargins->{{12, 12}, {3, 5}},
    StyleMenuListing->None],
  
  Cell[StyleData["Vita", "NumberedHeads"]],
  
  Cell[StyleData["Vita", "Presentation"],
    CellMargins->{{23, 12}, {5, 8}},
    FontSize->17],
  
  Cell[StyleData["Vita", "Printout"],
    CellMargins->{{2, 2}, {2, 4}}],
  
  Cell[StyleData["Vita", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {2, 4}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Outline", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{12, 12}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Outline1"], ". "}], "Outline1Label", CellBaseline -> 
            Baseline], Inherited}, {Inherited, Inherited}},
    CounterIncrements->"Outline1",
    CounterAssignments->{{"Outline2", 0}},
    StyleMenuListing->None,
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "NumberedHeads"]],
  
  Cell[StyleData["Outline1", "Presentation"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{12, 12}, {7, 7}},
    FontSize->27],
  
  Cell[StyleData["Outline1", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->16],
  
  Cell[StyleData["Outline1", "NumberedHeadsPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->16]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1Label"],
    CellSize->{40, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Outline1Label", "NumberedHeads"]],
  
  Cell[StyleData["Outline1Label", "Presentation"],
    CellSize->{60, Inherited}],
  
  Cell[StyleData["Outline1Label", "Printout"],
    CellSize->{36, Inherited}],
  
  Cell[StyleData["Outline1Label", "NumberedHeadsPrintout"],
    CellSize->{36, Inherited}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{32, 12}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 40},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Outline2"], ". "}], "Outline2Label", CellBaseline -> 
            Baseline], Inherited}, {Inherited, Inherited}},
    CounterIncrements->"Outline2",
    CounterAssignments->{{"Outline3", 0}},
    StyleMenuListing->None,
    FontSize->16,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "NumberedHeads"]],
  
  Cell[StyleData["Outline2", "Presentation"],
    CellMargins->{{52, 12}, {11, 11}},
    FontSize->24],
  
  Cell[StyleData["Outline2", "Printout"],
    CellMargins->{{22, 2}, {6, 6}},
    FontSize->14],
  
  Cell[StyleData["Outline2", "NumberedHeadsPrintout"],
    CellMargins->{{22, 2}, {6, 6}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2Label"],
    CellSize->{30, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Outline2Label", "NumberedHeads"]],
  
  Cell[StyleData["Outline2Label", "Presentation"],
    CellSize->{45, Inherited}],
  
  Cell[StyleData["Outline2Label", "Printout"],
    CellSize->{27, Inherited}],
  
  Cell[StyleData["Outline2Label", "NumberedHeadsPrintout"],
    CellSize->{27, Inherited}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{52, 12}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Outline3"], ". "}], "Outline3Label", CellBaseline -> 
            Baseline], Inherited}, {Inherited, Inherited}},
    CounterIncrements->"Outline3",
    CounterAssignments->{{"Outline4", 0}},
    StyleMenuListing->None,
    FontSize->14,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "NumberedHeads"]],
  
  Cell[StyleData["Outline3", "Presentation"],
    CellMargins->{{92, 12}, {11, 11}},
    FontSize->21],
  
  Cell[StyleData["Outline3", "Printout"],
    CellMargins->{{42, 2}, {6, 6}},
    FontSize->12],
  
  Cell[StyleData["Outline3", "NumberedHeadsPrintout"],
    CellMargins->{{42, 2}, {6, 6}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3Label"],
    CellSize->{21, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Outline3Label", "NumberedHeads"]],
  
  Cell[StyleData["Outline3Label", "Presentation"],
    CellSize->{32, Inherited}],
  
  Cell[StyleData["Outline3Label", "Printout"],
    CellSize->{18, Inherited}],
  
  Cell[StyleData["Outline3Label", "NumberedHeadsPrintout"],
    CellSize->{18, Inherited}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{67, 12}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Outline4"], ". "}], "Outline4Label", CellBaseline -> 
            Baseline], Inherited}, {Inherited, Inherited}},
    CounterIncrements->"Outline4",
    StyleMenuListing->None,
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "NumberedHeads"]],
  
  Cell[StyleData["Outline4", "Presentation"],
    CellMargins->{{122, 12}, {11, 11}},
    FontSize->17],
  
  Cell[StyleData["Outline4", "Printout"],
    CellMargins->{{57, 2}, {6, 6}},
    FontSize->10],
  
  Cell[StyleData["Outline4", "NumberedHeadsPrintout"],
    CellMargins->{{57, 2}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4Label"],
    CellSize->{18, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Outline4Label", "NumberedHeads"]],
  
  Cell[StyleData["Outline4Label", "Presentation"],
    CellSize->{27, Inherited}],
  
  Cell[StyleData["Outline4Label", "Printout"],
    CellSize->{16, Inherited}],
  
  Cell[StyleData["Outline4Label", "NumberedHeadsPrintout"],
    CellSize->{16, Inherited}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OutlineText"],
    CellMargins->{{91, 12}, {3, 5}},
    ConversionRules:>{"TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, 
      ""}}},
    TextAlignment->Left,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["OutlineText", "NumberedHeads"]],
  
  Cell[StyleData["OutlineText", "Presentation"],
    CellMargins->{{155, 12}, {5, 8}},
    FontSize->17],
  
  Cell[StyleData["OutlineText", "Printout"],
    CellMargins->{{79, 2}, {2, 4}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->10],
  
  Cell[StyleData["OutlineText", "NumberedHeadsPrintout"],
    CellMargins->{{79, 2}, {2, 4}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{0, 0}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"TitleGrouping", 1},
    PageBreakAbove->True,
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[0.8],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    CounterAssignments->{{"Item1Numbered", 0}},
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "Presentation"]],
  
  Cell[StyleData["SlideHyperlink", "Printout"]]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Common Inline", "Section"],
  
  Cell[CellGroupData[{
  
  Cell["General Text Attributes", "Subsection",
    StyleMenuListing->None],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    ConversionRules:>{"TeX" -> {"\\textbf{", "}"}},
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    ConversionRules:>{"TeX" -> {{"\\textit{", Automatic, "}"}, {"", Automatic,
       ""}}},
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["SmallCaps"],
    ConversionRules:>{"TeX" -> {{"", ChangeCase[ "Lower"][ 
        ExtractWord[ ][ #]]&, ""}, {"", Automatic, ""}}},
    StyleMenuListing->None,
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Font Specific Text Attributes", "Subsection",
    StyleMenuListing->None],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    ConversionRules:>{"TeX" -> {{"\\textit{", Automatic, "}"}, {"", Automatic,
       ""}}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    ConversionRules:>{"TeX" -> {{"\\textbf{", Automatic, "}"}, {"", Automatic,
       ""}}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    ConversionRules:>{"TeX" -> {{"\\textbf{\\textit{", Automatic, "}}"}, {"", 
      Automatic, ""}}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    ConversionRules:>{"TeX" -> {{"\\texttt{", Automatic, "}"}, {"", Automatic,
       ""}}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    ConversionRules:>{"TeX" -> {{"\\texttt{\\textit{", Automatic, "}}"}, {"", 
      Automatic, ""}}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    ConversionRules:>{"TeX" -> {{"\\texttt{\\textbf{", Automatic, "}}"}, {"", 
      Automatic, ""}}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    ConversionRules:>{"TeX" -> {{"\\texttt{\\textbf{\\textit{", Automatic, 
      "}}}"}, {"", Automatic, ""}}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    ConversionRules:>{"TeX" -> {{"\\textsf{", Automatic, "}"}, {"", Automatic,
       ""}}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    ConversionRules:>{"TeX" -> {{"\\textsf{\\textit{", Automatic, "}}"}, {"", 
      Automatic, ""}}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    ConversionRules:>{"TeX" -> {{"\\textsf{\\textbf{", Automatic, "}}"}, {"", 
      Automatic, ""}}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    ConversionRules:>{"TeX" -> {{"\\textsf{\\textbf{\\textit{", Automatic, 
      "}}}"}, {"", Automatic, ""}}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    ConversionRules:>{"TeX" -> {{"", 
      ExportAsHyperRef[ ], ""}, {"", Automatic, ""}}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["XMLWebLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(OpenAllTypes[ #]&),
    ButtonEvaluator->Automatic,
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["XMLWebLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageLink"],
    ConversionRules:>{"TeX" -> {{"", 
      ExportAsHyperRef[ ], ""}, {"", Automatic, ""}}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["PageLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["On-line Help System Links", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "UserGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["UserGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Reference", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["ReferenceLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["System", "Section"],
  
  Cell[CellGroupData[{
  
  Cell["Format Type Style", "Subsection",
    StyleMenuListing->None],
  
  Cell["\<\

The cells below define styles that are mixed in with the styles of 
most cells.  If a cell's FormatType matches the name of one of the styles 
defined below, then that style is applied between the cell's style and its 
own options. This is particularly true of Input and Output.
\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Document Settings and Templates", "Subsection"],
  
  Cell[StyleData["ReferenceTemplate"],
    CellMargins->{{12, 10}, {7, 7}},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["AuthorFormCustomizationTemplate"],
    CellMargins->{{12, 10}, {7, 7}},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["CSSDefinitions"],
    CellMargins->{{12, 10}, {7, 7}},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["LaTeXPreamble"],
    CellMargins->{{12, 10}, {7, 7}},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["DOCTYPEFormat"],
    CellMargins->{{12, 10}, {7, 7}},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["ValidationSetting"],
    CellMargins->{{12, 10}, {7, 7}},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["XRefPaletteSettings"],
    CellMargins->{{12, 10}, {7, 7}},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["MiscSettings"],
    CellMargins->{{12, 10}, {7, 7}},
    StyleMenuListing->None,
    FontFamily->"Courier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Cells", "Subsection",
    StyleMenuListing->None],
  
  Cell["\<\

The style defined below is mixed in to any cell that is in an 
inline cell within another.
\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    InputAutoReplacements->{"-"->"-"},
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[0.880003, 0.899992, 0.959991]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette", "Subsection",
    StyleMenuListing->None],
  
  Cell["\<\

The cells below define styles that define standard ButtonFunctions, 
for use in palette buttons.
\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["StyleApply"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(CellWriteStyle[ #]&),
    ButtonEvaluator->Automatic}],
  
  Cell[StyleData["StyleApplyWithVerification"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(CompoundExpression[ 
        CheckDocStyleMatch[ ], 
        CellWriteStyle[ #]]&),
    ButtonEvaluator->Automatic}],
  
  Cell[StyleData["ConvertCharacter"],
    ConversionRules:>{"TeX" -> {"", 
      ExtractButtonData[ "TeX"], ""}, "HTML" :> {"", 
      ExtractButtonData[ "HTML"], ""}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonEvaluator->Automatic,
    ButtonFrame->"None"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic", "Subsection",
    StyleMenuListing->None],
  
  Cell["\<\

The cells below define styles that are used to affect the display 
of certain types of objects in typeset expressions.  For example, 
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and 
parenthesis characters are displayed (typically by coloring them to make them \

stand out).
\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["DialogEffects", "Subsection",
    StyleMenuListing->None],
  
  Cell[StyleData["DialogStyleSheetMisapplicationEscape"],
    ShowCellBracket->False,
    CellMargins->{{12, 12}, {2000, 40}},
    CellOpen->True,
    TextAlignment->Center,
    StyleMenuListing->None]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Conformance", "Section"],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection",
    StyleMenuListing->None],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names. \
Some attributes for these styles are actually set in FormatType Styles (in \
the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{72, 72}, {6, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->StandardForm,
    InputAutoReplacements->{},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    SpanMaxSize->Automatic,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{21, 6}, {3, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputNumbered"],
    CellMargins->{{72, 6}, {6, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellFrameLabels->{{None, Cell[ 
            BoxData[ 
              StyleBox[ 
                RowBox[ {"(", 
                  CounterBox[ "Input"], ")"}], FontWeight -> "Plain", 
                FontFamily -> "Times"]]]}, {None, None}},
    CellFrameLabelMargins->{{0, 42}, {0, 0}},
    DefaultFormatType->StandardForm,
    InputAutoReplacements->{},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    SpanMaxSize->Automatic,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InputNumbered", "Printout"],
    CellMargins->{{21, 6}, {3, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    DefaultFormatType->StandardForm,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    SpanMaxSize->Automatic,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{72, 72}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->StandardForm,
    InputAutoReplacements->{},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    SpanMaxSize->Automatic,
    CounterIncrements->"Output",
    StyleMenuListing->None],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{21, 0}, {6, 3}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->StandardForm,
    AutoItalicWords->{},
    FormatType->InputForm,
    SpanMaxSize->Automatic,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->StandardForm,
    AutoItalicWords->{},
    FormatType->InputForm,
    SpanMaxSize->Automatic,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell["\<\
Do not remove TextAlignment->Left from \"Graphics\" style definitions or else \
graphics may behave badly as inline cells:\
\>", "Text",
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.500008]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    Editable->True,
    CellMargins->{{36, Inherited}, {0, 7}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->False,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->StandardForm,
    InputAutoReplacements->{},
    TextAlignment->Left,
    LanguageCategory->None,
    FormatType->InputForm,
    SpanMaxSize->Automatic,
    CounterIncrements->"Graphics",
    ImageMargins->{{0, 0}, {0, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{27, 0}, {6, 3}},
    ImageMargins->{{0, 0}, {0, 0}},
    FontSize->9,
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    SpanMaxSize->Automatic,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Help Browser Styles", "Subsection",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    StyleMenuListing->None],
  
  Cell[StyleData["MathCaption", "Printout"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    StyleMenuListing->None],
  
  Cell[StyleData["UserTips", "Printout"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTipsList"],
    StyleMenuListing->None],
  
  Cell[StyleData["UserTipsList", "Printout"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    StyleMenuListing->None]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Alternative Item Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item1NumberedNew"],
    CellMargins->{{12, 10}, {3, 5}},
    CellGroupingRules->"GraphicsGrouping",
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Item1Numbered"], ". "}], "Item1NumberedLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}},
    TextAlignment->Left,
    LineSpacing->{1, 3},
    ParagraphIndent->-24,
    CounterIncrements->"Item1Numbered",
    CounterAssignments->{{"Item1Numbered", 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Item1NumberedNew", "Printout"],
    CellMargins->{{0, 12}, {1, 4}},
    TextJustification->1,
    LineSpacing->{1, 2},
    ParagraphIndent->-18,
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item2NumberedNew"],
    CellMargins->{{24, 10}, {3, 5}},
    CellGroupingRules->"GraphicsGrouping",
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Item2Numbered"], ". "}], "Item2NumberedLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}},
    TextAlignment->Left,
    LineSpacing->{1, 3},
    ParagraphIndent->-24,
    CounterIncrements->"Item2Numbered",
    CounterAssignments->{{"Item2Numbered", 0}},
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Item2NumberedNew", "Printout"],
    CellMargins->{{12, 12}, {1, 4}},
    TextJustification->1,
    LineSpacing->{1, 2},
    ParagraphIndent->-18,
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item3NumberedNew"],
    CellMargins->{{36, 10}, {3, 5}},
    CellGroupingRules->"GraphicsGrouping",
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Item3Numbered"], ". "}], "Item3NumberedLabel", 
            CellBaseline -> Baseline], Inherited}, {Inherited, Inherited}},
    TextAlignment->Left,
    LineSpacing->{1, 3},
    ParagraphIndent->-24,
    CounterIncrements->"Item3Numbered",
    CounterAssignments->{{"Item3Numbered", 0}},
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Item3NumberedNew", "Printout"],
    CellMargins->{{24, 12}, {1, 4}},
    TextJustification->1,
    LineSpacing->{1, 2},
    ParagraphIndent->-18,
    StyleMenuListing->None,
    FontSize->10]
  }, Closed]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "LastSlide"->{
    Cell[66375, 1938, 1657, 43, 22, "SlideShowNavigationBar",
      CellTags->"LastSlide"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"LastSlide", 465118, 15087}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1775, 53, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[3432, 99, 74, 0, 80, "Section"],
Cell[3509, 101, 421, 7, 118, "Text"],
Cell[3933, 110, 1953, 53, 118, "Text"],
Cell[5889, 165, 282, 5, 76, "Text"],

Cell[CellGroupData[{
Cell[6196, 174, 57, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[6278, 178, 81, 1, 24, "Item1Numbered"],
Cell[6362, 181, 53, 0, 24, "Item1Numbered"],
Cell[6418, 183, 38, 0, 24, "Item1Numbered"],
Cell[6459, 185, 54, 0, 24, "Item1Numbered"],
Cell[6516, 187, 73, 0, 24, "Item1Numbered"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6662, 195, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[8319, 241, 43, 0, 52, "Subsection"],
Cell[8365, 243, 384, 8, 97, "Text"],
Cell[8752, 253, 366, 9, 76, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9167, 268, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[10824, 314, 47, 0, 52, "Subsection"],
Cell[10874, 316, 201, 6, 55, "Text"]
}, Open  ]],
Cell[11090, 325, 46, 0, 107, "Title"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11173, 330, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[12830, 376, 44, 0, 52, "Subsection"],
Cell[12877, 378, 388, 10, 76, "Text"],
Cell[13268, 390, 112, 4, 91, "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13429, 400, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[15086, 446, 38, 0, 52, "Subsection"],
Cell[15127, 448, 188, 4, 55, "Text"],
Cell[15318, 454, 149, 3, 70, "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15516, 463, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[17173, 509, 47, 0, 52, "Subsection"],
Cell[17223, 511, 697, 18, 76, "Text"],
Cell[17923, 531, 141, 7, 154, "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18113, 544, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[19770, 590, 30, 0, 52, "Subsection"],
Cell[19803, 592, 1461, 36, 118, "Text"],
Cell[21267, 630, 301, 6, 154, "Program"],
Cell[21571, 638, 90, 2, 34, "Text"],
Cell[21664, 642, 47, 0, 49, "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21760, 648, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[23417, 694, 37, 0, 52, "Subsection"],
Cell[23457, 696, 1160, 25, 139, "Text"],
Cell[24620, 723, 353, 11, 238, "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25022, 740, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[26679, 786, 30, 0, 52, "Subsection"],
Cell[26712, 788, 669, 12, 118, "Text"],
Cell[27384, 802, 443, 9, 238, "Program"],
Cell[27830, 813, 159, 3, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28038, 822, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[29695, 868, 26, 0, 52, "Subsection"],
Cell[29724, 870, 591, 11, 118, "Text"],
Cell[30318, 883, 393, 7, 175, "Program"],
Cell[30714, 892, 159, 3, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30922, 901, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[32579, 947, 32, 0, 52, "Subsection"],
Cell[32614, 949, 754, 12, 160, "Text"],
Cell[33371, 963, 189, 5, 112, "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[33609, 974, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[35266, 1020, 37, 0, 52, "Subsection"],
Cell[35306, 1022, 572, 17, 34, "Text"],
Cell[35881, 1041, 150, 3, 70, "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[36080, 1050, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[37737, 1096, 48, 0, 52, "Subsection"],
Cell[37788, 1098, 40, 0, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[37877, 1104, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[39534, 1150, 31, 0, 52, "Subsection"],
Cell[39568, 1152, 140, 3, 55, "Text"],
Cell[39711, 1157, 208, 4, 91, "Program"],
Cell[39922, 1163, 115, 3, 55, "Text"],
Cell[40040, 1168, 40, 0, 49, "Program"],
Cell[40083, 1170, 69, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[40201, 1178, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[41858, 1224, 38, 0, 52, "Subsection"],
Cell[41899, 1226, 65, 0, 34, "Text"],
Cell[41967, 1228, 189, 4, 91, "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[42205, 1238, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[43862, 1284, 41, 0, 52, "Subsection"],
Cell[43906, 1286, 109, 3, 34, "Text"],
Cell[44018, 1291, 33, 0, 49, "Program"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[44100, 1297, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[45757, 1343, 56, 0, 52, "Subsection"],
Cell[45816, 1345, 530, 10, 118, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[46395, 1361, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[48052, 1407, 67, 0, 80, "Section"],
Cell[48122, 1409, 495, 11, 97, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[48666, 1426, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[50323, 1472, 84, 2, 52, "Subsection"],
Cell[50410, 1476, 316, 6, 76, "Text"]
}, Open  ]],
Cell[50741, 1485, 60, 2, 154, "Title"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50838, 1492, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[52495, 1538, 40, 0, 52, "Subsection"],
Cell[52538, 1540, 653, 10, 139, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[53240, 1556, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[54897, 1602, 57, 0, 52, "Subsection"],
Cell[54957, 1604, 856, 15, 181, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[55862, 1625, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[57519, 1671, 43, 0, 52, "Subsection"],
Cell[57565, 1673, 107, 3, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[57721, 1682, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[59378, 1728, 44, 0, 52, "Subsection"],
Cell[59425, 1730, 400, 6, 97, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[59874, 1742, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[61531, 1788, 46, 0, 52, "Subsection"],
Cell[61580, 1790, 454, 10, 97, "Text"],

Cell[CellGroupData[{
Cell[62059, 1804, 267, 6, 43, "Item1Numbered",
  CounterAssignments->{{"Item1Numbered", 0}}],
Cell[62329, 1812, 680, 15, 80, "Item1Paragraph"],
Cell[63012, 1829, 186, 5, 24, "Item1Numbered"],
Cell[63201, 1836, 91, 1, 24, "Item1Numbered"],
Cell[63295, 1839, 159, 3, 24, "Item1Numbered"],
Cell[63457, 1844, 291, 7, 43, "Item1Numbered"],
Cell[63751, 1853, 121, 3, 24, "Item1Numbered"],
Cell[63875, 1858, 122, 3, 24, "Item1Numbered"],
Cell[64000, 1863, 151, 3, 24, "Item1Numbered"],
Cell[64154, 1868, 155, 3, 24, "Item1Numbered"],
Cell[64312, 1873, 48, 0, 24, "Item1Numbered"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[64421, 1880, 1632, 42, 22, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[66078, 1926, 51, 0, 52, "Subsection"],
Cell[66132, 1928, 194, 4, 55, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[66375, 1938, 1657, 43, 22, "SlideShowNavigationBar",
  CellTags->"LastSlide"],

Cell[CellGroupData[{
Cell[68057, 1985, 53, 0, 52, "Subsection"],
Cell[68113, 1987, 163, 3, 55, "Text"],
Cell[68279, 1992, 68006, 1118, 316, "Figure"],
Cell[136288, 3112, 175, 5, 34, "Text"],
Cell[136466, 3119, 176, 5, 97, "Text"],
Cell[136645, 3126, 328, 7, 139, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

