(************** Content-type: application/mathematica **************
                       CreatedBy='Publicon 1.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     47917,       1254]*)
(*NotebookOutlinePosition[     64671,       1797]*)
(*  CellTagsIndexPosition[     64268,       1780]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[
              AdjustmentBox["?",
                BoxMargins->{{0.0181818, -0.0181818}, {-0.214288, 0.214288}},
                BoxBaselineShift->0.214288],
              ButtonData:>"Physical Review Document Palette",
              ButtonStyle->"DialogHelp",
              ButtonNote->"Help"], 
            ButtonBox["s",
              ButtonData:>{"APS", "APS_PhysRevSample.nb"},
              ButtonStyle->"SampleDoc"], 
            ButtonBox[
              AdjustmentBox["\[LeftPointer]\[LeftPointer]",
                BoxMargins->{{0.1, -0.1}, {3.27826*^-07, -3.27826*^-07}}],
              ButtonStyle->"FullLeft",
              ButtonNote->"Move Full Left"], 
            ButtonBox["\[LeftPointer]",
              ButtonStyle->"InLeft",
              ButtonNote->"Move Near Left"], 
            ButtonBox[
              AdjustmentBox["\[RightPointer]",
                BoxMargins->{{0.1, -0.1}, {3.27826*^-07, -3.27826*^-07}}],
              ButtonStyle->"InRight",
              ButtonNote->"Move Near Right"], 
            ButtonBox[
              AdjustmentBox["\[RightPointer]\[RightPointer]",
                BoxMargins->{{0.2, -0.2}, {3.27826*^-07, -3.27826*^-07}}],
              ButtonStyle->"FullRight",
              ButtonNote->"Move Full Right"], 
            ButtonBox[
              
              AdjustmentBox[\(\[SkeletonIndicator]\[NegativeThinSpace]\
\[SkeletonIndicator]\[NegativeThinSpace]\[SkeletonIndicator]\),
                BoxMargins->{{0, 0}, {-0.333333, 0.333333}},
                BoxBaselineShift->0.333333],
              ButtonData:>"APS PhysRev",
              ButtonStyle->"Iconify"]}
          }], TraditionalForm]], "NavButtonRow",
  SingleLetterItalics->False],

Cell[BoxData[GridBox[{
        {
          ButtonBox[
            AdjustmentBox[\(New\ Document\),
              BoxMargins->{{0, 0}, {0.333334, -0.333334}},
              BoxBaselineShift->-0.333334],
            ButtonData:>{"Elsevier.nb", {
              Cell[ "F R O N T M A T T E R", "FrontmatterGroup"], 
              Cell[ 
                CellGroupData[ {
                  Cell[ "Title", "Title"], 
                  Cell[ 
                    CellGroupData[ {
                      Cell[ 
                        TextData[ {
                          Cell[ 
                            TextData[ 
                              ButtonBox[ 
                              "AuthorName", ButtonData :> "AuthorLastName1", 
                                ButtonStyle -> "AuthorLastName"]], "Author", 
                            TaggingRules :> {"AuthorData" -> {"TeX" -> {
                            "\\author{AuthorName}"}, "XML" -> {}}, 
                            "RadioButtonData" -> {"Settings" -> {}, 
                            "TeX" -> {}, "XML" -> {}}}], 
                          StyleBox[ "", "Nil"]}], "AuthorGroup", 
                        TaggingRules :> {"RadioButtonCorrelations" -> {
                        "ButtonLabels" -> {}, "TeX" -> {}, "XML" -> {}}, 
                        "FieldCorrelations" -> {"Fields" -> {"Email", 
                        "Homepage", "Institution"}, "TeX" -> {"AUTHORNAME" -> 
                        "\\author{}", "Email" -> "\\ead{}", "Homepage" -> 
                        "\\ead[url]{}", "Institution" -> "\\address{}"}, 
                        "XML" -> {}}}], 
                      Cell[ 
                        CellGroupData[ {
                          Cell[ "Abstract", "AbstractSection"], 
                          Cell[ "Abstract text...", "Abstract"], 
                          Cell[ "Keyword1, Keyword2", "Keywords"], 
                          Cell[ "12345, 67890", "PACS"], 
                          Cell[ " ", "SingleLine"]}, Open]]}, Open]]}, Open]],
               
              Cell[ "B O D Y", "MainmatterGroup"], 
              Cell[ 
                CellGroupData[ {
                  Cell[ "Section", "Section"], 
                  Cell[ "Text...", "Text"]}, Open]], 
              Cell[ "B A C K M A T T E R", "BackmatterGroup"], 
              Cell[ "Appendix Head", "AppendixSection"]}, {2, All}},
            ButtonStyle->"NewDocButton",
            ButtonNote->"Begin New Document"]}
        }]], "NewDocButton"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[" ",
              ButtonFunction:>GeneratePalette[ "TearOff", "Frontmatter"],
              ButtonEvaluator->Automatic,
              ButtonNote->"Tear-off Button Group"], 
            ButtonBox[GridBox[{
                  {" ", "Frontmatter", 
                    StyleBox[
                      AdjustmentBox["\[DownPointer]",
                        BoxMargins->{{0, 0}, {-0.25, 0.25}},
                        BoxBaselineShift->0.25],
                      "Pointer"]}
                  },
                ColumnWidths->{0.02, 0.71, 0.1}],
              ButtonNote->"Frontmatter"]}
          },
        ColumnWidths->{0.07, 0.95}], TraditionalForm]], "TopGroupButton"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox["Title",
              ButtonData:>{"Title", {
                Cell[ "Title", "Title"]}, "S"}]},
          {
            ButtonBox["Authors",
              ButtonFunction:>CompoundExpression[ 
                  CheckDocStyleMatch[ ], 
                  InsertAuthors[ ]]]},
          {
            ButtonBox["Abstract",
              ButtonData:>{"Abstract", {
                Cell[ "Abstract", "Abstract"]}, "S"}]},
          {
            ButtonBox[\(Key\ words\),
              ButtonData:>{"Keywords"}]},
          {
            ButtonBox["PACS",
              ButtonData:>{"AuthorPACS"}]}
          }], TraditionalForm]], "ButtonFind",
  CellTags->"Frontmatter"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[" ",
              ButtonFunction:>GeneratePalette[ "TearOff", "Dates"],
              ButtonEvaluator->Automatic,
              ButtonNote->"Tear-off Button Group"], 
            ButtonBox[GridBox[{
                  {" ", \(Dates/Times\), 
                    StyleBox[
                      AdjustmentBox["\[DownPointer]",
                        BoxMargins->{{0, 0}, {-0.25, 0.25}},
                        BoxBaselineShift->0.25],
                      "Pointer"]}
                  },
                ColumnWidths->{0.02, 0.71, 0.1}],
              ButtonNote->"Dates/Times"]}
          },
        ColumnWidths->{0.07, 0.93}], TraditionalForm]], "SubGroupButton"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[\(Current\ Date\),
              ButtonFunction:>CompoundExpression[ 
                  CheckDocStyleMatch[ ], 
                  DateApply[ ]],
              ButtonStyle->"Button"]},
          {
            ButtonBox[
              RowBox[{"Timestamp", "\[NegativeThinSpace]", ":", 
                
                StyleBox[\(y\[NegativeThinSpace]\[NegativeThinSpace] : \
\[NegativeThinSpace]\(m\[NegativeThinSpace]\[NegativeThinSpace] : \
\[NegativeThinSpace]\(d\[NegativeThinSpace]\[NegativeThinSpace] : \
\[NegativeThinSpace]\(h\[NegativeThinSpace]\[NegativeThinSpace] : \
\[NegativeThinSpace]\(m\[NegativeThinSpace]\[NegativeThinSpace] : \
\[NegativeThinSpace]s\)\)\)\)\),
                  "ColorTextDark"]}],
              ButtonFunction:>CompoundExpression[ 
                  CheckDocStyleMatch[ ], 
                  TimeApply[ ]],
              ButtonStyle->"SmallButton",
              ButtonMargins->5]},
          {
            ButtonBox[
              RowBox[{"Date", ":", " ", 
                StyleBox[\(\(mm/dd\)/yyyy\),
                  "ColorTextDark"]}],
              ButtonFunction:>DateApplyActiveShort[ ],
              ButtonStyle->"SmallButton",
              ButtonMargins->5]},
          {
            ButtonBox[
              RowBox[{"Date", ":", " ", 
                StyleBox[\(\(dd/mm\)/yyyy\),
                  "ColorTextDark"]}],
              ButtonFunction:>DateApplyActiveShortEuro[ ],
              ButtonStyle->"SmallButton",
              ButtonMargins->5]}
          },
        RowLines->{2, 2, False}], TraditionalForm]], "ButtonCell",
  SingleLetterItalics->False,
  CellTags->"Dates"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[" ",
              ButtonFunction:>GeneratePalette[ "TearOff", "MainElements"],
              ButtonEvaluator->Automatic,
              ButtonNote->"Tear-off Button Group"], 
            ButtonBox[GridBox[{
                  {" ", \(Main\ Elements\), 
                    StyleBox[
                      AdjustmentBox["\[DownPointer]",
                        BoxMargins->{{0, 0}, {-0.25, 0.25}},
                        BoxBaselineShift->0.25],
                      "Pointer"]}
                  },
                ColumnWidths->{0.02, 0.71, 0.1}],
              ButtonNote->"Main Elements"]}
          },
        ColumnWidths->{0.07, 0.95}], TraditionalForm]], "GroupButton"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox["Text",
              ButtonData:>{"Text"}]},
          {
            ButtonBox["TextFlush",
              ButtonData:>{"TextNoIndent"}]}
          }], TraditionalForm]], "Button",
  CellTags->"MainElements"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[
              StyleBox["Section",
                FontFamily->"Helvetica"],
              ButtonData:>{"Section", {
                Cell[ "Section", "Section"]}, "S"},
              ButtonNote->"Head 1"]},
          {
            ButtonBox[
              StyleBox["Subsection",
                FontFamily->"Helvetica"],
              ButtonData:>{"Subsection", {
                Cell[ "Subsection", "Subsection"]}, "S"},
              ButtonNote->"Head 2"]},
          {
            ButtonBox[
              StyleBox["Subsubsection",
                FontFamily->"Helvetica"],
              ButtonData:>{"Subsubsection", {
                Cell[ "Subsubsection", "Subsubsection"]}, "S"},
              ButtonNote->"Head 3"]}
          }], TraditionalForm]], "Button",
  CellTags->"MainElements"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox["Figure",
              ButtonData:>{"Figure", {
                Cell[ 
                  BoxData[ PicturePlaceholder], "Figure"], 
                Cell[ 
                  TextData[ {
                    Cell[ 
                      TextData[ {"Figure ", 
                        CounterBox[ "FigureCaption"], ": "}], 
                      "FigureCaptionLabel", TaggingRules :> {"CellLabel" -> 
                      True}], ""}], "FigureCaption"]}, 2, "S", 
                ImportFile[ "OverwriteWarning" -> False]}]},
          {
            ButtonBox["Caption",
              ButtonData:>{"FigureCaption", 
                Cell[ 
                  TextData[ {"Figure ", 
                    CounterBox[ "FigureCaption"], ": "}], 
                  "FigureCaptionLabel", TaggingRules :> {"CellLabel" -> 
                  True}], {
                Cell[ 
                  TextData[ {
                    Cell[ 
                      TextData[ {"Figure ", 
                        CounterBox[ "FigureCaption"], ": "}], 
                      "FigureCaptionLabel", TaggingRules :> {"CellLabel" -> 
                      True}], ""}], "FigureCaption"]}}]}
          }], TraditionalFrom]], "Button",
  CellTags->"MainElements"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[" ",
              ButtonFunction:>GeneratePalette[ "TearOff", "Lists"],
              ButtonEvaluator->Automatic,
              ButtonNote->"Tear-off Button Group"], 
            ButtonBox[GridBox[{
                  {" ", "Lists", 
                    StyleBox[
                      AdjustmentBox["\[DownPointer]",
                        BoxMargins->{{0, 0}, {-0.25, 0.25}},
                        BoxBaselineShift->0.25],
                      "Pointer"]}
                  },
                ColumnWidths->{0.02, 0.71, 0.1}],
              ButtonNote->"Lists"]}
          },
        ColumnWidths->{0.07, 0.93}], TraditionalForm]], "SubGroupButton"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[\(Bullet\ Item\),
              ButtonFunction:>Null,
              ButtonStyle->"ThinDarkButton"], 
            ButtonBox["1",
              ButtonData:>{"Item1"}], 
            ButtonBox["2",
              ButtonData:>{"Item2"}], 
            ButtonBox["3",
              ButtonData:>{"Item3"}]},
          {
            ButtonBox[\(Num\ Item\),
              ButtonFunction:>Null,
              ButtonStyle->"ThinDarkButton"], 
            ButtonBox["1",
              ButtonData:>{"Item1Numbered"}], 
            ButtonBox["2",
              ButtonData:>{"Item2Numbered"}], 
            ButtonBox["3",
              ButtonData:>{"Item3Numbered"}]},
          {
            ButtonBox[\(Item\ Para\),
              ButtonFunction:>Null,
              ButtonStyle->"ThinDarkButton"], 
            ButtonBox["1",
              ButtonData:>{"Item1Paragraph", {
                Cell[ "Item text", "Item1Paragraph"]}, "S"}], 
            ButtonBox["2",
              ButtonData:>{"Item2Paragraph", {
                Cell[ "Item text", "Item2Paragraph"]}, "S"}], 
            ButtonBox["3",
              ButtonData:>{"Item3Paragraph", {
                Cell[ "Item text", "Item3Paragraph"]}, "S"}]}
          },
        RowLines->{False, False, False, True, True, False, True}], 
      TraditionalForm]], "ThinButton",
  GridBoxOptions->{ColumnWidths->{0.61, 0.125}},
  CellTags->"Lists"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[\(Set\ Counter\ Value\),
              ButtonFunction:>CompoundExpression[ 
                  CheckDocStyleMatch[ ], 
                  ResetCounterAssignments[ "SetCounterValue" -> Automatic]],
              ButtonEvaluator->Automatic,
              ButtonNote->"Apply Arbitrary Increment"]}
          }], TraditionalForm]], "ThinButton",
  CellTags->"Lists"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[" ",
              ButtonFunction:>GeneratePalette[ "TearOff", "Equations"],
              ButtonEvaluator->Automatic,
              ButtonNote->"Tear-off Button Group"], 
            ButtonBox[GridBox[{
                  {" ", "Equations", 
                    StyleBox[
                      AdjustmentBox["\[DownPointer]",
                        BoxMargins->{{0, 0}, {-0.25, 0.25}},
                        BoxBaselineShift->0.25],
                      "Pointer"]}
                  },
                ColumnWidths->{0.02, 0.71, 0.1}],
              ButtonNote->"Equations"]}
          },
        ColumnWidths->{0.07, 0.95}], TraditionalForm]], "GroupButton"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox["Equation",
              ButtonFunction:>(CellWriteStyle[ #]&),
              ButtonData:>{"Equation", {
                Cell[ 
                  BoxData[ 
                    FormBox[ "\[Placeholder]", TraditionalForm]], 
                  "Equation"]}, "S"}], 
            ButtonBox["n",
              ButtonFunction:>(CellWriteStyle[ #]&),
              ButtonData:>{"EquationNumbered", {
                Cell[ 
                  BoxData[ 
                    FormBox[ "\[Placeholder]", TraditionalForm]], 
                  "EquationNumbered"]}, "S"},
              ButtonNote->"Numbered"]}
          }], TraditionalForm]], "Button",
  GridBoxOptions->{ColumnWidths->{0.69, 0.3}},
  CellTags->"Equations"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[GridBox[{
          {GridBox[{
                {
                  ButtonBox["Aligned",
                    ButtonFunction:>(CellWriteStyle[ #]&),
                    ButtonData:>{"EquationGroupAligned", {
                      Cell[ 
                        BoxData[ 
                          FormBox[ 
                            TagBox[ 
                              GridBox[ {{"\[Placeholder]", 
                                RowBox[ {"=", "\[Placeholder]"}]}}, 
                                ColumnSpacings -> 0, ColumnWidths -> .5, 
                                ColumnAlignments -> {Right, Left, Right, Left,
                                 Right, Left}], "EquationGrid", TagStyle -> 
                              "EquationGrid"], TraditionalForm]], 
                        "EquationGroupAligned"]}, {"S", 2, 1}},
                    ButtonNote->"Aligned Grouped Eqs"], 
                  ButtonBox["n",
                    ButtonFunction:>(CellWriteStyle[ #]&),
                    ButtonData:>{"EquationGroupAlignedNumbered", {
                      Cell[ 
                        BoxData[ 
                          FormBox[ 
                            TagBox[ 
                              GridBox[ {{"\[Placeholder]", 
                                RowBox[ {"=", "\[Placeholder]"}]}}, 
                                ColumnSpacings -> 0, ColumnWidths -> .5, 
                                ColumnAlignments -> {Right, Left, Right, Left,
                                 Right, Left}], "EquationGrid", TagStyle -> 
                              "EquationGrid"], TraditionalForm]], 
                        "EquationGroupAlignedNumbered"]}, {"S", 2, 1}},
                    ButtonNote->"Numbered Group"]}
                },
              ColumnWidths->{0.69, 0.3}]},
          {
            StyleBox[
              ButtonBox[" ",
                ButtonFunction:>CompoundExpression[ 
                    SelectionMove[ 
                      ButtonNotebook[ ], All, ButtonCell], 
                    FrontEndExecute[ 
                      FrontEnd`FrontEndToken[ 
                        ButtonNotebook[ ], "OpenCloseGroup"]]],
                ButtonMargins->1,
                ButtonNote->"Adjust col alignment"],
              FontSize->3]}
          },
        RowSpacings->0,
        ColumnSpacings->0,
        RowMinHeight->0.1,
        RowsEqual->False], TraditionalForm]], "Button",
  CellMargins->{{0.5, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->{"SectionGrouping", 20},
  CellTags->"Equations"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[
              AdjustmentBox["\[LeftPointer]\[LeftPointer]",
                BoxMargins->{{0.0166667, -0.0166667}, {
                3.27826*^-07, -3.27826*^-07}}],
              ButtonData:>"",
              ButtonNote->"Incremental Leftward"], 
            ButtonBox["\[LeftPointer]",
              ButtonData:>"Small",
              ButtonNote->"Small Increment Left"], 
            StyleBox[
              ButtonBox[
                AdjustmentBox["\[FilledSmallSquare]",
                  BoxMargins->{{0, 0}, {0.25, -0.25}},
                  BoxBaselineShift->-0.25],
                ButtonData:>"Interactive",
                ButtonNote->"Dialog"],
              FontSize->9], 
            ButtonBox[
              AdjustmentBox["\[LeftPointer]\[RightPointer]",
                BoxMargins->{{0.0166667, -0.0166667}, {
                3.27826*^-07, -3.27826*^-07}}],
              ButtonData:>"Center",
              ButtonNote->"Reset to Center"], 
            ButtonBox["\[RightPointer]",
              ButtonData:>"IncreaseSmall",
              ButtonNote->"Small Increment Right"], 
            ButtonBox[
              AdjustmentBox["\[RightPointer]\[RightPointer]",
                BoxMargins->{{0.116667, -0.116667}, {
                3.27826*^-07, -3.27826*^-07}}],
              ButtonData:>"Increase",
              ButtonNote->"Incremental Rightward"]}
          }], TraditionalForm]], "HalfButton2",
  CellMargins->{{Inherited, Inherited}, {1, -3}},
  SingleLetterItalics->False,
  FontSize->14,
  ButtonBoxOptions->{ButtonFunction:>(AdjustEquationGridAlignment[ 
      InputNotebook[ ], #]&),
  ButtonMargins->1},
  GridBoxOptions->{RowSpacings->0,
  ColumnSpacings->0,
  ColumnWidths->{0.17, 0.17, 0.15, 0.15, 0.17},
  RowMinHeight->0.1},
  CellTags->"Equations"]
}, Closed]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox["Nonaligned",
              ButtonFunction:>(CellWriteStyle[ #]&),
              ButtonData:>{"EquationGroup", {
                Cell[ 
                  BoxData[ 
                    FormBox[ "\[Placeholder]", TraditionalForm]], 
                  "EquationGroup"], 
                Cell[ 
                  BoxData[ 
                    FormBox[ "\[Placeholder]", TraditionalForm]], 
                  "EquationGroup"]}, 2, "F"},
              ButtonNote->"Nonaligned Grouped Eqs"], 
            ButtonBox["n",
              ButtonFunction:>(CellWriteStyle[ #]&),
              ButtonData:>{"EquationGroupNumbered", {
                Cell[ 
                  BoxData[ 
                    FormBox[ "\[Placeholder]", TraditionalForm]], 
                  "EquationGroupNumbered"], 
                Cell[ 
                  BoxData[ 
                    FormBox[ "\[Placeholder]", TraditionalForm]], 
                  "EquationGroupNumbered"]}, 2, "F"},
              ButtonNote->"Numbered Group"]}
          }], TraditionalForm]], "Button",
  CellElementSpacings->{"ClosedGroupTopMargin"->1},
  CellGroupingRules->{"SectionGrouping", 20},
  GridBoxOptions->{ColumnWidths->{0.69, 0.3}},
  CellTags->"Equations"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[" ",
              ButtonFunction:>GeneratePalette[ "TearOff", "XRefs"],
              ButtonEvaluator->Automatic,
              ButtonNote->"Tear-off Button Group"], 
            ButtonBox[GridBox[{
                  {
                    " ", \(Cross\[NegativeThinSpace] - \
\[NegativeThinSpace]References\), 
                    StyleBox[
                      AdjustmentBox["\[DownPointer]",
                        BoxMargins->{{0, 0}, {-0.25, 0.25}},
                        BoxBaselineShift->0.25],
                      "Pointer"]}
                  },
                ColumnWidths->{0.02, 0.71, 0.1}],
              ButtonNote->"Cross References"]}
          },
        ColumnWidths->{0.07, 0.95}], TraditionalForm]], "GroupButton"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[\(Insert\ \ from\ \ Outline\),
              ButtonFunction:>CompoundExpression[ 
                  CheckDocStyleMatch[ ], 
                  InsertXRef[ "Outline"]],
              ButtonStyle->"Button",
              ButtonNote->"Insert XRef from Outline"]},
          {
            ButtonBox[\(Target\ \ XRef\),
              ButtonFunction:>NewXRef[ ],
              ButtonStyle->"ThinButton"]},
          {
            ButtonBox[\(Insert\ \ XRef\),
              ButtonFunction:>InsertXRef[ ],
              ButtonStyle->"ThinButton"]}
          },
        RowLines->{2, False}], TraditionalForm]], "ButtonCell",
  CellTags->"XRefs"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[" ",
              ButtonFunction:>GeneratePalette[ "TearOff", "References"],
              ButtonEvaluator->Automatic,
              ButtonNote->"Tear-off Button Group"], 
            ButtonBox[GridBox[{
                  {" ", "References", 
                    StyleBox[
                      AdjustmentBox["\[DownPointer]",
                        BoxMargins->{{0, 0}, {-0.25, 0.25}},
                        BoxBaselineShift->0.25],
                      "Pointer"]}
                  },
                ColumnWidths->{0.02, 0.71, 0.1}],
              ButtonNote->"References"]}
          },
        ColumnWidths->{0.07, 0.95}], TraditionalForm]], "GroupButton"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[\(Insert\ Footnote\),
              ButtonFunction:>NewNote[ ],
              ButtonStyle->"Button"]},
          {
            ButtonBox[\(Insert\ Note\),
              ButtonFunction:>NewRef[ "New" -> True, "Type" -> "Note"],
              ButtonStyle->"Button"]},
          {
            ButtonBox[\(Insert\ Reference\),
              ButtonFunction:>NewRefInsert[ ],
              ButtonStyle->"Button"]}
          },
        RowLines->2], TraditionalForm]], "ButtonCell",
  CellTags->"References"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[\(Gather\ Backmatter\),
              ButtonFunction:>GatherBackmatter[ 
                  InputNotebook[ ]],
              ButtonStyle->"DarkButton"]},
          {
            ButtonBox[\(Restore\ Citations\),
              ButtonFunction:>ExpandCitations[ 
                  InputNotebook[ ]],
              ButtonStyle->"ThinDarkButton"]}
          },
        RowLines->{False, 2}], TraditionalForm]], "DarkButtonCell",
  CellTags->"References"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[" ",
              ButtonFunction:>GeneratePalette[ "TearOff", "Tables"],
              ButtonEvaluator->Automatic,
              ButtonNote->"Tear-off Button Group"], 
            ButtonBox[GridBox[{
                  {" ", "Tables", 
                    StyleBox[
                      AdjustmentBox["\[DownPointer]",
                        BoxMargins->{{0, 0}, {-0.25, 0.25}},
                        BoxBaselineShift->0.25],
                      "Pointer"]}
                  },
                ColumnWidths->{0.02, 0.71, 0.1}],
              ButtonNote->"Tables"]}
          },
        ColumnWidths->{0.07, 0.95}], TraditionalForm]], "GroupButton"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[\(Insert\ Table\),
              ButtonEvaluator->Automatic,
              ButtonData:>{{
                Cell[ 
                  TextData[ {
                    Cell[ 
                      TextData[ {"Table ", 
                        CounterBox[ "TableTitle"], ". "}], "TableTitleLabel", 
                      TaggingRules :> {"CellLabel" -> True}], 
                    "The title for your table..."}], "TableTitle"]}, 1, "AC", 
                
                TableApply[ "Dialog"]},
              ButtonStyle->"Button"]},
          {
            ButtonBox[\(Import\ Table\),
              ButtonEvaluator->Automatic,
              ButtonData:>{{
                Cell[ 
                  TextData[ {
                    Cell[ 
                      TextData[ {"Table ", 
                        CounterBox[ "TableTitle"], ". "}], "TableTitleLabel", 
                      TaggingRules :> {"CellLabel" -> True}], 
                    "The title for your table..."}], "TableTitle"]}, 1, "AC", 
                
                TableApply[ "ImportCSV"]},
              ButtonStyle->"Button"]},
          {
            ButtonBox[\(2\ Column\ Table\),
              ButtonFunction:>CompoundExpression[ 
                  CheckDocStyleMatch[ ], 
                  CellWriteStyle[ {{
                    Cell[ 
                      TextData[ {
                        Cell[ 
                          TextData[ {"Table ", 
                            CounterBox[ "TableTitle"], ". "}], 
                          "TableTitleLabel", TaggingRules :> {"CellLabel" -> 
                          True}], "The title for your table..."}], 
                      "TableTitle"]}, 1, "AC", 
                    CompoundExpression[ 
                      TableApply[ 2, 4], 
                      SelectTableTitle[ ]]}, SerialCursorPosition -> 1]],
              ButtonEvaluator->Automatic,
              ButtonStyle->"Button"]},
          {
            ButtonBox[\(3\ Column\ Table\),
              ButtonFunction:>CompoundExpression[ 
                  CheckDocStyleMatch[ ], 
                  CellWriteStyle[ {{
                    Cell[ 
                      TextData[ {
                        Cell[ 
                          TextData[ {"Table ", 
                            CounterBox[ "TableTitle"], ". "}], 
                          "TableTitleLabel", TaggingRules :> {"CellLabel" -> 
                          True}], "The title for your table..."}], 
                      "TableTitle"]}, 1, "AC", 
                    CompoundExpression[ 
                      TableApply[ 3, 4], 
                      SelectTableTitle[ ]]}, SerialCursorPosition -> 1]],
              ButtonEvaluator->Automatic,
              ButtonStyle->"Button"]},
          {
            ButtonBox[\(4\ Column\ Table\),
              ButtonFunction:>CompoundExpression[ 
                  CheckDocStyleMatch[ ], 
                  CellWriteStyle[ {{
                    Cell[ 
                      TextData[ {
                        Cell[ 
                          TextData[ {"Table ", 
                            CounterBox[ "TableTitle"], ". "}], 
                          "TableTitleLabel", TaggingRules :> {"CellLabel" -> 
                          True}], "The title for your table..."}], 
                      "TableTitle"]}, 1, "AC", 
                    CompoundExpression[ 
                      TableApply[ 4, 4], 
                      SelectTableTitle[ ]]}, SerialCursorPosition -> 1]],
              ButtonEvaluator->Automatic,
              ButtonStyle->"Button"]},
          {
            ButtonBox[\(5\ Column\ Table\),
              ButtonFunction:>CompoundExpression[ 
                  CheckDocStyleMatch[ ], 
                  CellWriteStyle[ {{
                    Cell[ 
                      TextData[ {
                        Cell[ 
                          TextData[ {"Table ", 
                            CounterBox[ "TableTitle"], ". "}], 
                          "TableTitleLabel", TaggingRules :> {"CellLabel" -> 
                          True}], "The title for your table..."}], 
                      "TableTitle"]}, 1, "AC", 
                    CompoundExpression[ 
                      TableApply[ 5, 4], 
                      SelectTableTitle[ ]]}, SerialCursorPosition -> 1]],
              ButtonEvaluator->Automatic,
              ButtonStyle->"Button"]},
          {
            ButtonBox[\(Insert\ Table\ Note\),
              ButtonFunction:>CompoundExpression[ 
                  CheckDocStyleMatch[ ], 
                  NewTableNote[ ]],
              ButtonStyle->"ThinButton"]}
          },
        RowSpacings->0,
        ColumnSpacings->0,
        RowLines->{False, 2, False, False, False, 2}], 
      TraditionalForm]], "ButtonCell",
  CellTags->"Tables"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[" ",
              ButtonFunction:>GeneratePalette[ "TearOff", "TableSettings"],
              ButtonEvaluator->Automatic,
              ButtonNote->"Tear-off Button Group"], 
            ButtonBox[GridBox[{
                  {" ", "Adjustments", 
                    StyleBox[
                      AdjustmentBox["\[DownPointer]",
                        BoxMargins->{{0, 0}, {-0.25, 0.25}},
                        BoxBaselineShift->0.25],
                      "Pointer"]}
                  },
                ColumnWidths->{0.02, 0.71, 0.1}],
              ButtonNote->"Adjustments"]}
          },
        ColumnWidths->{0.07, 0.93}], TraditionalForm]], "SubGroupButton"],

Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox[\(Col\ Align\),
              FontColor->GrayLevel[1]],
            ButtonFunction:>Null,
            ButtonStyle->"ThinDarkButton",
            ButtonNote->"Column Text Alignment"], 
          ButtonBox["L",
            ButtonFunction:>SmartTextAlignment[ "Left"],
            ButtonEvaluator->Automatic,
            ButtonNote->"Left"], 
          ButtonBox[
            StyleBox["C",
              FontFamily->"Helvetica",
              FontSize->10],
            ButtonFunction:>SmartTextAlignment[ "Center"],
            ButtonEvaluator->Automatic,
            ButtonNote->"Center"], 
          ButtonBox[
            StyleBox["R",
              FontFamily->"Helvetica",
              FontSize->10],
            ButtonFunction:>SmartTextAlignment[ "Right"],
            ButtonEvaluator->Automatic,
            ButtonNote->"Right"], 
          ButtonBox[
            StyleBox["D",
              FontFamily->"Helvetica",
              FontSize->10],
            ButtonFunction:>SmartTextAlignment[ "Inherited"],
            ButtonEvaluator->Automatic,
            ButtonNote->"Default"]}
        }]], "ThinButton",
  FontFamily->"Helvetica",
  FontSize->10,
  GridBoxOptions->{ColumnWidths->{0.42, 0.14}},
  CellTags->"TableSettings"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[\(Add\ Row\),
              ButtonFunction:>ColumnOrRowApply[ "Row"],
              ButtonStyle->"ThinButton"]},
          {
            ButtonBox[\(Add\ Column\),
              ButtonFunction:>ColumnOrRowApply[ "Column"],
              ButtonStyle->"ThinButton"]},
          {
            ButtonBox[\(Add\ Line\),
              ButtonFunction:>TableLineInsert[ ],
              ButtonStyle->"ThinButton"]},
          {
            ButtonBox[\(Column\ Head\),
              ButtonFunction:>TableSelectionEdit[ 
                  InputNotebook[ ], "CellStyle" -> "TableColumnHead"],
              ButtonStyle->"ThinButton"]},
          {
            ButtonBox[\(Table\ Text\),
              ButtonFunction:>TableSelectionEdit[ 
                  InputNotebook[ ], "CellStyle" -> "TableText"],
              ButtonStyle->"ThinButton"]}
          },
        RowSpacings->0,
        ColumnSpacings->0,
        RowLines->{False, False, 2, False}], TraditionalForm]], "ButtonCell",
  CellTags->"TableSettings"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox["Span",
              ButtonFunction:>CompoundExpression[ 
                  CheckDocStyleMatch[ ], 
                  TableSelectionSpan[ "Across"]],
              ButtonStyle->"ThinButton",
              ButtonNote->"Span Sel Across Cols"], 
            ButtonBox["Unspan",
              ButtonFunction:>CompoundExpression[ 
                  CheckDocStyleMatch[ ], 
                  TableSelectionUnspan[ "Across"]],
              ButtonStyle->"ThinButton",
              ButtonNote->"Restore Sel to Cols"]}
          },
        RowSpacings->0,
        ColumnSpacings->0,
        RowLines->{False, 2, 2, False}], TraditionalForm]], "ButtonCell",
  GridBoxOptions->{ColumnWidths->0.49},
  CellTags->"TableSettings"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[" ",
              ButtonFunction:>GeneratePalette[ "TearOff", "Backmatter"],
              ButtonEvaluator->Automatic,
              ButtonNote->"Tear-off Button Group"], 
            ButtonBox[GridBox[{
                  {" ", "Backmatter", 
                    StyleBox[
                      AdjustmentBox["\[DownPointer]",
                        BoxMargins->{{0, 0}, {-0.25, 0.25}},
                        BoxBaselineShift->0.25],
                      "Pointer"]}
                  },
                ColumnWidths->{0.02, 0.71, 0.1}],
              ButtonNote->"Backmatter"]}
          },
        ColumnWidths->{0.07, 0.95}], TraditionalForm]], "GroupButton"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[\(Appendix\ Head\),
              ButtonData:>{"AppendixSection", {
                Cell[ "Appendix Head", "AppendixSection"]}, "S"}]}
          }], TraditionalForm]], "Button",
  CellTags->"Backmatter"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[\(Appendix\ Equation\),
              ButtonData:>{"AppendixEquation", {
                Cell[ 
                  BoxData[ 
                    FormBox[ "\[Placeholder]", TraditionalForm]], 
                  "AppendixEquation"]}, "S"}]}
          }], TraditionalForm]], "Button",
  CellTags->"Backmatter"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[" ",
              ButtonFunction:>GeneratePalette[ "TearOff", "Navigation"],
              ButtonEvaluator->Automatic,
              ButtonNote->"Tear-off Button Group"], 
            ButtonBox[GridBox[{
                  {" ", "Navigation", 
                    StyleBox[
                      AdjustmentBox["\[DownPointer]",
                        BoxMargins->{{0, 0}, {-0.25, 0.25}},
                        BoxBaselineShift->0.25],
                      "Pointer"]}
                  },
                ColumnWidths->{0.02, 0.71, 0.1}],
              ButtonNote->"Navigation"]}
          },
        ColumnWidths->{0.07, 0.95}], TraditionalForm]], "GroupButton"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[
              RowBox[{"\t", 
                StyleBox[
                  AdjustmentBox["\[UpPointer]",
                    BoxMargins->{{0, 0}, {-0.272727, 0.272727}},
                    BoxBaselineShift->0.272727],
                  "BigPointer"], "  ", \(\(Section\)\(\t\t\t\t\t\t\)\)}],
              ButtonData:>"Section",
              ButtonStyle->"SearchUp"]},
          {
            ButtonBox[
              RowBox[{"\t", 
                StyleBox[
                  AdjustmentBox["\[DownPointer]",
                    BoxMargins->{{0, 0}, {-0.272727, 0.272727}},
                    BoxBaselineShift->0.272727],
                  "BigPointer"], "  ", \(\(Section\)\(\t\t\t\t\t\t\)\)}],
              ButtonData:>"Section",
              ButtonStyle->"SearchDown"]},
          {
            ButtonBox[
              RowBox[{"\t", 
                StyleBox[
                  AdjustmentBox["\[UpPointer]",
                    BoxMargins->{{0, 0}, {-0.272727, 0.272727}},
                    BoxBaselineShift->0.272727],
                  "BigPointer"], "  ", \(\(Subsection\)\(\t\t\t\)\)}],
              ButtonData:>"Subsection",
              ButtonStyle->"SearchUp"]},
          {
            ButtonBox[
              RowBox[{"\t", 
                StyleBox[
                  AdjustmentBox["\[DownPointer]",
                    BoxMargins->{{0, 0}, {-0.272727, 0.272727}},
                    BoxBaselineShift->0.272727],
                  "BigPointer"], "  ", \(\(Subsection\)\(\t\t\t\)\)}],
              ButtonData:>"Subsection",
              ButtonStyle->"SearchDown"]},
          {
            ButtonBox[
              RowBox[{"\t", 
                StyleBox[
                  AdjustmentBox["\[UpPointer]",
                    BoxMargins->{{0, 0}, {-0.272727, 0.272727}},
                    BoxBaselineShift->0.272727],
                  "BigPointer"], "  ", "Subsubsection"}],
              ButtonData:>"Subsubsection",
              ButtonStyle->"SearchUp"]},
          {
            ButtonBox[
              RowBox[{"\t", 
                StyleBox[
                  AdjustmentBox["\[DownPointer]",
                    BoxMargins->{{0, 0}, {-0.272727, 0.272727}},
                    BoxBaselineShift->0.272727],
                  "BigPointer"], "  ", "Subsubsection"}],
              ButtonData:>"Subsubsection",
              ButtonStyle->"SearchDown"]},
          {
            ButtonBox[\(Go\ Back\),
              ButtonFunction:>FrontEndExecute[ {
                  FrontEnd`FrontEndToken[ "HyperlinkGoBack"]}],
              ButtonStyle->"DarkButton",
              ButtonNote->"Hyperlink Go Back"]}
          },
        ColumnAlignments->{Left},
        RowLines->{False, 2, False, 2, False, 2, False}], 
      TraditionalForm]], "ButtonCell",
  ButtonBoxOptions->{ButtonMargins->5},
  CellTags->"Navigation"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[" ",
              ButtonFunction:>GeneratePalette[ "TearOff", "Slideshow"],
              ButtonEvaluator->Automatic,
              ButtonNote->"Tear-off Button Group"], 
            ButtonBox[GridBox[{
                  {" ", \(Slide\ Show\), 
                    StyleBox[
                      AdjustmentBox["\[DownPointer]",
                        BoxMargins->{{0, 0}, {-0.25, 0.25}},
                        BoxBaselineShift->0.25],
                      "Pointer"]}
                  },
                ColumnWidths->{0.02, 0.71, 0.1}],
              ButtonNote->"Slide Show"]}
          },
        ColumnWidths->{0.07, 0.93}], TraditionalForm]], "SubGroupButton"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[\(New\ Slide\),
              ButtonData:>{"SlideShowNavigationBar", {
                Cell[ 
                  TextData[ 
                    Cell[ 
                      BoxData[ 
                        GridBox[ {{
                          ButtonBox[ 
                            StyleBox[ "\[FirstPage]", "SR"], ButtonFunction :> 
                            FrontEndExecute[ {
                              FrontEndToken[ 
                                FrontEnd`SelectedNotebook[ ], 
                                "ScrollPageFirst"]}], ButtonStyle -> 
                            "SlideHyperlink", ButtonNote -> "First Slide"], 
                          ButtonBox[ 
                            StyleBox[ "\[LeftPointer]", "SR"], ButtonFunction :> 
                            FrontEndExecute[ {
                              FrontEndToken[ 
                                FrontEnd`SelectedNotebook[ ], 
                                "ScrollPagePrevious"]}], ButtonStyle -> 
                            "SlideHyperlink", ButtonNote -> "Previous Slide"],
                           
                          ButtonBox[ 
                            StyleBox[ "\[RightPointer]", "SR"], 
                            ButtonFunction :> FrontEndExecute[ {
                              FrontEndToken[ 
                                FrontEnd`SelectedNotebook[ ], 
                                "ScrollPageNext"]}], ButtonStyle -> 
                            "SlideHyperlink", ButtonNote -> "Next Slide"], 
                          ButtonBox[ 
                            StyleBox[ "\[LastPage]", "SR"], ButtonFunction :> 
                            FrontEndExecute[ {
                              FrontEndToken[ 
                                FrontEnd`SelectedNotebook[ ], 
                                "ScrollPageLast"]}], ButtonStyle -> 
                            "SlideHyperlink", ButtonNote -> "Last Slide"], 
                          " ", 
                          ButtonBox[ 
                            StyleBox[ 
                              RowBox[ {
                                CounterBox[ "SlideShowNavigationBar"], 
                                RowBox[ {" ", "of", " "}], 
                                CounterBox[ 
                                "SlideShowNavigationBar", "LastSlide"]}], 
                              "SR"], ButtonFrame -> "None"]}}]]]], 
                  "SlideShowNavigationBar"]}}]},
          {
            ButtonBox[\(Last\ Slide\),
              ButtonData:>{"SlideShowNavigationBar", {
                Cell[ 
                  TextData[ 
                    Cell[ 
                      BoxData[ 
                        GridBox[ {{
                          ButtonBox[ 
                            StyleBox[ "\[FirstPage]", "SR"], ButtonFunction :> 
                            FrontEndExecute[ {
                              FrontEndToken[ 
                                FrontEnd`SelectedNotebook[ ], 
                                "ScrollPageFirst"]}], ButtonStyle -> 
                            "SlideHyperlink", ButtonNote -> "First Slide"], 
                          ButtonBox[ 
                            StyleBox[ "\[LeftPointer]", "SR"], ButtonFunction :> 
                            FrontEndExecute[ {
                              FrontEndToken[ 
                                FrontEnd`SelectedNotebook[ ], 
                                "ScrollPagePrevious"]}], ButtonStyle -> 
                            "SlideHyperlink", ButtonNote -> "Previous Slide"],
                           
                          ButtonBox[ 
                            StyleBox[ "\[RightPointer]", "SR"], 
                            ButtonFunction :> FrontEndExecute[ {
                              FrontEndToken[ 
                                FrontEnd`SelectedNotebook[ ], 
                                "ScrollPageNext"]}], ButtonStyle -> 
                            "SlideHyperlink", ButtonNote -> "Next Slide"], 
                          ButtonBox[ 
                            StyleBox[ "\[LastPage]", "SR"], ButtonFunction :> 
                            FrontEndExecute[ {
                              FrontEndToken[ 
                                FrontEnd`SelectedNotebook[ ], 
                                "ScrollPageLast"]}], ButtonStyle -> 
                            "SlideHyperlink", ButtonNote -> "Last Slide"], 
                          " ", 
                          ButtonBox[ 
                            StyleBox[ 
                              RowBox[ {
                                CounterBox[ "SlideShowNavigationBar"], 
                                RowBox[ {" ", "of", " "}], 
                                CounterBox[ 
                                "SlideShowNavigationBar", "LastSlide"]}], 
                              "SR"], ButtonFrame -> "None"]}}]]]], 
                  "SlideShowNavigationBar", CellTags -> "LastSlide"]}}]}
          },
        RowLines->{False, False, False, True, True, False, True}], 
      TraditionalForm]], "ThinButton",
  CellTags->"Slideshow"]
}, Closed]]
}, Closed]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            ButtonBox[
              StyleBox[\(MAKE\ \ \ DEFAULT\),
                FontSize->9],
              ButtonNote->"Set as Default Palette"]}
          }], TraditionalForm]], "MakeDefaultButton"],

Cell[TextData[ButtonBox["\[UpPointer]\n\[DownPointer]",
  ButtonNote->"Toggle Scrollbar"]], "ScrollBar"],

Cell[BoxData[
    FormBox[
      StyleBox[
        ButtonBox[\(\(\ \ \ \ \ \ \ \ \ \ \ \ \)\(\(Make\)\(\ \)\(Palette\)\(\
\ \ \ \ \ \ \ \ \ \ \)\)\)],
        Selectable->True], TraditionalForm]], "GeneratePalette"]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{641, 651},
WindowMargins->{{1, Automatic}, {Automatic, 0}},
WindowTitle->"Elsevier",
ShowCellBracket->True,
TaggingRules:>{"AllowShowExpression" -> True},
Background->RGBColor[0.6, 0.700008, 0.8],
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Elsevier.nb Document Palette Styles", "Title"],
  
  Cell[CellGroupData[{
  
  Cell["Style Buttons", "Section"],
  
  Cell[StyleData["TopGroupButton"],
    Selectable->True,
    PageWidth->127,
    CellMargins->{{0, 0}, {-1, 5}},
    CellGroupingRules->{"SectionGrouping", 10},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    ButtonBoxOptions->{ButtonFunction:>CompoundExpression[ 
        SelectionMove[ 
          ButtonNotebook[ ], All, ButtonCell], 
        FrontEndExecute[ 
          FrontEndToken[ 
            ButtonNotebook[ ], "OpenCloseGroup"]]],
    ButtonEvaluator->None,
    ButtonMargins->1,
    Background->RGBColor[0.6, 0.6, 0.700008]},
    GridBoxOptions->{ColumnSpacings->0,
    ColumnWidths->{0.14, 0.72, 0.13},
    ColumnAlignments->{Right, Center, Left},
    RowMinHeight->1.2}],
  
  Cell[StyleData["GroupButton"],
    Selectable->True,
    PageWidth->127,
    CellMargins->{{0, 0}, {-1, 2}},
    CellElementSpacings->{"ClosedGroupTopMargin"->2},
    CellGroupingRules->{"SectionGrouping", 10},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    ButtonBoxOptions->{ButtonFunction:>CompoundExpression[ 
        SelectionMove[ 
          ButtonNotebook[ ], All, ButtonCell], 
        FrontEndToken[ 
          ButtonNotebook[ ], "OpenCloseGroup"]],
    ButtonEvaluator->None,
    ButtonMargins->1,
    Background->RGBColor[0.6, 0.6, 0.700008]},
    GridBoxOptions->{ColumnSpacings->0,
    ColumnWidths->{0.14, 0.72, 0.13},
    ColumnAlignments->{Left, Center, Left},
    RowMinHeight->1.2}],
  
  Cell[StyleData["SubGroupButton"],
    Selectable->True,
    PageWidth->129,
    CellMargins->{{0, 0}, {-1, 2}},
    CellElementSpacings->{"ClosedGroupTopMargin"->0},
    CellGroupingRules->{"SectionGrouping", 20},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    ButtonBoxOptions->{ButtonFunction:>CompoundExpression[ 
        SelectionMove[ 
          ButtonNotebook[ ], All, ButtonCell], 
        FrontEndToken[ 
          ButtonNotebook[ ], "OpenCloseGroup"]],
    ButtonEvaluator->None,
    ButtonMargins->1,
    Background->RGBColor[0.500008, 0.6, 0.700008]},
    GridBoxOptions->{ColumnSpacings->0,
    ColumnWidths->{0.13, 0.72, 0.12},
    ColumnAlignments->{Right, Center, Left},
    RowMinHeight->1.2}],
  
  Cell[StyleData["Button"],
    Selectable->True,
    PageWidth->131,
    CellMargins->{{0, 0}, {0, 0}},
    TabSpacings->0.65,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontColor->GrayLevel[0],
    ButtonBoxOptions->{ButtonFunction:>(CompoundExpression[ 
        CheckDocStyleMatch[ ], 
        CellWriteStyle[ #]]&),
    ButtonEvaluator->Automatic,
    ButtonMargins->6,
    Background->RGBColor[0.6, 0.700008, 0.8]},
    GridBoxOptions->{RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->0.99}],
  
  Cell[StyleData["ButtonCell"],
    Selectable->True,
    PageWidth->131,
    CellMargins->{{0, 0}, {0, 0}},
    TabSpacings->0.65,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontColor->RGBColor[0.549996, 0.650004, 0.749996],
    ButtonBoxOptions->{ButtonFunction:>(CompoundExpression[ 
        CheckDocStyleMatch[ ], 
        CellWriteStyle[ #]]&),
    ButtonEvaluator->Automatic,
    ButtonMargins->6,
    Background->RGBColor[0.6, 0.700008, 0.8]},
    GridBoxOptions->{RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->0.99}],
  
  Cell[StyleData["DarkButtonCell"],
    Selectable->True,
    PageWidth->131,
    CellMargins->{{0, 0}, {0, 0}},
    TabSpacings->0.65,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontColor->RGBColor[0.6, 0.700008, 0.8],
    ButtonBoxOptions->{ButtonFunction:>(CompoundExpression[ 
        CheckDocStyleMatch[ ], 
        CellWriteStyle[ #]]&),
    ButtonEvaluator->Automatic,
    ButtonMargins->6,
    Background->RGBColor[0.6, 0.700008, 0.8]},
    GridBoxOptions->{RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->0.99}],
  
  Cell[StyleData["ButtonFind"],
    Selectable->True,
    PageWidth->131,
    CellMargins->{{0, 0}, {0, 0}},
    TabSpacings->0.65,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontColor->GrayLevel[0],
    ButtonBoxOptions->{ButtonFunction:>(CompoundExpression[ 
        CheckDocStyleMatch[ ], 
        CellWriteStyle[ #, FindCellStyle -> True]]&),
    ButtonEvaluator->Automatic,
    ButtonMargins->6,
    Background->RGBColor[0.6, 0.700008, 0.8]},
    GridBoxOptions->{RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->0.99}],
  
  Cell[StyleData["MediumButton"],
    Selectable->True,
    PageWidth->131,
    CellMargins->{{0, 0}, {0, 0}},
    TabSpacings->0.65,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontColor->GrayLevel[0],
    ButtonBoxOptions->{ButtonFunction:>(CompoundExpression[ 
        CheckDocStyleMatch[ ], 
        CellWriteStyle[ #]]&),
    ButtonEvaluator->Automatic,
    ButtonMargins->5,
    Background->RGBColor[0.6, 0.700008, 0.8]},
    GridBoxOptions->{RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->0.99}],
  
  Cell[StyleData["ThinButton"],
    Selectable->True,
    PageWidth->131,
    CellMargins->{{0, 0}, {0, 0}},
    TabSpacings->0.65,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontColor->GrayLevel[0],
    ButtonBoxOptions->{ButtonFunction:>(CompoundExpression[ 
        CheckDocStyleMatch[ ], 
        CellWriteStyle[ #]]&),
    ButtonEvaluator->Automatic,
    ButtonMargins->3,
    Background->RGBColor[0.6, 0.700008, 0.8]},
    GridBoxOptions->{RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->0.99}],
  
  Cell[StyleData["DarkButton"],
    Selectable->True,
    PageWidth->131,
    CellMargins->{{0, 0}, {0, 0}},
    TabSpacings->0.65,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontColor->RGBColor[0.8, 0.900008, 1],
    ButtonBoxOptions->{ButtonFunction:>(CompoundExpression[ 
        CheckDocStyleMatch[ ], 
        CellWriteStyle[ #]]&),
    ButtonEvaluator->Automatic,
    ButtonMargins->6,
    Background->RGBColor[0.500008, 0.6, 0.700008]},
    GridBoxOptions->{RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->0.99}],
  
  Cell[StyleData["MakeDefaultButton"],
    Selectable->True,
    PageWidth->131,
    CellMargins->{{0, 0}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->3},
    CellGroupingRules->{"SectionGrouping", 10},
    TabSpacings->0.65,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontColor->RGBColor[0.8, 0.900008, 1],
    ButtonBoxOptions->{ButtonFunction:>SetDefaultPalette[ ],
    ButtonEvaluator->Automatic,
    ButtonMargins->1,
    Background->RGBColor[0.500008, 0.6, 0.700008]},
    GridBoxOptions->{RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->0.99}],
  
  Cell[StyleData["ThinDarkButton"],
    Selectable->True,
    PageWidth->131,
    CellMargins->{{0, 0}, {0, 0}},
    TabSpacings->0.65,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontColor->RGBColor[0.8, 0.900008, 1],
    ButtonBoxOptions->{ButtonFunction:>(CompoundExpression[ 
        CheckDocStyleMatch[ ], 
        CellWriteStyle[ #]]&),
    ButtonEvaluator->Automatic,
    ButtonMargins->2,
    Background->RGBColor[0.500008, 0.6, 0.700008]},
    GridBoxOptions->{RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->0.99}],
  
  Cell[StyleData["SmallButton"],
    Selectable->True,
    PageWidth->131,
    CellMargins->{{0, 0}, {0, 0}},
    TabSpacings->0.65,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[0],
    ButtonBoxOptions->{ButtonEvaluator->Automatic,
    ButtonMargins->2,
    Background->RGBColor[0.6, 0.700008, 0.8]},
    GridBoxOptions->{ColumnWidths->0.99}],
  
  Cell[StyleData["HalfButton2"],
    Selectable->True,
    PageWidth->129,
    CellMargins->{{0, 0}, {0, 0}},
    TabSpacings->0.65,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0.8, 0.900008, 1],
    ButtonBoxOptions->{ButtonFunction:>(CompoundExpression[ 
        CheckDocStyleMatch[ ], 
        CellWriteStyle[ #]]&),
    ButtonEvaluator->Automatic,
    ButtonMargins->3,
    Background->RGBColor[0.500008, 0.600015, 0.700008]},
    GridBoxOptions->{RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->0.5}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Utility Buttons", "Section"],
  
  Cell[StyleData["NewDocButton"],
    Selectable->True,
    PageWidth->131,
    CellMargins->{{0, 0}, {-1, -2}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Arial",
    FontWeight->"Bold",
    FontColor->GrayLevel[0.900008],
    ButtonBoxOptions->{ButtonFunction:>(GenerateDocument[ #]&),
    ButtonEvaluator->Automatic,
    ButtonMinHeight->2,
    ButtonMargins->0,
    Background->RGBColor[0.4, 0.4, 0.6]},
    GridBoxOptions->{ColumnWidths->0.99}],
  
  Cell[StyleData["NavButtonRow"],
    Selectable->True,
    PageWidth->125,
    CellMargins->{{0, 0}, {0, 0}},
    TextAlignment->Left,
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[0.700008],
    ButtonBoxOptions->{ButtonMargins->1,
    Background->RGBColor[0.100008, 0.2, 0.500008]},
    GridBoxOptions->{ColumnSpacings->0,
    ColumnWidths->{0.15, 0.15, 0.16, 0.13, 0.13, 0.16, 0.13}}],
  
  Cell[StyleData["Pointer"],
    Selectable->True,
    StyleMenuListing->None,
    FontSize->18],
  
  Cell[StyleData["BigPointer"],
    Selectable->True,
    StyleMenuListing->None,
    FontSize->24],
  
  Cell[StyleData["FullLeft"],
    Selectable->True,
    StyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>PalettePosition[ "FullLeft"],
    ButtonEvaluator->Automatic,
    Active->True,
    ButtonNote->"Move Full Left"}],
  
  Cell[StyleData["InLeft"],
    Selectable->True,
    StyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>(PalettePosition[ "InLeft"][ #2]&),
    ButtonEvaluator->Automatic,
    ButtonData:>{"Darwin" -> {165, 130}, "Other" -> {172, 138}},
    Active->True,
    ButtonNote->"Move Near Left"}],
  
  Cell[StyleData["InRight"],
    Selectable->True,
    StyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>(PalettePosition[ "InRight"][ #2]&),
    ButtonEvaluator->Automatic,
    ButtonData:>{"Darwin" -> {165, 130}, "Other" -> {172, 138}},
    Active->True,
    ButtonNote->"Move Near Right"}],
  
  Cell[StyleData["FullRight"],
    Selectable->True,
    StyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>PalettePosition[ "FullRight"],
    ButtonEvaluator->Automatic,
    Active->True,
    ButtonNote->"Move Full Right"}],
  
  Cell[StyleData["DialogHelp"],
    Selectable->True,
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "UserGuide", #]}]&),
    ButtonNote->"Help"}],
  
  Cell[StyleData["SampleDoc"],
    Selectable->True,
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>(OpenSampleDocument[ #]&),
    ButtonEvaluator->Automatic,
    ButtonNote->"Sample Document"}],
  
  Cell[StyleData["Iconify"],
    Selectable->True,
    StyleMenuListing->None,
    ButtonBoxOptions->{ButtonFunction:>(IconifyNotebook[ #]&),
    ButtonEvaluator->Automatic,
    ButtonNote->"Iconify"}],
  
  Cell[StyleData["SearchUp"],
    Selectable->True,
    StyleMenuListing->None,
    FontColor->GrayLevel[0],
    ButtonBoxOptions->{ButtonFunction:>(NotebookFind[ 
        SelectedNotebook[ ], #, Previous, CellStyle]&),
    ButtonEvaluator->None}],
  
  Cell[StyleData["SearchDown"],
    Selectable->True,
    StyleMenuListing->None,
    FontColor->GrayLevel[0],
    ButtonBoxOptions->{ButtonFunction:>(NotebookFind[ 
        SelectedNotebook[ ], #, Next, CellStyle]&),
    ButtonEvaluator->None}],
  
  Cell[StyleData["GeneratePalette"],
    Selectable->False,
    CellMargins->{{0, Inherited}, {Inherited, 20}},
    CellElementSpacings->{"ClosedGroupTopMargin"->20},
    CellGroupingRules->{"SectionGrouping", 10},
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    ButtonBoxOptions->{ButtonFunction:>GeneratePalette[ "DocumentPalette"],
    ButtonEvaluator->Automatic,
    Active->True}],
  
  Cell[StyleData["ScrollBar"],
    Selectable->True,
    ShowSelection->False,
    CellMargins->{{57, Inherited}, {Inherited, 24}},
    CellGroupingRules->{"SectionGrouping", 10},
    AutoIndent->False,
    LineSpacing->{0.4, 0},
    StyleMenuListing->None,
    FontSize->30,
    FontColor->RGBColor[0.549996, 0.650004, 0.749996],
    ButtonBoxOptions->{ButtonFunction:>ToggleScrollBar[ 
        ButtonNotebook[ ]],
    ButtonEvaluator->Automatic}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formatting", "Section"],
  
  Cell[StyleData["ColorTextDark"],
    Selectable->True,
    StyleMenuListing->None,
    FontColor->RGBColor[0.2, 0.300008, 0.4]],
  
  Cell[StyleData["ColorTextLight"],
    Selectable->True,
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0.500008, 0.6]],
  
  Cell[StyleData["ReverseText"],
    Selectable->True,
    StyleMenuListing->None,
    FontColor->GrayLevel[1]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Frontmatter"->{
    Cell[6807, 166, 737, 22, 70, "ButtonFind",
      CellTags->"Frontmatter"]},
  "Dates"->{
    Cell[8311, 212, 1702, 43, 70, "ButtonCell",
      CellTags->"Dates"]},
  "MainElements"->{
    Cell[10813, 281, 278, 9, 70, "Button",
      CellTags->"MainElements"],
    Cell[11094, 292, 864, 24, 70, "Button",
      CellTags->"MainElements"],
    Cell[11961, 318, 1298, 31, 70, "Button",
      CellTags->"MainElements"]},
  "Lists"->{
    Cell[14012, 373, 1455, 39, 70, "ThinButton",
      CellTags->"Lists"],
    Cell[15470, 414, 430, 10, 70, "ThinButton",
      CellTags->"Lists"]},
  "Equations"->{
    Cell[16686, 450, 780, 20, 70, "Button",
      CellTags->"Equations"],
    Cell[17491, 474, 2573, 55, 70, "Button",
      CellGroupingRules->{"SectionGrouping", 20},
      CellTags->"Equations"],
    Cell[20067, 531, 1853, 46, 70, "HalfButton2",
      CellTags->"Equations"],
    Cell[21935, 580, 1282, 31, 70, "Button",
      CellGroupingRules->{"SectionGrouping", 20},
      CellTags->"Equations"]},
  "XRefs"->{
    Cell[24068, 638, 707, 19, 70, "ButtonCell",
      CellTags->"XRefs"]},
  "References"->{
    Cell[25552, 682, 571, 16, 70, "ButtonCell",
      CellTags->"References"],
    Cell[26126, 700, 518, 14, 70, "DarkButtonCell",
      CellTags->"References"]},
  "Tables"->{
    Cell[27409, 739, 4867, 113, 70, "ButtonCell",
      CellTags->"Tables"]},
  "TableSettings"->{
    Cell[33049, 876, 1312, 37, 70, "ThinButton",
      CellTags->"TableSettings"],
    Cell[34364, 915, 1074, 28, 70, "ButtonCell",
      CellTags->"TableSettings"],
    Cell[35441, 945, 788, 20, 70, "ButtonCell",
      CellTags->"TableSettings"]},
  "Backmatter"->{
    Cell[37018, 991, 273, 7, 70, "Button",
      CellTags->"Backmatter"],
    Cell[37294, 1000, 376, 10, 70, "Button",
      CellTags->"Backmatter"]},
  "Navigation"->{
    Cell[38447, 1035, 2912, 73, 70, "ButtonCell",
      CellTags->"Navigation"]},
  "Slideshow"->{
    Cell[42129, 1132, 5179, 99, 70, "ThinButton",
      CellTags->"Slideshow"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Frontmatter", 62240, 1718},
  {"Dates", 62333, 1721},
  {"MainElements", 62428, 1724},
  {"Lists", 62673, 1731},
  {"Equations", 62840, 1736},
  {"XRefs", 63258, 1747},
  {"References", 63351, 1750},
  {"Tables", 63528, 1755},
  {"TableSettings", 63627, 1758},
  {"Backmatter", 63894, 1765},
  {"Navigation", 64063, 1770},
  {"Slideshow", 64162, 1773}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1753, 51, 1775, 40, 18, "NavButtonRow"],
Cell[3531, 93, 2505, 49, 70, "NewDocButton"],

Cell[CellGroupData[{
Cell[6061, 146, 743, 18, 70, "TopGroupButton"],
Cell[6807, 166, 737, 22, 70, "ButtonFind",
  CellTags->"Frontmatter"],

Cell[CellGroupData[{
Cell[7569, 192, 739, 18, 70, "SubGroupButton"],
Cell[8311, 212, 1702, 43, 70, "ButtonCell",
  CellTags->"Dates"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10062, 261, 748, 18, 70, "GroupButton"],
Cell[10813, 281, 278, 9, 70, "Button",
  CellTags->"MainElements"],
Cell[11094, 292, 864, 24, 70, "Button",
  CellTags->"MainElements"],
Cell[11961, 318, 1298, 31, 70, "Button",
  CellTags->"MainElements"],

Cell[CellGroupData[{
Cell[13284, 353, 725, 18, 70, "SubGroupButton"],
Cell[14012, 373, 1455, 39, 70, "ThinButton",
  CellTags->"Lists"],
Cell[15470, 414, 430, 10, 70, "ThinButton",
  CellTags->"Lists"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15949, 430, 734, 18, 70, "GroupButton"],
Cell[16686, 450, 780, 20, 70, "Button",
  CellTags->"Equations"],

Cell[CellGroupData[{
Cell[17491, 474, 2573, 55, 70, "Button",
  CellGroupingRules->{"SectionGrouping", 20},
  CellTags->"Equations"],
Cell[20067, 531, 1853, 46, 70, "HalfButton2",
  CellTags->"Equations"]
}, Closed]],
Cell[21935, 580, 1282, 31, 70, "Button",
  CellGroupingRules->{"SectionGrouping", 20},
  CellTags->"Equations"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23254, 616, 811, 20, 70, "GroupButton"],
Cell[24068, 638, 707, 19, 70, "ButtonCell",
  CellTags->"XRefs"]
}, Closed]],

Cell[CellGroupData[{
Cell[24812, 662, 737, 18, 70, "GroupButton"],
Cell[25552, 682, 571, 16, 70, "ButtonCell",
  CellTags->"References"],
Cell[26126, 700, 518, 14, 70, "DarkButtonCell",
  CellTags->"References"]
}, Closed]],

Cell[CellGroupData[{
Cell[26681, 719, 725, 18, 70, "GroupButton"],
Cell[27409, 739, 4867, 113, 70, "ButtonCell",
  CellTags->"Tables"],

Cell[CellGroupData[{
Cell[32301, 856, 745, 18, 70, "SubGroupButton"],
Cell[33049, 876, 1312, 37, 70, "ThinButton",
  CellTags->"TableSettings"],
Cell[34364, 915, 1074, 28, 70, "ButtonCell",
  CellTags->"TableSettings"],
Cell[35441, 945, 788, 20, 70, "ButtonCell",
  CellTags->"TableSettings"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[36278, 971, 737, 18, 70, "GroupButton"],
Cell[37018, 991, 273, 7, 70, "Button",
  CellTags->"Backmatter"],
Cell[37294, 1000, 376, 10, 70, "Button",
  CellTags->"Backmatter"]
}, Closed]],

Cell[CellGroupData[{
Cell[37707, 1015, 737, 18, 70, "GroupButton"],
Cell[38447, 1035, 2912, 73, 70, "ButtonCell",
  CellTags->"Navigation"],

Cell[CellGroupData[{
Cell[41384, 1112, 742, 18, 70, "SubGroupButton"],
Cell[42129, 1132, 5179, 99, 70, "ThinButton",
  CellTags->"Slideshow"]
}, Closed]]
}, Closed]],
Cell[47335, 1235, 253, 7, 70, "MakeDefaultButton"],
Cell[47591, 1244, 104, 1, 70, "ScrollBar"],
Cell[47698, 1247, 215, 5, 70, "GeneratePalette"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

